/****************************************************************************
 *
 *  Hameg HMO Digital Oscilloscope instrument driver include file
 *
 ****************************************************************************/

#ifndef __HMO_HEADER
#define __HMO_HEADER

#include "rsidr_core.h"
#include "hmo_attributes.h"
#include "hmo_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/
#define HMO_SIMULATION_ID_QUERY      "HAMEG,HMO,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define HMO_VALID_ID_RESPONSE_STRING "HAMEG"      /* Valid response for identification query */
#define HMO_ALTERNATIVE_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define HMO_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define HMO_IO_BUFFER_SIZE           1024L   /* I/O buffer size */
#define HMO_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */
#define IEEE_488_2_ERROR_MASK             0x3C    /* 488.2 STB Bits */   
#define IEEE_488_2_ESE_MASK               0x3D    /* 488.2 Event Status Register (ESE) Bits */
#define HMO_NAN                 9.91e+37
#define HMO_NAN_VI_INT32        0x80000000

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define HMO_CLASS_DRIVER_DESCRIPTION           ""
#define HMO_CLASS_DRIVER_PREFIX                ""
#define HMO_CLASS_DRIVER_VENDOR                ""
#define HMO_CLASS_DRIVER_REVISION              ""
#define HMO_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define HMO_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define HMO_SPECIFIC_DRIVER_DESCRIPTION        ""
#define HMO_SPECIFIC_DRIVER_PREFIX             "HMO"
#define HMO_SPECIFIC_DRIVER_LOCATOR            ""
#define HMO_SPECIFIC_DRIVER_VENDOR             ""
#define HMO_MAJOR_VERSION                      5L    /* Instrument driver major version          */
#define HMO_MINOR_VERSION                      91L   /* Instrument driver minor version          */
#define HMO_MINOR_MINOR_VERSION                0L    /* Instrument driver minor minor version    */

/* Driver Capabilities */          

#define HMO_SUPPORTED_INSTRUMENT_MODELS        ""    /* Instrument driver supported model(s)     */
#define HMO_GROUP_CAPABILITIES                 ""
#define HMO_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define HMO_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define HMO_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define HMO_ERROR_MARKER_NOT_ENABLED     (RS_CLASS_ERROR_BASE + 0x0003L)
#define HMO_ERROR_NOT_DELTA_MARKER       (RS_CLASS_ERROR_BASE + 0x0002L)
#define HMO_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define HMO_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define HMO_WARNMSG_OVER_RANGE           "Measurement overrange"

#define HMO_ERRMSG_MARKER_NOT_ENABLED    "Marker Not Enabled"
#define HMO_ERRMSG_NOT_DELTA_MARKER      "Not Delta Marker"
#define HMO_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define HMO_ERROR_CODES_AND_MSGS \
    {HMO_WARN_MEASURE_UNCALIBRATED,  HMO_WARNMSG_MEASURE_UNCALIBRATED},\
    {HMO_WARN_OVER_RANGE,            HMO_WARNMSG_OVER_RANGE},\
    {HMO_ERROR_MARKER_NOT_ENABLED,   HMO_ERRMSG_MARKER_NOT_ENABLED},\
    {HMO_ERROR_NOT_DELTA_MARKER,     HMO_ERRMSG_NOT_DELTA_MARKER},\
    {HMO_ERROR_MAX_TIME_EXCEEDED,    HMO_ERRMSG_MAX_TIME_EXCEEDED}


/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define HMO_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define HMO_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define HMO_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define HMO_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define HMO_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define HMO_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define HMO_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define HMO_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define HMO_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define HMO_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define HMO_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define HMO_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define HMO_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define HMO_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define HMO_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define HMO_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define HMO_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define HMO_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define HMO_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define HMO_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define HMO_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define HMO_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define HMO_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define HMO_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define HMO_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define HMO_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define HMO_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define HMO_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define HMO_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define HMO_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define HMO_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME

/* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

//#define HMO_ATTR_ID_QUERY_RESPONSE                                     (RS_SPECIFIC_PUBLIC_ATTR_BASE + 1L)                     /* ViString (Read Only)              */

/* BEGIN GENERATE */
#define HMO_ATTR_ACQUISITION_TYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1
#define HMO_ATTR_ACQUISITION_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 644
#define HMO_ATTR_ACQUISITION_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 645
#define HMO_ATTR_WAVEFORM_ACQUISITION_TYPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 769
#define HMO_ATTR_FILTER_FREQUENCY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 613
#define HMO_ATTR_INTERPOLATION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3
#define HMO_ATTR_NUM_AVERAGES                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define HMO_ATTR_AVERAGING_STATUS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 770
#define HMO_ATTR_SAMPLE_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define HMO_ATTR_WAVEFORM_RATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 469
#define HMO_ATTR_HORZ_TIME_PER_RECORD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define HMO_ATTR_HORIZONTAL_RECORD_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 771
#define HMO_ATTR_HORZ_SCALE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define HMO_ATTR_ACQUSITION_START_TIME                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define HMO_ATTR_ACQUISITION_TIME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define HMO_ATTR_HORZ_ADC_SAMPLE_RATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define HMO_ATTR_HORZ_SAMPLE_RATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 610
#define HMO_ATTR_AUTOSCALE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define HMO_ATTR_HORZ_DIVISIONS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define HMO_ATTR_HORZ_REFERENCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define HMO_ATTR_PEAK_DETECTION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 772
#define HMO_ATTR_HIGH_RESOLUTION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 773
#define HMO_ATTR_ROLL_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 774
#define HMO_ATTR_SEGMENTATION_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 775
#define HMO_ATTR_SEGMENTATION_MAXIMUM_ACQUISITION_COUNT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 776
#define HMO_ATTR_PROBE_TYPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 777
#define HMO_ATTR_PROBE_ATTENUATION_UNIT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 778
#define HMO_ATTR_PROBE_MANUAL_ATTENUATION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 779
#define HMO_ATTR_PROBE_ATTENUATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 780
#define HMO_ATTR_CHANNEL_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define HMO_ATTR_VERTICAL_RANGE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define HMO_ATTR_VERTICAL_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define HMO_ATTR_VERTICAL_COUPLING                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define HMO_ATTR_VERTICAL_SCALE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define HMO_ATTR_CHANNEL_OFFSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define HMO_ATTR_CHANNEL_BANDWIDTH_LIMIT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define HMO_ATTR_CHANNEL_POLARITY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 615
#define HMO_ATTR_CHANNEL_OVERLOAD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 32
#define HMO_ATTR_CHANNEL_SKEW                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 33
#define HMO_ATTR_CHANNEL_THRESHOLD                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 34
#define HMO_ATTR_CHANNEL_THRESHOLD_FIND_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 781
#define HMO_ATTR_CHANNEL_THRESHOLD_HYSTERESIS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 782
#define HMO_ATTR_CHANNEL_LABEL_STATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 646
#define HMO_ATTR_CHANNEL_LABEL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 647
#define HMO_ATTR_TRIGGER_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define HMO_ATTR_TRIGGER_SOURCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define HMO_ATTR_EXTERNAL_TRIGGER_COUPLING                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 616
#define HMO_ATTR_TRIGGER_LEVEL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define HMO_ATTR_TRIGGER_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 482
#define HMO_ATTR_TRIGGER_MODIFIER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define HMO_ATTR_TRIGGER_EVENT_COUNT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 489
#define HMO_ATTR_TRIGGER_DELAY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 488
#define HMO_ATTR_TRIGGER_LEVEL_UPPER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 783
#define HMO_ATTR_TRIGGER_LEVEL_LOWER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 784
#define HMO_ATTR_TRIGGER_HOLDOFF_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 785
#define HMO_ATTR_TRIGGER_HOLDOFF_TIME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 786
#define HMO_ATTR_TRIGGER_SLOPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define HMO_ATTR_TRIGGER_COUPLING                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 490
#define HMO_ATTR_TRIGGER_FILTER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 491
#define HMO_ATTR_TV_TRIGGER_EVENT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 51
#define HMO_ATTR_TV_TRIGGER_LINE_NUMBER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 52
#define HMO_ATTR_TV_TRIGGER_POLARITY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define HMO_ATTR_TV_STANDARD                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 477
#define HMO_ATTR_WIDTH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 481
#define HMO_ATTR_WIDTH_DELTA                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 480
#define HMO_ATTR_WIDTH_POLARITY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 478
#define HMO_ATTR_WIDTH_CONDITION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 479
#define HMO_ATTR_TRIGGER_PATTERN_SOURCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 494
#define HMO_ATTR_TRIGGER_PATTERN_FUNCTION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 495
#define HMO_ATTR_TRIGGER_PATTERN_POINT_STATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 496
#define HMO_ATTR_TRIGGER_PATTERN_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 666
#define HMO_ATTR_TRIGGER_PATTERN_CONDITION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 667
#define HMO_ATTR_TRIGGER_PATTERN_WIDTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 668
#define HMO_ATTR_TRIGGER_PATTERN_DELTA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 669
#define HMO_ATTR_RUNT_TRIGGER_UPPER_LEVEL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 787
#define HMO_ATTR_RUNT_TRIGGER_LOWER_LEVEL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 788
#define HMO_ATTR_RUNT_TRIGGER_POLARITY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 789
#define HMO_ATTR_TRIGGER_TIME_POLARITY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 790
#define HMO_ATTR_TRIGGER_TIME_RANGE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 791
#define HMO_ATTR_TRIGGER_TIME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 792
#define HMO_ATTR_TRIGGER_TIME_DELTA                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 793
#define HMO_ATTR_TRIGGER_OUT_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 794
#define HMO_ATTR_TRIGGER_OUT_POLARITY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 795
#define HMO_ATTR_TRIGGER_OUT_PULSE_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 796
#define HMO_ATTR_WAVEFORM_SAMPLES                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 500
#define HMO_ATTR_WAVEFORM_SAMPLE_RANGE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 797
#define HMO_ATTR_RUN_SINGLE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 130
#define HMO_ATTR_RUN_SINGLE_WAIT_FOR_OPC                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 931
#define HMO_ATTR_RUN_CONTINUOUS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 131
#define HMO_ATTR_STOP                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 132
#define HMO_ATTR_SEND_SW_TRIGGER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 134
#define HMO_ATTR_SEND_SW_TRIGGER_AND_WAIT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 798
#define HMO_ATTR_WAVEFORM_CONVERSION_X_START                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 727
#define HMO_ATTR_WAVEFORM_CONVERSION_X_INCREMENT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 728
#define HMO_ATTR_WAVEFORM_CONVERSION_Y_START                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 729
#define HMO_ATTR_WAVEFORM_CONVERSION_Y_INCREMENT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 730
#define HMO_ATTR_WAVEFORM_CONVERSION_Y_RESOLUTION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 731
#define HMO_ATTR_ENVELOPE_WAVEFORM_CONVERSION_X_START                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 732
#define HMO_ATTR_ENVELOPE_WAVEFORM_CONVERSION_X_INCREMENT                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 733
#define HMO_ATTR_ENVELOPE_WAVEFORM_CONVERSION_Y_START                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 734
#define HMO_ATTR_ENVELOPE_WAVEFORM_CONVERSION_Y_INCREMENT                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 735
#define HMO_ATTR_ENVELOPE_WAVEFORM_CONVERSION_Y_RESOLUTION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 736
#define HMO_ATTR_MATH_WAVEFORM_CONVERSION_X_START                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 737
#define HMO_ATTR_MATH_WAVEFORM_CONVERSION_X_INCREMENT                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 738
#define HMO_ATTR_MATH_WAVEFORM_CONVERSION_Y_START                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 739
#define HMO_ATTR_MATH_WAVEFORM_CONVERSION_Y_INCREMENT                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 740
#define HMO_ATTR_MATH_WAVEFORM_CONVERSION_Y_RESOLUTION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 741
#define HMO_ATTR_MATH_ENVELOPE_WAVEFORM_X_START                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 799
#define HMO_ATTR_MATH_ENVELOPE_WAVEFORM_X_INCREMENT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 800
#define HMO_ATTR_MATH_ENVELOPE_WAVEFORM_Y_START                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 801
#define HMO_ATTR_MATH_ENVELOPE_WAVEFORM_Y_INCREMENT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 802
#define HMO_ATTR_MATH_ENVELOPE_WAVEFORM_Y_RESOLUTION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 803
#define HMO_ATTR_QUICKMATH_WAVEFORM_CONVERSION_X_START                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 742
#define HMO_ATTR_QUICKMATH_WAVEFORM_CONVERSION_X_INCREMENT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 743
#define HMO_ATTR_QUICKMATH_WAVEFORM_CONVERSION_Y_START                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 744
#define HMO_ATTR_QUICKMATH_WAVEFORM_CONVERSION_Y_INCREMENT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 745
#define HMO_ATTR_QUICKMATH_WAVEFORM_CONVERSION_Y_RESOLUTION                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 746
#define HMO_ATTR_REFERENCE_WAVEFORM_CONVERSION_X_START                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 747
#define HMO_ATTR_REFERENCE_WAVEFORM_CONVERSION_X_INCREMENT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 748
#define HMO_ATTR_REFERENCE_WAVEFORM_CONVERSION_Y_START                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 749
#define HMO_ATTR_REFERENCE_WAVEFORM_CONVERSION_Y_INCREMENT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 750
#define HMO_ATTR_REFERENCE_WAVEFORM_CONVERSION_Y_RESOLUTION                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 751
#define HMO_ATTR_POD_WAVEFORM_CONVERSION_X_START                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 752
#define HMO_ATTR_POD_WAVEFORM_CONVERSION_X_INCREMENT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 753
#define HMO_ATTR_POD_WAVEFORM_CONVERSION_Y_START                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 754
#define HMO_ATTR_POD_WAVEFORM_CONVERSION_Y_INCREMENT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 755
#define HMO_ATTR_POD_WAVEFORM_CONVERSION_Y_RESOLUTION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 756
#define HMO_ATTR_MASK_DATA_CONVERSION_X_START                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 804
#define HMO_ATTR_MASK_DATA_CONVERSION_X_INCREMENT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 805
#define HMO_ATTR_MASK_DATA_CONVERSION_Y_START                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 806
#define HMO_ATTR_MASK_DATA_CONVERSION_Y_INCREMENT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 807
#define HMO_ATTR_MASK_DATA_CONVERSION_Y_RESOLUTION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 808
#define HMO_ATTR_MAIN_MEASUREMENT_RESULT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 508
#define HMO_ATTR_AMPT_MAIN_MEASUREMENT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 147
#define HMO_ATTR_MEAS_DELAY_SLOPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 617
#define HMO_ATTR_MEAS_CATEGORY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 618
#define HMO_ATTR_MEAS_RELATIVE_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 619
#define HMO_ATTR_MEASUREMENT_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 136
#define HMO_ATTR_MEASUREMENT_CATEGORY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 138
#define HMO_ATTR_QUICK_MEASUREMENTS_ENABLE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 139
#define HMO_ATTR_QUICK_MEASUREMENTS_DISABLE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 140
#define HMO_ATTR_QUICK_MEASUREMENTS_ENABLE_WITH_STATUS_BIT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 809
#define HMO_ATTR_CURSOR_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 173
#define HMO_ATTR_ALL_CURSORS_OFF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 174
#define HMO_ATTR_CURSOR_MEASUREMENT_TYPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 175
#define HMO_ATTR_CURSOR_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 176
#define HMO_ATTR_CURSOR_TRACKING                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 177
#define HMO_ATTR_CURSOR_X_POSITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 178
#define HMO_ATTR_CURSOR_X_POSITION_COUPLING                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 179
#define HMO_ATTR_CURSOR_Y_POSITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 180
#define HMO_ATTR_CURSOR_Y_POSITION_COUPLING                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 181
#define HMO_ATTR_CURSOR_ADJUSTMENT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 507
#define HMO_ATTR_CURSOR_X_RATIO_MEASUREMENT_UNIT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 187
#define HMO_ATTR_CURSOR_Y_RATIO_MEASUREMENT_UNIT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 189
#define HMO_ATTR_CURSOR_X_RATIO_MEASUREMENT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 188
#define HMO_ATTR_CURSOR_Y_RATIO_MEASUREMENT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 190
#define HMO_ATTR_CURSOR_DISTANCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 183
#define HMO_ATTR_CURSOR_INVERSE_DISTANCE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 184
#define HMO_ATTR_CURSOR_VOLTAGE_INVERSE_DISTANCE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 503
#define HMO_ATTR_CURSOR_POSITION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 506
#define HMO_ATTR_CURSOR_AUTOSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 810
#define HMO_ATTR_CURSOR_RESET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 811
#define HMO_ATTR_CURSOR_PEAK_RIGHT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 812
#define HMO_ATTR_CURSOR_PEAK_LEFT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 813
#define HMO_ATTR_AUTOMATIC_MEASUREMENT_STATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 758
#define HMO_ATTR_AUTOMATIC_MEASUREMENT_NUMBER_OF_WAVEFORMS                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 759
#define HMO_ATTR_RESET_AUTOMATIC_MEASUREMENT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 760
#define HMO_ATTR_AUTOMATIC_MEASUREMENT_NUMBER_OF_MEASURED_WAVEFORMS         RS_SPECIFIC_PUBLIC_ATTR_BASE + 761
#define HMO_ATTR_AUTOMATIC_MEASUREMENT_RESULT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 762
#define HMO_ATTR_MATH_WAVEFORM_HEADER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 337
#define HMO_ATTR_QUICKMATH_WAVEFORM_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 680
#define HMO_ATTR_QUICKMATH_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 681
#define HMO_ATTR_QUICKMATH_OPERATION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 682
#define HMO_ATTR_QUICKMATH_POSITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 763
#define HMO_ATTR_QUICKMATH_VERTICAL_SCALE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 764
#define HMO_ATTR_MATH_WAVEFORM_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 235
#define HMO_ATTR_MATH_WAVEFORM_POSITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 623
#define HMO_ATTR_MATH_VERTICAL_SCALE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 624
#define HMO_ATTR_MATH_ACQUISITION_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 236
#define HMO_ATTR_MATH_EXPRESSION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 237
#define HMO_ATTR_MATH_LABEL_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 648
#define HMO_ATTR_MATH_LABEL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 649
#define HMO_ATTR_FFT_CENTER_FREQUENCY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 241
#define HMO_ATTR_FFT_FREQUENCY_SPAN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 242
#define HMO_ATTR_FFT_FULL_SPAN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 243
#define HMO_ATTR_FFT_START_FREQUENCY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 244
#define HMO_ATTR_FFT_STOP_FREQUENCY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 245
#define HMO_ATTR_FFT_AVERAGING                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 509
#define HMO_ATTR_FFT_WINDOW_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 246
#define HMO_ATTR_FFT_RESOLUTION_BANDWIDTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 254
#define HMO_ATTR_FFT_RESOLUTION_BANDWIDTH_COUPLING_ENABLED                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 255
#define HMO_ATTR_FFT_RESOLUTION_BANDWIDTH_RATIO                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 256
#define HMO_ATTR_FFT_EFFECTIVE_RESOLUTION_BANDWIDTH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 257
#define HMO_ATTR_FFT_SCALING_UNIT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 625
#define HMO_ATTR_FFT_SAMPLE_RATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 814
#define HMO_ATTR_FFT_YT_WINDOW_WIDTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 815
#define HMO_ATTR_FFT_YT_WINDOW_POSITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 816
#define HMO_ATTR_REFERENCE_WAVEFORM_HEADER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 511
#define HMO_ATTR_REFERENCE_WAVEFORM_SOURCE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 270
#define HMO_ATTR_REFERENCE_WAVEFORM_UPDATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 276
#define HMO_ATTR_REFERENCE_WAVEFORM_DISPLAY_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 271
#define HMO_ATTR_REFERENCE_WAVEFORM_LOAD_FROM_FILE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 512
#define HMO_ATTR_REFERENCE_WAVEFORM_LOAD_CONFIGURATION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 513
#define HMO_ATTR_REFERENCE_WAVEFORM_SAVE_TO_FILE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 514
#define HMO_ATTR_REFERENCE_WAVEFORM_CATALOG                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 515
#define HMO_ATTR_REFERENCE_WAVEFORM_VERTICAL_SCALE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 281
#define HMO_ATTR_REFERENCE_WAVEFORM_VERTICAL_POSITION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 282
#define HMO_ATTR_REFERENCE_WAVEFORM_HORIZONTAL_SCALE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 516
#define HMO_ATTR_REFERENCE_WAVEFORM_HORIZONTAL_POSITION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 611
#define HMO_ATTR_MASK_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 517
#define HMO_ATTR_MASK_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 525
#define HMO_ATTR_MASK_TEST                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 526
#define HMO_ATTR_MASK_COPY_CHANNEL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 518
#define HMO_ATTR_MASK_HIT_COUNT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 522
#define HMO_ATTR_MASK_COUNT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 521
#define HMO_ATTR_MASK_STORE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 524
#define HMO_ATTR_MASK_LOAD                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 523
#define HMO_ATTR_MASK_YOUTPUT_PULSES_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 670
#define HMO_ATTR_MASK_EVENT_MODE_SOUND                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 817
#define HMO_ATTR_MASK_EVENT_MODE_STOP_ACQUISITION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 818
#define HMO_ATTR_MASK_EVENT_COUNT_STOP_ACQUISITION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 819
#define HMO_ATTR_MASK_EVENT_MODE_SCREENSHOT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 820
#define HMO_ATTR_MASK_SCREENSAVER_DESTINATION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 821
#define HMO_ATTR_MASK_EVENT_MODE_PRINT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 822
#define HMO_ATTR_MASK_EVENT_MODE_SAVE_WAVEFORM_DATA                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 823
#define HMO_ATTR_MASK_WAVEFORM_DESTINATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 824
#define HMO_ATTR_MASK_EVENT_MODE_IMPULSE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 825
#define HMO_ATTR_MASK_RESET_TEST_COUNTER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 826
#define HMO_ATTR_MASK_VERTICAL_OFFSET                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 519
#define HMO_ATTR_MASK_VERTICAL_SCALING                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 520
#define HMO_ATTR_MASK_VERTICAL_WIDTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 528
#define HMO_ATTR_MASK_HORIZONTAL_WIDTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 527
#define HMO_ATTR_SEARCH_STATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 683
#define HMO_ATTR_SEARCH_CONDITION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 684
#define HMO_ATTR_SEARCH_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 685
#define HMO_ATTR_SEARCH_TRIGGER_EDGE_SLOPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 686
#define HMO_ATTR_SEARCH_TRIGGER_EDGE_LEVEL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 687
#define HMO_ATTR_SEARCH_TRIGGER_EDGE_HYSTERSIS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 688
#define HMO_ATTR_SEARCH_TRIGGER_WIDTH_LEVEL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 689
#define HMO_ATTR_SEARCH_TRIGGER_WIDTH_LEVEL_DELTA                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 690
#define HMO_ATTR_SEARCH_TRIGGER_WIDTH_WIDTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 691
#define HMO_ATTR_SEARCH_TRIGGER_WIDTH_DELTA                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 692
#define HMO_ATTR_SEARCH_TRIGGER_WIDTH_POLARITY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 693
#define HMO_ATTR_SEARCH_TRIGGER_WIDTH_RANGE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 694
#define HMO_ATTR_SEARCH_TRIGGER_PEAK_POLARITY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 695
#define HMO_ATTR_SEARCH_TRIGGER_PEAK_LIMIT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 696
#define HMO_ATTR_SEARCH_TRIGGER_RUNT_POLARITY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 697
#define HMO_ATTR_SEARCH_TRIGGER_RUNT_LEVEL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 698
#define HMO_ATTR_SEARCH_TRIGGER_RUNT_RANGE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 699
#define HMO_ATTR_SEARCH_TRIGGER_RUNT_WIDTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 700
#define HMO_ATTR_SEARCH_TRIGGER_RUNT_DELTA_WIDTH                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 701
#define HMO_ATTR_SEARCH_TRIGGER_RISE_TIME_POLARITY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 702
#define HMO_ATTR_SEARCH_TRIGGER_RISE_TIME_LEVEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 703
#define HMO_ATTR_SEARCH_TRIGGER_RISE_TIME_RANGE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 704
#define HMO_ATTR_SEARCH_TRIGGER_RISE_TIME_REFERENCE_TIME                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 705
#define HMO_ATTR_SEARCH_TRIGGER_RISE_TIME_DELTA_TIME                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 706
#define HMO_ATTR_SEARCH_TRIGGER_D2C_CLOCK_SOURCE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 827
#define HMO_ATTR_SEARCH_TRIGGER_D2C_CLOCK_LEVEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 828
#define HMO_ATTR_SEARCH_TRIGGER_D2C_DATA_LEVEL                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 829
#define HMO_ATTR_SEARCH_TRIGGER_D2C_CLOCK_HYSTERESIS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 830
#define HMO_ATTR_SEARCH_TRIGGER_D2C_DATA_HYSTERESIS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 831
#define HMO_ATTR_SEARCH_TRIGGER_D2C_POLARITY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 832
#define HMO_ATTR_SEARCH_TRIGGER_D2C_SETUP_TIME                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 833
#define HMO_ATTR_SEARCH_TRIGGER_D2C_HOLD_TIME                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 834
#define HMO_ATTR_SEARCH_TRIGGER_PATTERN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 835
#define HMO_ATTR_SEARCH_TRIGGER_PATTERN_COMBINATION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 836
#define HMO_ATTR_SEARCH_TRIGGER_PATTERN_COMPARISON                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 837
#define HMO_ATTR_SEARCH_TRIGGER_PATTERN_WIDTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 838
#define HMO_ATTR_SEARCH_TRIGGER_PATTERN_WIDTH_DELTA                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 839
#define HMO_ATTR_SEARCH_TRIGGER_PATTERN_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 840
#define HMO_ATTR_SEARCH_TRIGGER_PATTERN_HYSTERESIS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 841
#define HMO_ATTR_SEARCH_SHOW_RESULT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 707
#define HMO_ATTR_SEARCH_NUMBER_OF_RESULTS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 708
#define HMO_ATTR_SEARCH_MAXIMUM_NUMBER_OF_RESULTS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 842
#define HMO_ATTR_SEARCH_LIN_CONDITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 843
#define HMO_ATTR_SEARCH_LIN_FRAME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 844
#define HMO_ATTR_SEARCH_LIN_CHECKSUM_ERROR                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 845
#define HMO_ATTR_SEARCH_LIN_ID_PARITY_ERROR                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 846
#define HMO_ATTR_SEARCH_LIN_SYNC_ERROR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 847
#define HMO_ATTR_SEARCH_LIN_ID_CONDITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 848
#define HMO_ATTR_SEARCH_LIN_IDENTIFIER_PATTERN                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 849
#define HMO_ATTR_SEARCH_LIN_DATA_LENGTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 850
#define HMO_ATTR_SEARCH_LIN_DATA_CONDITION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 851
#define HMO_ATTR_SEARCH_LIN_DATA                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 852
#define HMO_ATTR_SEARCH_CAN_CONDITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 853
#define HMO_ATTR_SEARCH_CAN_FRAME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 854
#define HMO_ATTR_SEARCH_CAN_CRC_RRROR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 855
#define HMO_ATTR_SEARCH_CAN_ACKNOWLEDGE_ERROR                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 856
#define HMO_ATTR_SEARCH_CAN_FORM_ERROR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 857
#define HMO_ATTR_SEARCH_CAN_BIT_STUFFING_ERROR                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 858
#define HMO_ATTR_SEARCH_CAN_FRAME_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 859
#define HMO_ATTR_SEARCH_CAN_ID_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 860
#define HMO_ATTR_SEARCH_CAN_ID_CONDITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 861
#define HMO_ATTR_SEARCH_CAN_IDENTIFIER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 862
#define HMO_ATTR_SEARCH_CAN_DATA_LENGTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 863
#define HMO_ATTR_SEARCH_CAN_DATA_CONDITION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 864
#define HMO_ATTR_SEARCH_CAN_DATA                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 865
#define HMO_ATTR_PROTOCOL_STATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 577
#define HMO_ATTR_PROTOCOL_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 578
#define HMO_ATTR_PROTOCOL_LABEL_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 650
#define HMO_ATTR_PROTOCOL_LABEL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 651
#define HMO_ATTR_BUS_SIGNAL_SOURCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 664
#define HMO_ATTR_BUS_SIGNAL_SOURCE_FREQUENCY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 665
#define HMO_ATTR_PROTOCOL_DISPLAY_FORMAT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 579
#define HMO_ATTR_PROTOCOL_DISPLAY_HEIGHT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 580
#define HMO_ATTR_PROTOCOL_DISPLAY_LINES                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 581
#define HMO_ATTR_PROTOCOL_DISPLAY_VERTICAL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 582
#define HMO_ATTR_PROTOCOL_I2C_SOURCE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350
#define HMO_ATTR_PROTOCOL_I2C_DATA_SOURCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 866
#define HMO_ATTR_PROTOCOL_I2C_CLOCK_SOURCE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 867
#define HMO_ATTR_PROTOCOL_I2C_7_BIT_ADDRESS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 868
#define HMO_ATTR_PROTOCOL_I2C_TRIGGER_ACCESS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 529
#define HMO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 531
#define HMO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 530
#define HMO_ATTR_PROTOCOL_I2C_TRIGGER_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 532
#define HMO_ATTR_PROTOCOL_I2C_TRIGGER_CONDITION_LENGTH                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 534
#define HMO_ATTR_PROTOCOL_I2C_TRIGGER_BIT_PATTERN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 533
#define HMO_ATTR_PROTOCOL_I2C_TRIGGER_FIRST_BYTE_OFFSET                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 535
#define HMO_ATTR_PROTOCOL_I2C_FRAME_COUNT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 671
#define HMO_ATTR_PROTOCOL_SPI_SOURCE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 382
#define HMO_ATTR_PROTOCOL_SPI_POLARITY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 383
#define HMO_ATTR_PROTOCOL_SPI_BIT_ORDER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 380
#define HMO_ATTR_PROTOCOL_SPI_WORD_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 381
#define HMO_ATTR_PROTOCOL_SPI_TRIGGER_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 537
#define HMO_ATTR_PROTOCOL_SPI_TRIGGER_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 388
#define HMO_ATTR_PROTOCOL_SPI_BIT_PATTERN_LENGTH                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 539
#define HMO_ATTR_PROTOCOL_SPI_BIT_PATTERN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 536
#define HMO_ATTR_PROTOCOL_SPI_FRAME_COUNT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 672
#define HMO_ATTR_PROTOCOL_SSPI_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 609
#define HMO_ATTR_PROTOCOL_SSPI_POLARITY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 594
#define HMO_ATTR_PROTOCOL_SSPI_INTERFRAME_TIME                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 597
#define HMO_ATTR_PROTOCOL_SSPI_BIT_ORDER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 598
#define HMO_ATTR_PROTOCOL_SSPI_WORD_LENGTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 599
#define HMO_ATTR_PROTOCOL_UART_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 600
#define HMO_ATTR_PROTOCOL_UART_POLARITY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 601
#define HMO_ATTR_PROTOCOL_UART_INTERFRAME_TIME                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 605
#define HMO_ATTR_PROTOCOL_UART_WORD_LENGTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 606
#define HMO_ATTR_PROTOCOL_UART_BIT_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 604
#define HMO_ATTR_PROTOCOL_UART_PARITY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 405
#define HMO_ATTR_PROTOCOL_UART_STOP_BITS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 603
#define HMO_ATTR_PROTOCOL_UART_TRIGGER_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 540
#define HMO_ATTR_PROTOCOL_UART_TRIGGER_DATA_PATTERN                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 541
#define HMO_ATTR_PROTOCOL_UART_TRIGGER_DATA_POSITION_INDEX_MIN              RS_SPECIFIC_PUBLIC_ATTR_BASE + 542
#define HMO_ATTR_PROTOCOL_UART_TRIGGER_CONDITION_LENGTH                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 543
#define HMO_ATTR_PROTOCOL_UART_FRAME_COUNT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 673
#define HMO_ATTR_PROTOCOL_LIN_SOURCE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 709
#define HMO_ATTR_PROTOCOL_LIN_POLARITY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 768
#define HMO_ATTR_PROTOCOL_LIN_STANDARD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 711
#define HMO_ATTR_PROTOCOL_LIN_BIT_RATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 712
#define HMO_ATTR_PROTOCOL_LIN_TRIGGER_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 713
#define HMO_ATTR_PROTOCOL_LIN_TRIGGER_CONDITION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 714
#define HMO_ATTR_PROTOCOL_LIN_TRIGGER_ID_PATTERN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 715
#define HMO_ATTR_PROTOCOL_LIN_TRIGGER_DATA_LENGTH                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 716
#define HMO_ATTR_PROTOCOL_LIN_TRIGGER_DATA_PATTERN                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 717
#define HMO_ATTR_PROTOCOL_LIN_TRIGGER_ERROR                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 718
#define HMO_ATTR_PROTOCOL_LIN_FRAME_COUNT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 719
#define HMO_ATTR_PROTOCOL_CAN_LINE_TYPE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 674
#define HMO_ATTR_PROTOCOL_CAN_SOURCE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 675
#define HMO_ATTR_PROTOCOL_CAN_BIT_RATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 676
#define HMO_ATTR_PROTOCOL_CAN_SAMPLE_POINT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 677
#define HMO_ATTR_PROTOCOL_CAN_TRIGGER_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 678
#define HMO_ATTR_PROTOCOL_CAN_TRIGGER_FRAME_TYPE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 679
#define HMO_ATTR_PROTOCOL_CAN_TRIGGER_ID_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 720
#define HMO_ATTR_PROTOCOL_CAN_TRIGGER_CONDITION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 721
#define HMO_ATTR_PROTOCOL_CAN_TRIGGER_ID_PATTERN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 722
#define HMO_ATTR_PROTOCOL_CAN_TRIGGER_DATA_LENGTH                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 723
#define HMO_ATTR_PROTOCOL_CAN_TRIGGER_DATA_PATTERN                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 724
#define HMO_ATTR_PROTOCOL_CAN_TRIGGER_ERROR                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 725
#define HMO_ATTR_PROTOCOL_CAN_FRAME_COUNT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 726
#define HMO_ATTR_PARALLEL_BUS_SOURCE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 607
#define HMO_ATTR_PARALLEL_BUS_ANALYZED_LINES                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 608
#define HMO_ATTR_PARALLEL_BUS_FRAME_COUNT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 869
#define HMO_ATTR_PARALLEL_BUS_CLOCKED_DATA_SOURCE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 870
#define HMO_ATTR_PARELLEL_BUS_CLOCKED_SOURCE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 871
#define HMO_ATTR_PARALLER_BUS_CLOCKED_SLOPE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 872
#define HMO_ATTR_PARALLER_BUS_CLOCKED_CS_SOURCE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 873
#define HMO_ATTR_PARALLER_BUS_CLOCKED_CS_POLARITY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 874
#define HMO_ATTR_PARALLER_BUS_CLOCKED_ANALYZED_LINES                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 875
#define HMO_ATTR_COMPONENT_TEST_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 652
#define HMO_ATTR_COMPONENT_TEST_FREQUENCY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 653
#define HMO_ATTR_LOGIC_CHANNEL_STATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 654
#define HMO_ATTR_LOGIC_CHANNEL_SIZE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 655
#define HMO_ATTR_LOGIC_CHANNEL_POSITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 656
#define HMO_ATTR_LOGIC_CHANNEL_LABEL_STATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 657
#define HMO_ATTR_LOGIC_CHANNEL_LABEL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 658
#define HMO_ATTR_POD_STATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 659
#define HMO_ATTR_POD_THRESHOLD                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 660
#define HMO_ATTR_POD_THRESHOLD_USER_LEVEL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 661
#define HMO_ATTR_POD_RANGE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 765
#define HMO_ATTR_POD_NUMBER_OF_SAMPLES                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 766
#define HMO_ATTR_POD_TYPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 876
#define HMO_ATTR_POD_STATUS_MIN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 877
#define HMO_ATTR_POD_STATUS_MAX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 878
#define HMO_ATTR_DVM_ENABLE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 879
#define HMO_ATTR_DVM_SOURCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 880
#define HMO_ATTR_DVM_TYPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 881
#define HMO_ATTR_DVM_POSITION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 882
#define HMO_ATTR_DVM_RESULT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 883
#define HMO_ATTR_DVM_RESULT_STATUS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 884
#define HMO_ATTR_GENERATOR_OUTPUT_ENABLE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 885
#define HMO_ATTR_GENERATOR_FUNCTION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 886
#define HMO_ATTR_GENERATOR_AMPLITUDE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 887
#define HMO_ATTR_GENERATOR_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 888
#define HMO_ATTR_GENERATOR_FREQUENCY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 889
#define HMO_ATTR_GENERATOR_RAMP_POLARITY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 890
#define HMO_ATTR_GENERATOR_DUTY_CYCLES                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 891
#define HMO_ATTR_PATTERN_GENERATOR_FUNCTION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 892
#define HMO_ATTR_PATTERN_GENERATOR_STATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 893
#define HMO_ATTR_PATTERN_GENERATOR_SAMPLE_TIME                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 894
#define HMO_ATTR_PATTERN_GENERATOR_PERIOD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 895
#define HMO_ATTR_PATTERN_GENERATOR_FREQUENCY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 896
#define HMO_ATTR_PATTERN_GENERATOR_IDLE_TIME                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 897
#define HMO_ATTR_PATTERN_GENERATOR_BURST_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 898
#define HMO_ATTR_PATTERN_GENERATOR_BURST_CYCLES                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 899
#define HMO_ATTR_PATTERN_GENERATOR_TRIGGER_MODE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 900
#define HMO_ATTR_PATTERN_GENERATOR_TRIGGER_SINGLE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 901
#define HMO_ATTR_PATTERN_GENERATOR_EXTERNAL_SLOPE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 902
#define HMO_ATTR_PATTERN_GENERATOR_ARBITRARY_DATA                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 903
#define HMO_ATTR_PATTERN_GENERATOR_APPEND_DATA                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 904
#define HMO_ATTR_PATTERN_GENERATOR_APPEND_DATA_BINARY_OR                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 905
#define HMO_ATTR_PATTERN_GENERATOR_APPEND_DATA_BINARY_AND                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 906
#define HMO_ATTR_PATTERN_GENERATOR_APPEND_INDEX                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 907
#define HMO_ATTR_PATTERN_GENERATOR_ARBITRATY_DATA_LENGTH                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 908
#define HMO_ATTR_PATTERN_GENERATOR_COUNTER_FREQUENCY                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 909
#define HMO_ATTR_PATTERN_GENERATOR_COUNT_DIRECTION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 910
#define HMO_ATTR_PATTERN_GENERATOR_SQUARE_WAVE_POLARITY                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 911
#define HMO_ATTR_PATTERN_GENERATOR_SQUARE_WAVE_DUTY_CYCLE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 912
#define HMO_ATTR_PATTERN_GENERATOR_PIN_STATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 913
#define HMO_ATTR_DISPLAY_STYLE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 574
#define HMO_ATTR_COLOR_AND_BRIGHTNESS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 547
#define HMO_ATTR_SIGNAL_STYLE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 427
#define HMO_ATTR_DIAGRAM_GRID_STYLE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 550
#define HMO_ATTR_WAVEFORM_INTENSITY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 573
#define HMO_ATTR_BACKGROUND_INTENSITY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 545
#define HMO_ATTR_GRID_INTENSITY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 546
#define HMO_ATTR_DISPLAY_LANGUAGE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 549
#define HMO_ATTR_REMOVE_DISPLAY_LANGUAGE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 767
#define HMO_ATTR_DISPLAY_LANGUAGE_CATALOG                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 914
#define HMO_ATTR_DIAGRAM_MODE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 548
#define HMO_ATTR_VIRTUAL_SCREEN_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 662
#define HMO_ATTR_VIRTUAL_SCREEN_POSITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 663
#define HMO_ATTR_DISPLAY_CLOSE_DIALOG                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 915
#define HMO_ATTR_DISPLAY_MESSAGE_TEXT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 916
#define HMO_ATTR_PERSISTENCE_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 422
#define HMO_ATTR_INFINITE_PERSISTENCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 423
#define HMO_ATTR_PERSISTENCE_TIME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 424
#define HMO_ATTR_PERSISTENCE_TIME_AUTO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 544
#define HMO_ATTR_PERSISTENCE_CLEAR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 572
#define HMO_ATTR_XY_X_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 551
#define HMO_ATTR_XY_Y_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 552
#define HMO_ATTR_XY_Y2_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 554
#define HMO_ATTR_XY_Z_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 553
#define HMO_ATTR_XY_Z_THRESHOLD                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 556
#define HMO_ATTR_XY_INTENSITY_CONTROL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 555
#define HMO_ATTR_ZOOM_WINDOW_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 557
#define HMO_ATTR_ZOOM_DIAGRAM_TIMEBASE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 558
#define HMO_ATTR_ZOOM_OFFSET_OF_TRIGGER_POINT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 559
#define HMO_ATTR_ZOOM_REFERENCE_POINT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 560
#define HMO_ATTR_MARKER_SET                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 561
#define HMO_ATTR_MARKER_CLEAR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 562
#define HMO_ATTR_MARKER_CLEAR_ALL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 563
#define HMO_ATTR_MARKER_NEXT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 564
#define HMO_ATTR_MARKER_PREVIOUS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 565
#define HMO_ATTR_HISTORY_CHANNEL_CURRENT_ACQUISITION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 917
#define HMO_ATTR_HISTORY_CHANNEL_PLAYER_STATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 918
#define HMO_ATTR_HISTORY_CHANNEL_PLAYER_SPEED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 919
#define HMO_ATTR_HISTORY_CHANNEL_REPEAT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 920
#define HMO_ATTR_HISTORY_CHANNEL_ACQUISITION_DATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 921
#define HMO_ATTR_HISTORY_CHANNEL_ACQUISITION_RELATIVE_TIME                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 922
#define HMO_ATTR_HISTORY_CHANNEL_ACQUISITION_ABSOLUTE_TIME                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 923
#define HMO_ATTR_HISTORY_GET_ACQUISITION_COUNT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 924
#define HMO_ATTR_DRIVES                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 297
#define HMO_ATTR_CHANGE_DRIVE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 298
#define HMO_ATTR_CURRENT_DIRECTORY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 299
#define HMO_ATTR_CREATE_DIRECTORY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 300
#define HMO_ATTR_REMOVE_DIRECTORY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 301
#define HMO_ATTR_DELETE_FILE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 302
#define HMO_ATTR_HARDCOPY_FILE_NAME                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 303
#define HMO_ATTR_HARDCOPY_DEVICE_DESTINATION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 455
#define HMO_ATTR_HARDCOPY_COLOR_SCHEME                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 571
#define HMO_ATTR_HARDCOPY_DEVICE_LANGUAGE_OUTPUT_FORMAT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 456
#define HMO_ATTR_HARDCOPY_DEVICE_ORIENTATION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 457
#define HMO_ATTR_HARDCOPY_PAGE_SIZE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 567
#define HMO_ATTR_HARDCOPY_PRINT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 458
#define HMO_ATTR_HARDCOPY_SELECT_PRINTER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 459
#define HMO_ATTR_HARDCOPY_GET_FIRST_PRINTER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 460
#define HMO_ATTR_HARDCOPY_GET_NEXT_PRINTER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 461
#define HMO_ATTR_HARDCOPY_COMMAND_SET                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 925
#define HMO_ATTR_ID_QUERY_RESPONSE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 304
#define HMO_ATTR_CALIBRATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 305
#define HMO_ATTR_CALIBRATION_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 926
#define HMO_ATTR_SELF_TEST_QUERY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 306
#define HMO_ATTR_SYSTEM_ERROR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 307
#define HMO_ATTR_SYST_ERR_LIST                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 642
#define HMO_ATTR_INSTRUMENT_NAME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 568
#define HMO_ATTR_RESET_STATUS_REGISTER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 643
#define HMO_ATTR_REGISTER                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 570
#define HMO_ATTR_SOUND_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 927
#define HMO_ATTR_SOUND_ERROR_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 928
#define HMO_ATTR_SOUND_TRIGGER_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 929
#define HMO_ATTR_SOUND_GENERATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 930

// hmo_rngSampleMode
#define HMO_VAL_REAL_TIME                                                   0
#define HMO_VAL_EQUIVALENT_TIME                                             1

// hmo_rngWaveformArithmetics
#define HMO_VAL_OFF                                                         0
#define HMO_VAL_ENVELOPE                                                    1
#define HMO_VAL_AVERAGE                                                     2

// hmo_rngVerticalCoupling
#define HMO_VAL_AC                                                          0
#define HMO_VAL_DC                                                          1
#define HMO_VAL_AC_LIMIT                                                    2
#define HMO_VAL_DC_LIMIT                                                    3
#define HMO_VAL_DC_GND                                                      4

// hmo_rngChannelBWLimit
#define HMO_VAL_BW_FULL                                                     0
#define HMO_VAL_BW_20                                                       1

// hmo_rngTriggerSource
#define HMO_VAL_NONE                                                        0
#define HMO_VAL_CHANNEL1                                                    1
#define HMO_VAL_CHANNEL2                                                    2
#define HMO_VAL_CHANNEL3                                                    3
#define HMO_VAL_CHANNEL4                                                    4
#define HMO_VAL_EXTERNAL                                                    5
#define HMO_VAL_LINE                                                        6
#define HMO_VAL_PATTERN                                                     7
#define HMO_VAL_BUS1                                                        8
#define HMO_VAL_BUS2                                                        9
#define HMO_VAL_D0                                                          10
#define HMO_VAL_D1                                                          11
#define HMO_VAL_D2                                                          12
#define HMO_VAL_D3                                                          13
#define HMO_VAL_D4                                                          14
#define HMO_VAL_D5                                                          15
#define HMO_VAL_D6                                                          16
#define HMO_VAL_D7                                                          17
#define HMO_VAL_D8                                                          18
#define HMO_VAL_D9                                                          19
#define HMO_VAL_D10                                                         20
#define HMO_VAL_D11                                                         21
#define HMO_VAL_D12                                                         22
#define HMO_VAL_D13                                                         23
#define HMO_VAL_D14                                                         24
#define HMO_VAL_D15                                                         25

// hmo_rngTriggerSlope
#define HMO_VAL_POSITIVE                                                    0
#define HMO_VAL_NEGATIVE                                                    1
#define HMO_VAL_EITHER                                                      2

// hmo_rngWidthCondition
#define HMO_VAL_SHORTER                                                     0
#define HMO_VAL_LONGER                                                      1
#define HMO_VAL_WITHIN                                                      2
#define HMO_VAL_OUTSIDE                                                     3

// hmo_rngTVTriggerEvent
#define HMO_VAL_TV_EVENT_EVEN                                               0
#define HMO_VAL_TV_EVENT_ODD                                                1
#define HMO_VAL_TV_EVENT_ANY_FIELD                                          2
#define HMO_VAL_TV_EVENT_LINE                                               3
#define HMO_VAL_TV_EVENT_ANY_LINE                                           4

// hmo_rngCursorFunction
#define HMO_VAL_CURSOR_HORIZONTAL                                           0
#define HMO_VAL_CURSOR_VERTICAL                                             1
#define HMO_VAL_CURSOR_PAIRED                                               2
#define HMO_VAL_CURSOR_HRAT                                                 3
#define HMO_VAL_CURSOR_VRAT                                                 4
#define HMO_VAL_CURSOR_PPC                                                  5
#define HMO_VAL_CURSOR_NPC                                                  6
#define HMO_VAL_CURSOR_REC                                                  7
#define HMO_VAL_CURSOR_FEC                                                  8
#define HMO_VAL_CURSOR_MEAN                                                 9
#define HMO_VAL_CURSOR_RMS                                                  10
#define HMO_VAL_CURSOR_RTIM                                                 11
#define HMO_VAL_CURSOR_FTIM                                                 12
#define HMO_VAL_CURSOR_PEAK                                                 13
#define HMO_VAL_CURSOR_UPE                                                  14
#define HMO_VAL_CURSOR_LPE                                                  15
#define HMO_VAL_CURSOR_STDDEV                                               16
#define HMO_VAL_CURSOR_PDCYCLE                                              17
#define HMO_VAL_CURSOR_NDCYCLE                                              18

// hmo_rngXRatioMeasurementUnit
#define HMO_VAL_UNIT_RATIO                                                  0
#define HMO_VAL_UNIT_PCT                                                    1
#define HMO_VAL_UNIT_DEGREE                                                 2
#define HMO_VAL_UNIT_RAD                                                    3

// hmo_rngInterpolation
#define HMO_VAL_SINE_X                                                      0
#define HMO_VAL_LINEAR                                                      1
#define HMO_VAL_SAMPLE_HOLD                                                 2

// hmo_rngMeasurementCategory
#define HMO_VAL_AMPTIME                                                     0

// hmo_rngFFTWindowType
#define HMO_VAL_RECTANGULAR                                                 0
#define HMO_VAL_HAMMING                                                     1
#define HMO_VAL_HANN                                                        2
#define HMO_VAL_BLACKMAN                                                    3

// hmo_rngProtocolSPIBitOrder
#define HMO_VAL_SPI_MSBF                                                    0
#define HMO_VAL_SPI_LSBF                                                    1

// hmo_rngProtocolSPIPolarity
#define HMO_VAL_ACTLOW                                                      0
#define HMO_VAL_ACTHIGH                                                     1

// hmo_rngProtocolUARTParity
#define HMO_VAL_UART_NONE                                                   0
#define HMO_VAL_UART_ODD                                                    1
#define HMO_VAL_UART_EVEN                                                   2

// hmo_rngProtocolUARTStopBits
#define HMO_VAL_UART_B1                                                     0
#define HMO_VAL_UART_B1_5                                                   1
#define HMO_VAL_UART_B2                                                     2

// hmo_rngProtocolUARTTriggerType
#define HMO_VAL_UART_TRIGGER_BURSTSTART                                     0
#define HMO_VAL_UART_TRIGGER_SBIT                                           1
#define HMO_VAL_UART_TRIGGER_NTHS                                           2
#define HMO_VAL_UART_TRIGGER_SYMB                                           3
#define HMO_VAL_UART_TRIGGER_PATT                                           4
#define HMO_VAL_UART_TRIGGER_PERR                                           5
#define HMO_VAL_UART_TRIGGER_FERR                                           6
#define HMO_VAL_UART_TRIGGER_BRE                                            7

// hmo_rngSignalStyle
#define HMO_VAL_SIGNAL_STYLE_VECTORS                                        0
#define HMO_VAL_SIGNAL_STYLE_DOTS                                           1

// hmo_rngHardcopyDeviceOrientation
#define HMO_VAL_HARDCOPY_ORIENTATION_PORTRAIT                               0
#define HMO_VAL_HARDCOPY_ORIENTATION_LANDSCAPE                              1

// hmo_rngWaveformParameterCursor
#define HMO_VAL_WAV_CH1                                                     1
#define HMO_VAL_WAV_CH2                                                     2
#define HMO_VAL_WAV_CH3                                                     3
#define HMO_VAL_WAV_CH4                                                     4
#define HMO_VAL_WAV_M1                                                      5
#define HMO_VAL_WAV_M2                                                      6
#define HMO_VAL_WAV_M3                                                      7
#define HMO_VAL_WAV_M4                                                      8
#define HMO_VAL_WAV_M5                                                      9
#define HMO_VAL_WAV_R1                                                      10
#define HMO_VAL_WAV_R2                                                      11
#define HMO_VAL_WAV_R3                                                      12
#define HMO_VAL_WAV_R4                                                      13
#define HMO_VAL_WAV_XY1                                                     14
#define HMO_VAL_WAV_XY2                                                     15
#define HMO_VAL_WAV_QMA                                                     16
#define HMO_VAL_WAV_POD1                                                    17
#define HMO_VAL_WAV_POD2                                                    18
#define HMO_VAL_WAV_D0                                                      19
#define HMO_VAL_WAV_D1                                                      20
#define HMO_VAL_WAV_D2                                                      21
#define HMO_VAL_WAV_D3                                                      22
#define HMO_VAL_WAV_D4                                                      23
#define HMO_VAL_WAV_D5                                                      24
#define HMO_VAL_WAV_D6                                                      25
#define HMO_VAL_WAV_D7                                                      26
#define HMO_VAL_WAV_D8                                                      27
#define HMO_VAL_WAV_D9                                                      28
#define HMO_VAL_WAV_D10                                                     29
#define HMO_VAL_WAV_D11                                                     30
#define HMO_VAL_WAV_D12                                                     31
#define HMO_VAL_WAV_D13                                                     32
#define HMO_VAL_WAV_D14                                                     33
#define HMO_VAL_WAV_D15                                                     34

// hmo_rngSampleRate
#define HMO_VAL_RATE_AUTO                                                   0
#define HMO_VAL_RATE_MAX_SAM                                                2
#define HMO_VAL_RATE_MAX_WAV                                                1
#define HMO_VAL_RATE_MAX_MAN                                                3

// hmo_rngColorBrightness
#define HMO_VAL_COLOR_NORM                                                  0
#define HMO_VAL_COLOR_INVERSE                                               1
#define HMO_VAL_COLOR_FCOLOR                                                2
#define HMO_VAL_COLOR_INVCOLOR                                              3

// hmo_rngDiagramMode
#define HMO_VAL_DISPLAY_YT                                                  0
#define HMO_VAL_DISPLAY_XY                                                  1

// hmo_rngLanguage
#define HMO_VAL_DISPLAY_ENGLISH                                             0
#define HMO_VAL_DISPLAY_GERMAN                                              1
#define HMO_VAL_DISPLAY_SPANISH                                             2
#define HMO_VAL_DISPLAY_FRENCH                                              3
#define HMO_VAL_DISPLAY_SCHIN                                               4
#define HMO_VAL_DISPLAY_TCHIN                                               5
#define HMO_VAL_DISPLAY_RUSSIAN                                             6
#define HMO_VAL_DISPLAY_JAPANESE                                            7
#define HMO_VAL_DISPLAY_KOREAN                                              8

// hmo_rngGridStyle
#define HMO_VAL_GRID_LINES                                                  0
#define HMO_VAL_GRID_CROSS                                                  1
#define HMO_VAL_GRID_NONE                                                   2

// hmo_rngSource
#define HMO_VAL_SOURCE_CH1                                                  1
#define HMO_VAL_SOURCE_CH2                                                  2
#define HMO_VAL_SOURCE_CH3                                                  3
#define HMO_VAL_SOURCE_CH4                                                  4
#define HMO_VAL_SOURCE_D0                                                   5
#define HMO_VAL_SOURCE_D1                                                   6
#define HMO_VAL_SOURCE_D2                                                   7
#define HMO_VAL_SOURCE_D3                                                   8
#define HMO_VAL_SOURCE_D4                                                   9
#define HMO_VAL_SOURCE_D5                                                   10
#define HMO_VAL_SOURCE_D6                                                   11
#define HMO_VAL_SOURCE_D7                                                   12
#define HMO_VAL_SOURCE_D8                                                   13
#define HMO_VAL_SOURCE_D9                                                   14
#define HMO_VAL_SOURCE_D10                                                  15
#define HMO_VAL_SOURCE_D11                                                  16
#define HMO_VAL_SOURCE_D12                                                  17
#define HMO_VAL_SOURCE_D13                                                  18
#define HMO_VAL_SOURCE_D14                                                  19
#define HMO_VAL_SOURCE_D15                                                  20
#define HMO_VAL_SOURCE_EXT                                                  21

// hmo_rngXY2Source
#define HMO_VAL_SOURCE_NONE                                                 0

// hmo_rngIntensityMode
#define HMO_VAL_ZMODE_ANALOG                                                0
#define HMO_VAL_ZMODE_DIGITAL                                               1
#define HMO_VAL_ZMODE_OFF                                                   2

// hmo_rngHardcopyDevice
#define HMO_VAL_HARDCOPY_DEVICE_MEM                                         0
#define HMO_VAL_HARDCOPY_DEVICE_PRINT                                       1

// hmo_rngHardcopyDeviceLang
#define HMO_VAL_HARDCOPY_DEVICE_LANG_PNG                                    0
#define HMO_VAL_HARDCOPY_DEVICE_LANG_BMP                                    1
#define HMO_VAL_HARDCOPY_DEVICE_LANG_GIF                                    2
#define HMO_VAL_HARDCOPY_DEVICE_LANG_GDI                                    3

// hmo_rngPageSize
#define HMO_VAL_PAGE_A4                                                     0
#define HMO_VAL_PAGE_A5                                                     1
#define HMO_VAL_PAGE_B5                                                     2
#define HMO_VAL_PAGE_B6                                                     3
#define HMO_VAL_PAGE_EX                                                     4
#define HMO_VAL_PAGE_LEG                                                    5
#define HMO_VAL_PAGE_LETT                                                   6

// hmo_rngMaskCondition
#define HMO_VAL_MASKCOND_RUN                                                0
#define HMO_VAL_MASKCOND_STOP                                               1
#define HMO_VAL_MASKCOND_PAUSE                                              2

// hmo_rngTriggerCoupling
#define HMO_VAL_COUPLING_DIRECT                                             0
#define HMO_VAL_COUPLING_ALTERNATING                                        1
#define HMO_VAL_COUPLING_HIGHFREQ                                           2
#define HMO_VAL_COUPLING_AUTO_LEVEL                                         3

// hmo_rngProtocolI2CAccessBit
#define HMO_VAL_I2C_TRIGGER_READ                                            1
#define HMO_VAL_I2C_TRIGGER_WRITE                                           2

// hmo_rngAddressLength
#define HMO_VAL_LENGTH_NORMAL                                               0
#define HMO_VAL_LENGTH_EXTENDED                                             1

// hmo_rngProtocolI2CTriggerType
#define HMO_VAL_TRIGGER_MODE_START                                          0
#define HMO_VAL_TRIGGER_MODE_RESTART                                        1
#define HMO_VAL_TRIGGER_MODE_STOP                                           2
#define HMO_VAL_TRIGGER_MODE_MISSING                                        3
#define HMO_VAL_TRIGGER_MODE_PATT                                           4

// hmo_rngTriggerMode
#define HMO_VAL_TRIGGER_AUTO                                                0
#define HMO_VAL_TRIGGER_NORMAL                                              1
#define HMO_VAL_TRIGGER_DELAY                                               2
#define HMO_VAL_TRIGGER_EVENTS                                              3

// hmo_rngTriggerPatternFunction
#define HMO_VAL_TRG_PATTERN_AND                                             0
#define HMO_VAL_TRG_PATTERN_OR                                              1

// hmo_rngProtocolSPITriggerType
#define HMO_VAL_SPI_MODE_BURSTSTART                                         0
#define HMO_VAL_SPI_MODE_BURSTEND                                           1
#define HMO_VAL_SPI_MODE_BIT                                                2
#define HMO_VAL_SPI_MODE_PATTERN                                            3

// hmo_rngTriggerType
#define HMO_VAL_EDGE_TRIGGER                                                0
#define HMO_VAL_WIDTH_TRIGGER                                               1
#define HMO_VAL_VIDEO_TRIGGER                                               2
#define HMO_VAL_PATTERN_TRIGGER                                             3
#define HMO_VAL_BUS_TRIGGER                                                 4

// hmo_rngTVStandard
#define HMO_VAL_TV_STANDART_PAL                                             0
#define HMO_VAL_TV_STANDART_NTSC                                            1
#define HMO_VAL_TV_STANDART_SECAM                                           2
#define HMO_VAL_TV_STANDART_PALM                                            3
#define HMO_VAL_TV_STANDART_I576                                            4
#define HMO_VAL_TV_STANDART_P720                                            5
#define HMO_VAL_TV_STANDART_P1080                                           6
#define HMO_VAL_TV_STANDART_I1080                                           7

// hmo_rngColorScheme
#define HMO_VAL_SCHEME_COLOR                                                0
#define HMO_VAL_SCHEME_GRAY                                                 1
#define HMO_VAL_SCHEME_INVERTED                                             2

// hmo_rngAcquisitionType
#define HMO_VAL_SAMPLE                                                      0
#define HMO_VAL_PEAK_DETECT                                                 1
#define HMO_VAL_HI_RES                                                      2

// hmo_rngAmplitudeTimeMeasurementType
#define HMO_VAL_MEAS_FREQUENCY                                              1
#define HMO_VAL_MEAS_PERIOD                                                 2
#define HMO_VAL_MEAS_PEAK                                                   3
#define HMO_VAL_MEAS_UPEAK                                                  4
#define HMO_VAL_MEAS_LPEAK                                                  5
#define HMO_VAL_MEAS_PPC                                                    6
#define HMO_VAL_MEAS_NPC                                                    7
#define HMO_VAL_MEAS_REC                                                    8
#define HMO_VAL_MEAS_FEC                                                    9
#define HMO_VAL_MEAS_HIGH                                                   10
#define HMO_VAL_MEAS_LOW                                                    11
#define HMO_VAL_MEAS_AMP                                                    12
#define HMO_VAL_MEAS_MEAN                                                   13
#define HMO_VAL_MEAS_RMS                                                    14
#define HMO_VAL_MEAS_RTM                                                    15
#define HMO_VAL_MEAS_FTIM                                                   16
#define HMO_VAL_MEAS_PDCY                                                   17
#define HMO_VAL_MEAS_NDCY                                                   18
#define HMO_VAL_MEAS_PPW                                                    19
#define HMO_VAL_MEAS_NPW                                                    20
#define HMO_VAL_MEAS_CYCM                                                   21
#define HMO_VAL_MEAS_CYCR                                                   22
#define HMO_VAL_MEAS_SSTDD                                                  23
#define HMO_VAL_MEAS_TFR                                                    24
#define HMO_VAL_MEAS_TPER                                                   25
#define HMO_VAL_MEAS_POV                                                    26
#define HMO_VAL_MEAS_NOV                                                    27
#define HMO_VAL_MEAS_DELAY                                                  28
#define HMO_VAL_MEAS_PHASE                                                  29
#define HMO_VAL_MEAS_WAVM                                                   30
#define HMO_VAL_MEAS_WAVR                                                   31
#define HMO_VAL_MEAS_WAVS                                                   32
#define HMO_VAL_MEAS_CYCS                                                   33
#define HMO_VAL_MEAS_BWID                                                   34
#define HMO_VAL_MEAS_CREST                                                  35

// hmo_rngProtocolType
#define HMO_VAL_PTYPE_PARALLEL                                              0
#define HMO_VAL_PTYPE_CPARALLEL                                             1
#define HMO_VAL_PTYPE_I2C                                                   2
#define HMO_VAL_PTYPE_SPI                                                   3
#define HMO_VAL_PTYPE_SSPI                                                  4
#define HMO_VAL_PTYPE_UART                                                  5
#define HMO_VAL_PTYPE_CAN                                                   6
#define HMO_VAL_PTYPE_LIN                                                   7

// hmo_rngProtocolFormat
#define HMO_VAL_PFORMAT_ASCI                                                0
#define HMO_VAL_PFORMAT_HEX                                                 1
#define HMO_VAL_PFORMAT_BIN                                                 2
#define HMO_VAL_PFORMAT_DEC                                                 3
#define HMO_VAL_PFORMAT_OCT                                                 4

// hmo_rngProtocolHeight
#define HMO_VAL_PHEIGHT_SMALL                                               0
#define HMO_VAL_PHEIGHT_MEDIUM                                              1
#define HMO_VAL_PHEIGHT_LARGE                                               2

// hmo_rngRelativeMode
#define HMO_VAL_MEAS_RELATIVE_TEN                                           0
#define HMO_VAL_MEAS_RELATIVE_TWENTY                                        1

// hmo_rngChannelPolarity
#define HMO_VAL_POLARITY_NORM                                               0
#define HMO_VAL_POLARITY_INV                                                1

// hmo_rngExternalTriggerCoupling
#define HMO_VAL_COUPLING_AC                                                 0
#define HMO_VAL_COUPLING_DC                                                 1

// hmo_rngMeasCategory
#define HMO_VAL_MEAS_AMPT                                                   0

// hmo_rngSearchCondition
#define HMO_VAL_SEARCHCOND_EDGE                                             0
#define HMO_VAL_SEARCHCOND_WIDTH                                            1
#define HMO_VAL_SEARCHCOND_PEAK                                             2
#define HMO_VAL_SEARCHCOND_RUNT                                             3
#define HMO_VAL_SEARCHCOND_RTIME                                            4
#define HMO_VAL_SEARCHCOND_DAT                                              5
#define HMO_VAL_SEARCHCOND_PATT                                             6
#define HMO_VAL_SEARCHCOND_PROT                                             7

// hmo_rngSearchSource
#define HMO_VAL_MEASUREMENT_SOURCE_CH1                                      1
#define HMO_VAL_MEASUREMENT_SOURCE_CH2                                      2
#define HMO_VAL_MEASUREMENT_SOURCE_CH3                                      3
#define HMO_VAL_MEASUREMENT_SOURCE_CH4                                      4
#define HMO_VAL_MEASUREMENT_SOURCE_M1                                       5
#define HMO_VAL_MEASUREMENT_SOURCE_M2                                       6
#define HMO_VAL_MEASUREMENT_SOURCE_M3                                       7
#define HMO_VAL_MEASUREMENT_SOURCE_M4                                       8
#define HMO_VAL_MEASUREMENT_SOURCE_M5                                       9
#define HMO_VAL_MEASUREMENT_SOURCE_R1                                       10
#define HMO_VAL_MEASUREMENT_SOURCE_R2                                       11
#define HMO_VAL_MEASUREMENT_SOURCE_R3                                       12
#define HMO_VAL_MEASUREMENT_SOURCE_R4                                       13
#define HMO_VAL_MEASUREMENT_SOURCE_QMA                                      14

// hmo_rngScalingUnit
#define HMO_VAL_FFT_LIN                                                     0
#define HMO_VAL_FFT_DBM                                                     1
#define HMO_VAL_FFT_DBV                                                     2

// hmo_rngAcquisitionState
#define HMO_VAL_ACQUISITION_RUN                                             0
#define HMO_VAL_ACQUISITION_STOP                                            1
#define HMO_VAL_ACQUISITION_COMPLETE                                        2
#define HMO_VAL_ACQUISITION_BREAK                                           3

// hmo_rngAcquisitionMode
#define HMO_VAL_ACQUISITION_REFRESH                                         0
#define HMO_VAL_ACQUISITION_ROLL                                            1
#define HMO_VAL_ACQUISITION_ENVELOPE                                        2
#define HMO_VAL_ACQUISITION_AVERAGE                                         3
#define HMO_VAL_ACQUISITION_FILTER                                          4

// hmo_rngComponentTestFrequency
#define HMO_VAL_COMPONENT_TEST_FREQUENCY_50                                 0
#define HMO_VAL_COMPONENT_TEST_FREQUENCY_200                                1

// hmo_rngLogicChannelSize
#define HMO_VAL_LOGIC_CHANNEL_SIZE_SMALL                                    0
#define HMO_VAL_LOGIC_CHANNEL_SIZE_MEDIUM                                   1
#define HMO_VAL_LOGIC_CHANNEL_SIZE_LARGE                                    2

// hmo_rngPodThreshold
#define HMO_VAL_POD_THRESHOLD_TTL                                           0
#define HMO_VAL_POD_THRESHOLD_ECL                                           1
#define HMO_VAL_POD_THRESHOLD_CMOS                                          2
#define HMO_VAL_POD_THRESHOLD_USER_1                                        3
#define HMO_VAL_POD_THRESHOLD_USER_2                                        4

// hmo_rngBusSignalSource
#define HMO_VAL_BUS_SIGNAL_SOURCE_FUNCTION_SQUARE                           0
#define HMO_VAL_BUS_SIGNAL_SOURCE_FUNCTION_RANDOM                           1
#define HMO_VAL_BUS_SIGNAL_SOURCE_FUNCTION_I2C                              2
#define HMO_VAL_BUS_SIGNAL_SOURCE_FUNCTION_SPI                              3
#define HMO_VAL_BUS_SIGNAL_SOURCE_FUNCTION_COUNT                            4
#define HMO_VAL_BUS_SIGNAL_SOURCE_FUNCTION_UART                             5

// hmo_rngTriggerPatternPointState
#define HMO_VAL_FALSE                                                       0
#define HMO_VAL_TRUE                                                        1

// hmo_rngPatternMode
#define HMO_VAL_PATTERN_OFF                                                 0
#define HMO_VAL_PATTERN_TIMEOUT                                             1
#define HMO_VAL_PATTERN_WIDTH                                               2

// hmo_rngProtocolCANLineType
#define HMO_VAL_CAN_LOW                                                     0
#define HMO_VAL_CAN_HIGH                                                    1

// hmo_rngProtocolCANTriggerMode
#define HMO_VAL_CAN_FRAME_START                                             0
#define HMO_VAL_CAN_FRAME_END                                               1
#define HMO_VAL_CAN_MSG_ID                                                  2
#define HMO_VAL_CAN_MSG_IDDT                                                3
#define HMO_VAL_CAN_FRAME_TYPE                                              4
#define HMO_VAL_CAN_ERROR_COND                                              5

// hmo_rngCANFrameType
#define HMO_VAL_CAN_FRAME_TYPE_DATA                                         0
#define HMO_VAL_CAN_FRAME_TYPE_REMOTE                                       1
#define HMO_VAL_CAN_FRAME_TYPE_ERROR                                        2
#define HMO_VAL_CAN_FRAME_TYPE_OVER_LOAD                                    3
#define HMO_VAL_CAN_FRAME_TYPE_ANY                                          4

// hmo_rngCANTriggerIDType
#define HMO_VAL_CAN_ID_TYPE_B11                                             0
#define HMO_VAL_CAN_ID_TYPE_B29                                             1
#define HMO_VAL_CAN_ID_TYPE_ANY                                             2

// hmo_rngProtocolCondition
#define HMO_VAL_COND_NQ                                                     0
#define HMO_VAL_COND_EQ                                                     1
#define HMO_VAL_COND_LT                                                     2
#define HMO_VAL_COND_GT                                                     3

// hmo_rngProtocolLINStandard
#define HMO_VAL_LIN_STANDARD_AUTO                                           0
#define HMO_VAL_LIN_STANDARD_1X                                             1
#define HMO_VAL_LIN_STANDARD_2X                                             2
#define HMO_VAL_LIN_STANDARD_J2602                                          3

// hmo_rngLINTriggerMode
#define HMO_VAL_LIN_FRAME_SYNC                                              0
#define HMO_VAL_LIN_FRAME_ID                                                1
#define HMO_VAL_LIN_FRAME_ID_DATA                                           2
#define HMO_VAL_LIN_FRAME_WAKEUP                                            3
#define HMO_VAL_LIN_ERR_COND                                                4

// hmo_rngQuickmathOperation
#define HMO_VAL_ADD                                                         0
#define HMO_VAL_SUB                                                         1
#define HMO_VAL_MUL                                                         2
#define HMO_VAL_DIV                                                         3

// hmo_rngPodRange
#define HMO_VAL_POD_RANGE_DEFAULT                                           0
#define HMO_VAL_POD_RANGE_MAXIMUM                                           1
#define HMO_VAL_POD_RANGE_DISPLAY_MAX                                       2

// hmo_rngPeakDetection
#define HMO_VAL_AUTO                                                        1

// hmo_rngProtocolI2CAddressMode
#define HMO_VAL_ADDRESS_MODE_ARWRITE                                        0
#define HMO_VAL_ADDRESS_MODE_AONLY                                          1

// hmo_rngChannelThresholdHysteresis
#define HMO_VAL_TRESHOLD_HYSTERESIS_SMALL                                   0
#define HMO_VAL_TRESHOLD_HYSTERESIS_MEDIUM                                  1
#define HMO_VAL_TRESHOLD_HYSTERESIS_LARGE                                   2

// hmo_rngWaveformAcquisitionType
#define HMO_VAL_FILTER                                                      3

// hmo_rngWaveformSampleRange
#define HMO_VAL_SAMPLE_RANGE_DEFAULT                                        0
#define HMO_VAL_SAMPLE_RANGE_MAXIMUM                                        1
#define HMO_VAL_SAMPLE_RANGE_DMAXIMUM                                       2

// hmo_rngHistoryChannelPlayerState
#define HMO_VAL_HISTORY_PLAYER_STOP                                         0
#define HMO_VAL_HISTORY_PLAYER_RUN                                          1

// hmo_rngHistoryChannelPlayerSpeed
#define HMO_VAL_HISTORY_PLAYER_SPEED_SLOW                                   0
#define HMO_VAL_HISTORY_PLAYER_SPEED_MEDIUM                                 1
#define HMO_VAL_HISTORY_PLAYER_SPEED_FAST                                   2
#define HMO_VAL_HISTORY_PLAYER_SPEED_AUTO                                   3

// hmo_rngMaskEventMode
#define HMO_VAL_MASK_EVENT_MODE_OFF                                         0
#define HMO_VAL_MASK_EVENT_MODE_EACH                                        1

// hmo_rngProbeUnit
#define HMO_VAL_PROBE_UNIT_V                                                0
#define HMO_VAL_PROBE_UNIT_A                                                1

// hmo_rngDVMPosition
#define HMO_VAL_DVM_POSITION_TLEFT                                          0
#define HMO_VAL_DVM_POSITION_TRIGHT                                         1
#define HMO_VAL_DVM_POSITION_BLEFT                                          2
#define HMO_VAL_DVM_POSITION_BRIGHT                                         3

// hmo_rngPodType
#define HMO_VAL_POD_TYPE_SAMPLE                                             0
#define HMO_VAL_POD_TYPE_PDETECT                                            1

// hmo_rngData2ClockSource
#define HMO_VAL_MEASUREMENT_SOURCE_MA1                                      5
#define HMO_VAL_MEASUREMENT_SOURCE_MA2                                      6
#define HMO_VAL_MEASUREMENT_SOURCE_MA3                                      7
#define HMO_VAL_MEASUREMENT_SOURCE_MA4                                      8
#define HMO_VAL_MEASUREMENT_SOURCE_MA5                                      9
#define HMO_VAL_MEASUREMENT_SOURCE_RE1                                      10
#define HMO_VAL_MEASUREMENT_SOURCE_RE2                                      11
#define HMO_VAL_MEASUREMENT_SOURCE_RE3                                      12
#define HMO_VAL_MEASUREMENT_SOURCE_RE4                                      13

// hmo_rngSearchTriggerPatternCombination
#define HMO_VAL_PATTERN_COMBINATION_AND                                     0
#define HMO_VAL_PATTERN_COMBINATION_OR                                      1
#define HMO_VAL_PATTERN_COMBINATION_NAND                                    2
#define HMO_VAL_PATTERN_COMBINATION_NOR                                     3

// hmo_rngSearchLINCondition
#define HMO_VAL_SEARCH_LIN_CONDITION_FRAME                                  0
#define HMO_VAL_SEARCH_LIN_CONDITION_ERROR                                  1
#define HMO_VAL_SEARCH_LIN_CONDITION_IDENTIFIER                             2
#define HMO_VAL_SEARCH_LIN_CONDITION_ID_DATA                                3
#define HMO_VAL_SEARCH_LIN_CONDITION_ID_ERROR                               4

// hmo_rngSearchLINFrame
#define HMO_VAL_SEARCH_LIN_FRAME_SOF                                        0
#define HMO_VAL_SEARCH_LIN_FRAME_WAKEUP                                     1

// hmo_rngSearchCANCondition
#define HMO_VAL_SEARCH_CAN_CONDITION_FRAME                                  0
#define HMO_VAL_SEARCH_CAN_CONDITION_ERROR                                  1
#define HMO_VAL_SEARCH_CAN_CONDITION_IDENTIFIER                             2
#define HMO_VAL_SEARCH_CAN_CONDITION_ID_DATA                                3
#define HMO_VAL_SEARCH_CAN_CONDITION_ID_ERROR                               4

// hmo_rngSearchCANFrame
#define HMO_VAL_SEARCH_CAN_FRAME_SOF                                        0
#define HMO_VAL_SEARCH_CAN_FRAME_EOF                                        1
#define HMO_VAL_SEARCH_CAN_FRAME_OVERLOAD                                   2
#define HMO_VAL_SEARCH_CAN_FRAME_ERROR                                      3
#define HMO_VAL_SEARCH_CAN_FRAME_DTA11                                      4
#define HMO_VAL_SEARCH_CAN_FRAME_DTA29                                      5
#define HMO_VAL_SEARCH_CAN_FRAME_REM11                                      6
#define HMO_VAL_SEARCH_CAN_FRAME_REM29                                      7

// hmo_rngSearchCANIDType
#define HMO_VAL_SEARCH_CAN_ID_TYPE_B11                                      0
#define HMO_VAL_SEARCH_CAN_ID_TYPE_B29                                      1
#define HMO_VAL_SEARCH_CAN_ID_TYPE_ANY                                      2

// hmo_rngSearchCANFrameType
#define HMO_VAL_SEARCH_CAN_FRAME_TYPE_DATA                                  0
#define HMO_VAL_SEARCH_CAN_FRAME_TYPE_REMOTE                                1
#define HMO_VAL_SEARCH_CAN_FRAME_TYPE_ANY                                   2

// hmo_rngHardcopyCommandSet
#define HMO_VAL_COMMAND_SET_PCL5                                            0
#define HMO_VAL_COMMAND_SET_PCLXL                                           1
#define HMO_VAL_COMMAND_SET_PS                                              2

// hmo_rngTriggerHoldoffMode
#define HMO_VAL_HOLDOFF_MODE_OFF                                            0
#define HMO_VAL_HOLDOFF_MODE_TIME                                           1

// hmo_rngTriggerOutMode
#define HMO_VAL_TRIGGER_OUT_MODE_OFF                                        0
#define HMO_VAL_TRIGGER_OUT_MODE_TRIG                                       1
#define HMO_VAL_TRIGGER_OUT_MODE_MASK                                       2

// hmo_rngGeneratorFunction
#define HMO_VAL_GENERATOR_FUNCTION_DC                                       0
#define HMO_VAL_GENERATOR_FUNCTION_SINUSOID                                 1
#define HMO_VAL_GENERATOR_FUNCTION_SQUARE                                   2
#define HMO_VAL_GENERATOR_FUNCTION_PULSE                                    3
#define HMO_VAL_GENERATOR_FUNCTION_TRIANGLE                                 4
#define HMO_VAL_GENERATOR_FUNCTION_RAMP                                     5

// hmo_rngPatternGeneratorFunction
#define HMO_VAL_PATTERN_GENERATOR_FUNCTION_SQUAREWAVE                       0
#define HMO_VAL_PATTERN_GENERATOR_FUNCTION_COUNTER                          1
#define HMO_VAL_PATTERN_GENERATOR_FUNCTION_ARBITRARY                        2
#define HMO_VAL_PATTERN_GENERATOR_FUNCTION_SPI                              3
#define HMO_VAL_PATTERN_GENERATOR_FUNCTION_I2C                              4
#define HMO_VAL_PATTERN_GENERATOR_FUNCTION_UART                             5
#define HMO_VAL_PATTERN_GENERATOR_FUNCTION_CAN                              6
#define HMO_VAL_PATTERN_GENERATOR_FUNCTION_LIN                              7
#define HMO_VAL_PATTERN_GENERATOR_FUNCTION_MANUAL                           8

// hmo_rngPatternGeneratorTriggerMode
#define HMO_VAL_PGEN_TRIGGER_MODE_CONTINUOUS                                0
#define HMO_VAL_PGEN_TRIGGER_MODE_SINGLE                                    1
#define HMO_VAL_PGEN_TRIGGER_MODE_EXTERNAL                                  2

// hmo_rngPatternGeneratorExternalSlope
#define HMO_VAL_PGEN_SLOPE_POSITIVE                                         0
#define HMO_VAL_PGEN_SLOPE_NEGATIVE                                         1
#define HMO_VAL_PGEN_SLOPE_EITHER                                           2

// hmo_rngPatternGeneratorCountDirection
#define HMO_VAL_DIRECTION_UPWARD                                            0
#define HMO_VAL_DIRECTION_DOWNWARD                                          1

// hmo_rngPatternGeneratorSquareWavePolarity
#define HMO_VAL_SW_POLARITY_NORMAL                                          0
#define HMO_VAL_SW_POLARITY_INVERTED                                        1

// hmo_rngSelfAlignmentState
#define HMO_VAL_SELF_ALIGNMENT_NO_ALIGNMENT                                 0
#define HMO_VAL_SELF_ALIGNMENT_RUN                                          1
#define HMO_VAL_SELF_ALIGNMENT_ERROR                                        2
#define HMO_VAL_SELF_ALIGNMENT_OK                                           3
#define HMO_VAL_SELF_ALIGNMENT_ABORT                                        4

// hmo_rngDVMType
#define HMO_VAL_DVM_TYPE_OFF                                                0
#define HMO_VAL_DVM_TYPE_DC                                                 1
#define HMO_VAL_DVM_TYPE_ACDC                                               2
#define HMO_VAL_DVM_TYPE_ACRMS                                              3
#define HMO_VAL_DVM_TYPE_UPE                                                4
#define HMO_VAL_DVM_TYPE_LPE                                                5
#define HMO_VAL_DVM_TYPE_PEAK                                               6
#define HMO_VAL_DVM_TYPE_CRES                                               7
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define HMO_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define HMO_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define HMO_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define HMO_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *---------------- Constant definition  ------------------------------------*
 ****************************************************************************/
#define HMO_VAL_CHANNEL_1   1
#define HMO_VAL_CHANNEL_2   2
#define HMO_VAL_CHANNEL_3   3
#define HMO_VAL_CHANNEL_4   4
#define HMO_VAL_CHANNEL_EXT 5

#define HMO_VAL_TRIGGER_A 0
#define HMO_VAL_TRIGGER_B 1
    
#define HMO_VAL_BUS_1 1
#define HMO_VAL_BUS_2 2

#define HMO_VAL_TRIGGER_FILTER_LOW  0
#define HMO_VAL_TRIGGER_FILTER_HIGH 1
    
#define HMO_VAL_DISPLAY_BACKGROUND 0
#define HMO_VAL_DISPLAY_GRID       1
#define HMO_VAL_DISPLAY_WAVEFORM   2

#define HMO_VAL_MARKER_ACTION_SET    0
#define HMO_VAL_MARKER_ACTION_NEXT   1
#define HMO_VAL_MARKER_ACTION_PREV   2
#define HMO_VAL_MARKER_ACTION_CLEAR  3
#define HMO_VAL_MARKER_ACTION_ACLEAR 4

#define HMO_VAL_MEASUREMENT_1 1
#define HMO_VAL_MEASUREMENT_2 2
#define HMO_VAL_MEASUREMENT_3 3
#define HMO_VAL_MEASUREMENT_4 4
#define HMO_VAL_MEASUREMENT_5 5
#define HMO_VAL_MEASUREMENT_6 6
#define HMO_VAL_MEASUREMENT_7 7
#define HMO_VAL_MEASUREMENT_8 8

#define HMO_VAL_MEASUREMENT_SOURCE_NONE 0
#define HMO_VAL_MEASUREMENT_SOURCE_D0   15
#define HMO_VAL_MEASUREMENT_SOURCE_D1   16
#define HMO_VAL_MEASUREMENT_SOURCE_D2   17
#define HMO_VAL_MEASUREMENT_SOURCE_D3   18
#define HMO_VAL_MEASUREMENT_SOURCE_D4   19
#define HMO_VAL_MEASUREMENT_SOURCE_D5   20
#define HMO_VAL_MEASUREMENT_SOURCE_D6   21
#define HMO_VAL_MEASUREMENT_SOURCE_D7   22
#define HMO_VAL_MEASUREMENT_SOURCE_D8   23
#define HMO_VAL_MEASUREMENT_SOURCE_D9   24
#define HMO_VAL_MEASUREMENT_SOURCE_D10  25
#define HMO_VAL_MEASUREMENT_SOURCE_D11  26
#define HMO_VAL_MEASUREMENT_SOURCE_D12  27
#define HMO_VAL_MEASUREMENT_SOURCE_D13  28
#define HMO_VAL_MEASUREMENT_SOURCE_D14  29
#define HMO_VAL_MEASUREMENT_SOURCE_D15  30

#define HMO_VAL_CURSOR_1 1
#define HMO_VAL_CURSOR_2 2
#define HMO_VAL_CURSOR_3 3

#define HMO_VAL_I2C_SCL       0
#define HMO_VAL_I2C_SDA       1

#define HMO_VAL_SPI_CLOCK  0
#define HMO_VAL_SPI_DATA   1
#define HMO_VAL_SPI_CSEL   2

#define HMO_VAL_PARALLEL_BIT0 0
#define HMO_VAL_PARALLEL_BIT1 1
#define HMO_VAL_PARALLEL_BIT2 2
#define HMO_VAL_PARALLEL_BIT3 3

#define HMO_VAL_WAV_LOAD      0
#define HMO_VAL_WAV_LOAD_CFG  1
#define HMO_VAL_WAV_SAVE      2

#define HMO_VAL_REF_WAVEFORM_1 1
#define HMO_VAL_REF_WAVEFORM_2 2
#define HMO_VAL_REF_WAVEFORM_3 3
#define HMO_VAL_REF_WAVEFORM_4 4

#define HMO_VAL_INIT_SINGLE     0
#define HMO_VAL_INIT_CONTINUOUS 1
#define HMO_VAL_INIT_SINGLE_AND_WAIT 2
    
#define HMO_VAL_FILE_COPY    0
#define HMO_VAL_FILE_MOVE    1
#define HMO_VAL_FILE_DELETE  2
#define HMO_VAL_FILE_NEW_DIR 3
#define HMO_VAL_FILE_CDIR    4
#define HMO_VAL_FILE_RDIR    5
#define HMO_VAL_FILE_CDRIVE  6

#define HMO_VAL_REG_OPER 0
#define HMO_VAL_REG_QUES 1

#define HMO_VAL_REG_NONE     0
#define HMO_VAL_REG_COV      1
#define HMO_VAL_REG_LIM      2
#define HMO_VAL_REG_MASK     3
#define HMO_VAL_REG_NO_ALIGN 4


#define HMO_VAL_REG_COND   0
#define HMO_VAL_REG_ENABLE 1
#define HMO_VAL_REG_EVENT  2
#define HMO_VAL_REG_NTR    3
#define HMO_VAL_REG_PTR    4
    
#define HMO_VAL_MEM_SAVE    0
#define HMO_VAL_MEM_RECALL  1
    
#define HMO_VAL_MEAS_SLOPE_POS 0
#define HMO_VAL_MEAS_SLOPE_NEG 1

#define HMO_VAL_POD_1 1
#define HMO_VAL_POD_2 2

#define HMO_VAL_CAN_FIELD_DLC         0
#define HMO_VAL_CAN_FIELD_CHECKSUM    1
#define HMO_VAL_CAN_FIELD_ACKNOWLEDGE 2

#define HMO_VAL_LIN_FIELD_SYNC   0
#define HMO_VAL_LIN_FIELD_CHKSUM 1

#define HMO_VAL_AUTOMATIC_MEASUREMENT_AVERAGE   0
#define HMO_VAL_AUTOMATIC_MEASUREMENT_DEVIATION 1
#define HMO_VAL_AUTOMATIC_MEASUREMENT_MINIMUM   2
#define HMO_VAL_AUTOMATIC_MEASUREMENT_MAXIMUM   3

#define HMO_VAL_DIALOG_SHOW  0
#define HMO_VAL_DIALOG_CLOSE 1

#define HMO_VAL_CURSOR_POSITION_AUTOSET 0
#define HMO_VAL_CURSOR_POSITION_RESET   1

#define HMO_VAL_CURSOR_PEAK_NEXT     0
#define HMO_VAL_CURSOR_PEAK_PREVIOUS 1

#define HMO_VAL_DVM_1   1
#define HMO_VAL_DVM_2   2
#define HMO_VAL_DVM_3   3
#define HMO_VAL_DVM_4   4

#define HMO_VAL_NORMAL 0
#define HMO_VAL_AND    1
#define HMO_VAL_OR     2

#define HMO_VAL_DIGITAL_INPUT_0     0
#define HMO_VAL_DIGITAL_INPUT_1     1
#define HMO_VAL_DIGITAL_INPUT_2     2
#define HMO_VAL_DIGITAL_INPUT_3     3
#define HMO_VAL_DIGITAL_INPUT_4     4
#define HMO_VAL_DIGITAL_INPUT_5     5
#define HMO_VAL_DIGITAL_INPUT_6     6
#define HMO_VAL_DIGITAL_INPUT_7     7

/****************************************************************************
*---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/

ViStatus _VI_FUNC hmo_init (ViRsrc resourceName, ViBoolean IDQuery,
                            ViBoolean resetDevice, ViSession* instrumentHandle);
ViStatus _VI_FUNC hmo_InitWithOptions (ViRsrc resourceName, ViBoolean IDQuery,
                                       ViBoolean resetDevice, ViString optionString,
                                       ViSession* instrumentHandle);
ViStatus _VI_FUNC hmo_Autoset (ViSession instrumentHandle);
ViStatus _VI_FUNC hmo_ConfigureAcquisitionType (ViSession instrumentHandle,
                                                ViInt32 channel,
                                                ViInt32 acquisitionType);
ViStatus _VI_FUNC hmo_ConfigureAcquisitionMode (ViSession instrumentHandle,
                                                ViInt32 acquisitionMode);
ViStatus _VI_FUNC hmo_ConfigureAcquisitionState (ViSession instrumentHandle,
                                                 ViInt32 acquisitionState);
ViStatus _VI_FUNC hmo_ConfigureAcquisitionRecord (ViSession instrumentHandle,
                                                  ViReal64 timePerRecord,
                                                  ViReal64 acquisitionStartTime_Offset);
ViStatus _VI_FUNC hmo_ConfigureTimeBase (ViSession instrumentHandle,
                                         ViReal64 timeScale,
                                         ViReal64 referencePoint);
ViStatus _VI_FUNC hmo_QueryDivisions (ViSession instrumentHandle,
                                      ViInt32* divisions);
ViStatus _VI_FUNC hmo_QuerySampleRate (ViSession instrumentHandle,
                                       ViReal64* sampleRate);
ViStatus _VI_FUNC hmo_QueryAcquisitionTime (ViSession instrumentHandle,
                                            ViReal64* acquisitionTime);
ViStatus _VI_FUNC hmo_ConfigureWaveformAcquisitionRate (ViSession instrumentHandle,
                                                        ViInt32 waveformRate);
ViStatus _VI_FUNC hmo_ConfigureWaveformAcquisitionType (ViSession instrumentHandle,
                                                        ViInt32 arithmetics);
ViStatus _VI_FUNC hmo_QueryADCSampleRate (ViSession instrumentHandle,
                                          ViReal64* ADCSampleRate);
ViStatus _VI_FUNC hmo_ConfigureRecordLength (ViSession instrumentHandle,
                                             ViInt32 recordLength);
ViStatus _VI_FUNC hmo_ConfigureResolutionEnhancement (ViSession instrumentHandle,
                                                      ViInt32 resolutionEnhancement);
ViStatus _VI_FUNC hmo_ConfigureInterpolation (ViSession instrumentHandle,
                                              ViInt32 interpolation);
ViStatus _VI_FUNC hmo_ConfigureFilterFrequency (ViSession instrumentHandle,
                                                ViReal64 filterFrequency);
ViStatus _VI_FUNC hmo_ConfigureWaveformSamplesRange (ViSession instrumentHandle,
                                                     ViInt32 channel,
                                                     ViInt32 sampleRange);
ViStatus _VI_FUNC hmo_QueryWaveformSamplesRange (ViSession instrumentHandle,
                                                 ViInt32 channel, ViInt32* samples);
ViStatus _VI_FUNC hmo_ConfigureNumberOfAverages (ViSession instrumentHandle,
                                                 ViInt32 numberOfAverages);
ViStatus _VI_FUNC hmo_QueryAveragingStatus (ViSession instrumentHandle,
                                            ViBoolean* averagingComplete);
ViStatus _VI_FUNC hmo_ConfigurePeakDetection (ViSession instrumentHandle,
                                              ViInt32 peakDetection);
ViStatus _VI_FUNC hmo_ConfigureHighResolution (ViSession instrumentHandle,
                                               ViInt32 highResolution);
ViStatus _VI_FUNC hmo_ConfigureRollMode (ViSession instrumentHandle,
                                         ViBoolean rollMode);
ViStatus _VI_FUNC hmo_ConfigureSegmentation (ViSession instrumentHandle,
                                             ViBoolean segmentation,
                                             ViInt32 maximumAcquisitionCount);
ViStatus _VI_FUNC hmo_ConfigureChannel (ViSession instrumentHandle, ViInt32 channel,
                                        ViBoolean channelEnabled,
                                        ViReal64 verticalRange,
                                        ViReal64 verticalOffset,
                                        ViInt32 verticalCoupling);
ViStatus _VI_FUNC hmo_ConfigureChannelOffset (ViSession instrumentHandle,
                                              ViInt32 channel, ViReal64 offset);
ViStatus _VI_FUNC hmo_ConfigureChannelVerticalScale (ViSession instrumentHandle,
                                                     ViInt32 channel,
                                                     ViReal64 verticalScale);
ViStatus _VI_FUNC hmo_ConfigureChannelThreshold (ViSession instrumentHandle,
                                                 ViInt32 channel,
                                                 ViReal64 threshold);
ViStatus _VI_FUNC hmo_ConfigureChannelBandwidth (ViSession instrumentHandle,
                                                 ViInt32 channel,
                                                 ViInt32 bandwidth);
ViStatus _VI_FUNC hmo_ConfigureChannelPolarity (ViSession instrumentHandle,
                                                ViInt32 channel, ViInt32 polarity);
ViStatus _VI_FUNC hmo_ConfigureChannelOverload (ViSession instrumentHandle,
                                                ViInt32 channel,
                                                ViBoolean overload);
ViStatus _VI_FUNC hmo_ConfigureChannelSkew (ViSession instrumentHandle,
                                            ViInt32 channel, ViReal64 deskewValue);
ViStatus _VI_FUNC hmo_ConfigureChannelLabel (ViSession instrumentHandle,
                                             ViInt32 channel, ViBoolean labelState,
                                             ViString label);
ViStatus _VI_FUNC hmo_FindChannelThresholdLevel (ViSession instrumentHandle,
                                                 ViInt32 channel);
ViStatus _VI_FUNC hmo_ConfigureChannelThresholdHysteresis
             (ViSession instrumentHandle, ViInt32 channel,
              ViInt32 thresholdHysteresis);
ViStatus _VI_FUNC hmo_QueryProbeCharacteristics (ViSession instrumentHandle,
                                                 ViInt32 channel,
                                                 ViInt32 bufferSize,
                                                 ViChar _VI_FAR type[],
                                                 ViReal64* attenuation);
ViStatus _VI_FUNC hmo_ConfigureProbeAttenuation (ViSession instrumentHandle,
                                                 ViInt32 channel,
                                                 ViInt32 verticalUnit,
                                                 ViReal64 attenuation);
ViStatus _VI_FUNC hmo_ConfigureTrigger (ViSession instrumentHandle, ViInt32 trigger,
                                        ViInt32 triggerType);
ViStatus _VI_FUNC hmo_ConfigureTriggerSource (ViSession instrumentHandle,
                                              ViInt32 trigger, ViInt32 source);
ViStatus _VI_FUNC hmo_ConfigureExternalTriggerCoupling (ViSession instrumentHandle,
                                                        ViInt32 externalCoupling);
ViStatus _VI_FUNC hmo_ConfigureTriggerBState (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC hmo_ConfigureTriggerModifier (ViSession instrumentHandle,
                                                ViInt32 trigger,
                                                ViInt32 triggerModifier);
ViStatus _VI_FUNC hmo_ConfigureTriggerEventCount (ViSession instrumentHandle,
                                                  ViInt32 eventCount);
ViStatus _VI_FUNC hmo_ConfigureTriggerChannelLevel (ViSession instrumentHandle,
                                                    ViInt32 trigger,
                                                    ViInt32 channel,
                                                    ViReal64 triggerLevel);
ViStatus _VI_FUNC hmo_ConfigureTriggerHoldoffTime (ViSession instrumentHandle,
                                                   ViInt32 mode, ViReal64 time);
ViStatus _VI_FUNC hmo_ConfigureEdgeTriggerSource (ViSession instrumentHandle,
                                                  ViInt32 trigger, ViInt32 channel,
                                                  ViInt32 triggerSource,
                                                  ViReal64 triggerLevel,
                                                  ViInt32 triggerSlope);
ViStatus _VI_FUNC hmo_ConfigureEdgeTriggerCoupling (ViSession instrumentHandle,
                                                    ViInt32 coupling);
ViStatus _VI_FUNC hmo_ConfigureEdgeTriggerFilter (ViSession instrumentHandle,
                                                  ViInt32 filterType,
                                                  ViBoolean filterState);
ViStatus _VI_FUNC hmo_ConfigureWidthTriggerSource (ViSession instrumentHandle,
                                                   ViInt32 triggerSource,
                                                   ViReal64 triggerLevel,
                                                   ViReal64 width,
                                                   ViReal64 widthDelta,
                                                   ViInt32 widthPolarity,
                                                   ViInt32 widthCondition);
ViStatus _VI_FUNC hmo_ConfigurePatternTriggerSource (ViSession instrumentHandle,
                                                     ViString patternSource,
                                                     ViInt32 patternFunction,
                                                     ViInt32 patternCondition);
ViStatus _VI_FUNC hmo_ConfigurePatternTriggerMode (ViSession instrumentHandle,
                                                   ViInt32 patternMode,
                                                   ViInt32 timeoutCondition,
                                                   ViReal64 timeout,
                                                   ViInt32 patternCondition,
                                                   ViReal64 patternWidth,
                                                   ViReal64 patternDelta);
ViStatus _VI_FUNC hmo_ConfigureVideoTriggerSource (ViSession instrumentHandle,
                                                   ViInt32 standard,
                                                   ViInt32 polarity, ViInt32 field,
                                                   ViInt32 line);
ViStatus _VI_FUNC hmo_ConfigureRuntTrigger (ViSession instrumentHandle,
                                            ViInt32 polarity, ViInt32 channel,
                                            ViReal64 lowerLevel,
                                            ViReal64 upperLevel);
ViStatus _VI_FUNC hmo_ConfigureTimeTrigger (ViSession instrumentHandle,
                                            ViInt32 slope, ViInt32 range,
                                            ViReal64 time, ViReal64 deltaT);
ViStatus _VI_FUNC hmo_ConfigureTimeTriggerLevel (ViSession instrumentHandle,
                                                 ViInt32 channel,
                                                 ViReal64 lowerLevel,
                                                 ViReal64 upperLevel);
ViStatus _VI_FUNC hmo_ConfigureOutputTrigger (ViSession instrumentHandle,
                                              ViInt32 mode, ViInt32 polarity,
                                              ViReal64 pulseLength);
ViStatus _VI_FUNC hmo_ConfigureTriggerDelay (ViSession instrumentHandle,
                                             ViReal64 delayTime);
ViStatus _VI_FUNC hmo_ConfigureSignalStyle (ViSession instrumentHandle,
                                            ViInt32 style);
ViStatus _VI_FUNC hmo_ConfigureDisplayIntensity (ViSession instrumentHandle,
                                                 ViInt32 element,
                                                 ViReal64 intensity);
ViStatus _VI_FUNC hmo_ConfigureColorAndBrightness (ViSession instrumentHandle,
                                                   ViInt32 palette);
ViStatus _VI_FUNC hmo_ConfigureDisplayGridStyle (ViSession instrumentHandle,
                                                 ViInt32 style);
ViStatus _VI_FUNC hmo_ConfigureDisplayLanguage (ViSession instrumentHandle,
                                                ViInt32 language);
ViStatus _VI_FUNC hmo_DisplayAddLanguage (ViSession instrumentHandle,
                                          ViInt32 language, ViString source);
ViStatus _VI_FUNC hmo_DisplayLanguageCatalog (ViSession instrumentHandle,
                                              ViInt32 bufferSize,
                                              ViChar _VI_FAR languageCatalog[]);
ViStatus _VI_FUNC hmo_DisplayRemoveLanguage (ViSession instrumentHandle,
                                             ViInt32 language);
ViStatus _VI_FUNC hmo_ConfigureDiagramMode (ViSession instrumentHandle,
                                            ViInt32 mode);
ViStatus _VI_FUNC hmo_MarkerSearch (ViSession instrumentHandle,
                                    ViInt32 markerAction);
ViStatus _VI_FUNC hmo_ConfigureVirtualScreen (ViSession instrumentHandle,
                                              ViBoolean state,
                                              ViReal64 virtualScreenPosition);
ViStatus _VI_FUNC hmo_ConfigureDisplayDialog (ViSession instrumentHandle,
                                              ViInt32 mode, ViString text);
ViStatus _VI_FUNC hmo_ConfigurePersistence (ViSession instrumentHandle,
                                            ViBoolean enable, ViBoolean infinite,
                                            ViReal64 time);
ViStatus _VI_FUNC hmo_ClearPersistence (ViSession instrumentHandle);
ViStatus _VI_FUNC hmo_ConfigurePersistenceTimeAuto (ViSession instrumentHandle,
                                                    ViBoolean autoPersist);
ViStatus _VI_FUNC hmo_ConfigureSourceX (ViSession instrumentHandle, ViInt32 source);
ViStatus _VI_FUNC hmo_ConfigureSourceY1 (ViSession instrumentHandle,
                                         ViInt32 source);
ViStatus _VI_FUNC hmo_ConfigureSourceY2 (ViSession instrumentHandle,
                                         ViInt32 source);
ViStatus _VI_FUNC hmo_ConfigureIntensityControl (ViSession instrumentHandle,
                                                 ViInt32 mode);
ViStatus _VI_FUNC hmo_ConfigureSourceIntensity (ViSession instrumentHandle,
                                                ViInt32 source);
ViStatus _VI_FUNC hmo_ConfigureIntensityThreshold (ViSession instrumentHandle,
                                                   ViReal64 threshold);
ViStatus _VI_FUNC hmo_ConfigureZoomWindowState (ViSession instrumentHandle,
                                                ViBoolean zoomEnabled);
ViStatus _VI_FUNC hmo_ConfigureZoomReferencePoint (ViSession instrumentHandle,
                                                   ViReal64 position);
ViStatus _VI_FUNC hmo_ConfigureZoomDiagramTimebase (ViSession instrumentHandle,
                                                    ViReal64 scale);
ViStatus _VI_FUNC hmo_ConfigureZoomOffsetOfTriggerPoint (ViSession instrumentHandle,
                                                         ViReal64 time);
ViStatus _VI_FUNC hmo_ConfigureHistory (ViSession instrumentHandle, ViInt32 channel,
                                        ViInt32 playerState, ViInt32 playerSpeed,
                                        ViBoolean repeat);
ViStatus _VI_FUNC hmo_ConfigureHistoryAcquisitionView (ViSession instrumentHandle,
                                                       ViInt32 channel,
                                                       ViInt32 currentAcquisition);
ViStatus _VI_FUNC hmo_QueryHistoryDateTime (ViSession instrumentHandle,
                                            ViInt32 channel, ViInt32 bufferSize,
                                            ViChar _VI_FAR date[],
                                            ViChar _VI_FAR relativeTime[],
                                            ViChar _VI_FAR absoluteTime[]);
ViStatus _VI_FUNC hmo_QueryHistoryAcquisitionsCount (ViSession instrumentHandle,
                                                     ViInt32* count);
ViStatus _VI_FUNC hmo_ConfigureMeasurement (ViSession instrumentHandle,
                                            ViInt32 measurement,
                                            ViBoolean measurementState);
ViStatus _VI_FUNC hmo_ConfigureMeasurementSource (ViSession instrumentHandle,
                                                  ViInt32 measurement,
                                                  ViInt32 signalSource,
                                                  ViInt32 referenceSource);
ViStatus _VI_FUNC hmo_ConfigureAmplitudeTimeMainMeasurement
             (ViSession instrumentHandle, ViInt32 measurement,
              ViInt32 measurementFunction);
ViStatus _VI_FUNC hmo_QueryMeasurementCategory (ViSession instrumentHandle,
                                                ViInt32 measurement,
                                                ViInt32* category);
ViStatus _VI_FUNC hmo_ConfigureDelayMeasurementSlope (ViSession instrumentHandle,
                                                      ViInt32 measurement,
                                                      ViInt32 source1Slope,
                                                      ViInt32 source2Slope);
ViStatus _VI_FUNC hmo_ConfigureReferenceLevelMode (ViSession instrumentHandle,
                                                   ViInt32 relativeMode);
ViStatus _VI_FUNC hmo_ConfigureCursor (ViSession instrumentHandle,
                                       ViBoolean cursorState, ViInt32 source,
                                       ViInt32 type);
ViStatus _VI_FUNC hmo_AllCursorsOff (ViSession instrumentHandle);
ViStatus _VI_FUNC hmo_SetCursorPosition (ViSession instrumentHandle,
                                         ViInt32 position);
ViStatus _VI_FUNC hmo_ConfigureCursorPosition (ViSession instrumentHandle,
                                               ViInt32 cursor, ViReal64 xPosition,
                                               ViReal64 yPosition);
ViStatus _VI_FUNC hmo_ConfigureCursorCoupling (ViSession instrumentHandle,
                                               ViBoolean xCoupling,
                                               ViBoolean yCoupling);
ViStatus _VI_FUNC hmo_ConfigureCursorWaveformTracking (ViSession instrumentHandle,
                                                       ViBoolean tracking);
ViStatus _VI_FUNC hmo_ConfigureCursorAdjustment (ViSession instrumentHandle,
                                                 ViBoolean adjustment);
ViStatus _VI_FUNC hmo_ConfigureCursorRatioMeasurementUnit
             (ViSession instrumentHandle, ViInt32 direction,
              ViInt32 measurementUnit);
ViStatus _VI_FUNC hmo_QueryCursorRatioMeasurement (ViSession instrumentHandle,
                                                   ViInt32 direction,
                                                   ViReal64* ratioMeasurement);
ViStatus _VI_FUNC hmo_QueryCursorDistance (ViSession instrumentHandle,
                                           ViInt32 direction,
                                           ViReal64* cursorDistance);
ViStatus _VI_FUNC hmo_QueryCursorInverseDistance (ViSession instrumentHandle,
                                                  ViReal64* cursorDistance);
ViStatus _VI_FUNC hmo_QueryCursorVoltageInverseDistance (ViSession instrumentHandle,
                                                         ViReal64* cursorDistance);
ViStatus _VI_FUNC hmo_QueryCursorPosition (ViSession instrumentHandle,
                                           ViReal64* data);
ViStatus _VI_FUNC hmo_SetFFTAnalysisCursorToPeak (ViSession instrumentHandle,
                                                  ViInt32 cursor, ViInt32 peak);
ViStatus _VI_FUNC hmo_ConfigureQuickMeasurements (ViSession instrumentHandle,
                                                  ViInt32 measurement,
                                                  ViBoolean quickMeasurementsEnabled);
ViStatus _VI_FUNC hmo_QueryQuickMeasurementResults (ViSession instrumentHandle,
                                                    ViInt32 measurement,
                                                    ViInt32 arraySize,
                                                    ViReal64 _VI_FAR results[]);
ViStatus _VI_FUNC hmo_ConfigureAutomaticMeasurement (ViSession instrumentHandle,
                                                     ViInt32 measurement,
                                                     ViBoolean state,
                                                     ViInt32 numberOfWaveforms);
ViStatus _VI_FUNC hmo_ResetAutomaticMeasurement (ViSession instrumentHandle,
                                                 ViInt32 measurement);
ViStatus _VI_FUNC hmo_QueryAutomaticMeasurementNumberOfWaveforms
             (ViSession instrumentHandle, ViInt32 measurement,
              ViInt32* numberOfWaveforms);
ViStatus _VI_FUNC hmo_QueryAutomaticMeasurementResult (ViSession instrumentHandle,
                                                       ViInt32 measurement,
                                                       ViInt32 resultType,
                                                       ViReal64* result);
ViStatus _VI_FUNC hmo_SampleMode (ViSession instrumentHandle, ViInt32* sampleMode);
ViStatus _VI_FUNC hmo_ActualSampleRate (ViSession instrumentHandle,
                                        ViReal64* sampleRate);
ViStatus _VI_FUNC hmo_ConfigureMaskTestEnable (ViSession instrumentHandle,
                                               ViBoolean state);
ViStatus _VI_FUNC hmo_ConfigureMaskTest (ViSession instrumentHandle, ViInt32 source,
                                         ViInt32 action);
ViStatus _VI_FUNC hmo_MaskCopyChannel (ViSession instrumentHandle);
ViStatus _VI_FUNC hmo_MaskLoad (ViSession instrumentHandle, ViString name);
ViStatus _VI_FUNC hmo_MaskStore (ViSession instrumentHandle, ViString name);
ViStatus _VI_FUNC hmo_ConfigureMaskYOutputPulsesEnable (ViSession instrumentHandle,
                                                        ViBoolean state);
ViStatus _VI_FUNC hmo_ConfigureMaskActions (ViSession instrumentHandle,
                                            ViInt32 sound, ViInt32 stop,
                                            ViInt32 stopCount, ViInt32 pulse,
                                            ViInt32 screenshot,
                                            ViString screenshotDestination,
                                            ViInt32 print, ViInt32 trace,
                                            ViString traceDestination);
ViStatus _VI_FUNC hmo_MaskResetTestCounter (ViSession instrumentHandle);
ViStatus _VI_FUNC hmo_ConfigureMaskVerticalOffset (ViSession instrumentHandle,
                                                   ViReal64 yPosition);
ViStatus _VI_FUNC hmo_ConfigureMaskVerticalScaling (ViSession instrumentHandle,
                                                    ViReal64 yStretch);
ViStatus _VI_FUNC hmo_ConfigureMaskVerticalWidth (ViSession instrumentHandle,
                                                  ViReal64 yWidth);
ViStatus _VI_FUNC hmo_ConfigureMaskHorizontalWidth (ViSession instrumentHandle,
                                                    ViReal64 xWidth);
ViStatus _VI_FUNC hmo_QueryMaskAcquisitions (ViSession instrumentHandle,
                                             ViInt32* totalCount);
ViStatus _VI_FUNC hmo_QueryMaskHitCount (ViSession instrumentHandle,
                                         ViInt32* acquistions);
ViStatus _VI_FUNC hmo_ConfigureDecodeState (ViSession instrumentHandle, ViInt32 bus,
                                            ViBoolean state);
ViStatus _VI_FUNC hmo_ConfigureBusProtocol (ViSession instrumentHandle, ViInt32 bus,
                                            ViInt32 protocol);
ViStatus _VI_FUNC hmo_ConfigureProtocolDisplay (ViSession instrumentHandle,
                                                ViInt32 bus, ViInt32 format,
                                                ViInt32 height,
                                                ViBoolean displayLines,
                                                ViReal64 verticalPosition);
ViStatus _VI_FUNC hmo_ConfigureProtocolLabel (ViSession instrumentHandle,
                                              ViInt32 bus, ViBoolean labelState,
                                              ViString label);
ViStatus _VI_FUNC hmo_ConfigureBusSignalSource (ViSession instrumentHandle,
                                                ViInt32 busSignalSourceFunction,
                                                ViReal64 busSignalSourceFrequency);
ViStatus _VI_FUNC hmo_ConfigureI2CSource (ViSession instrumentHandle, ViInt32 bus,
                                          ViInt32 line, ViInt32 waveformSource);
ViStatus _VI_FUNC hmo_ConfigureI2CTriggerSetting (ViSession instrumentHandle,
                                                  ViInt32 access,
                                                  ViInt32 addressLength,
                                                  ViString deviceAddress,
                                                  ViInt32 triggerMode,
                                                  ViInt32 patternLength,
                                                  ViString pattern,
                                                  ViInt32 patternOffset);
ViStatus _VI_FUNC hmo_QueryI2CFrameCount (ViSession instrumentHandle, ViInt32 bus,
                                          ViInt32* count);
ViStatus _VI_FUNC hmo_QueryI2CFrameStatus (ViSession instrumentHandle, ViInt32 bus,
                                           ViInt32 frame, ViInt32* status,
                                           ViReal64* frameStart,
                                           ViReal64* frameStop,
                                           ViInt32* addressType, ViInt32* address,
                                           ViInt32* RWBit, ViInt32* ackBit);
ViStatus _VI_FUNC hmo_QueryI2CFrameSlaveAddress (ViSession instrumentHandle,
                                                 ViInt32 bus, ViInt32 frame,
                                                 ViInt32* address);
ViStatus _VI_FUNC hmo_QueryI2CFrameAddressStartTime (ViSession instrumentHandle,
                                                     ViInt32 bus, ViInt32 frame,
                                                     ViReal64* addressStart);
ViStatus _VI_FUNC hmo_QueryI2CFrameAddressAckBitStart (ViSession instrumentHandle,
                                                       ViInt32 bus, ViInt32 frame,
                                                       ViReal64* ackBitStart);
ViStatus _VI_FUNC hmo_QueryI2CFrameAddressComplete (ViSession instrumentHandle,
                                                    ViInt32 bus, ViInt32 frame,
                                                    ViBoolean* complete);
ViStatus _VI_FUNC hmo_QueryI2CFrameLength (ViSession instrumentHandle, ViInt32 bus,
                                           ViInt32 frame, ViInt32* length);
ViStatus _VI_FUNC hmo_QueryI2CFrameData (ViSession instrumentHandle, ViInt32 bus,
                                         ViInt32 frame, ViInt32 byteNumber,
                                         ViInt32* data, ViInt32* ackBit);
ViStatus _VI_FUNC hmo_QueryI2CFrameAcknowledgeByteStart (ViSession instrumentHandle,
                                                         ViInt32 bus, ViInt32 frame,
                                                         ViInt32 byteNumber,
                                                         ViReal64* startTime);
ViStatus _VI_FUNC hmo_QueryI2CFrameDataByteStart (ViSession instrumentHandle,
                                                  ViInt32 bus, ViInt32 frame,
                                                  ViInt32 byteNumber,
                                                  ViReal64* startTime);
ViStatus _VI_FUNC hmo_QueryI2CFrameDataComplete (ViSession instrumentHandle,
                                                 ViInt32 bus, ViInt32 frame,
                                                 ViInt32 byteNumber,
                                                 ViBoolean* complete);
ViStatus _VI_FUNC hmo_QueryI2CFrameAllData (ViSession instrumentHandle, ViInt32 bus,
                                            ViInt32 frame, ViInt32 arraySize,
                                            ViInt32 _VI_FAR data[],
                                            ViInt32* returnedValues);
ViStatus _VI_FUNC hmo_ConfigureSPISource (ViSession instrumentHandle, ViInt32 bus,
                                          ViInt32 line, ViInt32 waveformSource);
ViStatus _VI_FUNC hmo_ConfigureSPIPolarity (ViSession instrumentHandle, ViInt32 bus,
                                            ViInt32 line, ViInt32 polarity);
ViStatus _VI_FUNC hmo_ConfigureSPIWord (ViSession instrumentHandle, ViInt32 bus,
                                        ViInt32 bitOrder, ViInt32 wordLength);
ViStatus _VI_FUNC hmo_ConfigureSPITriggerType (ViSession instrumentHandle,
                                               ViInt32 mode);
ViStatus _VI_FUNC hmo_ConfigureSPITriggerData (ViSession instrumentHandle,
                                               ViReal64 offset,
                                               ViInt32 bitPatternLength,
                                               ViString bitPattern);
ViStatus _VI_FUNC hmo_ConfigureSSPISource (ViSession instrumentHandle, ViInt32 bus,
                                           ViInt32 line, ViInt32 waveformSource);
ViStatus _VI_FUNC hmo_ConfigureSSPIPolarity (ViSession instrumentHandle,
                                             ViInt32 bus, ViInt32 line,
                                             ViInt32 polarity);
ViStatus _VI_FUNC hmo_ConfigureSSPIPackets (ViSession instrumentHandle, ViInt32 bus,
                                            ViReal64 interframeTime,
                                            ViInt32 bitOrder, ViInt32 wordLength);
ViStatus _VI_FUNC hmo_QuerySPIFrameCount (ViSession instrumentHandle, ViInt32 bus,
                                          ViInt32* count);
ViStatus _VI_FUNC hmo_QuerySPIWordCount (ViSession instrumentHandle, ViInt32 bus,
                                         ViInt32 frame, ViInt32* count);
ViStatus _VI_FUNC hmo_QuerySPIFrameStatus (ViSession instrumentHandle, ViInt32 bus,
                                           ViInt32 frame, ViReal64* frameStart,
                                           ViReal64* frameStop, ViInt32* status);
ViStatus _VI_FUNC hmo_QuerySPIFrameData (ViSession instrumentHandle, ViInt32 bus,
                                         ViInt32 frame, ViInt32 word,
                                         ViReal64* valueStart, ViReal64* valueStop,
                                         ViInt32* MOSIValue, ViInt32* MISOValue);
ViStatus _VI_FUNC hmo_QuerySPIFrameAllData (ViSession instrumentHandle, ViInt32 bus,
                                            ViInt32 frame, ViInt32 arraySize,
                                            ViInt32 _VI_FAR data[],
                                            ViInt32* returnedValues);
ViStatus _VI_FUNC hmo_ConfigureUARTSource (ViSession instrumentHandle, ViInt32 bus,
                                           ViInt32 waveformSource);
ViStatus _VI_FUNC hmo_ConfigureUARTPolarity (ViSession instrumentHandle,
                                             ViInt32 bus, ViInt32 polarity);
ViStatus _VI_FUNC hmo_ConfigureUART (ViSession instrumentHandle, ViInt32 bus,
                                     ViReal64 interframeTime, ViInt32 wordLength,
                                     ViReal64 bitRate, ViInt32 parity,
                                     ViInt32 stopBits);
ViStatus _VI_FUNC hmo_ConfigureUARTTriggerType (ViSession instrumentHandle,
                                                ViInt32 mode);
ViStatus _VI_FUNC hmo_ConfigureUARTTriggerPattern (ViSession instrumentHandle,
                                                   ViString pattern,
                                                   ViInt32 patternLength,
                                                   ViInt32 patternOffset);
ViStatus _VI_FUNC hmo_QueryUARTFrameCount (ViSession instrumentHandle, ViInt32 bus,
                                           ViInt32* count);
ViStatus _VI_FUNC hmo_QueryUARTWordCount (ViSession instrumentHandle, ViInt32 bus,
                                          ViInt32 frame, ViInt32* count);
ViStatus _VI_FUNC hmo_QueryUARTFrameData (ViSession instrumentHandle, ViInt32 bus,
                                          ViInt32 frame, ViInt32 word,
                                          ViInt32* status, ViReal64* start,
                                          ViReal64* stop, ViInt32* value);
ViStatus _VI_FUNC hmo_ConfigureCANSource (ViSession instrumentHandle, ViInt32 bus,
                                          ViInt32 line, ViInt32 waveformSource);
ViStatus _VI_FUNC hmo_ConfigureCANBitRate (ViSession instrumentHandle, ViInt32 bus,
                                           ViReal64 bitRate);
ViStatus _VI_FUNC hmo_ConfigureCANSamplePoint (ViSession instrumentHandle,
                                               ViInt32 bus, ViReal64 samplePoint);
ViStatus _VI_FUNC hmo_ConfigureCANTriggerType (ViSession instrumentHandle,
                                               ViInt32 type, ViInt32 frameType);
ViStatus _VI_FUNC hmo_ConfigureCANTriggerID (ViSession instrumentHandle,
                                             ViInt32 IDType, ViInt32 condition,
                                             ViString identifierPattern);
ViStatus _VI_FUNC hmo_ConfigureCANTriggerData (ViSession instrumentHandle,
                                               ViInt32 condition,
                                               ViInt32 dataLength,
                                               ViString dataPattern);
ViStatus _VI_FUNC hmo_ConfigureCANTriggerErrorConditions (ViSession instrumentHandle,
                                                          ViBoolean CRC,
                                                          ViBoolean stuffing,
                                                          ViBoolean form,
                                                          ViBoolean ack);
ViStatus _VI_FUNC hmo_QueryCANFrameCount (ViSession instrumentHandle, ViInt32 bus,
                                          ViInt32* count);
ViStatus _VI_FUNC hmo_QueryCANFrameStatus (ViSession instrumentHandle, ViInt32 bus,
                                           ViInt32 frame, ViInt32* frameStatus,
                                           ViReal64* frameStart,
                                           ViReal64* frameStop, ViInt32* frameType);
ViStatus _VI_FUNC hmo_QueryCANFrameID (ViSession instrumentHandle, ViInt32 bus,
                                       ViInt32 frame, ViInt32* IDType,
                                       ViInt32* IDValue, ViInt32* statusCode);
ViStatus _VI_FUNC hmo_QueryCANFrameField (ViSession instrumentHandle, ViInt32 bus,
                                          ViInt32 frame, ViInt32 field,
                                          ViInt32* fieldValue,
                                          ViInt32* fieldStatus);
ViStatus _VI_FUNC hmo_QueryCANFrameByteCount (ViSession instrumentHandle,
                                              ViInt32 bus, ViInt32 frame,
                                              ViInt32* byteCount);
ViStatus _VI_FUNC hmo_QueryCANFrameBitStuffingError (ViSession instrumentHandle,
                                                     ViInt32 bus, ViInt32 frame,
                                                     ViReal64* errorPosition);
ViStatus _VI_FUNC hmo_QueryCANFrameData (ViSession instrumentHandle, ViInt32 bus,
                                         ViInt32 frame, ViInt32 byteNumber,
                                         ViInt32* data, ViInt32* statusCode);
ViStatus _VI_FUNC hmo_QueryCANFrameAllData (ViSession instrumentHandle, ViInt32 bus,
                                            ViInt32 frame, ViInt32 arraySize,
                                            ViInt32 _VI_FAR data[],
                                            ViInt32* returnedValues);
ViStatus _VI_FUNC hmo_ConfigureCANSearchCondition (ViSession instrumentHandle,
                                                   ViInt32 condition);
ViStatus _VI_FUNC hmo_ConfigureCANSearchFrame (ViSession instrumentHandle,
                                               ViInt32 frame);
ViStatus _VI_FUNC hmo_ConfigureCANSearchErrorConditions (ViSession instrumentHandle,
                                                         ViBoolean CRC,
                                                         ViBoolean stuffing,
                                                         ViBoolean form,
                                                         ViBoolean ack);
ViStatus _VI_FUNC hmo_ConfigureCANSearchID (ViSession instrumentHandle,
                                            ViInt32 frameType, ViInt32 IDType,
                                            ViInt32 condition,
                                            ViString identifierPattern);
ViStatus _VI_FUNC hmo_ConfigureCANSearchData (ViSession instrumentHandle,
                                              ViInt32 condition, ViInt32 dataLength,
                                              ViString dataPattern);
ViStatus _VI_FUNC hmo_ConfigureLINSource (ViSession instrumentHandle, ViInt32 bus,
                                          ViInt32 waveformSource);
ViStatus _VI_FUNC hmo_ConfigureLINPolarity (ViSession instrumentHandle, ViInt32 bus,
                                            ViInt32 polarity);
ViStatus _VI_FUNC hmo_ConfigureLINStandard (ViSession instrumentHandle, ViInt32 bus,
                                            ViInt32 standard, ViReal64 bitRate);
ViStatus _VI_FUNC hmo_ConfigureLINTriggerType (ViSession instrumentHandle,
                                               ViInt32 type);
ViStatus _VI_FUNC hmo_ConfigureLINTriggerID (ViSession instrumentHandle,
                                             ViInt32 condition,
                                             ViString identifierPattern);
ViStatus _VI_FUNC hmo_ConfigureLINTriggerData (ViSession instrumentHandle,
                                               ViInt32 condition,
                                               ViInt32 dataLength,
                                               ViString dataPattern);
ViStatus _VI_FUNC hmo_ConfigureLINTriggerErrorConditions (ViSession instrumentHandle,
                                                          ViBoolean checksum,
                                                          ViBoolean parityError,
                                                          ViBoolean syncError);
ViStatus _VI_FUNC hmo_QueryLINFrameCount (ViSession instrumentHandle, ViInt32 bus,
                                          ViInt32* count);
ViStatus _VI_FUNC hmo_QueryLINFrameStatus (ViSession instrumentHandle, ViInt32 bus,
                                           ViInt32 frame, ViInt32* frameStatus,
                                           ViReal64* frameStart,
                                           ViReal64* frameStop, ViInt32* version);
ViStatus _VI_FUNC hmo_QueryLINFrameID (ViSession instrumentHandle, ViInt32 bus,
                                       ViInt32 frame, ViInt32* value,
                                       ViInt32* parity, ViInt32* status);
ViStatus _VI_FUNC hmo_QueryLINFrameField (ViSession instrumentHandle, ViInt32 bus,
                                          ViInt32 frame, ViInt32 field,
                                          ViInt32* fieldValue,
                                          ViInt32* fieldStatus);
ViStatus _VI_FUNC hmo_QueryLINFrameByteCount (ViSession instrumentHandle,
                                              ViInt32 bus, ViInt32 frame,
                                              ViInt32* byteCount);
ViStatus _VI_FUNC hmo_QueryLINFrameData (ViSession instrumentHandle, ViInt32 bus,
                                         ViInt32 frame, ViInt32 byteNumber,
                                         ViInt32* data, ViInt32* statusCode);
ViStatus _VI_FUNC hmo_QueryLINFrameAllData (ViSession instrumentHandle, ViInt32 bus,
                                            ViInt32 frame, ViInt32 arraySize,
                                            ViInt32 _VI_FAR data[],
                                            ViInt32* returnedValues);
ViStatus _VI_FUNC hmo_ConfigureLINSearchCondition (ViSession instrumentHandle,
                                                   ViInt32 condition);
ViStatus _VI_FUNC hmo_ConfigureLINSearchFrame (ViSession instrumentHandle,
                                               ViInt32 frame);
ViStatus _VI_FUNC hmo_ConfigureLINSearchErrorConditions (ViSession instrumentHandle,
                                                         ViBoolean checksum,
                                                         ViBoolean IDParityError,
                                                         ViBoolean syncError);
ViStatus _VI_FUNC hmo_ConfigureLINSearchID (ViSession instrumentHandle,
                                            ViInt32 condition,
                                            ViString identifierPattern);
ViStatus _VI_FUNC hmo_ConfigureLINSearchData (ViSession instrumentHandle,
                                              ViInt32 condition, ViInt32 dataLength,
                                              ViString dataPattern);
ViStatus _VI_FUNC hmo_ConfigureParallelSource (ViSession instrumentHandle,
                                               ViInt32 bus, ViInt32 bit,
                                               ViInt32 channel);
ViStatus _VI_FUNC hmo_ConfigureParallelAnalyzedLines (ViSession instrumentHandle,
                                                      ViInt32 bus, ViInt32 line);
ViStatus _VI_FUNC hmo_QueryParallelBusFrameCount (ViSession instrumentHandle,
                                                  ViInt32 bus, ViInt32* count);
ViStatus _VI_FUNC hmo_QueryParallelBusFrameStatus (ViSession instrumentHandle,
                                                   ViInt32 bus, ViInt32 frame,
                                                   ViInt32* frameStatus,
                                                   ViReal64* frameStart,
                                                   ViReal64* frameStop);
ViStatus _VI_FUNC hmo_QueryParallelBusFrameAllData (ViSession instrumentHandle,
                                                    ViInt32 bus, ViInt32 frame,
                                                    ViInt32 arraySize,
                                                    ViInt32 _VI_FAR data[],
                                                    ViInt32* returnedValues);
ViStatus _VI_FUNC hmo_ConfigureParallelClockedDataLine (ViSession instrumentHandle,
                                                        ViInt32 bus, ViInt32 bit,
                                                        ViInt32 channel);
ViStatus _VI_FUNC hmo_ConfigureParallelClockedClockLine (ViSession instrumentHandle,
                                                         ViInt32 bus,
                                                         ViInt32 channel,
                                                         ViInt32 slope);
ViStatus _VI_FUNC hmo_ConfigureParallelClockedChipSelectLine
             (ViSession instrumentHandle, ViInt32 bus, ViInt32 channel,
              ViInt32 polarity);
ViStatus _VI_FUNC hmo_ConfigureParallelClockedAnalyzedLines
             (ViSession instrumentHandle, ViInt32 bus, ViInt32 line);
ViStatus _VI_FUNC hmo_ConfigureSearchState (ViSession instrumentHandle,
                                            ViBoolean state);
ViStatus _VI_FUNC hmo_ConfigureSearchCondition (ViSession instrumentHandle,
                                                ViInt32 action);
ViStatus _VI_FUNC hmo_ConfigureSearchSource (ViSession instrumentHandle,
                                             ViInt32 searchSource);
ViStatus _VI_FUNC hmo_ConfigureEdgeTriggerSearch (ViSession instrumentHandle,
                                                  ViInt32 triggerSlope,
                                                  ViReal64 triggerLevel,
                                                  ViReal64 triggerHystersis);
ViStatus _VI_FUNC hmo_ConfigureWidthTriggerSearch (ViSession instrumentHandle,
                                                   ViReal64 level,
                                                   ViReal64 levelDelta,
                                                   ViReal64 width,
                                                   ViReal64 widthDelta,
                                                   ViInt32 polarity, ViInt32 range);
ViStatus _VI_FUNC hmo_ConfigurePeakTriggerSearch (ViSession instrumentHandle,
                                                  ViInt32 polarity, ViReal64 limit);
ViStatus _VI_FUNC hmo_ConfigureRuntTriggerSearch (ViSession instrumentHandle,
                                                  ViInt32 polarity,
                                                  ViReal64 upperLevel,
                                                  ViReal64 lowerLevel,
                                                  ViInt32 range, ViReal64 width,
                                                  ViReal64 deltaWidth);
ViStatus _VI_FUNC hmo_ConfigureRiseTimeTriggerSearch (ViSession instrumentHandle,
                                                      ViInt32 polarity,
                                                      ViReal64 upperLevel,
                                                      ViReal64 lowerLevel,
                                                      ViInt32 range, ViReal64 time,
                                                      ViReal64 deltaTime);
ViStatus _VI_FUNC hmo_ConfigureData2ClockTriggerSearch (ViSession instrumentHandle,
                                                        ViInt32 clockSource,
                                                        ViReal64 clockLevel,
                                                        ViReal64 clockHysteresis,
                                                        ViReal64 dataLevel,
                                                        ViReal64 dataHysteresis,
                                                        ViInt32 polarity,
                                                        ViReal64 setupTime,
                                                        ViReal64 holdTime);
ViStatus _VI_FUNC hmo_ConfigurePatternTriggerSearch (ViSession instrumentHandle,
                                                     ViInt32 sourceChannel,
                                                     ViReal64 level,
                                                     ViReal64 hysteresis,
                                                     ViString pattern,
                                                     ViInt32 combination,
                                                     ViInt32 comparison,
                                                     ViReal64 width,
                                                     ViReal64 variation);
ViStatus _VI_FUNC hmo_ConfigureShowResultDiagram (ViSession instrumentHandle,
                                                  ViBoolean showResult);
ViStatus _VI_FUNC hmo_QueryNumberOfResults (ViSession instrumentHandle,
                                            ViInt32* numberOfResults);
ViStatus _VI_FUNC hmo_QueryMaxNumberOfStorableResults (ViSession instrumentHandle,
                                                       ViInt32* maxNumberOfStorableResults);
ViStatus _VI_FUNC hmo_QuerySearchResult (ViSession instrumentHandle,
                                         ViInt32 resultNumber, ViReal64* xPosition,
                                         ViReal64* yPosition, ViInt32* resultType,
                                         ViInt32* polarity, ViReal64* voltageWidth);
ViStatus _VI_FUNC hmo_QueryAllSearchResults (ViSession instrumentHandle,
                                             ViInt32 arraySize,
                                             ViReal64 _VI_FAR xPosition[],
                                             ViReal64 _VI_FAR yPosition[],
                                             ViInt32 _VI_FAR resultType[],
                                             ViInt32 _VI_FAR polarity[],
                                             ViReal64 _VI_FAR voltageWidth[],
                                             ViInt32* numberOfResults);
ViStatus _VI_FUNC hmo_ConfigureComponentTest (ViSession instrumentHandle,
                                              ViBoolean state,
                                              ViInt32 sourceFrequency);
ViStatus _VI_FUNC hmo_ConfigureLogicChannel (ViSession instrumentHandle,
                                             ViInt32 channel, ViBoolean state,
                                             ViInt32 size, ViReal64 position);
ViStatus _VI_FUNC hmo_ConfigureLogicChannelLabel (ViSession instrumentHandle,
                                                  ViInt32 channel,
                                                  ViBoolean labelState,
                                                  ViString label);
ViStatus _VI_FUNC hmo_ConfigurePod (ViSession instrumentHandle, ViInt32 pod,
                                    ViBoolean state, ViInt32 threshold,
                                    ViReal64 userDefinedThreshold);
ViStatus _VI_FUNC hmo_ConfigurePodRange (ViSession instrumentHandle, ViInt32 pod,
                                         ViInt32 range);
ViStatus _VI_FUNC hmo_ConfigurePodType (ViSession instrumentHandle, ViInt32 pod,
                                        ViInt32 type);
ViStatus _VI_FUNC hmo_QueryPodValueState (ViSession instrumentHandle, ViInt32 pod,
                                          ViInt32* minimum, ViInt32* maximum);
ViStatus _VI_FUNC hmo_ConfigureDigitalVoltmeter (ViSession instrumentHandle,
                                                 ViInt32 measurementPlace,
                                                 ViBoolean state, ViInt32 source,
                                                 ViInt32 type, ViInt32 position);
ViStatus _VI_FUNC hmo_QueryDigitalVoltmeterResult (ViSession instrumentHandle,
                                                   ViInt32 measurementPlace,
                                                   ViReal64* result,
                                                   ViInt32* status);
ViStatus _VI_FUNC hmo_ConfigureFunctionGenerator (ViSession instrumentHandle,
                                                  ViBoolean generatorOutputState,
                                                  ViInt32 function,
                                                  ViReal64 amplitude,
                                                  ViReal64 DCOffset,
                                                  ViReal64 frequency,
                                                  ViInt32 rampPolarity,
                                                  ViReal64 pulseDutyCycles);
ViStatus _VI_FUNC hmo_ConfigurePatternGenerator (ViSession instrumentHandle,
                                                 ViBoolean patternGeneratorState,
                                                 ViInt32 function);
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorSettings (ViSession instrumentHandle,
                                                         ViReal64 sampleTime,
                                                         ViReal64 period,
                                                         ViReal64 frequency);
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorBurst (ViSession instrumentHandle,
                                                      ViBoolean burstState,
                                                      ViInt32 burstCycles,
                                                      ViReal64 idleTime);
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorTrigger (ViSession instrumentHandle,
                                                        ViInt32 mode,
                                                        ViInt32 externalSlope);
ViStatus _VI_FUNC hmo_SendPatternGeneratorTrigger (ViSession instrumentHandle);
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorArbitraryData
             (ViSession instrumentHandle, ViInt32 dataLength,
              ViInt32 _VI_FAR patternData[]);
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorAppendArbitraryData
             (ViSession instrumentHandle, ViInt32 index, ViInt32 appendType,
              ViInt32 dataLength, ViInt32 _VI_FAR patternData[]);
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorCounter (ViSession instrumentHandle,
                                                        ViReal64 frequency,
                                                        ViInt32 direction);
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorSquareWave
             (ViSession instrumentHandle, ViInt32 polarity, ViReal64 dutyCycle);
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorPinState (ViSession instrumentHandle,
                                                         ViBoolean pinS0,
                                                         ViBoolean pinS1,
                                                         ViBoolean pinS2,
                                                         ViBoolean pinS3);
ViStatus _VI_FUNC hmo_ConfigureHardcopyPrinter (ViSession instrumentHandle,
                                                ViString printerName,
                                                ViInt32 pageOrientation,
                                                ViInt32 scheme, ViInt32 size);
ViStatus _VI_FUNC hmo_ConfigureHardcopyFile (ViSession instrumentHandle,
                                             ViString name, ViInt32 format,
                                             ViInt32 scheme);
ViStatus _VI_FUNC hmo_HardcopyPrint (ViSession instrumentHandle);
ViStatus _VI_FUNC hmo_HardcopyGetPrinterList (ViSession instrumentHandle,
                                              ViInt32 bufferSize,
                                              ViChar _VI_FAR printerList[]);
ViStatus _VI_FUNC hmo_ConfigureHardcopyCommandSet (ViSession instrumentHandle,
                                                   ViInt32 commandSet);
ViStatus _VI_FUNC hmo_SetAttributeViInt32 (ViSession instrumentHandle,
                                           ViString channelName, ViAttr attributeID,
                                           ViInt32 attributeValue);
ViStatus _VI_FUNC hmo_SetAttributeViReal64 (ViSession instrumentHandle,
                                            ViString channelName,
                                            ViAttr attributeID,
                                            ViReal64 attributeValue);
ViStatus _VI_FUNC hmo_SetAttributeViString (ViSession instrumentHandle,
                                            ViString channelName,
                                            ViAttr attributeID,
                                            ViString attributeValue);
ViStatus _VI_FUNC hmo_SetAttributeViBoolean (ViSession instrumentHandle,
                                             ViString channelName,
                                             ViAttr attributeID,
                                             ViBoolean attributeValue);
ViStatus _VI_FUNC hmo_SetAttributeViSession (ViSession instrumentHandle,
                                             ViString channelName,
                                             ViAttr attributeID,
                                             ViSession attributeValue);
ViStatus _VI_FUNC hmo_GetAttributeViInt32 (ViSession instrumentHandle,
                                           ViString channelName, ViAttr attributeID,
                                           ViInt32* attributeValue);
ViStatus _VI_FUNC hmo_GetAttributeViReal64 (ViSession instrumentHandle,
                                            ViString channelName,
                                            ViAttr attributeID,
                                            ViReal64* attributeValue);
ViStatus _VI_FUNC hmo_GetAttributeViString (ViSession instrumentHandle,
                                            ViString channelName,
                                            ViAttr attributeID, ViInt32 bufferSize,
                                            ViChar _VI_FAR attributeValue[]);
ViStatus _VI_FUNC hmo_GetAttributeViBoolean (ViSession instrumentHandle,
                                             ViString channelName,
                                             ViAttr attributeID,
                                             ViBoolean* attributeValue);
ViStatus _VI_FUNC hmo_GetAttributeViSession (ViSession instrumentHandle,
                                             ViString channelName,
                                             ViAttr attributeID,
                                             ViSession* attributeValue);
ViStatus _VI_FUNC hmo_CheckAttributeViInt32 (ViSession instrumentHandle,
                                             ViString channelName,
                                             ViAttr attributeID,
                                             ViInt32 attributeValue);
ViStatus _VI_FUNC hmo_CheckAttributeViReal64 (ViSession instrumentHandle,
                                              ViString channelName,
                                              ViAttr attributeID,
                                              ViReal64 attributeValue);
ViStatus _VI_FUNC hmo_CheckAttributeViString (ViSession instrumentHandle,
                                              ViString channelName,
                                              ViAttr attributeID,
                                              ViString attributeValue);
ViStatus _VI_FUNC hmo_CheckAttributeViBoolean (ViSession instrumentHandle,
                                               ViString channelName,
                                               ViAttr attributeID,
                                               ViBoolean attributeValue);
ViStatus _VI_FUNC hmo_CheckAttributeViSession (ViSession instrumentHandle,
                                               ViString channelName,
                                               ViAttr attributeID,
                                               ViSession attributeValue);
ViStatus _VI_FUNC hmo_GetAttributeRepeatedCapabilityIds (ViSession instrumentHandle,
                                                         ViUInt32 attributeID,
                                                         ViInt32 bufferSize,
                                                         ViChar _VI_FAR repeatedCapabilityId_s[]);
ViStatus _VI_FUNC hmo_GetAttributeRepeatedCapabilityIdNames
             (ViSession instrumentHandle, ViUInt32 attributeID,
              ViString repeatedCapabilityId, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityIdName_s[]);
ViStatus _VI_FUNC hmo_ConfigureMathEnabled (ViSession instrumentHandle,
                                            ViInt32 mathNumber,
                                            ViBoolean mathEnabled);
ViStatus _VI_FUNC hmo_ConfigureMathWaveformPosition (ViSession instrumentHandle,
                                                     ViInt32 mathNumber,
                                                     ViReal64 waveformPosition);
ViStatus _VI_FUNC hmo_ConfigureMathScaling (ViSession instrumentHandle,
                                            ViInt32 mathNumber,
                                            ViReal64 verticalScale);
ViStatus _VI_FUNC hmo_ConfigureMathSetup (ViSession instrumentHandle,
                                          ViInt32 mathNumber,
                                          ViInt32 calculationMethod,
                                          ViString expression);
ViStatus _VI_FUNC hmo_ConfigureMathLabel (ViSession instrumentHandle,
                                          ViInt32 mathNumber, ViBoolean labelState,
                                          ViString label);
ViStatus _VI_FUNC hmo_ConfigureQuickmathEnabled (ViSession instrumentHandle,
                                                 ViBoolean quickmathEnabled);
ViStatus _VI_FUNC hmo_ConfigureQuickmathSource (ViSession instrumentHandle,
                                                ViInt32 source1, ViInt32 source2,
                                                ViInt32 operation);
ViStatus _VI_FUNC hmo_ConfigureQuickmathWaveformPosition (ViSession instrumentHandle,
                                                          ViReal64 waveformPosition);
ViStatus _VI_FUNC hmo_ConfigureQuickmathScaling (ViSession instrumentHandle,
                                                 ViReal64 verticalScale);
ViStatus _VI_FUNC hmo_ConfigureFFTFrequencyCenterSpan (ViSession instrumentHandle,
                                                       ViInt32 mathNumber,
                                                       ViReal64 centerFrequency,
                                                       ViReal64 frequencySpan);
ViStatus _VI_FUNC hmo_ConfigureFFTFrequencySpanFull (ViSession instrumentHandle,
                                                     ViInt32 mathNumber);
ViStatus _VI_FUNC hmo_ConfigureFFTFrequencyStartStop (ViSession instrumentHandle,
                                                      ViInt32 mathNumber,
                                                      ViReal64 startFrequency,
                                                      ViReal64 stopFrequency);
ViStatus _VI_FUNC hmo_ConfigureFFTResolutionBandwidth (ViSession instrumentHandle,
                                                       ViInt32 mathNumber,
                                                       ViBoolean RBWAndSpanCouplingEnabled,
                                                       ViReal64 RBWRatio,
                                                       ViReal64 resolutionBandwidth);
ViStatus _VI_FUNC hmo_QueryFFTAdjustedResolutionBandwidth
             (ViSession instrumentHandle, ViInt32 mathNumber,
              ViReal64* adjustedRBW);
ViStatus _VI_FUNC hmo_ConfigureFFTWindowType (ViSession instrumentHandle,
                                              ViInt32 mathNumber,
                                              ViInt32 windowType);
ViStatus _VI_FUNC hmo_ConfigureFFTAveraging (ViSession instrumentHandle,
                                             ViInt32 mathNumber,
                                             ViInt32 numberOfSpectrums);
ViStatus _VI_FUNC hmo_ConfigureFFTScaling (ViSession instrumentHandle,
                                           ViInt32 mathNumber, ViInt32 scalingUnit,
                                           ViReal64 verticalScale);
ViStatus _VI_FUNC hmo_QueryFFTSampleRate (ViSession instrumentHandle,
                                          ViInt32 mathNumber, ViReal64* sampleRate);
ViStatus _VI_FUNC hmo_ConfigureFFTTimeBase (ViSession instrumentHandle,
                                            ViInt32 mathNumber, ViReal64 width,
                                            ViReal64 position);
ViStatus _VI_FUNC hmo_ConfigureReferenceWaveformSource (ViSession instrumentHandle,
                                                        ViInt32 referenceNumber,
                                                        ViInt32 source);
ViStatus _VI_FUNC hmo_UpdateReferenceWaveformWithSelectedSource
             (ViSession instrumentHandle, ViInt32 referenceNumber);
ViStatus _VI_FUNC hmo_ConfigureReferenceWaveformDisplayState
             (ViSession instrumentHandle, ViInt32 referenceNumber,
              ViBoolean displayEnabled);
ViStatus _VI_FUNC hmo_ReferenceWaveformFileOperations (ViSession instrumentHandle,
                                                       ViInt32 referenceWfm,
                                                       ViInt32 operation,
                                                       ViString fileName);
ViStatus _VI_FUNC hmo_ConfigureReferenceWaveformVerticalScale
             (ViSession instrumentHandle, ViInt32 referenceNumber,
              ViReal64 verticalScale, ViReal64 verticalPosition);
ViStatus _VI_FUNC hmo_ConfigureReferenceWaveformHorizontalScale
             (ViSession instrumentHandle, ViInt32 referenceWfm, ViReal64 scale,
              ViReal64 horizontalPosition);
ViStatus _VI_FUNC hmo_ReferenceReadWaveformCatalog (ViSession instrumentHandle,
                                                    ViInt32 referenceWfm,
                                                    ViInt32 arraySize,
                                                    ViChar _VI_FAR catalog[],
                                                    ViInt32* returnedValues);
ViStatus _VI_FUNC hmo_ReadWaveform (ViSession instrumentHandle, ViInt32 channel,
                                    ViInt32 waveformSize, ViInt32 maximumTime,
                                    ViReal64 _VI_FAR waveformArray[],
                                    ViInt32* actualPoints, ViReal64* initialX,
                                    ViReal64* xIncrement);
ViStatus _VI_FUNC hmo_ReadMainWaveformMeasurement (ViSession instrumentHandle,
                                                   ViInt32 measurement,
                                                   ViInt32 measurementFunction,
                                                   ViInt32 maximumTime,
                                                   ViReal64* measurementResult);
ViStatus _VI_FUNC hmo_InitiateAcquisition (ViSession instrumentHandle,
                                           ViInt32 action);
ViStatus _VI_FUNC hmo_SendSoftwareTrigger (ViSession instrumentHandle,
                                           ViInt32 maximumTime);
ViStatus _VI_FUNC hmo_FetchWaveform (ViSession instrumentHandle, ViInt32 channel,
                                     ViInt32 waveformSize,
                                     ViReal64 _VI_FAR waveformArray[],
                                     ViInt32* actualPoints, ViReal64* initialX,
                                     ViReal64* xIncrement);
ViStatus _VI_FUNC hmo_FetchWaveformInteger (ViSession instrumentHandle,
                                            ViInt32 channel, ViInt32 waveformSize,
                                            ViUInt16 _VI_FAR waveformArray[],
                                            ViInt32* actualPoints,
                                            ViReal64* initialX,
                                            ViReal64* xIncrement);
ViStatus _VI_FUNC hmo_FetchWaveformByte (ViSession instrumentHandle,
                                         ViInt32 channel, ViInt32 waveformSize,
                                         ViByte _VI_FAR waveformArray[],
                                         ViInt32* actualPoints, ViReal64* initialX,
                                         ViReal64* xIncrement);
ViStatus _VI_FUNC hmo_FetchWaveformHeader (ViSession instrumentHandle,
                                           ViInt32 channel, ViReal64* xStart,
                                           ViReal64* xStop, ViInt32* recordLength,
                                           ViInt32* valuesPerSample);
ViStatus _VI_FUNC hmo_FetchWaveformConversionData (ViSession instrumentHandle,
                                                   ViInt32 channel,
                                                   ViReal64* xStart,
                                                   ViReal64* xIncrement,
                                                   ViReal64* yStart,
                                                   ViReal64* yIncrement,
                                                   ViInt32* yResolution);
ViStatus _VI_FUNC hmo_FetchEnvelopeWaveform (ViSession instrumentHandle,
                                             ViInt32 channel, ViInt32 waveformSize,
                                             ViReal64 _VI_FAR waveformArray[],
                                             ViInt32* actualPoints,
                                             ViReal64* initialX,
                                             ViReal64* xIncrement);
ViStatus _VI_FUNC hmo_FetchEnvelopeWaveformHeader (ViSession instrumentHandle,
                                                   ViInt32 channel,
                                                   ViReal64* xStart,
                                                   ViReal64* xStop,
                                                   ViInt32* recordLength,
                                                   ViInt32* valuesPerSample);
ViStatus _VI_FUNC hmo_FetchEnvelopeWaveformConversionData
             (ViSession instrumentHandle, ViInt32 channel, ViReal64* xStart,
              ViReal64* xIncrement, ViReal64* yStart, ViReal64* yIncrement,
              ViInt32* yResolution);
ViStatus _VI_FUNC hmo_FetchMathWaveform (ViSession instrumentHandle,
                                         ViInt32 mathNumber, ViInt32 waveformSize,
                                         ViReal64 _VI_FAR waveformArray[],
                                         ViInt32* actualPoints);
ViStatus _VI_FUNC hmo_FetchMathWaveformHeader (ViSession instrumentHandle,
                                               ViInt32 mathNumber, ViReal64* xStart,
                                               ViReal64* xStop,
                                               ViInt32* recordLength,
                                               ViInt32* valuesPerSample);
ViStatus _VI_FUNC hmo_FetchMathWaveformConversionData (ViSession instrumentHandle,
                                                       ViInt32 mathNumber,
                                                       ViReal64* xStart,
                                                       ViReal64* xIncrement,
                                                       ViReal64* yStart,
                                                       ViReal64* yIncrement,
                                                       ViInt32* yResolution);
ViStatus _VI_FUNC hmo_FetchMathEnvelopeWaveform (ViSession instrumentHandle,
                                                 ViInt32 mathNumber,
                                                 ViInt32 waveformSize,
                                                 ViReal64 _VI_FAR waveformArray[],
                                                 ViInt32* actualPoints);
ViStatus _VI_FUNC hmo_FetchMathEnvelopeWaveformHeader (ViSession instrumentHandle,
                                                       ViInt32 mathNumber,
                                                       ViReal64* xStart,
                                                       ViReal64* xStop,
                                                       ViInt32* recordLength,
                                                       ViInt32* valuesPerSample);
ViStatus _VI_FUNC hmo_FetchMathEnvelopeWaveformConversionData
             (ViSession instrumentHandle, ViInt32 mathNumber, ViReal64* xStart,
              ViReal64* xIncrement, ViReal64* yStart, ViReal64* yIncrement,
              ViInt32* yResolution);
ViStatus _VI_FUNC hmo_FetchQuickmathWaveform (ViSession instrumentHandle,
                                              ViInt32 waveformSize,
                                              ViReal64 _VI_FAR waveformArray[],
                                              ViInt32* actualPoints);
ViStatus _VI_FUNC hmo_FetchQuickmathWaveformHeader (ViSession instrumentHandle,
                                                    ViReal64* xStart,
                                                    ViReal64* xStop,
                                                    ViInt32* recordLength,
                                                    ViInt32* valuesPerSample);
ViStatus _VI_FUNC hmo_FetchQuickmathWaveformConversionData
             (ViSession instrumentHandle, ViReal64* xStart, ViReal64* xIncrement,
              ViReal64* yStart, ViReal64* yIncrement, ViInt32* yResolution);
ViStatus _VI_FUNC hmo_FetchReferenceWaveform (ViSession instrumentHandle,
                                              ViInt32 referenceWfm,
                                              ViInt32 waveformSize,
                                              ViReal64 _VI_FAR waveformArray[],
                                              ViInt32* actualPoints);
ViStatus _VI_FUNC hmo_FetchReferenceWaveformHeader (ViSession instrumentHandle,
                                                    ViInt32 referenceWfm,
                                                    ViReal64* xStart,
                                                    ViReal64* xStop,
                                                    ViInt32* recordLength,
                                                    ViInt32* valuesPerSample);
ViStatus _VI_FUNC hmo_FetchReferenceWaveformConversionData
             (ViSession instrumentHandle, ViInt32 referenceWfm, ViReal64* xStart,
              ViReal64* xIncrement, ViReal64* yStart, ViReal64* yIncrement,
              ViInt32* yResolution);
ViStatus _VI_FUNC hmo_FetchMainWaveformMeasurement (ViSession instrumentHandle,
                                                    ViInt32 measurement,
                                                    ViInt32 measurementFunction,
                                                    ViReal64* measurementResult);
ViStatus _VI_FUNC hmo_FetchPodData (ViSession instrumentHandle, ViInt32 pod,
                                    ViInt32 waveformSize,
                                    ViReal64 _VI_FAR waveformArray[],
                                    ViInt32* actualPoints);
ViStatus _VI_FUNC hmo_FetchPodDataHeader (ViSession instrumentHandle, ViInt32 pod,
                                          ViReal64* xStart, ViReal64* xStop,
                                          ViInt32* numberOfSamples,
                                          ViInt32* valuesPerSample);
ViStatus _VI_FUNC hmo_FetchPodNumberOfSamples (ViSession instrumentHandle,
                                               ViInt32 pod,
                                               ViInt32* numberOfSamples);
ViStatus _VI_FUNC hmo_FetchPodDataConversionData (ViSession instrumentHandle,
                                                  ViInt32 pod, ViReal64* xStart,
                                                  ViReal64* xIncrement,
                                                  ViReal64* yStart,
                                                  ViReal64* yIncrement,
                                                  ViInt32* yResolution);
ViStatus _VI_FUNC hmo_FetchMaskDataWaveform (ViSession instrumentHandle,
                                             ViInt32 waveformSize,
                                             ViReal64 _VI_FAR waveformArray[],
                                             ViInt32* actualPoints);
ViStatus _VI_FUNC hmo_FetchMaskDataWaveformHeader (ViSession instrumentHandle,
                                                   ViReal64* xStart,
                                                   ViReal64* xStop,
                                                   ViInt32* recordLength,
                                                   ViInt32* valuesPerSample);
ViStatus _VI_FUNC hmo_FetchMaskDataWaveformConversionData
             (ViSession instrumentHandle, ViReal64* xStart, ViReal64* xIncrement,
              ViReal64* yStart, ViReal64* yIncrement, ViInt32* yResolution);
ViStatus _VI_FUNC hmo_Abort (ViSession instrumentHandle);
ViStatus _VI_FUNC hmo_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC hmo_self_test (ViSession instrumentHandle,
                                 ViInt16* selfTestResult,
                                 ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC hmo_revision_query (ViSession instrumentHandle,
                                      ViChar _VI_FAR instrumentDriverRevision[],
                                      ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC hmo_error_query (ViSession instrumentHandle, ViInt32* errorCode,
                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC hmo_ErrorList (ViSession instrumentHandle, ViInt32 bufferSize,
                                 ViChar _VI_FAR errors[]);
ViStatus _VI_FUNC hmo_error_message (ViSession instrumentHandle, ViStatus errorCode,
                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC hmo_ConfigureInstrumentName (ViSession instrumentHandle,
                                               ViString name);
ViStatus _VI_FUNC hmo_ResetStatusRegisters (ViSession instrumentHandle);
ViStatus _VI_FUNC hmo_SetStatusRegister (ViSession instrumentHandle,
                                         ViInt32 registerType,
                                         ViInt32 statusRegister,
                                         ViInt32 registerPart,
                                         ViInt32 registerValue);
ViStatus _VI_FUNC hmo_GetStatusRegister (ViSession instrumentHandle,
                                         ViInt32 registerType,
                                         ViInt32 statusRegister,
                                         ViInt32 registerPart,
                                         ViInt32* registerValue);
ViStatus _VI_FUNC hmo_SetVISATimeout (ViSession instrumentHandle,
                                      ViUInt32 VISATimeout);
ViStatus _VI_FUNC hmo_GetVISATimeout (ViSession instrumentHandle,
                                      ViPUInt32 VISATimeout);
ViStatus _VI_FUNC hmo_ConfigureErrorChecking (ViSession instrumentHandle,
                                              ViBoolean optionChecking,
                                              ViBoolean rangeChecking,
                                              ViBoolean statusChecking);
ViStatus _VI_FUNC hmo_ClearStatus (ViSession instrumentHandle);
ViStatus _VI_FUNC hmo_IDQueryResponse (ViSession instrumentHandle,
                                       ViUInt32 bufferSize,
                                       ViChar _VI_FAR IDQueryResponse[]);
ViStatus _VI_FUNC hmo_ProcessAllPreviousCommands (ViSession instrumentHandle);
ViStatus _VI_FUNC hmo_QueryOPC (ViSession instrumentHandle, ViInt32* OPC);
ViStatus _VI_FUNC hmo_GetError (ViSession instrumentHandle, ViStatus* code,
                                ViInt32 bufferSize, ViChar _VI_FAR description[]);
ViStatus _VI_FUNC hmo_ClearError (ViSession instrumentHandle);
ViStatus _VI_FUNC hmo_WriteInstrData (ViSession instrumentHandle,
                                      ViString writeBuffer);
ViStatus _VI_FUNC hmo_ReadInstrData (ViSession instrumentHandle,
                                     ViInt32 numberOfBytesToRead,
                                     ViChar _VI_FAR readBuffer[],
                                     ViUInt32* numBytesRead);
ViStatus _VI_FUNC hmo_QueryViBoolean (ViSession instrumentHandle, ViString command,
                                      ViBoolean* value);
ViStatus _VI_FUNC hmo_QueryViInt32 (ViSession instrumentHandle, ViString command,
                                    ViInt32* value);
ViStatus _VI_FUNC hmo_QueryViReal64 (ViSession instrumentHandle, ViString command,
                                     ViReal64* value);
ViStatus _VI_FUNC hmo_QueryViString (ViSession instrumentHandle, ViString command,
                                     ViInt32 bufferSize, ViChar _VI_FAR value[]);
ViStatus _VI_FUNC hmo_WriteCommandWithOPCSync (ViSession instrumentHandle,
                                               ViString writeBuffer,
                                               ViUInt32 timeout);
ViStatus _VI_FUNC hmo_QueryWithOPCSync (ViSession instrumentHandle,
                                        ViString writeBuffer, ViUInt32 timeout,
                                        ViInt32 bufferSize,
                                        ViChar _VI_FAR readBuffer[],
                                        ViPUInt32 numBytesRead);
ViStatus _VI_FUNC hmo_FileManagerOperations (ViSession instrumentHandle,
                                             ViInt32 operation, ViString source,
                                             ViString destination);
ViStatus _VI_FUNC hmo_FileCount (ViSession instrumentHandle, ViString directory,
                                 ViInt32* numberOfFilesAndFolders);
ViStatus _VI_FUNC hmo_FileDirectoryContent (ViSession instrumentHandle,
                                            ViString directory, ViInt32 bufferSize,
                                            ViChar _VI_FAR output[]);
ViStatus _VI_FUNC hmo_FileSubdirectoriesCount (ViSession instrumentHandle,
                                               ViString directory,
                                               ViInt32* numberOfSubdirectories);
ViStatus _VI_FUNC hmo_FileSubdirectories (ViSession instrumentHandle,
                                          ViString directory, ViInt32 bufferSize,
                                          ViChar _VI_FAR output[]);
ViStatus _VI_FUNC hmo_FileDrives (ViSession instrumentHandle, ViInt32 bufferSize,
                                  ViChar _VI_FAR output[]);
ViStatus _VI_FUNC hmo_ReadToFileFromInstrument (ViSession instrumentHandle,
                                                ViString source,
                                                ViString destination);
ViStatus _VI_FUNC hmo_WriteFromFileToInstrument (ViSession instrumentHandle,
                                                 ViString source,
                                                 ViString destination);
ViStatus _VI_FUNC hmo_DataSetFileOperations (ViSession instrumentHandle,
                                             ViInt32 operation, ViInt32 stateNumber,
                                             ViString path);
ViStatus _VI_FUNC hmo_ConfigureSound (ViSession instrumentHandle,
                                      ViBoolean controlSound,
                                      ViBoolean triggerSound, ViBoolean errorSound);
ViStatus _VI_FUNC hmo_GenerateSound (ViSession instrumentHandle);
ViStatus _VI_FUNC hmo_close (ViSession instrumentHandle);

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __HMO_HEADER */



