/*****************************************************************************
 *  HAMEG HMO Instrument Driver                               
 *  LabWindows/CVI Instrument Driver                                     
 *  Original Release: 2011-10-17                                 
 *  By: Martin Krcmar
 *                                                                           
 *  Modification History:                                                    
 *                                                                           
 *       See ChangeLog
 *                                                                           
 *****************************************************************************/

#include <string.h>
#include <stdio.h>  
#include <stdlib.h>
#include <math.h>
#include "hmo.h"

#include "time.h"
#if (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__))
    #define ANSI
#endif
#ifndef ANSI                /* UNIX compatible */
    #include <sys/timeb.h>
    #include <sys/types.h>
    #include <unistd.h>
    #define Sleep sleep
#else                       /* ANSI compatible */
        #include <windows.h>
#endif
#if defined (_CVI_)
	#include <utility.h>
#endif

ViStatus _VI_FUNC  hmo_RsClose (ViSession vi);

/*****************************************************************************
 *- Value Definition and Range Tables ---------------------------------------*
 *****************************************************************************/
 static ViString protocolI2CFrameStatus_Arr[] = {"INC", "OK", "UNEX", "INS", "ADD", NULL};
 static ViString protocolI2CAddressType_Arr[] = {"BIT7", "BIT10", NULL};
 static ViString protocolI2CRWBit_Arr[] = {"EITH", "READ", "WRIT", "INC", "UNDF", NULL};
 static ViString protocolI2CAckBit_Arr[] = {"EITH", "ACK", "NACK", "INC", NULL};
 static ViString protocolSPIFrameStatus_Arr[] = {"OK", "INCF", "INCL", "INS", NULL};
 static ViString protocolUARTStatus_Arr[] = {"OK", "FRST", "FREN", "FRME", "STER", "SPER", "PRER", "INS", "BRE", NULL};
 static ViString protocolCANFrameStatus_Arr[] = {"OK", "BTST", "CRC", "FORM", "NACK", "INS", NULL};
 static ViString protocolCANFrameType_Arr[] = {"DATA", "REM", "ERR", "OVLDF", NULL};
 static ViString protocolCANIDType_Arr[] = {"B11", "B29", "ANY", NULL};
 static ViString protocolCANFieldStatus_Arr[] = {"OK", "UNDF", NULL};  
 static ViString protocolLINFrameStatus_Arr[] = {"OK", "CHKS", "WAK", "SYER", "INS", "ERR", "LEN", "PRER", "UART", NULL};
 static ViString protocolLINVersion_Arr[] = {"UNK", "V1X", "V2X", "J2602", NULL};
 static ViString protocolLINIDStatus_Arr[] = {"OK", "PRER", "UVAL", "INS", NULL};
 static ViString protocolLINFieldStatus_Arr[] = {"OK", "ERR", "UNDF", NULL};
 static ViString protocolLINDataStatus_Arr[] = {"OK", "INS", "UART", NULL};
 static ViString LanguageArr[] = {"ENGL","GERM","FREN","SPAN","SCH","TCH","RUSS", "JAP", "KOR", NULL};
 static ViString autoMeasTypeArr[] = {"Average","Deviation","Minimum","Maximum",NULL};
 static ViString protocolParallelFrameStatus_Arr[] = {"OK", "ERR", "INS", NULL};
/*****************************************************************************
 *- User-Callable Functions (Exportable Functions) --------------------------*
 *****************************************************************************/

/*****************************************************************************
 * Function: hmo_init
 * Purpose:  VXIplug&play required function. Calls the
 *           hmo_InitWithOptions function.
 *****************************************************************************/
ViStatus _VI_FUNC hmo_init (ViRsrc resourceName, ViBoolean IDQuery,
                                 ViBoolean resetDevice, ViSession *newInstrSession)
{
    ViStatus    error = VI_SUCCESS;

    if (newInstrSession == NULL)
        {
        (void) Rs_SetErrorInfo (0, VI_FALSE, RS_ERROR_INVALID_PARAMETER,
                          VI_ERROR_PARAMETER4, "Null address for Instrument Handle");
        checkErr( RS_ERROR_INVALID_PARAMETER);
        }

    checkErr( hmo_InitWithOptions (resourceName, IDQuery, resetDevice,
                                      "QueryInstrStatus=1", newInstrSession));

Error:
    return error;
}

/*****************************************************************************
 * Function: hmo_InitWithOptions
 * Purpose:  This function creates a new RS session and calls the
 *           RsInit function.
 *****************************************************************************/
ViStatus _VI_FUNC hmo_InitWithOptions(
    ViRsrc          resourceName,
    ViBoolean       IDQuery,
    ViBoolean       resetDevice,
    ViString        optionString,
    ViSession      *newInstrSession
)
{
    ViStatus                error = VI_SUCCESS;
    ViChar                  newResourceName[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar                  newOptionString[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViBoolean               isLogicalName = 0;
    ViSession               instrSession = 0, rmSession = 0;
    RsAttrPropertiesPtr     *attrList=NULL;
    RsRepCapPtr             repCapTable = NULL;
    ViInt16				intfc;
	
    if (newInstrSession == NULL)
        {
        (void) Rs_SetErrorInfo (0, VI_FALSE, RS_ERROR_INVALID_PARAMETER,
                         VI_ERROR_PARAMETER5, "Null address for Instrument Handle");
        checkErr( RS_ERROR_INVALID_PARAMETER);
        }

    /* Prepare resource manager session handle */
    checkErr (viOpenDefaultRM (&rmSession));

    /* Establish communication session with the instrument */

    viCheckErr( viOpen (rmSession, resourceName, 0, 0, &instrSession));
	viCheckErr( viClear (instrSession));
    
    /* Configure VISA Formatted I/O */
    viCheckErr( viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, 5000 ));
    viCheckErr( viSetBuf (instrSession, (ViUInt16) (VI_READ_BUF | VI_WRITE_BUF), 4000));
    viCheckErr( viSetAttribute (instrSession, VI_ATTR_WR_BUF_OPER_MODE, VI_FLUSH_ON_ACCESS));
    viCheckErr( viSetAttribute (instrSession, VI_ATTR_RD_BUF_OPER_MODE, VI_FLUSH_ON_ACCESS));
	checkErr (viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &intfc));
    viCheckErr (viSetAttribute (instrSession, VI_ATTR_SEND_END_EN, VI_TRUE));
	viCheckErr( viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_FALSE));
	if (intfc == 4)
	{
		viCheckErr( viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR));
		viCheckErr( viSetAttribute (instrSession, VI_ATTR_ASRL_END_OUT, VI_ASRL_END_NONE));
		viCheckErr( viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE));   
	}
 
    checkErr( Rs_GetInfoFromResourceName (resourceName,
                                          (ViString)optionString,
                                          newResourceName,
                                          newOptionString,
                                          &isLogicalName));
    
    ATTRLIST(attrList,hmo);  
    checkErr( Rs_SpecificDriverNew (instrSession, "hmo", newOptionString, attrList));
    
    /* Build repeated capability table */
    REPCAPTABLE(repCapTable,hmo);
    checkErr( Rs_BuildRepCapTable (instrSession, repCapTable));

    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_VISA_RM_SESSION, 0, &rmSession));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_IO_SESSION, 0, &instrSession));

    /* With remote control via Ethernet, remote control is not automatically
       set by means of a command. The instrument must be explicitly set to
       the REMOTE state, e.g. by sending the intf command &GTR
    */
    checkErr (viWrite (instrSession, (ViBuf) "&GTR\n", 5, NULL));
    
    /*- Reset instrument ----------------------------------------------------*/
    if (resetDevice == VI_TRUE)
    {
        checkErr( hmo_reset (instrSession));
    }
    else  /*- Send Default Instrument Setup ---------------------------------*/
        checkErr( hmo_DefaultInstrSetup (instrSession));

    /*- Identification Query ------------------------------------------------*/
    if (IDQuery == VI_TRUE)
        {
        ViChar rdBuffer[HMO_IO_BUFFER_SIZE] = "";

        checkErr( Rs_GetAttribute (instrSession, NULL, (ViAttr) HMO_ATTR_ID_QUERY_RESPONSE,
                                   0, HMO_IO_BUFFER_SIZE, rdBuffer));

        if ((strncmp (rdBuffer, HMO_VALID_ID_RESPONSE_STRING, strlen(HMO_VALID_ID_RESPONSE_STRING)) != 0) &&
			(strncmp (rdBuffer, HMO_ALTERNATIVE_VALID_ID_RESPONSE_STRING, strlen(HMO_ALTERNATIVE_VALID_ID_RESPONSE_STRING)) != 0))
            {
            viCheckErr( VI_ERROR_FAIL_ID_QUERY);
            }
        }

    if (isLogicalName == VI_FALSE)
        {
        ViInt32 oldFlag = 0;

        checkErr (Rs_GetAttributeFlags (instrSession, RS_ATTR_IO_RESOURCE_DESCRIPTOR, &oldFlag));
        checkErr (Rs_SetAttributeFlags (instrSession, RS_ATTR_IO_RESOURCE_DESCRIPTOR, oldFlag & 0xfffb | 0x0010));
        checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_IO_RESOURCE_DESCRIPTOR, 0, newResourceName));
        }
    
    if (isLogicalName == VI_TRUE)
        checkErr( Rs_ApplyDefaultSetup (instrSession));

    /* Instrument session accessible by the end user is native VISA session,
       or when simulated virtual instrument (instrSession) session. */
    checkErr( hmo_CheckStatus (instrSession));

Error:

    if (error < VI_SUCCESS)
    {
        if (instrSession != 0)
        {
            (void) viClose (instrSession);
            (void) Rs_Dispose (instrSession);
        }
        
        if (rmSession != 0)
            (void) viClose (rmSession);
    }
    else
    {
        *newInstrSession = instrSession;
    }
    
    return error;
    
}

/// HIFN  This function returns the sample mode the oscilloscope is currently 
/// HIFN  using.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR sampleMode/Returns the method of adding waveform points to the samples of the ADC 
/// HIPAR sampleMode/in order to fill the record length.
ViStatus _VI_FUNC hmo_SampleMode(
    ViSession   instrSession,
    ViInt32*    sampleMode
)
{
    ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeViInt32 (instrSession, "",
                                               HMO_ATTR_SAMPLE_MODE,
                                               sampleMode), 2, "SampleMode");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the effective sample rate of the acquired 
/// HIFN  waveform using the current configuration in samples per second.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR sampleRate/Return the sample rate, that is the number of recorded waveform 
/// HIPAR sampleRate/samples per second.
ViStatus _VI_FUNC hmo_ActualSampleRate(
    ViSession   instrSession,
    ViReal64*   sampleRate
)
{
    ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeViReal64 (instrSession, "",
                                                HMO_ATTR_HORZ_SAMPLE_RATE,
                                                sampleRate), 2, "Sample Rate");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function performs an autoset process: analyzes the enabled channel signals, and obtains appropriate horizontal, vertical, and trigger settings to display stable waveforms.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
ViStatus _VI_FUNC hmo_Autoset(
    ViSession   instrSession
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckErr(hmo_SetAttributeViString(instrSession, "",HMO_ATTR_AUTOSCALE, NULL));
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures how the oscilloscope acquires data and fills the waveform record.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR acquisitionType/Specify the manner in which you want the oscilloscope to acquire data and fill the waveform record.
ViStatus _VI_FUNC hmo_ConfigureAcquisitionType(
    ViSession instrSession,
    ViInt32   channel,
    ViInt32   acquisitionType
)
{
    ViStatus error = VI_SUCCESS;
    ViChar   rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_ACQUISITION_TYPE,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_ACQUISITION_TYPE, acquisitionType), 3, "Acquisition Type");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the type of the aquisition mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR acquisitionMode/Specify the manner in which you want the oscilloscope to acquire data and fill the waveform record.
ViStatus _VI_FUNC hmo_ConfigureAcquisitionMode (ViSession instrSession,
                                                ViInt32 acquisitionMode)
{
    ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViInt32(instrSession, "",
        HMO_ATTR_ACQUISITION_MODE, acquisitionMode), 2, "Acquisition Mode");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the aquisition state of the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR acquisitionState/Specify the manner in which you want the oscilloscope to acquire data and fill the waveform record.
ViStatus _VI_FUNC hmo_ConfigureAcquisitionState (ViSession instrSession,
                                                 ViInt32 acquisitionState)
{
    ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViInt32(instrSession, "",
        HMO_ATTR_ACQUISITION_STATE, acquisitionState), 2, "Acquisition State");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the common attributes of the acquisition subsystem.  These attributes are the time per record and acquisition start time.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR timePerRecord/Pass the time in seconds that corresponds to the record length.  
/// HIPAR acquisitionStartTime_Offset/Specifies the length of time from the trigger event to the first point in the waveform record.  If the value is positive, the first point in the waveform record occurs after the trigger event.  If the 
///           value is negative, the first point in the waveform record occurs before the trigger event.
ViStatus _VI_FUNC hmo_ConfigureAcquisitionRecord(
    ViSession   instrSession,
    ViReal64    timePerRecord,
    ViReal64    acquisitionStartTime_Offset
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViReal64(instrSession, "",
        HMO_ATTR_HORZ_TIME_PER_RECORD, timePerRecord), 2, "Time Per Record");
    
    viCheckParm(hmo_SetAttributeViReal64(instrSession, "",
        HMO_ATTR_ACQUSITION_START_TIME, acquisitionStartTime_Offset), 3, "Acqusition Start Time");  
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the basic settings for the time axis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR timeScale/Sets the horizontal scale - the time per division on the x-axis - for all channel and math waveforms.
/// HIPAR referencePoint/Sets the reference point of the time scale in % of the display.
ViStatus _VI_FUNC hmo_ConfigureTimeBase(
    ViSession   instrSession,
    ViReal64    timeScale,
    ViReal64     referencePoint
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViReal64(instrSession, "",
        HMO_ATTR_HORZ_SCALE, timeScale), 2, "Time Scale");

    viCheckParm(hmo_SetAttributeViReal64(instrSession, "",
        HMO_ATTR_HORZ_REFERENCE, referencePoint), 3, "Reference Point");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function queries the number of horizontal divisions on the screen.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR divisions/Queries the number of horizontal divisions on the screen
ViStatus _VI_FUNC hmo_QueryDivisions(
    ViSession   instrSession,
    ViInt32*    divisions
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_GetAttributeViInt32(instrSession, "",
        HMO_ATTR_HORZ_DIVISIONS, divisions), 2, "Divisions");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the sample rate, that is the number of recorded waveform samples per second.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR sampleRate/Sets the sample rate, that is the number of recorded waveform samples per second.
ViStatus _VI_FUNC hmo_QuerySampleRate(
    ViSession   instrSession,
    ViReal64*    sampleRate
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_GetAttributeViReal64(instrSession, NULL,
        HMO_ATTR_HORZ_SAMPLE_RATE, sampleRate), 2, "Sample Rate");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the required acquisition time.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR acquisitionTime/Queries the required acquisition time
ViStatus _VI_FUNC hmo_QueryAcquisitionTime (ViSession instrSession,
                                              ViReal64 *acquisitionTime)
{
    ViStatus    error = VI_SUCCESS;
    
    viCheckParm(hmo_GetAttributeViReal64(instrSession, NULL,
        HMO_ATTR_ACQUISITION_TIME, acquisitionTime), 2, "Acquisition Time");
Error:
    return error;
}

/// HIFN  This function defines the mode to set the sample rate
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR waveformRate/Sets the mode to set the sample rate.
ViStatus _VI_FUNC hmo_ConfigureWaveformAcquisitionRate (ViSession instrSession,
                                                        ViInt32 waveformRate)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViInt32(instrSession, "",
        HMO_ATTR_WAVEFORM_RATE, waveformRate), 2, "Waveform Rate");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Selects the method to build the resulting waveform from several 
/// HIFN  consecutive acquisitions of the signal. 
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR arithmetics/Selects the method to build the resulting waveform from several 
/// HIPAR arithmetics/consecutive acquisitions of the signal. 
ViStatus _VI_FUNC hmo_ConfigureWaveformAcquisitionType(
	ViSession	instrSession,
	ViInt32	arithmetics
)
{
    ViStatus error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViInt32(instrSession, "",
        HMO_ATTR_WAVEFORM_ACQUISITION_TYPE, arithmetics), 3, "Arithmetics");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function queries the sample rate of the ADC, that is the number of points that are sampled by the ADC in one second.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR adcSampleRate/Returns the sample rate of the ADC, that is the number of points that are sampled by the ADC in one second.
ViStatus _VI_FUNC hmo_QueryADCSampleRate(
    ViSession   instrSession,
    ViReal64*   adcSampleRate
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_GetAttributeViReal64(instrSession, "",
        HMO_ATTR_HORZ_ADC_SAMPLE_RATE, adcSampleRate), 2, "ADC Sample Rate");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the record length, the number of recorded 
/// HIFN  waveform points that build the waveform across the acquisition time.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR recordLength/Indicates the record length, the number of recorded waveform points 
/// HIPAR recordLength/that build the waveform across the acquisition time.
ViStatus _VI_FUNC hmo_ConfigureRecordLength(
	ViSession	instrSession,
	ViInt32	recordLength
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViInt32(instrSession, "",
        HMO_ATTR_HORIZONTAL_RECORD_LENGTH, recordLength), 2, "Record Length");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the method of adding waveform points to the samples of the ADC in order to fill the record length.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR resolutionEnhancement/Selects the method of adding waveform points to the samples of the ADC in order to fill the record length.
ViStatus _VI_FUNC hmo_ConfigureResolutionEnhancement(
    ViSession   instrSession,
    ViInt32     resolutionEnhancement
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViInt32(instrSession, "",
        HMO_ATTR_SAMPLE_MODE, resolutionEnhancement), 2, "Resolution Enhancement");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the interpolation method the oscilloscope uses when it cannot sample a voltage for a point in the waveform record.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR interpolation/Pass the interpolation method you want the oscilloscope to 
ViStatus _VI_FUNC hmo_ConfigureInterpolation(
    ViSession   instrSession,
    ViInt32     interpolation
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViInt32(instrSession, "",
        HMO_ATTR_INTERPOLATION, interpolation), 2, "Interpolation");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Sets the limit frequency if Waveform arithmetics is set to "Smooth".
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.e.
/// HIPAR filterFrequency/Sets the limit frequency if Waveform Arithmetics  is set to "Smooth".
ViStatus _VI_FUNC hmo_ConfigureFilterFrequency (ViSession instrSession,
                                                  ViReal64 filterFrequency)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
   
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
        HMO_ATTR_FILTER_FREQUENCY, filterFrequency), 2, "Filter Frequency");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function selects a range of samples.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR sampleRange/The control selects a range of samples.
ViStatus _VI_FUNC hmo_ConfigureWaveformSamplesRange(
	ViSession	instrSession,
	ViInt32	channel,
	ViInt32	sampleRange
)
{
    ViStatus error = VI_SUCCESS;
    ViChar   rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_WAVEFORM_SAMPLE_RANGE,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_WAVEFORM_SAMPLE_RANGE, sampleRange), 3, "Sample Range");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function selects a range of samples.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR samples/Selects a range of samples.
ViStatus _VI_FUNC hmo_QueryWaveformSamplesRange (ViSession instrSession,
                                                         ViInt32 channel,
                                                         ViInt32* samples)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_WAVEFORM_SAMPLES,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");
    
    viCheckParm (hmo_GetAttributeViInt32 (instrSession, rep_cap,
        HMO_ATTR_WAVEFORM_SAMPLES, samples), 3, "Samples");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the number of waveforms that the oscilloscope  acquires and averages.  After the oscilloscope acquires as many waveforms as you specify, it returns to the idle state.  
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR numberofAverages/Pass the number of waveforms you want the oscilloscope to acquire and to average. After the oscilloscope acquires as many waveforms as you specify, it returns to the idle state.
ViStatus _VI_FUNC hmo_ConfigureNumberOfAverages(
    ViSession    instrSession,
    ViInt32      numberofAverages
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViInt32(instrSession, "",
        HMO_ATTR_NUM_AVERAGES, numberofAverages), 2, "Number of Averages");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
} 

/// HIFN  This function returns the state of averaging.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR averagingComplete/Returns the state of averaging.
ViStatus _VI_FUNC hmo_QueryAveragingStatus(
	ViSession	instrSession,
	ViBoolean*	averagingComplete
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_AVERAGING_STATUS,
                                            averagingComplete), 2, "Averaging Complete");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function enables the peak detection.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR peakDetection/Enables the peak detection.
ViStatus _VI_FUNC hmo_ConfigurePeakDetection(
	ViSession	instrSession,
	ViInt32	peakDetection
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_PEAK_DETECTION,
                                          peakDetection), 2, "Peak Detection");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function enables the high resolution mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR highResolution/Enables the high resolution mode.
ViStatus _VI_FUNC hmo_ConfigureHighResolution(
	ViSession	instrSession,
	ViInt32	highResolution
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_HIGH_RESOLUTION,
                                          highResolution), 2, "High Resolution");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function enables the roll mode.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     TIMebase:ROLL:ENABle
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR rollMode/Enables the roll mode.
ViStatus _VI_FUNC hmo_ConfigureRollMode(
	ViSession	instrSession,
	ViBoolean	rollMode
)
{
    ViStatus  error = VI_SUCCESS;
    
	checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_ROLL_MODE,
                                            rollMode), 2, "Roll Mode");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function configures the segmentation. 
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR segmentation/Switches the segmentation function on and off.
/// HIPAR maximumAcquisitionCount/Defines the segmentation number.
ViStatus _VI_FUNC hmo_ConfigureSegmentation(
	ViSession	instrSession,
	ViBoolean	segmentation,
	ViInt32	maximumAcquisitionCount
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

	viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_SEGMENTATION_STATE,
                                            segmentation), 2, "Segmentation");

	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEGMENTATION_MAXIMUM_ACQUISITION_COUNT,
                                          maximumAcquisitionCount), 3, "Maximum Acquisition Count");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the common attributes of the oscilloscope's channel subsystem for a particular channel.  These attributes are the vertical range, vertical offset, coupling, probe attenuation, 
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR verticalRange/Sets the voltage range across the 10 vertical divisions of the diagram.
/// HIPAR verticalOffset/Pass the location of the center of the range that you specify with for the Vertical Range parameter. Express the value with respect to ground.
/// HIPAR verticalCoupling/Specify how you want the oscilloscope to couple the input signal for the channel.
/// HIPAR channelEnabled/Switches the channel signal on or off.
ViStatus _VI_FUNC hmo_ConfigureChannel(
    ViSession    instrSession,
    ViInt32      channel,
    ViBoolean    channelEnabled,
    ViReal64     verticalRange,
    ViReal64     verticalOffset,
    ViInt32      verticalCoupling
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_CHANNEL_ENABLED,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm(hmo_SetAttributeViBoolean(instrSession, rep_cap,
        HMO_ATTR_CHANNEL_ENABLED, channelEnabled), 3, "Channel Enabled");
    
    viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_VERTICAL_RANGE, verticalRange), 4, "Vertical Range");
    
    viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_VERTICAL_OFFSET, verticalOffset), 5, "Vertical Offset"); 

    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_VERTICAL_COUPLING, verticalCoupling), 6, "Vertical Coupling");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the offset voltage. The offset is subtracted to correct an offset-affected signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR offset/Sets the offset voltage.
ViStatus _VI_FUNC hmo_ConfigureChannelOffset(
    ViSession   instrSession,
    ViInt32     channel,
    ViReal64    offset
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_CHANNEL_OFFSET,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_CHANNEL_OFFSET, offset), 3, "Offset");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the vertical scale for the indicated channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR verticalScale/Sets the vertical scale for the indicated channel.
ViStatus _VI_FUNC hmo_ConfigureChannelVerticalScale(
    ViSession    instrSession,
    ViInt32      channel,
    ViReal64     verticalScale
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_VERTICAL_SCALE,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_VERTICAL_SCALE, verticalScale), 3, "Vertical Scale");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function sets threshold value for digitization of analog signals.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR threshold/Threshold value for digitization of analog signals.
ViStatus _VI_FUNC hmo_ConfigureChannelThreshold (ViSession instrSession,
                                                     ViInt32 channel,
                                                     ViReal64 threshold)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_CHANNEL_THRESHOLD,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_CHANNEL_THRESHOLD, threshold), 3, "Threshold");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the bandwidth limit for the indicated channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR bandwidth/Selects the bandwidth limit for the indicated channel.
ViStatus _VI_FUNC hmo_ConfigureChannelBandwidth(
    ViSession    instrSession,
    ViInt32      channel,
    ViInt32      bandwidth
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_CHANNEL_BANDWIDTH_LIMIT,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_CHANNEL_BANDWIDTH_LIMIT, bandwidth), 3, "Bandwidth");  
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function turns the inversion of the signal amplitude on or off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR polarity/Selects polarity.
ViStatus _VI_FUNC hmo_ConfigureChannelPolarity (ViSession instrSession,
                                                  ViInt32 channel,
                                                  ViInt32 polarity)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_CHANNEL_POLARITY,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_CHANNEL_POLARITY, polarity), 3, "Polarity");  
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the overload status of the specified channel from the status bit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR overload/Retrieves the overload status of the specified channel from the status bit. When the overload problem is solved, the command resets the status bit. Use VI_FALSE to clear the overload condition.
ViStatus _VI_FUNC hmo_ConfigureChannelOverload(
    ViSession   instrSession,
    ViInt32     channel,
    ViBoolean   overload
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_CHANNEL_OVERLOAD,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm(hmo_SetAttributeViBoolean(instrSession, rep_cap,
        HMO_ATTR_CHANNEL_OVERLOAD, overload), 3, "Overload");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function compensates delay differences between channels
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR deskewValue/Compensates delay differences between channels.
ViStatus _VI_FUNC hmo_ConfigureChannelSkew (ViSession instrSession,
                                                ViInt32 channel,
                                                ViReal64 deskewValue)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_CHANNEL_SKEW,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_CHANNEL_SKEW, deskewValue), 3, "Deskew Value");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function turns an additional 5 kHz or 100 MHz low-pass filter in the trigger path
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR filterType/Selects the filter type.
/// HIPAR filterState/Activates or deactivates a low-pass filter in the trigger path.
ViStatus _VI_FUNC hmo_ConfigureEdgeTriggerFilter (ViSession instrSession,
                                                   ViInt32 filterType,
                                                   ViBoolean filterState)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_TRIGGER_FILTER,
                                                 "TriggerFilter",
                                                 filterType,
                                                 15,
                                                 rep_cap), 3, "Filter Type");

    viCheckParm(hmo_SetAttributeViBoolean (instrSession, rep_cap,
        HMO_ATTR_TRIGGER_FILTER, filterState), 4, "Filter State");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures Runt trigger settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR polarity/Indicates the polarity of a the runt to be searched for.
/// HIPAR channel/Selects the trigger input.
/// HIPAR lowerLevel/Sets the lower voltage threshold for runt detection. A positive runt 
/// HIPAR lowerLevel/crosses the lower level twice without crossing the upper level.
/// HIPAR upperLevel/Sets the upper voltage threshold for runt detection. A negative runt 
/// HIPAR upperLevel/crosses the upper level twice without crossing the lower level.
ViStatus _VI_FUNC hmo_ConfigureRuntTrigger(
	ViSession	instrSession,
	ViInt32	polarity,
	ViInt32	channel,
	ViReal64	lowerLevel,
	ViReal64	upperLevel
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_RUNT_TRIGGER_POLARITY,
                                          polarity), 2, "polarity");
    
	viCheckParm (hmo_invalidViInt32Range (instrSession, channel, HMO_VAL_CHANNEL_1, HMO_VAL_CHANNEL_4), 3, "Channel");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_RUNT_TRIGGER_LOWER_LEVEL,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 3, "Channel");

    viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                           HMO_ATTR_RUNT_TRIGGER_LOWER_LEVEL,
                                           lowerLevel), 4, "Lower Level");

	viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                           HMO_ATTR_RUNT_TRIGGER_UPPER_LEVEL,
                                           upperLevel), 5, "Upper Level");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures rise/fall time trigger settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR slope/Sets the slope to be found.
/// HIPAR range/Sets how the measured rise or fall time is compared with the given 
/// HIPAR range/limit(s).
/// HIPAR time/For the ranges LONGer and SHORter, the value defines the minimum and 
/// HIPAR time/maximum transition times, respectively.
/// HIPAR deltat/Sets a range delta t to the reference rise/fall time set with 'Time' 
/// HIPAR deltat/control if 'Range' control is set to Within or Outside. The instrument 
/// HIPAR deltat/finds rise/fall times inside or outside the range time +/- delta t.
ViStatus _VI_FUNC hmo_ConfigureTimeTrigger(
	ViSession	instrSession,
	ViInt32	slope,
	ViInt32	range,
	ViReal64	time,
	ViReal64	deltat
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_TRIGGER_TIME_POLARITY,
                                          slope), 2, "Slope");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_TRIGGER_TIME_RANGE,
                                          range), 3, "Range");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_TRIGGER_TIME,
                                           time), 4, "Time");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_TRIGGER_TIME_DELTA,
                                           deltat), 5, "Delta t");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the voltage threshold. When the signal 
/// HIFN  crosses this level, the rise time measurement starts or stops depending 
/// HIFN  on the selected slope.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects the trigger input.
/// HIPAR lowerLevel/Sets the lower voltage threshold. When the signal crosses this level, 
/// HIPAR lowerLevel/the rise time measurement starts or stops depending on the selected 
/// HIPAR lowerLevel/slope.
/// HIPAR upperLevel/Sets the upper voltage threshold. When the signal crosses this level, 
/// HIPAR upperLevel/the rise time measurement starts or stops depending on the selected 
/// HIPAR upperLevel/slope.
ViStatus _VI_FUNC hmo_ConfigureTimeTriggerLevel(
	ViSession	instrSession,
	ViInt32	channel,
	ViReal64	lowerLevel,
	ViReal64	upperLevel
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, channel, HMO_VAL_CHANNEL_1, HMO_VAL_CHANNEL_4), 2, "Channel");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_TRIGGER_LEVEL_UPPER,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                           HMO_ATTR_TRIGGER_LEVEL_LOWER,
                                           lowerLevel), 3, "Lower Level");

	viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                           HMO_ATTR_TRIGGER_LEVEL_UPPER,
                                           upperLevel), 4, "Upper Level");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function configures output trigger settings.
/// HIFN     
/// HIFN     Attribute(s):
/// HIFN     
/// HIFN     
/// HIFN     
/// HIFN     
/// HIFN     Remote-control command(s):
/// HIFN     TRIGger:OUT:MODE
/// HIFN     TRIGger:OUT:POLarity
/// HIFN     TRIGger:OUT:PLENgth
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Sets the trigger output mode.
/// HIPAR polarity/Sets the trigger output polarity.
/// HIPAR pulseLength/Sets the trigger output pulse length.
ViStatus _VI_FUNC hmo_ConfigureOutputTrigger(
	ViSession	instrSession,
	ViInt32	mode,
	ViInt32	polarity,
	ViReal64	pulseLength
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_TRIGGER_OUT_MODE,
                                          mode), 2, "Mode");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_TRIGGER_OUT_POLARITY,
                                          polarity), 3, "Polarity");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_TRIGGER_OUT_PULSE_LENGTH,
                                           pulseLength), 4, "Pulse Length");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function sets the time the instrument waits after an A-event until it recognizes B-events.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR delayTime/Sets the time the instrument waits after an A-event until it recognizes B-events.
ViStatus _VI_FUNC hmo_ConfigureTriggerDelay (ViSession instrSession,
                                           ViReal64 delayTime)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm(hmo_SetAttributeViReal64(instrSession, NULL,
        HMO_ATTR_TRIGGER_DELAY, delayTime), 2, "Delay Time");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}



/// HIFN Sets the coupling for the external trigger input.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR externalCoupling/Sets the coupling for the external trigger input.
ViStatus _VI_FUNC hmo_ConfigureExternalTriggerCoupling (ViSession instrSession,
                                                          ViInt32 externalCoupling)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_EXTERNAL_TRIGGER_COUPLING, externalCoupling), 2, "External Coupling");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function activates or deactivates the second trigger. The instrument triggers if both trigger event conditions (A and B) are fulfilled.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR state/This Control activates or deactivates the second trigger.
ViStatus _VI_FUNC hmo_ConfigureTriggerBState (ViSession instrSession,
                                           ViBoolean state)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm(hmo_SetAttributeViBoolean (instrSession, NULL,
        HMO_ATTR_TRIGGER_STATE, state), 2, "State");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Sets a number of B-trigger events that fulfill all B-trigger conditions but do not cause the trigger. The oscilloscope triggers on the n-th event (the last of the specified number of events).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR eventCount/This Control sets a number of B-trigger events.
ViStatus _VI_FUNC hmo_ConfigureTriggerEventCount (ViSession instrSession,
                                                ViInt32 eventCount)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_TRIGGER_EVENT_COUNT, eventCount), 4, "Event Count");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Configuration of the channel label.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR labelState/Switches the label of the channel on or off.
/// HIPAR label/Sets the label for the input channel, maximum 8 characters.
ViStatus _VI_FUNC hmo_ConfigureChannelLabel (ViSession instrSession,
                                             ViInt32 channel,
                                             ViBoolean labelState,
                                             ViString label)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, channel, HMO_VAL_CHANNEL_1, HMO_VAL_CHANNEL_EXT), 2, "Channel");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_CHANNEL_LABEL_STATE,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm(hmo_SetAttributeViBoolean(instrSession, rep_cap,
        HMO_ATTR_CHANNEL_LABEL_STATE, labelState), 3, "Label State");    
    
    viCheckParm(hmo_SetAttributeViString(instrSession, rep_cap,
        HMO_ATTR_CHANNEL_LABEL, label), 4, "Label");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Sets the appropriate threshold level automatically.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/This control selects the channel.
ViStatus _VI_FUNC hmo_FindChannelThresholdLevel(
	ViSession	instrSession,
	ViInt32	channel
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, channel, HMO_VAL_CHANNEL_1, HMO_VAL_CHANNEL_EXT), 2, "Channel");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_CHANNEL_THRESHOLD_FIND_LEVEL,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckErr (hmo_SetAttributeViString (instrSession, rep_cap,
                                          HMO_ATTR_CHANNEL_THRESHOLD_FIND_LEVEL, NULL));
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Defines the size of the hysteresis to avoid the change of signal 
/// HIFN  states due to noise.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR thresholdHysteresis/Defines the size of the hysteresis to avoid the change of signal 
/// HIPAR thresholdHysteresis/states due to noise.
ViStatus _VI_FUNC hmo_ConfigureChannelThresholdHysteresis(
	ViSession	instrSession,
	ViInt32	channel,
	ViInt32	thresholdHysteresis
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, channel, HMO_VAL_CHANNEL_1, HMO_VAL_CHANNEL_EXT), 2, "Channel");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_CHANNEL_THRESHOLD_HYSTERESIS,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                          HMO_ATTR_CHANNEL_THRESHOLD_HYSTERESIS,
                                          thresholdHysteresis), 3, "ThresholdHysteresis");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the probe characteristics.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the Type 
/// HIPAR bufferSize/Parameter.
/// HIPAR type/Queries the type of the probe.
/// HIPAR attenuation/Returns the attenuation of an automatically detected probe.
ViStatus _VI_FUNC hmo_QueryProbeCharacteristics(
	ViSession	instrSession,
	ViInt32	channel,
	ViInt32	bufferSize,
	ViChar	type[],
	ViReal64*	attenuation
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, channel, HMO_VAL_CHANNEL_1, HMO_VAL_CHANNEL_4), 2, "Channel");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROBE_TYPE,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm (hmo_GetAttributeViString (instrSession, rep_cap,
                                           HMO_ATTR_PROBE_TYPE, bufferSize,
                                           type), 4, "Type");

	viCheckParm (hmo_GetAttributeViReal64 (instrSession, rep_cap,
                                           HMO_ATTR_PROBE_ATTENUATION,
                                           attenuation), 5, "Attenuation");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function configures the probe attenuation manually.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR verticalUnit/This control selects the unit that the probe can measure.
/// HIPAR attenuation/Sets the attenuation or gain of the probe if the probe was not 
/// HIPAR attenuation/detected by the instrument.
ViStatus _VI_FUNC hmo_ConfigureProbeAttenuation(
	ViSession	instrSession,
	ViInt32	channel,
	ViInt32	verticalUnit,
	ViReal64	attenuation
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, channel, HMO_VAL_CHANNEL_1, HMO_VAL_CHANNEL_4), 2, "Channel");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROBE_ATTENUATION_UNIT,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                          HMO_ATTR_PROBE_ATTENUATION_UNIT,
                                          verticalUnit), 3, "Vertical Unit");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                           HMO_ATTR_PROBE_MANUAL_ATTENUATION,
                                           attenuation), 4, "Attenuation");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the common attributes of the trigger subsystem.  These attributes are the trigger type and holdoff.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR trigger/Selects trigger event.
/// HIPAR triggerType/Sets the trigger type.
ViStatus _VI_FUNC hmo_ConfigureTrigger(
    ViSession   instrSession,
    ViInt32     trigger,
    ViInt32     triggerType
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[15] = "";
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_TRIGGER_TYPE,
                                                 "Trigger",
                                                 trigger,
                                                 15,
                                                 rep_cap), 2, "Trigger");
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_TRIGGER_TYPE, triggerType), 3, "Trigger Type");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Defines how the range of a pulse width is defined for keeping up the 
/// HIFN  true result of the pattern condition.         
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR patternMode/Adds additional time limitation to the pattern definition.
/// HIPAR timeoutCondition/For future use
/// HIPAR timeout/For future use.
/// HIPAR patternCondition/Defines how the range of a pulse width is defined for keeping up the 
/// HIPAR patternCondition/true result of the pattern condition.
/// HIPAR patternWidth/For the ranges "Within" and "Outside", the width defines the center of 
/// HIPAR patternWidth/a range which is defined by the limits "Delta".
/// HIPAR patternDelta/Defines a range around the width value.
ViStatus _VI_FUNC hmo_ConfigurePatternTriggerMode (ViSession instrSession,
                                                   ViInt32 patternMode,
                                                   ViInt32 timeoutCondition,
                                                   ViReal64 timeout,
                                                   ViInt32 patternCondition,
                                                   ViReal64 patternWidth,
                                                   ViReal64 patternDelta)
{
	ViStatus    error = VI_SUCCESS;
	timeout;
	timeoutCondition;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, NULL, 
		HMO_ATTR_TRIGGER_PATTERN_MODE, patternMode), 2, "patternMode");    
    
    if (patternMode == HMO_VAL_PATTERN_WIDTH)
	{
		viCheckParm (hmo_SetAttributeViInt32 (instrSession, NULL,
        	HMO_ATTR_TRIGGER_PATTERN_CONDITION, patternCondition), 5, "Pattern Condition");    
        
	    viCheckParm (hmo_SetAttributeViReal64 (instrSession, NULL,
	        HMO_ATTR_TRIGGER_PATTERN_WIDTH, patternWidth), 6, "Pattern Width");    
    
	    viCheckParm (hmo_SetAttributeViReal64 (instrSession, NULL,
	        HMO_ATTR_TRIGGER_PATTERN_DELTA, patternDelta), 7, "Pattern Delta");    
    }                                            
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the TV trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR standard/This Control sets the color television standard.
/// HIPAR polarity/This Control sets the polarity.
/// HIPAR field/Selects the frame or line.
/// HIPAR line/This Control sets an exact line number.
ViStatus _VI_FUNC hmo_ConfigureVideoTriggerSource (ViSession instrSession,
                                                ViInt32 standard, 
                                                ViInt32 polarity,
                                                ViInt32 field, 
                                                ViInt32 line)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    checkErr (hmo_ConfigureTrigger (instrSession, HMO_VAL_TRIGGER_A, HMO_VAL_VIDEO_TRIGGER));
    viCheckParm(hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_TV_STANDARD, standard), 2, "Standard");    
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_TV_TRIGGER_POLARITY, polarity), 3, "Polarity");    
        
    viCheckParm(hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_TV_TRIGGER_EVENT, field), 4, "Field");    
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_TV_TRIGGER_LINE_NUMBER, line), 5, "Line");    
                                                
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR trigger/Selects trigger event.
/// HIPAR channel/This control selects the channel.
/// HIPAR triggerSource/selects the channel.
/// HIPAR triggerLevel/This control sets the trigger threshold voltage.
/// HIPAR triggerSlope/Selects the slope.
ViStatus _VI_FUNC hmo_ConfigureEdgeTriggerSource (ViSession instrSession,
                                            ViInt32  trigger,
                                            ViInt32  channel,
                                            ViInt32  triggerSource,
                                            ViReal64 triggerLevel,
                                            ViInt32  triggerSlope)
{
    ViStatus    error = VI_SUCCESS;
    ViChar   rep_cap_trigger[15] = "";
    ViChar   rep_cap_channel[15] = "";
    ViChar   rep_cap[50] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_TRIGGER_SOURCE,
                                                 "Trigger",
                                                 trigger,
                                                 15,
                                                 rep_cap_trigger), 2, "Trigger");
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap_trigger,
        HMO_ATTR_TRIGGER_SOURCE, triggerSource), 4, "Trigger Source");
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap_trigger,
        HMO_ATTR_TRIGGER_SLOPE, triggerSlope), 6, "Trigger Slope");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_TRIGGER_LEVEL,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap_channel), 2, "Channel");
    
    strcpy (rep_cap, rep_cap_trigger);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_channel);
    
    viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_TRIGGER_LEVEL, triggerLevel), 5, "Trigger Level");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Sets the trigger source for the selected trigger type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR trigger/Selects trigger event.
/// HIPAR source/Selects the source.
ViStatus _VI_FUNC hmo_ConfigureTriggerSource (ViSession instrSession,
                                            ViInt32 trigger, 
                                            ViInt32 source)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_TRIGGER_SOURCE,
                                                 "Trigger",
                                                 trigger,
                                                 15,
                                                 rep_cap), 2, "Trigger");

    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_TRIGGER_SOURCE, source), 3, "Source");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Sets the coupling for the trigger source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR coupling/Selects coupling event for the trigger source.
ViStatus _VI_FUNC hmo_ConfigureEdgeTriggerCoupling (ViSession instrSession,
                                                ViInt32 coupling)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_TRIGGER_COUPLING, coupling), 2, "Coupling");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Sets the trigger mode. The trigger mode determines the behaviour of the instrument if no trigger occurs.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR trigger/Selects trigger event.
/// HIPAR triggerModifier/Sets the trigger mode. The trigger mode determines the behaviour of the instrument if no trigger occurs.
ViStatus _VI_FUNC hmo_ConfigureTriggerModifier(
    ViSession   instrSession,
    ViInt32     trigger,
    ViInt32     triggerModifier
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_TRIGGER_MODIFIER,
                                                 "Trigger",
                                                 trigger,
                                                 15,
                                                 rep_cap), 2, "Trigger");

    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_TRIGGER_MODIFIER, triggerModifier), 3, "Trigger Modifier");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function configures selected trigger level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR trigger/Selects trigger event.
/// HIPAR channel/Sets the trigger source for the selected trigger type.
/// HIPAR triggerLevel/Sets the trigger level for the specified event and channel.
ViStatus _VI_FUNC hmo_ConfigureTriggerChannelLevel (ViSession instrSession,
                                                        ViInt32 trigger,
                                                        ViInt32 channel,
                                                        ViReal64 triggerLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   rep_cap_trigger[15] = "";
    ViChar   rep_cap_channel[15] = "";
    ViChar   rep_cap[50] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_TRIGGER_LEVEL,
                                                 "Trigger",
                                                 trigger,
                                                 15,
                                                 rep_cap_trigger), 2, "Trigger");
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_TRIGGER_LEVEL,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap_channel), 2, "Channel");
    strcpy (rep_cap, rep_cap_trigger);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_channel);
    
    viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_TRIGGER_LEVEL, triggerLevel), 4, "Trigger Level");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the trigger holdoff.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Sets the trigger holdoff mode.
/// HIPAR time/Defines the holdoff time. The next trigger only occurs after the 
/// HIPAR time/holdoff time has passed.
ViStatus _VI_FUNC hmo_ConfigureTriggerHoldoffTime(
	ViSession	instrSession,
	ViInt32	mode,
	ViReal64	time
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_TRIGGER_HOLDOFF_MODE,
                                          mode), 2, "Mode");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_TRIGGER_HOLDOFF_TIME,
                                           time), 3, "Time");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the width trigger.  A width trigger occurs 
/// HIFN  when the oscilloscope detects a positive or negative pulse with a width 
/// HIFN  between, or optionally outside, the width thresholds.  You specify the 
/// HIFN  width thresholds with the Width Low Threshold and Width High Threshold 
/// HIFN  parameters.  You specify whether the oscilloscope triggers on pulse 
/// HIFN  widths that are within or outside the width thresholds with the Width 
/// HIFN  Condition parameter.  You specify the polarity of the pulse with the 
/// HIFN  Width Polarity parameter.  The trigger does not actually occur until 
/// HIFN  the edge of a pulse that corresponds to the Width Low Threshold, Width 
/// HIFN  High Threshold, Width Condition, and Width Polarity crosses the 
/// HIFN  threshold you specify in the Trigger Level parameter.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR width/For the ranges "Within" and "Outside", the width defines the center of 
/// HIPAR width/ a range which is defined by the limits "+/-Delta". For the ranges 
/// HIPAR width/ "Shorter" and "Longer", the width defines the maximum and minimum pulse 
/// HIPAR width/ width, respectively.
/// HIPAR widthDelta/Defines a range around the width value.
/// HIPAR widthPolarity/Sets the polarity of the pulse.
/// HIPAR triggerSource/Sets the trigger source for the selected trigger type.
/// HIPAR widthCondition/Sets how the measured pulse width is compared with the given limit(s).
ViStatus _VI_FUNC hmo_ConfigureWidthTriggerSource(
    ViSession   instrSession,
    ViInt32     triggerSource,
    ViReal64    triggerLevel,
    ViReal64    width,
    ViReal64    widthDelta,
    ViInt32     widthPolarity,
    ViInt32     widthCondition
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    checkErr (hmo_ConfigureTrigger (instrSession, HMO_VAL_TRIGGER_A,
                                      HMO_VAL_WIDTH_TRIGGER));
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, "TrigA",
        HMO_ATTR_TRIGGER_SOURCE, triggerSource), 3, "Trigger Source");

    if ((triggerSource >= HMO_VAL_CHANNEL1) && (triggerSource <= HMO_VAL_CHANNEL4)) {
		viCheckParm(hmo_ConfigureTriggerChannelLevel (instrSession,
                                                    HMO_VAL_TRIGGER_A,
                                                    triggerSource,
                                                    triggerLevel), 4, "Trigger Level");
    
    }
	viCheckParm(hmo_SetAttributeViReal64(instrSession, NULL,
        HMO_ATTR_WIDTH, width), 5, "Width");

    viCheckParm(hmo_SetAttributeViReal64(instrSession, NULL,
        HMO_ATTR_WIDTH_DELTA, widthDelta), 6, "Width Delta");   

    viCheckParm(hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_WIDTH_POLARITY, widthPolarity), 7, "Width Polarity");  

    viCheckParm(hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_WIDTH_CONDITION, widthCondition), 8, "Width Condition");   

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the virtual screen.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR state/Switches the virtual screen on or off.
/// HIPAR virtualScreenPosition/Set the position of the virtual screen window.
ViStatus _VI_FUNC hmo_ConfigureVirtualScreen (ViSession instrSession,
                                              ViBoolean state,
                                              ViReal64 virtualScreenPosition)
{
    ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViInt32(instrSession, "",
        HMO_ATTR_VIRTUAL_SCREEN_STATE, state), 2, "State");

    
    viCheckParm(hmo_SetAttributeViReal64(instrSession, "",
        HMO_ATTR_VIRTUAL_SCREEN_POSITION, virtualScreenPosition), 3, "Virtual Screen Position");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function shows a dialog message on display or closes it.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Select to either show or close the dialog.
/// HIPAR text/Sends a message text to the instrument and displays it in a message 
/// HIPAR text/box.
ViStatus _VI_FUNC hmo_ConfigureDisplayDialog(
	ViSession	instrSession,
	ViInt32	    mode,
	ViString	text
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    switch (mode)
	{
		case HMO_VAL_DIALOG_CLOSE:
		{
			viCheckErr (hmo_SetAttributeViString (instrSession, "",
                                               HMO_ATTR_DISPLAY_CLOSE_DIALOG, NULL));
			break;
		}
    	case HMO_VAL_DIALOG_SHOW:
		{
			viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                                HMO_ATTR_DISPLAY_MESSAGE_TEXT,
                                                text), 3, "Text");
			break;
		}
		default:
			viCheckParm (RS_ERROR_INVALID_PARAMETER, 2, "Mode");
	}
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures persistence.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR enable/If enabled, each new data point in the diagram area remains on the 
/// HIPAR enable/screen for the defined duration. If disabled, the signal value is only 
/// HIPAR enable/displayed as long as it actually occurs.
/// HIPAR infinite/If persistence is enabled, each new data point in the diagram area 
/// HIPAR infinite/remains on the screen infinitely until is disabled.
/// HIPAR time/If persistence is enabled, each new data point in the diagram area 
/// HIPAR time/remains on the screen for the duration defined here.
ViStatus _VI_FUNC hmo_ConfigurePersistence(
    ViSession    instrSession,
    ViBoolean    enable,
    ViBoolean    infinite,
    ViReal64    time
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                                 HMO_ATTR_PERSISTENCE_STATE,
                                                 enable
                                                 ), 2, "Enable");
    
    if (enable == VI_TRUE)
    {
        viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                                     HMO_ATTR_INFINITE_PERSISTENCE,
                                                     infinite
                                                     ), 3, "Infinite");
        if (infinite == VI_FALSE)
            {
                viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                                            HMO_ATTR_PERSISTENCE_TIME,
                                                            time
                                                                ), 4, "Time");
            }
    }
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function removes the displayed persistent waveform from the screen.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC hmo_ClearPersistence (ViSession instrSession)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                                HMO_ATTR_PERSISTENCE_CLEAR,
                                                NULL
                                                ), 1, "Session");
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures optimal persistence time.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR autoPersist/If enabled, sets optimal persistence time.
ViStatus _VI_FUNC hmo_ConfigurePersistenceTimeAuto (ViSession instrSession,
                                               ViBoolean autoPersist)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViBoolean(instrSession, "",
        HMO_ATTR_PERSISTENCE_TIME_AUTO, autoPersist),
        2, "AutoPersist");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures signal intensity and style.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR style/Select the style in which the waveform is displayed.
ViStatus _VI_FUNC hmo_ConfigureSignalStyle(
    ViSession    instrSession,
    ViInt32        style
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                               HMO_ATTR_SIGNAL_STYLE,
                                               style
                                               ), 2, "Style");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Document your function here.
/// HIFN You may use multiple lines for documentation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR element/Selects the element.
/// HIPAR intensity/This value defines the intensity of the lighting of the selected display element
ViStatus _VI_FUNC hmo_ConfigureDisplayIntensity (ViSession instrSession,
                                                   ViInt32 element,
                                                   ViReal64 intensity)
{
    ViStatus    error = VI_SUCCESS;
    ViAttr      attribute = 0;

    switch (element)
    {
        case HMO_VAL_DISPLAY_BACKGROUND:
            attribute = HMO_ATTR_BACKGROUND_INTENSITY;
            break;
        case HMO_VAL_DISPLAY_GRID:
            attribute = HMO_ATTR_GRID_INTENSITY;
            break;
        case HMO_VAL_DISPLAY_WAVEFORM:
            attribute = HMO_ATTR_WAVEFORM_INTENSITY;
            break;
        default:
            viCheckParm (RS_ERROR_INVALID_PARAMETER, 2, "Element");
    }
    
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, NULL, attribute, intensity), 3, "Intensity");
Error:
    return error;
}

/// HIFN  This function sets the color and brightness of the displayed waveform samples depending on their cumulative occurance.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR palette/Selects the color and brightness of the displayed waveform samples.
ViStatus _VI_FUNC hmo_ConfigureColorAndBrightness (ViSession instrSession,
                                              ViInt32 palette)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "", 
        HMO_ATTR_COLOR_AND_BRIGHTNESS, palette), 2, "Palette");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function sets the language.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR language/Selects the language.
ViStatus _VI_FUNC hmo_ConfigureDisplayLanguage (ViSession instrSession,
                                           ViInt32 language)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "", 
        HMO_ATTR_DISPLAY_LANGUAGE, language), 2, "Language");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function installs the specified language on the instrument. For each language
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR language/Selects the language.
/// HIPAR source/This control specifies the string parameter containing source path and file.
ViStatus _VI_FUNC hmo_DisplayAddLanguage (ViSession instrSession,
                                          ViInt32 language, ViString source)
{
    ViStatus    error = VI_SUCCESS;
	ViInt32		timeout = 36000;
	
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, language, HMO_VAL_DISPLAY_ENGLISH, HMO_VAL_DISPLAY_KOREAN), 2, "Measurement");
    
	viCheckErr( hmo_GetOPCTimeout(instrSession, &timeout));
	
	checkErr (hmo_ClearBeforeRead (instrSession));   
	
    viCheckErr (viPrintf(instrSession, "DISP:LANG:ADD %s,\"%s\";*OPC\n", 
                LanguageArr[language], source));
	viCheckErr (hmo_WaitForOPC (instrSession, timeout));
    
    viCheckErr(hmo_CheckStatusTimed(instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns all installed menu language files. 
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/This control indicates the allocated memory in Language Catalog.
/// HIPAR languageCatalog/Returns all installed menu language files.
ViStatus _VI_FUNC hmo_DisplayLanguageCatalog(
	ViSession	instrSession,
	ViInt32	bufferSize,
	ViChar	languageCatalog[]
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeViString (instrSession, "",
                                           HMO_ATTR_DISPLAY_LANGUAGE_CATALOG, bufferSize,
                                           languageCatalog), 2, "Language Catalog");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Removes the specified language from the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR language/Selects the language.
ViStatus _VI_FUNC hmo_DisplayRemoveLanguage (ViSession instrSession,
                                             ViInt32 language)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    viCheckErr (hmo_ClearBeforeRead(instrSession));
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "", 
        HMO_ATTR_REMOVE_DISPLAY_LANGUAGE, language), 2, "Language");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function sets the diagram mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Selects the diagram mode.
ViStatus _VI_FUNC hmo_ConfigureDiagramMode (ViSession instrSession, ViInt32 mode)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "", 
        HMO_ATTR_DIAGRAM_MODE, mode), 2, "Mode");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function defines how the grid is displayed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR style/Selects the grid style.
ViStatus _VI_FUNC hmo_ConfigureDisplayGridStyle (ViSession instrSession,
                                            ViInt32 style)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                               HMO_ATTR_DIAGRAM_GRID_STYLE,
                                               style
                                               ), 3, "Style");
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function defines the source to be displayed in x direction in an XY-diagram, replacing the usual time base.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR source/Defines the source to be displayed.
ViStatus _VI_FUNC hmo_ConfigureSourceX (ViSession instrSession, ViInt32 source)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "", 
        HMO_ATTR_XY_X_SOURCE, source), 2, "Source");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function defines the (first) source to be displayed in y direction in an XY-diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR source/Defines the source to be displayed.
ViStatus _VI_FUNC hmo_ConfigureSourceY1 (ViSession instrSession, ViInt32 source)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "", 
        HMO_ATTR_XY_Y_SOURCE, source), 2, "Source");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function defines an optional second source to be displayed in y direction in an XY-diagram. The command is only relevant for 4-channel R&S RTM instruments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR source/Defines the source to be displayed.
ViStatus _VI_FUNC hmo_ConfigureSourceY2 (ViSession instrSession, ViInt32 source)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "", 
        HMO_ATTR_XY_Y2_SOURCE, source), 2, "Source");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function activates or deactivates the intensity control of the waveform via an additional signal source and sets the intensity mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Selects the mode of intensity control.
ViStatus _VI_FUNC hmo_ConfigureIntensityControl (ViSession instrSession,
                                            ViInt32 mode)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "", 
        HMO_ATTR_XY_INTENSITY_CONTROL, mode), 2, "Mode");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function defines the source to be used to determine the intensity of the xy-waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR source/Defines the source.
ViStatus _VI_FUNC hmo_ConfigureSourceIntensity (ViSession instrSession,
                                           ViInt32 source)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "", 
        HMO_ATTR_XY_Z_SOURCE, source), 2, "Source");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function defines the threshold for intensity with a two-state modulation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR threshold/This control defines the threshold.
ViStatus _VI_FUNC hmo_ConfigureIntensityThreshold (ViSession instrSession,
                                             ViReal64 threshold)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, "", 
        HMO_ATTR_XY_Z_THRESHOLD, threshold), 2, "Threshold");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function defines the position of the zoom reference point (the reference point of the zoom window) in relation to the reference point of original time base.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR position/Defines the zoom reference point.
ViStatus _VI_FUNC hmo_ZoomReferencePoint (ViSession instrSession,
                                              ViInt32 position)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                               HMO_ATTR_ZOOM_REFERENCE_POINT,
                                               position
                                               ), 2, "Position");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function switches the zoom window on or off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR zoomEnabled/Switches the zoom window on or off.
ViStatus _VI_FUNC hmo_ConfigureZoomWindowState (ViSession instrSession,
                                           ViBoolean zoomEnabled)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViBoolean(instrSession, NULL,
        HMO_ATTR_ZOOM_WINDOW_STATE, zoomEnabled), 2, "Zoom Enabled");
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function defines the position of the zoom reference point (the reference point of the zoom window) in relation to the reference point of original time base.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR position/Defines the zoom reference point.
ViStatus _VI_FUNC hmo_ConfigureZoomReferencePoint (ViSession instrSession,
                                                     ViReal64 position)
{
    ViStatus    error = VI_SUCCESS;
    viCheckParm(hmo_SetAttributeViReal64(instrSession, NULL,
        HMO_ATTR_ZOOM_REFERENCE_POINT, position), 2, "Position");
Error:
    return error;
}

/// HIFN  This function defines the time base in the zoom diagram in seconds per division.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR scale/Scaling of the zoom time base.
ViStatus _VI_FUNC hmo_ConfigureZoomDiagramTimebase (ViSession instrSession,
                                               ViReal64 scale)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViReal64(instrSession, NULL,
        HMO_ATTR_ZOOM_DIAGRAM_TIMEBASE, scale), 2, "Scale");    

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function defines the offset of the trigger point to the reference point of the zoom diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR time/Defines the offset of the trigger.
ViStatus _VI_FUNC hmo_ConfigureZoomOffsetOfTriggerPoint (ViSession instrSession,
                                                    ViReal64 time)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViReal64(instrSession, "",
        HMO_ATTR_ZOOM_OFFSET_OF_TRIGGER_POINT, time), 2, "Time");    

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures history display.
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) The segmented memory player is only visible on the HMO screen with 
/// HIFN  activated segmentation and STOP mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR playerState/Enables or disables the history display.
/// HIPAR playerSpeed/Sets the display time for one acquisition. The shorter the time, the 
/// HIPAR playerSpeed/faster is the replay.
/// HIPAR repeat/If ON, the replay of the history waveform sequence repeats 
/// HIPAR repeat/automatically.
ViStatus _VI_FUNC hmo_ConfigureHistory(
	ViSession	instrSession,
	ViInt32	channel,
	ViInt32	playerState,
	ViInt32	playerSpeed,
	ViBoolean	repeat
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, channel, HMO_VAL_CHANNEL_1, HMO_VAL_CHANNEL_4), 2, "Channel");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_HISTORY_CHANNEL_PLAYER_STATE,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                          HMO_ATTR_HISTORY_CHANNEL_PLAYER_STATE,
                                          playerState), 3, "Player State");
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                          HMO_ATTR_HISTORY_CHANNEL_PLAYER_SPEED,
                                          playerSpeed), 4, "Player Speed");
    
	viCheckParm (hmo_SetAttributeViBoolean (instrSession, rep_cap,
                                            HMO_ATTR_HISTORY_CHANNEL_REPEAT,
                                            repeat), 5, "Repeat");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures history display.
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) The segmented memory player is only visible on the HMO screen with 
/// HIFN  activated segmentation and STOP mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR currentAcquisition/Accesses a particular acquisition in the memory to display it.
ViStatus _VI_FUNC hmo_ConfigureHistoryAcquisitionView (ViSession instrSession,
                                                       ViInt32 channel,
                                                       ViInt32 currentAcquisition)
{
	ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, channel, HMO_VAL_CHANNEL_1, HMO_VAL_CHANNEL_4), 2, "Channel");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_HISTORY_CHANNEL_PLAYER_STATE,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                          HMO_ATTR_HISTORY_CHANNEL_CURRENT_ACQUISITION,
                                          currentAcquisition), 3, "Current Acquisition");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns history display date and time.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR bufferSize/This control indicates the allocated memory in Time and Date.
/// HIPAR date/Returns the date of the current acquisition that is shown in the 
/// HIPAR date/segment table (CHANnel<m>:HISTory:CURRent).
/// HIPAR relativeTime/Returns the relative time of the current acquisition - the time 
/// HIPAR relativeTime/difference to the newest acquisition (index = 0). See also: 
/// HIPAR relativeTime/CHANnel<m>:HISTory:CURRent.
/// HIPAR absoluteTime/Returns the abolsute daytime of the current acquisition that is shown 
/// HIPAR absoluteTime/in the segment table (CHANnel<m>:HISTory:CURRent).
ViStatus _VI_FUNC hmo_QueryHistoryDateTime(
	ViSession	instrSession,
	ViInt32	channel,
	ViInt32	bufferSize,
	ViChar	date[],
	ViChar	relativeTime[],
	ViChar	absoluteTime[]
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, channel, HMO_VAL_CHANNEL_1, HMO_VAL_CHANNEL_4), 2, "Channel");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_HISTORY_CHANNEL_ACQUISITION_DATE,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap), 2, "Channel");

    viCheckParm (hmo_GetAttributeViString (instrSession, rep_cap,
                                           HMO_ATTR_HISTORY_CHANNEL_ACQUISITION_DATE, bufferSize,
                                           date), 3, "Date");

    viCheckParm (hmo_GetAttributeViString (instrSession, rep_cap,
                                           HMO_ATTR_HISTORY_CHANNEL_ACQUISITION_RELATIVE_TIME, bufferSize,
                                           relativeTime), 4, "RelativeT ime");

    viCheckParm (hmo_GetAttributeViString (instrSession, rep_cap,
                                           HMO_ATTR_HISTORY_CHANNEL_ACQUISITION_ABSOLUTE_TIME, bufferSize,
                                           absoluteTime), 5, "Absolute Time");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function queries the number of acquisitions currently saved in 
/// HIFN  the memory. This number of acquisitions is available for history 
/// HIFN  viewing. It is also the number of acquisitions in an Ultra Segmentation 
/// HIFN  acquisition series.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR count/Returns the number of acquisitions currently saved in the memory.
ViStatus _VI_FUNC hmo_QueryHistoryAcquisitionsCount(
	ViSession	instrSession,
	ViInt32*	count
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_HISTORY_GET_ACQUISITION_COUNT,
                                          count), 2, "Count");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the markers.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR markerAction/This Control selects the marker action.
ViStatus _VI_FUNC hmo_MarkerSearch (ViSession instrSession,
                                              ViInt32 markerAction)
{
    ViStatus    error = VI_SUCCESS;

    viCheckParm (hmo_invalidViInt32Range (instrSession, markerAction, HMO_VAL_MARKER_ACTION_SET, HMO_VAL_MARKER_ACTION_ACLEAR), 2, "Marker Action");
    
    checkErr (Rs_LockSession (instrSession, 0));

    switch (markerAction)
    {
        case HMO_VAL_MARKER_ACTION_SET:
            viCheckErr (hmo_SetAttributeViString (instrSession, "",
                HMO_ATTR_MARKER_SET, NULL));
            break;
        case HMO_VAL_MARKER_ACTION_NEXT:
            viCheckErr (hmo_SetAttributeViString (instrSession, "",
                HMO_ATTR_MARKER_NEXT, NULL));
            break;
        case HMO_VAL_MARKER_ACTION_PREV:
            viCheckErr (hmo_SetAttributeViString (instrSession, "",
                HMO_ATTR_MARKER_PREVIOUS, NULL));
            break;
        case HMO_VAL_MARKER_ACTION_CLEAR:
            viCheckErr (hmo_SetAttributeViString (instrSession, "",
                HMO_ATTR_MARKER_CLEAR, NULL));
            break;
        case HMO_VAL_MARKER_ACTION_ACLEAR:
            viCheckErr (hmo_SetAttributeViString (instrSession, "",
                HMO_ATTR_MARKER_CLEAR_ALL, NULL));
            break;

        default:
            break;
    }
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the indicated measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR measurement/This control selects the measurement.
/// HIPAR measurementState/Switches the indicated measurement on or off.
ViStatus _VI_FUNC hmo_ConfigureMeasurement(
    ViSession   instrSession,
    ViInt32     measurement,
    ViBoolean   measurementState
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar   rep_cap_measurement[25] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_MEASUREMENT_ENABLED,
                                                 "Measurement",
                                                 measurement - 1,
                                                 25,
                                                 rep_cap_measurement), 2, "Measurement");

    viCheckParm(hmo_SetAttributeViBoolean(instrSession, rep_cap_measurement,
        HMO_ATTR_MEASUREMENT_ENABLED, measurementState), 3, "Measurement State");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the state of the indicated measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR measurement/This control selects the measurement.
/// HIPAR signalSource/Selects the source of the measurement.
/// HIPAR referenceSource/Selects the source of the reference.
ViStatus _VI_FUNC hmo_ConfigureMeasurementSource(
    ViSession   instrSession,
    ViInt32     measurement,
    ViInt32     signalSource,
    ViInt32     referenceSource
)
{
    ViStatus    error = VI_SUCCESS;
    ViString    signalSourceArr[] = {"NONE","CH1","CH2","CH3","CH4","M1","M2","M3","M4","M5","R1",
                                     "R2","R3","R4","QMA","D0","D1","D2","D3","D4","D5","D6","D7","D8","D9","D10","D11","D12","D13","D14","D15"};
	ViString	cmd = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, measurement, HMO_VAL_MEASUREMENT_1, HMO_VAL_MEASUREMENT_6), 2, "Measurement");

    viCheckParm (hmo_invalidViInt32Range (instrSession, signalSource, HMO_VAL_MEASUREMENT_SOURCE_NONE, HMO_VAL_MEASUREMENT_SOURCE_D15), 3, "Signal Source");

    viCheckParm (hmo_invalidViInt32Range (instrSession, referenceSource, HMO_VAL_MEASUREMENT_SOURCE_NONE, HMO_VAL_MEASUREMENT_SOURCE_R4), 4, "Reference Source");
    																									  
    if (referenceSource == HMO_VAL_MEASUREMENT_SOURCE_NONE)
	{
		sprintf (cmd, "MEAS%ld:SOUR %s\n", measurement, signalSourceArr[signalSource]);
	}
	else
	{
		sprintf (cmd, "MEAS%ld:SOUR %s,%s\n", measurement, signalSourceArr[signalSource], signalSourceArr[referenceSource]);
	}
	
	viCheckErr (viPrintf(instrSession, cmd));
    
    viCheckErr(hmo_CheckStatusTimed(instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Document your function here.
/// HIFN You may use multiple lines for documentation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR measurement/This control selects the measurement.
/// HIPAR quickMeasurementsEnabled/This function enables and disables all quick measurements of the indicated measurement
ViStatus _VI_FUNC hmo_ConfigureQuickMeasurements (ViSession instrSession,
                                                    ViInt32 measurement,
                                                    ViBoolean quickMeasurementsEnabled)
{
    ViStatus    error = VI_SUCCESS;
    ViChar   rep_cap_measurement[25] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_MEASUREMENT_ENABLED,
                                                 "Measurement",
                                                 measurement - 1,
                                                 25,
                                                 rep_cap_measurement), 2, "Measurement");
    
    if (quickMeasurementsEnabled)
    {
        viCheckParm(hmo_SetAttributeViString(instrSession, rep_cap_measurement,
        HMO_ATTR_QUICK_MEASUREMENTS_ENABLE, NULL), 3, "Quick Measurements Enable");
    }
    else
    {
        viCheckParm(hmo_SetAttributeViString(instrSession, rep_cap_measurement,
        HMO_ATTR_QUICK_MEASUREMENTS_DISABLE, NULL), 3, "Quick Measurements Disable");
    }
Error:
    return error;
}

/// HIFN  This function returns the results of the quick measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR measurement/This control selects the measurement.
/// HIPAR results/Returns the list of values.
ViStatus _VI_FUNC hmo_QueryQuickMeasurementResults (ViSession instrSession,
                                            ViInt32 measurement,
                                            ViInt32 arraySize,
                                            ViReal64 results[])
{
    ViStatus    error = VI_SUCCESS;
    ViChar      *buffer = NULL;
    ViChar      *pbuff = NULL;
    ViInt32     i = 0;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, measurement, HMO_VAL_MEASUREMENT_1, HMO_VAL_MEASUREMENT_6), 2, "Measurement");
    
    checkErr (viPrintf (instrSession, "MEAS%ld:ARES?\n", measurement));
    viCheckErr(Rs_ReadDataUnknownLength (instrSession, &buffer, NULL)); 
    
    pbuff = strtok (buffer, ",");
    
    while (pbuff != NULL && (i<arraySize))
    {
        if (i<arraySize)
        {
            results[i++] = atof (pbuff);
            pbuff = strtok (NULL, ",");
        }
        i++;
    }
    
    viCheckErr(hmo_CheckStatus(instrSession));
Error:
    if (buffer) free (buffer);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures automatic measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/This control selects the measurement.
/// HIPAR state/Activates or deactivates the statistical evaluation for the selected measurement.
/// HIPAR numberOfWaveforms/Sets the number of measured waveforms used for calculation of average and standard deviation.
ViStatus _VI_FUNC hmo_ConfigureAutomaticMeasurement (ViSession instrSession,
                                                     ViInt32 measurement,
                                                     ViBoolean state,
                                                     ViInt32 numberOfWaveforms)
{
    ViStatus    error = VI_SUCCESS;
    ViChar   rep_cap_measurement[25] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_AUTOMATIC_MEASUREMENT_STATE,
                                                 "Measurement",
                                                 measurement - 1,
                                                 25,
                                                 rep_cap_measurement), 2, "Measurement");

    viCheckParm(hmo_SetAttributeViBoolean (instrSession, rep_cap_measurement,
        HMO_ATTR_AUTOMATIC_MEASUREMENT_STATE, state), 3, "State");    
    
	viCheckParm(hmo_SetAttributeViInt32 (instrSession, rep_cap_measurement,
        HMO_ATTR_AUTOMATIC_MEASUREMENT_NUMBER_OF_WAVEFORMS, numberOfWaveforms), 4, "Number Of Waveforms");    
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function deletes the statistical results for the selected measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR instrSession/The handle identifies a particular instrument session.
/// HIPAR measurement/This control selects the measurement.
ViStatus _VI_FUNC hmo_ResetAutomaticMeasurement (ViSession instrSession,
                                                 ViInt32 measurement)
{
    ViStatus    error = VI_SUCCESS;
	ViChar   rep_cap_measurement[25] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_RESET_AUTOMATIC_MEASUREMENT,
                                                 "Measurement",
                                                 measurement - 1,
                                                 25,
                                                 rep_cap_measurement), 2, "Measurement");
    
    viCheckErr (hmo_SetAttributeViString (instrSession, rep_cap_measurement,
                                                HMO_ATTR_RESET_AUTOMATIC_MEASUREMENT,
                                                NULL));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
	
}

/// HIFN  This function returns the result of the automatic measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR instrSession/The handle identifies a particular instrument session.
/// HIPAR measurement/This control selects the measurement.
/// HIPAR numberOfWaveforms/Returns the current number of measured waveforms.
ViStatus _VI_FUNC hmo_QueryAutomaticMeasurementNumberOfWaveforms (ViSession instrSession,
                                                                  ViInt32 measurement,
                                                                  ViInt32 *numberOfWaveforms)
{
    ViStatus    error = VI_SUCCESS;
    ViChar   rep_cap_measurement[25] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_AUTOMATIC_MEASUREMENT_NUMBER_OF_MEASURED_WAVEFORMS,
                                                 "Measurement",
                                                 measurement - 1,
                                                 25,
                                                 rep_cap_measurement), 2, "Measurement");

    viCheckParm(hmo_GetAttributeViInt32 (instrSession, rep_cap_measurement,
        HMO_ATTR_AUTOMATIC_MEASUREMENT_NUMBER_OF_MEASURED_WAVEFORMS, numberOfWaveforms), 3, "Number Of Waveforms");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
	
}

/// HIFN  This function returns the result of the automatic measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR instrSession/The handle identifies a particular instrument session.
/// HIPAR measurement/This control selects the measurement.
/// HIPAR resultType/This control selects the result type.
/// HIPAR result/Returns the automatic measuremnt result.
ViStatus _VI_FUNC hmo_QueryAutomaticMeasurementResult (ViSession instrSession,
                                                       ViInt32 measurement,
                                                       ViInt32 resultType,
                                                       ViReal64 *result)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap_measurement[25] = "";
	ViChar      rep_cap_type[25] = "";

    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, resultType, HMO_VAL_AUTOMATIC_MEASUREMENT_AVERAGE, HMO_VAL_AUTOMATIC_MEASUREMENT_MAXIMUM), 3, "Result Type");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_MEASUREMENT_ENABLED,
                                                 "Measurement",
                                                 measurement - 1,
                                                 25,
                                                 rep_cap_measurement), 2, "Measurement");

	sprintf(rep_cap_type, ",%s", autoMeasTypeArr[resultType]);
	strcat(rep_cap_measurement, rep_cap_type);
	
    viCheckParm(hmo_GetAttributeViReal64 (instrSession, rep_cap_measurement,
        						HMO_ATTR_AUTOMATIC_MEASUREMENT_RESULT, result), 4, "Result"); 
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function returns the measurement category.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR instrSession/The handle identifies a particular instrument session.
/// HIPAR measurement/This control selects the measurement.
/// HIPAR category/Returns the measurement category.
ViStatus _VI_FUNC hmo_QueryMeasurementCategory (ViSession instrSession,
                                                  ViInt32 measurement,
                                                  ViInt32 *category)
{
    ViStatus    error = VI_SUCCESS;
    ViChar   rep_cap_measurement[25] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_MEAS_CATEGORY,
                                                 "Measurement",
                                                 measurement - 1,
                                                 25,
                                                 rep_cap_measurement), 2, "Measurement");

    viCheckParm(hmo_GetAttributeViInt32 (instrSession, rep_cap_measurement,
        HMO_ATTR_MEAS_CATEGORY, category), 3, "Category");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Sets the edges to be used for delay measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR instrSession/The handle identifies a particular instrument session.
/// HIPAR measurement/This control selects the measurement.
/// HIPAR source1Slope/Slope of source 1 (first waveform).
/// HIPAR source2Slope/Slope of source 2 (second waveform).
ViStatus _VI_FUNC hmo_ConfigureDelayMeasurementSlope (ViSession instrSession,
                                                      ViInt32 measurement,
                                                      ViInt32 source1Slope,
                                                      ViInt32 source2Slope)
{
    ViStatus    error = VI_SUCCESS;
    ViString	slopeArr[] = {"Pos","Neg"};
	ViChar      rep_cap[25] = "";
	ViChar      rep_cap_slope[25] = "";
	
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, source1Slope, HMO_VAL_MEAS_SLOPE_POS, HMO_VAL_MEAS_SLOPE_NEG), 3, "Source 1 Slope");
    
	viCheckParm (hmo_invalidViInt32Range (instrSession, source2Slope, HMO_VAL_MEAS_SLOPE_POS, HMO_VAL_MEAS_SLOPE_NEG), 4, "Source 2 Slope");
    
	viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_MEASUREMENT_ENABLED,
                                                 "Measurement",
                                                 measurement - 1,
                                                 25,
                                                 rep_cap), 2, "Measurement");
	
	sprintf (rep_cap_slope, ",%s", slopeArr[source1Slope]);
	strcat (rep_cap, rep_cap_slope);
	sprintf (rep_cap_slope, ",%s", slopeArr[source2Slope]);
	strcat (rep_cap, rep_cap_slope);

    viCheckParm(hmo_SetAttributeViString(instrSession, rep_cap,
        HMO_ATTR_MEAS_DELAY_SLOPE, NULL), 2, "Measurement"); 
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
	
}

/// HIFN  This function sets the lower and upper reference levels.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR instrSession/The handle identifies a particular instrument session.
/// HIPAR relativeMode/Selects the reference level.
ViStatus _VI_FUNC hmo_ConfigureReferenceLevelMode (ViSession instrSession,
                                                     ViInt32 relativeMode)
{
    ViStatus    error = VI_SUCCESS;

    viCheckParm(hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_MEAS_RELATIVE_MODE, relativeMode), 3, "Relative Mode");  

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the cursor settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR cursorState/Switches the indicated cursor on or off.
/// HIPAR source/Defines the source of the cursor measurement.
/// HIPAR type/Defines the cursor measurement type.
ViStatus _VI_FUNC hmo_ConfigureCursor(
    ViSession   instrSession,
    ViBoolean   cursorState,
    ViInt32     source,
    ViInt32     type
)
{
    ViStatus    error = VI_SUCCESS;

    viCheckParm(hmo_SetAttributeViBoolean(instrSession, NULL,
        HMO_ATTR_CURSOR_ENABLED, cursorState), 2, "Cursor State");  
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_CURSOR_SOURCE, source), 3, "Cursor Source");
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_CURSOR_MEASUREMENT_TYPE, type), 4, "Type");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function switches all cursors off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
ViStatus _VI_FUNC hmo_AllCursorsOff(
    ViSession   instrSession
)
{
    ViStatus    error = VI_SUCCESS;

    viCheckParm(hmo_SetAttributeViString(instrSession, "",
        HMO_ATTR_ALL_CURSORS_OFF, NULL), 2, "All Cursors Off");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function resets the cursor to the initial position or sets the 
/// HIFN  cursor lines to typical points of the waveform depending
/// HIFN  on the selected measurement type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR position/Selects if the cursor position resets or autosets.
ViStatus _VI_FUNC hmo_SetCursorPosition(
	ViSession	instrSession,
	ViInt32	position
)
{
    ViStatus  error = VI_SUCCESS;
	ViAttr attr[2] = {HMO_ATTR_CURSOR_AUTOSET, HMO_ATTR_CURSOR_RESET};

    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, position, HMO_VAL_CURSOR_POSITION_AUTOSET, HMO_VAL_CURSOR_POSITION_RESET), 2, "Position");
    
    viCheckErr (hmo_SetAttributeViString (instrSession, "",
                                          attr[position], NULL));
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the horizontal and vertical position of selected cursor or cursor line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR cursor/This control selects the cursor.
/// HIPAR xPosition/Defines X position of selected cursor.
/// HIPAR xPosition/Defines Y position of selected cursor.
ViStatus _VI_FUNC hmo_ConfigureCursorPosition (ViSession instrSession,
                                                 ViInt32 cursor,
                                                 ViReal64 xPosition,
                                                 ViReal64 yPosition)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                               HMO_ATTR_CURSOR_X_POSITION,
                                               "CPosition",
                                               cursor - 1,
                                               15,
                                               rep_cap), 2, "Cursor");

    viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_CURSOR_X_POSITION, xPosition), 3, "X Position"); 
    
    viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_CURSOR_Y_POSITION, yPosition), 4, "Y Position");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the positioning mode of the horizontal and vertical cursors.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR xCoupling/Defines the positioning mode of the vertical cursor.
/// HIPAR yCoupling/Defines the positioning mode of the horizontal cursor.
ViStatus _VI_FUNC hmo_ConfigureCursorCoupling(
    ViSession   instrSession,
    ViBoolean   xCoupling,
    ViBoolean   yCoupling
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, NULL));

    viCheckParm(hmo_SetAttributeViBoolean(instrSession, NULL,
        HMO_ATTR_CURSOR_X_POSITION_COUPLING, xCoupling), 2, "X Coupling");  
    
    viCheckParm(hmo_SetAttributeViBoolean(instrSession, NULL,
        HMO_ATTR_CURSOR_Y_POSITION_COUPLING, yCoupling), 3, "Y Coupling");  
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the cursor waveform tracking
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR tracking/Switches the cursor waveform tracking.
ViStatus _VI_FUNC hmo_ConfigureCursorWaveformTracking(
    ViSession   instrSession,
    ViBoolean   tracking
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_SetAttributeViBoolean(instrSession, NULL,
        HMO_ATTR_CURSOR_TRACKING, tracking), 3, "Cursor Tracking");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the adjustment of cursor lines if the vertical or horizontal scales are changed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR adjustment/Switches the adjustment of cursor lines if the vertical or horizontal scales are changed.
ViStatus _VI_FUNC hmo_ConfigureCursorAdjustment (ViSession instrSession,
                                                     ViBoolean adjustment)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm(hmo_SetAttributeViBoolean (instrSession, NULL,
        HMO_ATTR_CURSOR_ADJUSTMENT, adjustment), 2, "Adjustment");   
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function sets the unit for horizontal or vertical ratio measurements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR direction/Selects the distance direction
/// HIPAR measurementUnit/Defines the measurement unit.
ViStatus _VI_FUNC hmo_ConfigureCursorRatioMeasurementUnit (ViSession instrSession,
                                                               ViInt32 direction,
                                                               ViInt32 measurementUnit)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    switch(direction) 
    {
        case HMO_VAL_CURSOR_HORIZONTAL:
            viCheckParm(hmo_SetAttributeViInt32 (instrSession, NULL,
            HMO_ATTR_CURSOR_X_RATIO_MEASUREMENT_UNIT, measurementUnit), 3, "Measurement Unit");   
            
        break;
            
        case HMO_VAL_CURSOR_VERTICAL: {
		    viCheckParm (hmo_invalidViInt32Range (instrSession, measurementUnit, HMO_VAL_UNIT_RATIO, HMO_VAL_UNIT_PCT), 3, "Measurement Unit");
            viCheckParm(hmo_SetAttributeViInt32 (instrSession, NULL,
            HMO_ATTR_CURSOR_Y_RATIO_MEASUREMENT_UNIT, measurementUnit), 3, "Measurement Unit");   
		}
        
		break;
            
        default: 
        break;
    }
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}



/// HIFN  This function returns the ratio of the x-values (e.g. a duty cycle) between the first and second cursors and the first and third cursors
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR direction/Selects the distance direction
/// HIPAR ratioMeasurement/Returns the ratio.
ViStatus _VI_FUNC hmo_QueryCursorRatioMeasurement (ViSession instrSession,
                                                       ViInt32 direction,
                                                       ViReal64 *ratioMeasurement)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    switch(direction) 
    {
        case HMO_VAL_CURSOR_HORIZONTAL:
            viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
                HMO_ATTR_CURSOR_X_RATIO_MEASUREMENT, ratioMeasurement), 3, "Ratio Measurement");   
        break;
            
        case HMO_VAL_CURSOR_VERTICAL:
            viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
                HMO_ATTR_CURSOR_Y_RATIO_MEASUREMENT, ratioMeasurement), 3, "Ratio Measurement");   
        break;
            
        default: 
        break;
    }
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function queries the delta value (distance) of two horizontal or vertical cursors (RTM) / cursor lines (RTO).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR cursorDistance/Returns the delta value (distance) of two horizontal or vertical cursors (RTM) / cursor lines (RTO).
/// HIPAR direction/Selects the distance direction
ViStatus _VI_FUNC hmo_QueryCursorDistance (ViSession instrSession,
                                             ViInt32 direction,
                                               ViReal64 *cursorDistance)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_CURSOR_DISTANCE,
                                                 "CursorDirection",
                                                 direction,
                                                 15,
                                                 rep_cap), 2, "Direction");
    
    viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_CURSOR_DISTANCE, cursorDistance), 3, "Cursor Distance");   
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function queries the inverse value of the delta value (distance) of the two vertical or horizontal cursors (RTM) / cursor lines (RTO).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR cursorDistance/Returns the inverse value of the delta value (distance) of the two vertical or horizontal cursors (RTM) / cursor lines (RTO).
ViStatus _VI_FUNC hmo_QueryCursorInverseDistance(
    ViSession   instrSession,
    ViReal64*   cursorDistance
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_GetAttributeViReal64(instrSession, NULL,
        HMO_ATTR_CURSOR_INVERSE_DISTANCE, cursorDistance), 2, "Cursor Distance");   
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function queries the inverse value of the voltage difference
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR cursorDistance/Returns the inverse value of the voltage difference.
ViStatus _VI_FUNC hmo_QueryCursorVoltageInverseDistance (ViSession instrSession,
                                                             ViReal64 *cursorDistance)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeViReal64 (instrSession, "Vert", 
        HMO_ATTR_CURSOR_VOLTAGE_INVERSE_DISTANCE, cursorDistance), 3, "Cursor Distance");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function queries the cursor positions.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR data/Returns the cursor positions.
ViStatus _VI_FUNC hmo_QueryCursorPosition (ViSession instrSession,
                                              ViReal64*  data)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckErr (hmo_GetAttributeViReal64 (instrSession, NULL,
        HMO_ATTR_CURSOR_POSITION, data));
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function sets the cursor to the next or the previous peak.
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) For FFT analysis only
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/This control selects the cursor number.
/// HIPAR peak/This control selects if the cursor is set to the next or the previous 
/// HIPAR peak/peak.
ViStatus _VI_FUNC hmo_SetFFTAnalysisCursorToPeak(
	ViSession	instrSession,
	ViInt32	cursor,
	ViInt32	peak
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";
	ViAttr  attr[2] = {HMO_ATTR_CURSOR_PEAK_RIGHT, HMO_ATTR_CURSOR_PEAK_LEFT};

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, cursor, HMO_VAL_CURSOR_1, HMO_VAL_CURSOR_2), 2, "Cursor");
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, peak, HMO_VAL_CURSOR_PEAK_NEXT, HMO_VAL_CURSOR_PEAK_PREVIOUS), 3, "Peak");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_CURSOR_PEAK_RIGHT,
                                                 "CursorNumber",
                                                 cursor,
                                                 15,
                                                 rep_cap), 2, "Cursor");

    viCheckErr (hmo_SetAttributeViString (instrSession, rep_cap,
                                          attr[peak], NULL));

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Defines the main measurement. This measurement is the one referred to 
/// HIFN  if the measurement waveform is used as a source for math calculations. 
/// HIFN  The main measurement type must belong to the same category as the other 
/// HIFN  types assigned to the same measurement waveform, if there are any.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR measurement/Selects waveform measurement.
/// HIPAR measurementFunction/Defines or queries the main measurement. This measurement is the one 
/// HIPAR measurementFunction/referred to if the measurement waveform is used as a source for math 
/// HIPAR measurementFunction/calculations. The main measurement type must belong to the same 
/// HIPAR measurementFunction/category as the other types assigned to the same measurement waveform, 
/// HIPAR measurementFunction/if there are any.
ViStatus _VI_FUNC hmo_ConfigureAmplitudeTimeMainMeasurement(
    ViSession   instrSession,
    ViInt32 measurement,
    ViInt32 measurementFunction
)
{
    ViStatus error = VI_SUCCESS;
    ViChar   rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_AMPT_MAIN_MEASUREMENT,
                                                 "Measurement",
                                                 measurement - 1,
                                                 15,
                                                 rep_cap), 2, "Measurement");

    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_AMPT_MAIN_MEASUREMENT, measurementFunction), 3, "Amplitude Time Measurement Function");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function turns the mask test mode on or off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR state/This Control Turns the mask test mode on or off.
ViStatus _VI_FUNC hmo_ConfigureMaskTestEnable (ViSession instrSession,
                                          ViBoolean state)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
        HMO_ATTR_MASK_ENABLED, state), 3, "State");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Creates a mask from the envelope waveform of the test source set with MASK: SOURce.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC hmo_MaskCopyChannel (ViSession instrSession)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckErr (hmo_SetAttributeViString (instrSession, NULL,
        HMO_ATTR_MASK_COPY_CHANNEL, NULL ));

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Creates a mask from the envelope waveform of the test source set with MASK: SOURce.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR totalCount/This Output shows the number of tested acquisitions.
ViStatus _VI_FUNC hmo_QueryMaskAcquisitions (ViSession instrSession,
                                        ViInt32 *totalCount)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeViInt32 (instrSession, NULL,
        HMO_ATTR_MASK_COUNT, totalCount), 2, "Total Count");
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function returns the number of acquistions that hit the mask.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR acquistions/This Control shows the number of acquistions.
ViStatus _VI_FUNC hmo_QueryMaskHitCount (ViSession instrSession,
                                           ViInt32 *acquistions)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeViInt32 (instrSession, NULL,
        HMO_ATTR_MASK_HIT_COUNT, acquistions), 2, "Acquistions");
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function loads a stored mask from the specified file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR name/Defines the file with stored mask.
ViStatus _VI_FUNC hmo_MaskLoad (ViSession instrSession, ViString name)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViString (instrSession, NULL,
        HMO_ATTR_MASK_LOAD, name), 2, "Name");
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function saves the current mask in the specified file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR name/Defines the file.
ViStatus _VI_FUNC hmo_MaskStore (ViSession instrSession,
                                        ViString name)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViString (instrSession, NULL,
        HMO_ATTR_MASK_STORE, name), 2, "Name");
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Enable or disable of pulses at the Y-OUTput if mask is distorted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR state/Enable or disable of pulses at the Y-OUTput if mask is distorted.
ViStatus _VI_FUNC hmo_ConfigureMaskYOutputPulsesEnable (ViSession instrSession,
                                                        ViBoolean state)
{
	ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViBoolean (instrSession, NULL,
        			HMO_ATTR_MASK_YOUTPUT_PULSES_ENABLED, state), 2, "State");
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Configures the conditions for mask failures.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR sound/Generates a beep sound. Defines when and how often the action will be 
/// HIPAR sound/executed.
/// HIPAR stop/Stops the waveform acquisition. Defines when and how often the action 
/// HIPAR stop/will be executed.
/// HIPAR stopCount/Sets the number of mask violations after which the action is executed.
/// HIPAR pulse/Emits an impulse. Defines when and how often the action will be 
/// HIPAR pulse/executed.
/// HIPAR screenshot/Saves a screenshot according to printer output settings. Defines when 
/// HIPAR screenshot/and how often the action will be executed.
/// HIPAR screenshotDestination/Defines the storage location whether the violated mask screenshot is 
/// HIPAR screenshotDestination/saved. For output settings, see chapter Data and File Management.
/// HIPAR print/Prints a screenshot to a printer connected to the USB connector on the 
/// HIPAR print/front or rear panel. Defines when and how often the action will be 
/// HIPAR print/executed.
/// HIPAR trace/Saves the waveform data according to the screenshot output settings. 
/// HIPAR trace/Defines when and how often the action will be executed.
/// HIPAR traceDestination/Defines whether the violated mask trace (waveform) is printed. For 
/// HIPAR traceDestination/output settings, see chapter 'Data and File Management'.
ViStatus _VI_FUNC hmo_ConfigureMaskActions(
	ViSession	instrSession,
	ViInt32	sound,
	ViInt32	stop,
	ViInt32	stopCount,
	ViInt32	pulse,
	ViInt32	screenshot,
	ViString	screenshotDestination,
	ViInt32	print,
	ViInt32	trace,
	ViString	traceDestination
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_MASK_EVENT_MODE_SOUND,
                                          sound), 2, "Sound");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_MASK_EVENT_MODE_STOP_ACQUISITION,
                                          stop), 3, "Stop");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_MASK_EVENT_COUNT_STOP_ACQUISITION,
                                          stopCount), 4, "Stop Count");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_MASK_EVENT_MODE_IMPULSE,
                                          pulse), 5, "Pulse");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_MASK_EVENT_MODE_SCREENSHOT,
                                          screenshot), 6, "Screenshot");
    
	viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                           HMO_ATTR_MASK_SCREENSAVER_DESTINATION,
                                           screenshotDestination), 7, "Screenshot Destination");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_MASK_EVENT_MODE_PRINT,
                                          print), 8, "Print");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_MASK_EVENT_MODE_SAVE_WAVEFORM_DATA,
                                          trace), 9, "Trace");
    
	viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                           HMO_ATTR_MASK_WAVEFORM_DESTINATION,
                                           traceDestination), 10, "Trace Destination");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Sets the counters of passed and failed acquisitions to Zero.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC hmo_MaskResetTestCounter(
	ViSession	instrSession
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckErr (hmo_SetAttributeViString (instrSession, "",
                                          HMO_ATTR_MASK_RESET_TEST_COUNTER, NULL));
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function changes the width of the mask in vertical direction.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR yPosition/This control defines the offset.
ViStatus _VI_FUNC hmo_ConfigureMaskVerticalOffset (ViSession instrSession,
                                          ViReal64 yPosition)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, NULL,
        HMO_ATTR_MASK_VERTICAL_OFFSET, yPosition), 2, "yPosition ");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function changes the width of the mask in vertical direction.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR yStretch/This control defines stretch or compress.
ViStatus _VI_FUNC hmo_ConfigureMaskVerticalScaling (ViSession instrSession,
                                                    ViReal64 yStretch)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, NULL,
        HMO_ATTR_MASK_VERTICAL_SCALING, yStretch), 2, "Y Stretch");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function changes the width of the mask in vertical direction.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR yWidth/This control defines the shift.
ViStatus _VI_FUNC hmo_ConfigureMaskVerticalWidth (ViSession instrSession,
                                          ViReal64 yWidth)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, NULL,
        HMO_ATTR_MASK_VERTICAL_WIDTH, yWidth), 3, "Y Width");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function changes the width of the mask in vertical direction.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR xWidth/This control defines the width.
ViStatus _VI_FUNC hmo_ConfigureMaskHorizontalWidth (ViSession instrSession,
                                          ViReal64 xWidth)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, NULL,
        HMO_ATTR_MASK_HORIZONTAL_WIDTH, xWidth), 2, "X Width");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Configures mask test parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR action/Selects the action.
ViStatus _VI_FUNC hmo_ConfigureMaskTest (ViSession instrSession,
                                         ViInt32 channel,
                                         ViInt32 action)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
        HMO_ATTR_MASK_SOURCE, channel), 2, "Channel");
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
        HMO_ATTR_MASK_TEST, action), 3, "Action");
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function enables the decoding of the selected bus.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR state/Enables the decoding of the selected bus.
ViStatus _VI_FUNC hmo_ConfigureDecodeState(
    ViSession    instrSession,
    ViInt32 bus,
    ViBoolean    state
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_STATE,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm (hmo_SetAttributeViBoolean (instrSession, rep_cap,
                                                 HMO_ATTR_PROTOCOL_STATE, 
                                                 state
                                                 ), 3, "State");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Selects protocol type.
/// HIFN You may use multiple lines for documentation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR protocol/This control selects protocol type.
ViStatus _VI_FUNC hmo_ConfigureBusProtocol (ViSession instrSession,
                                            ViInt32 bus, ViInt32 protocol)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_TYPE,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_TYPE, protocol), 3, "Protocol Type");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Configuration of the protocol display
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR format/Sets the decoding format for the display on the screen.
/// HIPAR height/Sets the height of the display on the screen.
/// HIPAR displayLines/Displays the individual bit lines above the decoded bus line.
/// HIPAR verticalPosition/selects the vertical position of the decoded bus signal in divisions on the sreen
ViStatus _VI_FUNC hmo_ConfigureProtocolDisplay (ViSession instrSession,
                                                ViInt32 bus, ViInt32 format, 
                                                ViInt32 height, ViBoolean displayLines,
                                                ViReal64 verticalPosition)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_DISPLAY_FORMAT,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_DISPLAY_FORMAT, format), 3, "Format");
    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_DISPLAY_HEIGHT, height), 4, "Height");
    viCheckParm(hmo_SetAttributeViBoolean(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_DISPLAY_LINES, displayLines), 5, "Display Lines");    
    viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_DISPLAY_VERTICAL, verticalPosition), 6, "Vertical Position");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Configuration of the protocol label.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR labelState/Swichtes the label of the Bus on or off.
/// HIPAR label/Sets the label for the Bus, maximum 8 characters.
ViStatus _VI_FUNC hmo_ConfigureProtocolLabel (ViSession instrSession,
                                              ViInt32 bus, ViBoolean labelState,
                                              ViString label)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_LABEL_STATE,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm(hmo_SetAttributeViBoolean(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_LABEL_STATE, labelState), 3, "Label State");    
    
    viCheckParm(hmo_SetAttributeViString(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_LABEL, label), 4, "Label");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Configuration of the internal bus signal source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR busSignalSourceFunction/Define the function of the internal bus signal source.
/// HIPAR busSignalSourceFrequency/Define the frequency of the internal bus signal source.
ViStatus _VI_FUNC hmo_ConfigureBusSignalSource (ViSession instrSession,
                                                ViInt32 busSignalSourceFunction,
                                                ViReal64 busSignalSourceFrequency)
{
    ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                               HMO_ATTR_BUS_SIGNAL_SOURCE,
                                               busSignalSourceFunction
                                               ), 2, "Bus Signal Source Function");

    viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                               HMO_ATTR_BUS_SIGNAL_SOURCE_FREQUENCY,
                                               busSignalSourceFrequency
                                               ), 3, "Bus Signal Source Frequency");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures source waveform of the data line (SDA) and 
/// HIFN  clock line (SCL).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR line/This control select I2C line.
/// HIPAR waveformSource/Selects the source of the waveform.
ViStatus _VI_FUNC hmo_ConfigureI2CSource(
    ViSession    instrSession,
    ViInt32 bus,
    ViInt32      line,
    ViInt32      waveformSource
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar    rep_cap[15] = "";
    ViAttr    attr[2] = {HMO_ATTR_PROTOCOL_I2C_CLOCK_SOURCE, HMO_ATTR_PROTOCOL_I2C_DATA_SOURCE};
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	viCheckParm (hmo_invalidViInt32Range (instrSession, line, HMO_VAL_I2C_SCL, HMO_VAL_I2C_SDA), 3, "Line");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_I2C_CLOCK_SOURCE,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                               attr[line],
                                               waveformSource
                                               ), 4, "Waveform Source");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function sets the trigger for i2c bus.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR access/Selects access mode.
/// HIPAR addressLength/Sets the length of the slave address.
/// HIPAR deviceAddress/This control sets the address of the slave device.
/// HIPAR triggerMode/Sets the trigger mode for I2C.
/// HIPAR patternLength/This Control defines how many bytes are considered in the trigger condition.
/// HIPAR pattern/This control defines the bit pattern as trigger condition.
/// HIPAR patternOffset/Sets the number of bytes before the first byte of interest, relating to the end of the address bytes.
ViStatus _VI_FUNC hmo_ConfigureI2CTriggerSetting (ViSession instrSession,
                                               ViInt32 access,
                                               ViInt32 addressLength,
                                               ViString deviceAddress,
                                               ViInt32 triggerMode,
                                               ViInt32 patternLength,
                                               ViString pattern,
                                               ViInt32 patternOffset)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_PROTOCOL_I2C_TRIGGER_ACCESS, access), 2, "Access");    
    
    viCheckParm (hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_TYPE, addressLength), 3, "Address length");    

    viCheckParm (hmo_SetAttributeViString (instrSession, NULL,
        HMO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS, deviceAddress), 4, "Device Address");    

    viCheckParm (hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_PROTOCOL_I2C_TRIGGER_MODE, triggerMode), 5, "Trigger Mode");    
    
    viCheckParm (hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_PROTOCOL_I2C_TRIGGER_CONDITION_LENGTH, patternLength), 6, "Pattern Length");    
    
    viCheckParm (hmo_SetAttributeViString (instrSession, NULL,
        HMO_ATTR_PROTOCOL_I2C_TRIGGER_BIT_PATTERN, pattern), 7, "Pattern");    

    viCheckParm (hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_PROTOCOL_I2C_TRIGGER_FIRST_BYTE_OFFSET, patternOffset), 8, "Pattern Offset");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Select the state for each digital channel. Sets the logical combination of the trigger states of the channels. Sets the trigger point depending on the result of the logical combination of the channel states. 
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR patternSource/This control sets the state for each digital channel.
/// HIPAR patternFunction/Sets the logical combination of the trigger states of the channels.
/// HIPAR patternCondition/This Control sets the trigger point depending on the result of the logical combination of the channel states.
ViStatus _VI_FUNC hmo_ConfigurePatternTriggerSource (ViSession instrSession,
                                                         ViString patternSource,
                                                         ViInt32 patternFunction,
                                                         ViInt32 patternCondition)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    checkErr (hmo_ConfigureTrigger (instrSession, HMO_VAL_TRIGGER_A,
                                      HMO_VAL_PATTERN_TRIGGER));
    viCheckParm (hmo_SetAttributeViString (instrSession, NULL,
        HMO_ATTR_TRIGGER_PATTERN_SOURCE, patternSource), 3, "Pattern Source");    
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, NULL,
        HMO_ATTR_TRIGGER_PATTERN_FUNCTION, patternFunction), 4, "Pattern Function");    

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, NULL,
        HMO_ATTR_TRIGGER_PATTERN_POINT_STATE, patternCondition), 5, "Pattern Condition");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the number of decoded frames.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR count/Number of decoded frames.
ViStatus _VI_FUNC hmo_QueryI2CFrameCount (ViSession instrSession, ViInt32 bus,
                                            ViInt32 *count)
{
	ViStatus    error = VI_SUCCESS;
	ViChar  rep_cap[15] = "";
	
    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_LABEL_STATE,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");
	
    viCheckParm (hmo_GetAttributeViInt32 (instrSession, rep_cap,
				        						HMO_ATTR_PROTOCOL_I2C_FRAME_COUNT, 
												count), 2, "Count"); 
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the overall state of the frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR frame/This control selects the frame.
/// HIPAR status/The overall state of the frame.
/// HIPAR frameStart/Time of frame start
/// HIPAR frameStop/Time of frame end.
/// HIPAR addressType/This control show address length.
/// HIPAR address/Value of the frame address.
/// HIPAR RWBit/Value of the R/W bit.
/// HIPAR ackBit/Value of the address acknowledge bit.
ViStatus _VI_FUNC hmo_QueryI2CFrameStatus (ViSession instrSession, ViInt32 bus,
                                             ViInt32 frame, ViInt32 *status,
                                             ViReal64 *frameStart,
                                             ViReal64 *frameStop,
                                             ViInt32 *addressType,
                                             ViInt32 *address, ViInt32 *RWBit,
                                             ViInt32 *ackBit)
{
	ViStatus    error = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE];

    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
	
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:STAT?", "%s", bus, frame, buffer));
    *status = hmo_StringIndex (protocolI2CFrameStatus_Arr, buffer);
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:STAR?", "%le", bus, frame, frameStart));
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:STOP?", "%le", bus, frame, frameStop));
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:AMOD?", "%s", bus, frame, buffer));
    *addressType = hmo_StringIndex (protocolI2CAddressType_Arr, buffer);
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:ADDR?", "%ld", bus, frame, address));
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:ACC?", "%s", bus, frame, buffer));
    *RWBit = hmo_StringIndex (protocolI2CRWBit_Arr, buffer);
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:AACC?", "%s", bus, frame, buffer));
    *ackBit = hmo_StringIndex (protocolI2CAckBit_Arr, buffer);
    
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the slave address of the indicated frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR frame/This control selects the frame.
/// HIPAR address/Value of the frame slave address.
ViStatus _VI_FUNC hmo_QueryI2CFrameSlaveAddress (ViSession instrSession, ViInt32 bus,
                                                   ViInt32 frame,
                                                   ViInt32 *address)
{
	ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:ADEV?", "%ld", bus, frame, address));

    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the start time of the address field for the indicated frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR frame/This control selects the frame.
/// HIPAR addressStart/Time of address start.
ViStatus _VI_FUNC hmo_QueryI2CFrameAddressStartTime (ViSession instrSession, ViInt32 bus,
                                                             ViInt32 frame,
                                                             ViReal64 *addressStart)
{
	ViStatus    error = VI_SUCCESS;
    
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:AST?", "%le", bus, frame, addressStart));

    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the start time of the address acknowledge bit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR frame/This control selects the frame.
/// HIPAR ackBitStart/Time of ack bit start.
ViStatus _VI_FUNC hmo_QueryI2CFrameAddressAckBitStart (ViSession instrSession, ViInt32 bus,
                                                         ViInt32 frame,
                                                         ViReal64 *ackBitStart)
{
	ViStatus    error = VI_SUCCESS;
    
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:ADBS?", "%le", bus, frame, ackBitStart));

    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function checks if address is complete.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR frame/This control selects the frame.
/// HIPAR complete/Status of address.
ViStatus _VI_FUNC hmo_QueryI2CFrameAddressComplete (ViSession instrSession, ViInt32 bus,
                                                      ViInt32 frame,
                                                      ViBoolean *complete)
{
	ViStatus    error = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE];
	
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
	viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:ACOM?", "%s", bus, frame, buffer));
    if (strcmp (buffer, "ON") == 0) 
        *complete = VI_TRUE;
    else
        *complete = VI_FALSE;	

    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function returns the number of bytes in the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR frame/This control selects the frame.
/// HIPAR length/Returns the number of bytes in the specified frame
ViStatus _VI_FUNC hmo_QueryI2CFrameLength (ViSession instrSession, ViInt32 bus,
                                             ViInt32 frame, ViInt32 *length)
{
	ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:BCO?", "%ld", bus, frame, length));

    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the data value of the specified byte.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR frame/This control selects the frame.
/// HIPAR byteNumber/This control selects the Byte.
/// HIPAR data/Value of the specified byte
/// HIPAR ackBit/Value of the data acknowledge bit.
ViStatus _VI_FUNC hmo_QueryI2CFrameData (ViSession instrSession, ViInt32 bus,
                                           ViInt32 frame, ViInt32 byteNumber,
                                           ViInt32 *data, ViInt32 *ackBit)
{
	ViStatus    error = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE];

    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:BYTE%ld:VAL?", "%ld", bus, frame, byteNumber, data));
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:BYTE%ld:ACC?", "%s", bus, frame, byteNumber, buffer));
    *ackBit = hmo_StringIndex(protocolI2CAckBit_Arr, buffer);
    
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the start time of the acknowledge bit of the specified byte.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR frame/This control selects the frame.
/// HIPAR byteNumber/This control selects the Byte.
/// HIPAR startTime/Start time of the acknowledge bit of the specified byte
ViStatus _VI_FUNC hmo_QueryI2CFrameAcknowledgeByteStart (ViSession instrSession, ViInt32 bus,
                                                           ViInt32 frame,
                                                           ViInt32 byteNumber,
                                                           ViReal64 *startTime)
{
	ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:BYTE%ld:ACKS?", "%le", bus, frame, byteNumber, startTime));
	
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the start time of the specified data byte.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR frame/This control selects the frame.
/// HIPAR byteNumber/Document parameter here.
/// HIPAR startTime/Start time of the byte.
ViStatus _VI_FUNC hmo_QueryI2CFrameDataByteStart (ViSession instrSession, ViInt32 bus,
                                                    ViInt32 frame,
                                                    ViInt32 byteNumber,
                                                    ViReal64 *startTime)
{
	ViStatus    error = VI_SUCCESS;
   
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:BYTE%ld:STAR?", "%le", bus, frame, byteNumber, startTime));
	
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function checks if data byte is complete.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR frame/This control selects the frame.
/// HIPAR byteNumber/This control selects the Byte.
/// HIPAR complete/Indicates if specified data byte is complete.
ViStatus _VI_FUNC hmo_QueryI2CFrameDataComplete (ViSession instrSession, ViInt32 bus,
                                                   ViInt32 frame,
                                                   ViInt32 byteNumber,
                                                   ViBoolean *complete)
{
	ViStatus    error = VI_SUCCESS;
	ViChar      buffer[HMO_IO_BUFFER_SIZE];
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:I2C:FRAM%ld:BYTE%ld:COMP?", "%s", bus, frame, byteNumber, buffer));
    
    if (strcmp(buffer, "ON") == 0) 
        *complete = VI_TRUE;
    else
        *complete = VI_FALSE;
	
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the all data words of the specified frame in comma-separated list of decimal values of the data bytes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR frame/This control selects the frame.
/// HIPAR arraySize/Pass the number of values allocated for Data result array.
/// HIPAR data/Data words of the specified frame.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC hmo_QueryI2CFrameAllData (ViSession instrSession, ViInt32 bus,
                                              ViInt32 frame, ViInt32 arraySize,
                                              ViInt32 data[],
                                              ViInt32 *returnedValues)
{
	ViStatus    error = VI_SUCCESS;
	ViChar      *p2buf  = NULL;
    ViChar      *extBuf=NULL; 
    ViUInt32    ret_cnt;
    ViInt32     i=0;
    ViInt32     value_count = 0;
	
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
	
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
    viCheckErr( viPrintf(instrSession, "BUS%ld:I2C:FRAM%d:DATA?", bus, frame));
    viCheckErr (Rs_ReadDataUnknownLength(instrSession, &extBuf, &ret_cnt)); 
    
    p2buf = strtok(extBuf, ",");
    
    value_count = atoi (p2buf);
    
    arraySize = (arraySize < value_count) ? arraySize : value_count;
    
    p2buf = strtok(NULL, ",");
    
    while (p2buf && (i < arraySize))
    {                  
        data[i] = atol(p2buf);
        p2buf = strtok(NULL, ",");
        i++;
    }
    *returnedValues = i;
	
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures input channel of the selected line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR line/This control select configured SPI line.
/// HIPAR waveformSource/Selects the source of the waveform.
ViStatus _VI_FUNC hmo_ConfigureSPISource(
    ViSession    instrSession,
    ViInt32 bus,
    ViInt32        line,
    ViInt32        waveformSource
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[35] = "";
    ViChar      rep_cap_bus[15] = "";
    ViChar      rep_cap_line[20] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, line, HMO_VAL_SPI_CLOCK, HMO_VAL_SPI_CSEL), 3, "Line");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_SPI_SOURCE,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap_bus), 2, "Bus");

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_SPI_SOURCE,
                                                 "SPILine",
                                                 line,
                                                 20,
                                                 rep_cap_line), 3, "Line");
    
    strcpy (rep_cap, rep_cap_bus);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_line);
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_SPI_SOURCE,
                                               waveformSource
                                               ), 4, "Waveform Source");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures whether transmitted data or the slave select 
/// HIFN  signal is high active (high = 1) or low active (low = 1).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR line/This control select configured SPI line.
/// HIPAR polarity/Selects line polarity.
ViStatus _VI_FUNC hmo_ConfigureSPIPolarity(
    ViSession    instrSession,
    ViInt32 bus,
    ViInt32        line,
    ViInt32        polarity
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[35] = "";
    ViChar      rep_cap_bus[15] = "";
    ViChar      rep_cap_line[20] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, line, HMO_VAL_SPI_CLOCK, HMO_VAL_SPI_CSEL), 3, "Line");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_SPI_POLARITY,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap_bus), 2, "Bus");

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_SPI_POLARITY,
                                                 "SPILine",
                                                 line,
                                                 20,
                                                 rep_cap_line), 3, "Line");
    
    strcpy (rep_cap, rep_cap_bus);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_line);
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_SPI_POLARITY,
                                               polarity
                                               ), 4, "Polarity");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures bit count and it's order in message. The 
/// HIFN  display of the decoded signal considers this setting.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR bitOrder/Select if the data of the messages starts with msb or lsb.
/// HIPAR wordLength/Sets the number of bits in a word.
ViStatus _VI_FUNC hmo_ConfigureSPIWord(
    ViSession    instrSession,
    ViInt32 bus,
    ViInt32        bitOrder,
    ViInt32        wordLength
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_SPI_WORD_LENGTH,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_SPI_BIT_ORDER,
                                               bitOrder
                                               ), 3, "Bit Order");

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_SPI_WORD_LENGTH,
                                               wordLength
                                               ), 4, "Word Length");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Specifies the trigger mode for SPI/SSPI protocols.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR mode/This control specifies the trigger mode.
ViStatus _VI_FUNC hmo_ConfigureSPITriggerType (ViSession instrSession,
                                                 ViInt32 mode)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, NULL,
        HMO_ATTR_PROTOCOL_SPI_TRIGGER_MODE, mode), 3, "Mode");    

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configure MOSI and MISO trigger conditions.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR offset/Sets the number of bits or words before the first word of interest.
/// HIPAR bitPatternLength/Defines how many bits build up the serial pattern.
/// HIPAR bitPattern/Specifies the trigger bit pattern.
ViStatus _VI_FUNC hmo_ConfigureSPITriggerData(
    ViSession    instrSession,
    ViReal64        offset,
    ViInt32    bitPatternLength,
    ViString    bitPattern
)
{
    ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                               HMO_ATTR_PROTOCOL_SPI_TRIGGER_OFFSET,
                                               offset
                                               ), 2, "Offset");    
    
    viCheckParm (hmo_SetAttributeViString (instrSession, "Bit Pattern",
                                                HMO_ATTR_PROTOCOL_SPI_BIT_PATTERN,
                                                bitPattern
                                                ), 4, "Bit Pattern");
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "Bit Pattern Length",
                                                HMO_ATTR_PROTOCOL_SPI_BIT_PATTERN_LENGTH,
                                                bitPatternLength
                                                ), 3, "Bit Pattern Length"); 

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function configures input channel of the selected line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR line/Selects configured SSPI line.
/// HIPAR waveformSource/Sets the waveform of the selected line.
ViStatus _VI_FUNC hmo_ConfigureSSPISource (ViSession instrSession,
                                           ViInt32 bus, ViInt32 line,
                                             ViInt32 waveformSource)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[35] = "";
    ViChar      rep_cap_bus[15] = "";
    ViChar      rep_cap_line[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, line, HMO_VAL_SPI_CLOCK, HMO_VAL_SPI_CSEL), 3, "Line");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_SSPI_SOURCE,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap_bus), 2, "Bus");

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_SSPI_SOURCE,
                                                 "SSPILine",
                                                 line,
                                                 15,
                                                 rep_cap_line), 3, "Line");
    
    
    strcpy (rep_cap, rep_cap_bus);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_line);
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_SSPI_SOURCE, waveformSource), 4, "Waveform Source");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN configures whether transmitted data or the slave select signal is high active (high = 1) or low active (low = 1)..
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR line/Selects configured SSPI line.
/// HIPAR polarity/Selects line polarity.
ViStatus _VI_FUNC hmo_ConfigureSSPIPolarity (ViSession instrSession,
                                             ViInt32 bus, ViInt32 line, ViInt32 polarity)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[35] = "";
    ViChar      rep_cap_bus[15] = "";
    ViChar      rep_cap_line[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, line, HMO_VAL_SPI_CLOCK, HMO_VAL_SPI_CSEL), 3, "Line");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_SSPI_POLARITY,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap_bus), 2, "Bus");

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_SSPI_POLARITY,
                                                 "SSPILine",
                                                 line,
                                                 15,
                                                 rep_cap_line), 3, "Line");
    
    strcpy (rep_cap, rep_cap_bus);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_line);
    
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_SSPI_POLARITY, polarity), 4, "Polarity");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function configures the idle time the data and clock lines are low
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR interframeTime/This control configures the interframe time
/// HIPAR bitOrder/Select if the data of the messages starts with msb or lsb
/// HIPAR wordLength/Sets the number of bits in a word.
ViStatus _VI_FUNC hmo_ConfigureSSPIPackets (ViSession instrSession,
                                            ViInt32 bus, ViReal64 interframeTime,
                                              ViInt32 bitOrder,
                                              ViInt32 wordLength)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_DISPLAY_FORMAT,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_SSPI_INTERFRAME_TIME, interframeTime), 3, "Interframe Time");
    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_SSPI_BIT_ORDER, bitOrder), 4, "Bit Order");
    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_SSPI_WORD_LENGTH, wordLength), 5, "Word Length");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the number of decoded frames.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR count/Number of decoded frames.
ViStatus _VI_FUNC hmo_QuerySPIFrameCount (ViSession instrSession, ViInt32 bus,
                                            ViInt32 *count)
{
	ViStatus    error = VI_SUCCESS;
	ViChar      rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_DISPLAY_FORMAT,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");
    viCheckParm (hmo_GetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_SPI_FRAME_COUNT,
                                               count), 2, "count"); 

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the number of words in frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR frame/This control selects the frame.
/// HIPAR count/Number of words.
ViStatus _VI_FUNC hmo_QuerySPIWordCount (ViSession instrSession, ViInt32 bus,
                                           ViInt32 frame, ViInt32 *count)
{
	ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:SPI:FRAM%ld:WCO?", "%ld", bus, frame, count));
    
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the overall state of the frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR frame/This control selects the frame.
/// HIPAR frameStart/Returns the start time of the specified frame.
/// HIPAR frameStop/Returns the end time of the specified frame.
/// HIPAR status/The overall state of the frame.
ViStatus _VI_FUNC hmo_QuerySPIFrameStatus (ViSession instrSession, ViInt32 bus,
                                             ViInt32 frame, ViReal64 *frameStart,
                                             ViReal64 *frameStop,
                                             ViInt32 *status)
{
	ViStatus    error = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE];

    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:SPI:FRAM%ld:STAR?", "%le", bus, frame, frameStart));
    viCheckErr (viQueryf (instrSession, "BUS%ld:SPI:FRAM%ld:STOP?", "%le", bus, frame, frameStop));
    viCheckErr (viQueryf (instrSession, "BUS%ld:SPI:FRAM%ld:STAT?", "%s", bus, frame, buffer));
    *status = hmo_StringIndex (protocolSPIFrameStatus_Arr, buffer);
    
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the data value of the specified word.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR frame/This control selects the frame.
/// HIPAR word/This control selects the word.
/// HIPAR valueStart/Start time of the data word.
/// HIPAR valueStop/Stop time of the data word.
/// HIPAR MOSIValue/Returns the data value of the specified word on the MOSI line.
/// HIPAR MISOValue/Returns the data value of the specified word on the MISO line.
ViStatus _VI_FUNC hmo_QuerySPIFrameData (ViSession instrSession, ViInt32 bus,
                                           ViInt32 frame, ViInt32 word,
                                           ViReal64 *valueStart,
                                           ViReal64 *valueStop,
                                           ViInt32 *MOSIValue,
                                           ViInt32 *MISOValue)
{
	ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
	
	if (word < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 4, "Word");
    }
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:SPI:FRAM%ld:WORD%ld:STAR?", "%le", bus, frame, word, valueStart));
    viCheckErr (viQueryf (instrSession, "BUS%ld:SPI:FRAM%ld:WORD%ld:STOP?", "%le", bus, frame, word, valueStop));
    viCheckErr (viQueryf (instrSession, "BUS%ld:SPI:FRAM%ld:WORD%ld:MOSI?", "%ld", bus, frame, word, MOSIValue));
    viCheckErr (viQueryf (instrSession, "BUS%ld:SPI:FRAM%ld:WORD%ld:MISO?", "%ld", bus, frame, word, MISOValue));
    
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the data words of the specified frame of the MISO or MOSI line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR frame/This control selects the frame.
/// HIPAR arraySize/Pass the number of values allocated for Data result array.
/// HIPAR data/Data words of the specified frame.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC hmo_QuerySPIFrameAllData (ViSession instrSession, ViInt32 bus,
                                              ViInt32 frame, ViInt32 arraySize, 
											  ViInt32 data[],
                                              ViInt32 *returnedValues)
{
	ViStatus    error = VI_SUCCESS;
	ViChar      *p2buf  = NULL; 
    ViChar      *extBuf=NULL; 
    ViUInt32    ret_cnt;
    ViInt32     i=0;
    ViInt32     value_count = 0;
	
    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
	viCheckErr( viPrintf(instrSession, "BUS%ld:SPI:FRAM%d:DATA?", bus, frame)); 
	
    viCheckErr (Rs_ReadDataUnknownLength(instrSession, &extBuf, &ret_cnt)); 
    
    p2buf = strtok (extBuf, ",");
    
    value_count = atoi (p2buf);
    
    arraySize = (arraySize < value_count) ? arraySize : value_count;
    
    p2buf = strtok(NULL, ",");
    
    while (p2buf && (i < arraySize))
    {                  
        data[i] = atol(p2buf);
        p2buf = strtok(NULL, ",");
        i++;
    }
    *returnedValues = i;
    
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the input channels for the transmitter and 
/// HIFN  receiver signals. 
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR waveformSource/Selects the source of the waveform.
ViStatus _VI_FUNC hmo_ConfigureUARTSource(
    ViSession    instrSession,
    ViInt32 bus,
    ViInt32        waveformSource
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_DISPLAY_FORMAT,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_UART_SOURCE,
                                               waveformSource
                                               ), 3, "Waveform Source");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN This function selects whether transmitted data is high active (high = 1, Positive) or low active (low = 1, Negative).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR polarity/Selects whether transmitted data is high active (high = 1, Positive) or low active (low = 1, Negative).
ViStatus _VI_FUNC hmo_ConfigureUARTPolarity (ViSession instrSession,
                                             ViInt32 bus, ViInt32 polarity)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_DISPLAY_FORMAT,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_UART_POLARITY, polarity), 3, "Polarity");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function configures the UART port.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR interframeTime/This control configures the interframe time.
/// HIPAR wordLength/Sets the number of bits in a word.
/// HIPAR bitRate/Sets the number of transmitted bits per second.
/// HIPAR parity/Selects the optional parity bit that is used for error detection.
/// HIPAR stopBits/Selects the number of stop bits.
ViStatus _VI_FUNC hmo_ConfigureUART (ViSession instrSession,
                                     ViInt32 bus, ViReal64 interframeTime,
                                     ViInt32 wordLength, ViReal64 bitRate,
                                     ViInt32 parity, ViInt32 stopBits)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_DISPLAY_FORMAT,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_UART_INTERFRAME_TIME, interframeTime), 3, "Interframe Time");
    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_UART_WORD_LENGTH, wordLength), 4, "Word Length");    
    viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_UART_BIT_RATE, bitRate), 5, "Bit Rate");    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_UART_PARITY, parity), 6, "Parity");    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_PROTOCOL_UART_STOP_BITS, stopBits), 7, "Stop Bits");    
    
    
    
    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function sets the trigger for UART/RS-232 interfaces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mode/This control select trigger type.
ViStatus _VI_FUNC hmo_ConfigureUARTTriggerType (ViSession instrSession,
                                              ViInt32 mode)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, NULL,
        HMO_ATTR_PROTOCOL_UART_TRIGGER_MODE, mode), 2, "Mode");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function sets trigger pattern for UART/RS-232 interfaces
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR pattern/This control defines the bit pattern as trigger condition.
/// HIPAR patternLength/Defines how many symbols build up the serial pattern.
/// HIPAR patternOffset/Sets the number of symbols before the first symbol of the pattern.
ViStatus _VI_FUNC hmo_ConfigureUARTTriggerPattern (ViSession instrSession,
                                                     ViString pattern,
                                                     ViInt32 patternLength,
                                                     ViInt32 patternOffset)
{
    ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm(hmo_SetAttributeViString(instrSession, NULL,
        HMO_ATTR_PROTOCOL_UART_TRIGGER_DATA_PATTERN, pattern), 2, "Pattern");
    viCheckParm(hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_PROTOCOL_UART_TRIGGER_CONDITION_LENGTH, patternLength), 3, "Pattern Length");
    viCheckParm(hmo_SetAttributeViInt32(instrSession, NULL,
        HMO_ATTR_PROTOCOL_UART_TRIGGER_DATA_POSITION_INDEX_MIN, patternOffset), 4, "Pattern Offset");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the number of decoded frames.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR count/Number of decoded frames on the RX and TX lines, respectively.
ViStatus _VI_FUNC hmo_QueryUARTFrameCount (ViSession instrSession, ViInt32 bus,
                                             ViInt32 *count)
{
	ViStatus    error = VI_SUCCESS;
	ViChar      rep_cap [15] = "";

	checkErr (Rs_LockSession (instrSession, 0));
	
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_UART_FRAME_COUNT,
                                                 "Bus", bus-1, 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm (hmo_GetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_UART_FRAME_COUNT,
                                               count), 3, "count"); 
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the number of words in frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frame/This control selects the frame.
/// HIPAR count/Number of words. 
ViStatus _VI_FUNC hmo_QueryUARTWordCount (ViSession instrSession, ViInt32 bus,
                                            ViInt32 frame,
                                            ViInt32 *count)
{
	ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:UART:FRAM%ld:WCO?", "%ld", bus, frame, count));
    
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Queries the detailed decoded data of the specified word.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the serial bus.
/// HIPAR frame/This control selects the frame.
/// HIPAR word/This control selects the word.
/// HIPAR status/The status of the specified word.
/// HIPAR start/Time of the word start (start bit)
/// HIPAR stop/Time of the word stop (stop bit)
/// HIPAR value/Returns the value of the specified symbol (word) on the data line.
ViStatus _VI_FUNC hmo_QueryUARTFrameData (ViSession instrSession,
                                          ViInt32 bus, ViInt32 frame,
                                          ViInt32 word, ViInt32 *status,
                                          ViReal64 *start, ViReal64 *stop,
                                          ViInt32 *value)
{
	ViStatus    error = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE];

    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
	if (word < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 4, "Word");
    }
    
	viCheckErr (viQueryf (instrSession, "BUS%ld:UART:FRAM%ld:WORD%ld:STAT?", "%s", 
															bus, frame, word, buffer));
    *status = hmo_StringIndex (protocolUARTStatus_Arr, buffer);
	
	viCheckErr (viQueryf (instrSession, "BUS%ld:UART:FRAM%ld:WORD%ld:STAR?", "%le", 
															bus,  frame, word, start));
	
    viCheckErr (viQueryf (instrSession, "BUS%ld:UART:FRAM%ld:WORD%ld:STOP?", "%le", 
															bus,  frame, word, stop));
	
	viCheckErr (viQueryf (instrSession, "BUS%ld:UART:FRAM%ld:WORD%ld:VAL?", "%ld", 
															bus,  frame, word, value));
	
	checkErr (hmo_CheckStatus (instrSession));
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures input channel of the CAN line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR line/Selects the CAN-High or CAN-Low line. Both lines are required for 
/// HIPAR line/differential signal transmission used by CAN.
/// HIPAR waveformSource/Sets the input channel of the CAN signal.
ViStatus _VI_FUNC hmo_ConfigureCANSource (ViSession instrSession,
                                          ViInt32 bus, ViInt32 line,
                                          ViInt32 waveformSource)
{
	ViStatus    error = VI_SUCCESS;
    ViChar    rep_cap[30] = "";
    
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_CAN_LINE_TYPE,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_CAN_LINE_TYPE,
                                               line), 3, "Line");
	
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_CAN_SOURCE,
                                               waveformSource), 4, "Waveform Source");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the number of transmitted bits per second.     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR bitRate/Sets the number of transmitted bits per second.
ViStatus _VI_FUNC hmo_ConfigureCANBitRate (ViSession instrSession,
                                           ViInt32 bus, ViReal64 bitRate)
{
	ViStatus    error = VI_SUCCESS;
    ViChar    rep_cap[30] = "";
    
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_CAN_BIT_RATE,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_CAN_BIT_RATE,
                                               bitRate), 3, "Bit Rate");
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the position of the sample point within the 
/// HIFN  bit in percent of the nominal bit time.     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR samplePoint/Sets the position of the sample point within the bit in percent of the 
/// HIPAR samplePoint/nominal bit time.
ViStatus _VI_FUNC hmo_ConfigureCANSamplePoint (ViSession instrSession,
                                               ViInt32 bus, ViReal64 samplePoint)
{
	ViStatus    error = VI_SUCCESS;
    ViChar    rep_cap[30] = "";
    
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_CAN_SAMPLE_POINT,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_CAN_SAMPLE_POINT,
                                               samplePoint), 3, "Sample Point");
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the trigger type for CAN analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR type/Selects the trigger type for CAN analysis.
/// HIPAR frameType/Selects the frame type which will be used as trigger condition.
ViStatus _VI_FUNC hmo_ConfigureCANTriggerType (ViSession instrSession,
                                               ViInt32 type, ViInt32 frameType)
{
	ViStatus    error = VI_SUCCESS;
	
	checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                               HMO_ATTR_PROTOCOL_CAN_TRIGGER_MODE,
                                               type), 2, "Type");
	if (type == HMO_VAL_CAN_FRAME_TYPE)
	{
		viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                               HMO_ATTR_PROTOCOL_CAN_TRIGGER_FRAME_TYPE,
	                                           frameType), 3, "Frame Type");
	}
Error:
    Rs_UnlockSession (instrSession, 0);    
    return error;
}

/// HIFN  This function configures conditions for ID trigger.     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR IDType/Specifies the identifier type for CAN.
/// HIPAR condition/Sets the comparison condition: If the pattern contains at least one X 
/// HIPAR condition/(don't care), you can trigger on values equal or not equal to the 
/// HIPAR condition/specified value. If the pattern contains only 0 and 1, you can also 
/// HIPAR condition/trigger on a range greater than or lower than the specified value.
/// HIPAR identifierPattern/Defines the identifier pattern.
ViStatus _VI_FUNC hmo_ConfigureCANTriggerID (ViSession instrSession,
                                             ViInt32 IDType, ViInt32 condition,
                                             ViString identifierPattern)
{
	ViStatus    error = VI_SUCCESS;
	
	checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                               HMO_ATTR_PROTOCOL_CAN_TRIGGER_ID_TYPE,
                                               IDType), 2, "ID Type");
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "ID",
                                               HMO_ATTR_PROTOCOL_CAN_TRIGGER_CONDITION,
                                               condition), 3, "Condition");
	
	viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                               HMO_ATTR_PROTOCOL_CAN_TRIGGER_ID_PATTERN,
                                               identifierPattern), 4, "Identifier Pattern");
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures conditions for data trigger.      
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR condition/Sets the comparison condition for data: If the pattern contains at 
/// HIPAR condition/least one X (don't care), you can trigger on values equal or not equal 
/// HIPAR condition/to the specified value. If the pattern contains only 0 and 1, you can 
/// HIPAR condition/also trigger on a range greater than or lower than the specified value.
/// HIPAR dataLength/Defines the length of the data pattern - the number of bytes in the 
/// HIPAR dataLength/pattern.
/// HIPAR dataPattern/Defines the data pattern. The number of bytes in the data pattern is 
/// HIPAR dataPattern/defined with Data Length.
ViStatus _VI_FUNC hmo_ConfigureCANTriggerData (ViSession instrSession,
                                               ViInt32 condition,
                                               ViInt32 dataLength,
                                               ViString dataPattern)
{
	ViStatus    error = VI_SUCCESS;
	
	checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "Data",
                                               HMO_ATTR_PROTOCOL_CAN_TRIGGER_CONDITION,
                                               condition), 2, "Condition");
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                               HMO_ATTR_PROTOCOL_CAN_TRIGGER_DATA_LENGTH,
                                               dataLength), 3, "Data Length");
	
	viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                               HMO_ATTR_PROTOCOL_CAN_TRIGGER_DATA_PATTERN,
                                               dataPattern), 4, "Data Pattern");
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures conditions for Error Condition trigger.       
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR CRC/Sets state of triggering on the CRC error. A CRC error occurs
/// HIPAR stuffing/Sets state of triggering on the bit stuffing error. A stuff error 
/// HIPAR stuffing/occurs when the 6th consecutive equal bit level in the mentioned fields 
/// HIPAR stuffing/is detected
/// HIPAR form/Sets state of triggering on the form error. A form error occurs when a 
/// HIPAR form/fixed-form bit field contains one or more illegal bits. 
/// HIPAR ack/Sets state of triggering on the acknowledge error. An acknowledgement 
/// HIPAR ack/error occurs when the transmitter does not receive an acknowledgment - 
/// HIPAR ack/a dominant bit during the Ack Slot.
ViStatus _VI_FUNC hmo_ConfigureCANTriggerErrorConditions (ViSession instrSession,
                                                          ViBoolean CRC,
                                                          ViBoolean stuffing,
                                                          ViBoolean form,
                                                          ViBoolean ack)
{
	ViStatus    error = VI_SUCCESS;
	
	checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_SetAttributeViBoolean (instrSession, "CRC",
                                               HMO_ATTR_PROTOCOL_CAN_TRIGGER_ERROR,
                                               CRC), 2, "CRC");
	
	viCheckParm (hmo_SetAttributeViBoolean (instrSession, "Stuffing",
                                               HMO_ATTR_PROTOCOL_CAN_TRIGGER_ERROR,
                                               stuffing), 3, "Stuffing");
	
	viCheckParm (hmo_SetAttributeViBoolean (instrSession, "Form",
                                               HMO_ATTR_PROTOCOL_CAN_TRIGGER_ERROR,
                                               form), 4, "Form");
	
	viCheckParm (hmo_SetAttributeViBoolean (instrSession, "Ack",
                                               HMO_ATTR_PROTOCOL_CAN_TRIGGER_ERROR,
                                               ack), 5, "Ack");
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the number of decoded frames.
/// HIFN You may use multiple lines for documentation.
/// HIRET Document return value here.
/// HIRET You may use multiple lines for documentation.
/// HIPAR instrSession/Document parameter here.
/// HIPAR count/Number of decoded frames.
ViStatus _VI_FUNC hmo_QueryCANFrameCount (ViSession instrSession, ViInt32 bus,
                                            ViInt32 *count)
{
	ViStatus    error = VI_SUCCESS;
	ViChar      rep_cap [15] = "";

	checkErr (Rs_LockSession (instrSession, 0));
	
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_CAN_FRAME_COUNT,
                                                 "Bus", bus, 15,
                                                 rep_cap), 2, "Bus"); 
	
	viCheckParm (hmo_GetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_CAN_FRAME_COUNT,
                                               count), 2, "Count"); 
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the overall state of the frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frame/This control selects the frame.
/// HIPAR frameStatus/The overall state of the frame.
/// HIPAR frameStart/Time of frame start.
/// HIPAR frameStop/Time of frame stop.
/// HIPAR frameType/Returns the frame type of the selected frame.
ViStatus _VI_FUNC hmo_QueryCANFrameStatus (ViSession instrSession, ViInt32 bus,
                                             ViInt32 frame, ViInt32 *frameStatus,
                                             ViReal64 *frameStart,
                                             ViReal64 *frameStop,
                                             ViInt32 *frameType)
{
	ViStatus    error = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE];

    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
	viCheckErr (viQueryf (instrSession, "BUS%ld:CAN:FRAM%ld:STAT?","%s", bus, frame, buffer));
    *frameStatus = hmo_StringIndex (protocolCANFrameStatus_Arr, buffer);
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:CAN:FRAM%ld:STAR?","%le", bus, frame, frameStart));
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:CAN:FRAM%ld:STOP?","%le", bus, frame, frameStop));
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:CAN:FRAM%ld:TYPE?","%s", bus, frame, buffer));
    *frameType = hmo_StringIndex (protocolCANFrameType_Arr, buffer); 
	
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the identifier parameters of the frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frame/This control selects the frame.
/// HIPAR IDType/Returns the identifier type of the selected frame,
/// HIPAR IDValue/Returns the identifier value of the selected frame.
/// HIPAR statusCode/Return the identifier state.
ViStatus _VI_FUNC hmo_QueryCANFrameID (ViSession instrSession, ViInt32 bus,
                                         ViInt32 frame, ViInt32 *IDType,
                                         ViInt32 *IDValue, ViInt32 *statusCode)
{
	ViStatus    error = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE];

    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
	viCheckErr (viQueryf (instrSession, "BUS%ld:CAN:FRAM%ld:IDTY?", "%s", bus, frame, buffer));
    *IDType = hmo_StringIndex(protocolCANIDType_Arr, buffer);

    viCheckErr (viQueryf (instrSession, "BUS%ld:CAN:FRAM%ld:IDV?", "%ld", bus, frame, IDValue));
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:CAN:FRAM%ld:IDST?", "%s", bus, frame, buffer));
    *statusCode = hmo_StringIndex (protocolCANFieldStatus_Arr, buffer);
	
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the parameters of selected field of the frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frame/This control selects the frame.
/// HIPAR field/This control selects the field which will be queried.
/// HIPAR fieldValue/Returns the value of selected field for the specified frame.
/// HIPAR fieldStatus/Returns the field state of the selected frame.
ViStatus _VI_FUNC hmo_QueryCANFrameField (ViSession instrSession, ViInt32 bus,
                                            ViInt32 frame, ViInt32 field,
                                            ViInt32 *fieldValue,
                                            ViInt32 *fieldStatus)
{
	ViStatus    error = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE];
	ViString    fieldArr[] = {"DLC", "CS", "ACK"};
	
    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, field, HMO_VAL_CAN_FIELD_DLC, HMO_VAL_CAN_FIELD_ACKNOWLEDGE), 4, "Field");
    
	viCheckErr (viQueryf (instrSession, "BUS%ld:CAN:FRAM%ld:%sV?", "%ld", bus, frame, fieldArr[field], fieldValue));
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:CAN:FRAM%ld:%sST?", "%s", bus, frame, fieldArr[field], buffer));
    *fieldStatus = hmo_StringIndex (protocolCANFieldStatus_Arr, buffer);
	
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the number of data bytes in the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frame/This control selects the frame.
/// HIPAR byteCount/Returns the number of data bytes in the specified frame.
ViStatus _VI_FUNC hmo_QueryCANFrameByteCount (ViSession instrSession, ViInt32 bus,
                                                ViInt32 frame,
                                                ViInt32 *byteCount)
{
	ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
	viCheckErr (viQueryf (instrSession, "BUS%ld:CAN:FRAM%ld:BCO?", "%ld", bus, frame, byteCount));
    
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the location of a bit stuffing error of the frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frame/This control selects the frame.
/// HIPAR errorPosition/Returns the location of a bit stuffing error.
ViStatus _VI_FUNC hmo_QueryCANFrameBitStuffingError (ViSession instrSession, ViInt32 bus,
                                                       ViInt32 frame,
                                                       ViReal64 *errorPosition)
{
	ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
	viCheckErr (viQueryf (instrSession, "BUS%ld:CAN:FRAM%ld:BSEP?", "%le", bus, frame, errorPosition));
    
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the data value of the specified byte.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frame/This control selects the frame.
/// HIPAR byteNumber/This control selects the Byte.
/// HIPAR data/Returns the state of the specified byte.
/// HIPAR statusCode/Returns the state of the specified byte.
ViStatus _VI_FUNC hmo_QueryCANFrameData (ViSession instrSession, ViInt32 bus,
                                           ViInt32 frame, ViInt32 byteNumber,
                                           ViInt32 *data, ViInt32 *statusCode)
{
	ViStatus    error = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE];
	
    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
	
	if (byteNumber < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 4, "Byte Number");
    }
    
	viCheckErr (viQueryf (instrSession, "BUS%ld:CAN:FRAM%ld:BYTE%ld:VAL?", "%ld", bus, frame, byteNumber, data));
    
    viCheckErr (viQueryf (instrSession, "BUS%ld:CAN:FRAM%ld:BYTE%ld:STAT?", "%s", bus, frame, byteNumber, buffer));
    *statusCode = hmo_StringIndex(protocolCANFieldStatus_Arr, buffer);
    
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the data bytes of the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frame/This control selects the frame.
/// HIPAR arraySize/Pass the number of values allocated for Data result array.
/// HIPAR data/Array of decimal values of the data bytes.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC hmo_QueryCANFrameAllData (ViSession instrSession, ViInt32 bus,
                                              ViInt32 frame, ViInt32 arraySize,
                                              ViInt32 data[],
                                              ViInt32 *returnedValues)
{
	ViStatus    error = VI_SUCCESS;
	ViChar      *p2buf  = NULL; 
    ViChar      *extBuf=NULL; 
    ViUInt32    ret_cnt; 
    ViInt32     i=0;
    ViInt32     value_count = 0;
	
    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
	viCheckErr (viPrintf (instrSession, "BUS%ld:CAN:FRAM%ld:DATA?", bus, frame));
    viCheckErr (Rs_ReadDataUnknownLength (instrSession, &extBuf, &ret_cnt)); 
    
    p2buf = strtok(extBuf, ",");
    
    value_count = atoi (p2buf);
    
    arraySize = (arraySize < value_count) ? arraySize : value_count;
    
    p2buf = strtok(NULL, ",");
    
    while (p2buf && (i < arraySize))
    {                  
        data[i] = atol (p2buf);
        p2buf = strtok (NULL, ",");
        i++;
    }
    *returnedValues = i;
    
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession (instrSession, 0);    
    return error;
}

/// HIFN  This function sets the event or combination of events to be searched 
/// HIFN  for. Depending on the selected event, further settings are required.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR condition/Sets the event or combination of events to be searched for. Depending 
/// HIPAR condition/on the selected event, further settings are required.
ViStatus _VI_FUNC hmo_ConfigureCANSearchCondition(
	ViSession	instrSession,
	ViInt32	condition
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_CAN_CONDITION,
                                          condition), 2, "Condition");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function selects the frame type to be searched for. The function 
/// HIFN  is relevant if hmo_ConfigureCANSearchCondition is set to Frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frame/Selects the frame type to be searched for.
ViStatus _VI_FUNC hmo_ConfigureCANSearchFrame(
	ViSession	instrSession,
	ViInt32	frame
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_CAN_FRAME,
                                          frame), 2, "Frame");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures conditions for Error Condition search.
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) This function is relevant only if Search Condition is set to Error 
/// HIFN  or ID Error (see hmo_ConfigureCANSearchCondition)
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR crc/Searches for errors in the Cyclic Redundancy Check.
/// HIPAR stuffing/Searches for bit stuffing errors. See also: 'Stuff bit'. 
/// HIPAR form/Searches for form errors. A form error occurs when a fixed-form bit 
/// HIPAR form/field contains one or more illegal bits. 
/// HIPAR ack/Searches for acknowledgement errors. An acknowledgement error occurs 
/// HIPAR ack/when the transmitter does not receive an acknowledgment - a dominant 
/// HIPAR ack/bit during the Ack Slot.
ViStatus _VI_FUNC hmo_ConfigureCANSearchErrorConditions(
	ViSession	instrSession,
	ViBoolean	crc,
	ViBoolean	stuffing,
	ViBoolean	form,
	ViBoolean	ack
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_SEARCH_CAN_CRC_RRROR,
                                            crc), 2, "CRC");
    
	viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_SEARCH_CAN_BIT_STUFFING_ERROR,
                                            stuffing), 3, "Stuffing");
    
	viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_SEARCH_CAN_FORM_ERROR,
                                            form), 4, "Form");
    
	viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_SEARCH_CAN_ACKNOWLEDGE_ERROR,
                                            ack), 5, "ACK");
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures conditions for ID search.
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) This function is relevant only if Search Condition is set to 
/// HIFN  Identifier, IDData, or ID Error. (see hmo_ConfigureCANSearchCondition) 
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frameType/Specifies the frame type to be searched for if 
/// HIPAR frameType/hmo_ConfigureCANSearchCondition is set to Identifier.
/// HIPAR idType/Selects the length of the identifier: 11 bit for CAN base frames, or 
/// HIPAR idType/29 bits for CAN extended frames.
/// HIPAR condition/Sets the comparison condition: If the pattern contains at least one X 
/// HIPAR condition/(don't care), you can trigger on values equal or not equal to the 
/// HIPAR condition/specified value. If the pattern contains only 0 and 1, you can also 
/// HIPAR condition/trigger on a range greater than or lower than the specified value.
/// HIPAR identifierPattern/Defines the identifier pattern.
ViStatus _VI_FUNC hmo_ConfigureCANSearchID(
	ViSession	instrSession,
	ViInt32	frameType,
	ViInt32	idType,
	ViInt32	condition,
	ViString	identifierPattern
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_CAN_FRAME_TYPE,
                                          frameType), 2, "Frame Type");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_CAN_ID_TYPE,
                                          idType), 3, "ID Type");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_CAN_ID_CONDITION,
                                          condition), 4, "Condition");
    
	viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                           HMO_ATTR_SEARCH_CAN_IDENTIFIER,
                                           identifierPattern), 5, "Identifier Pattern");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures conditions for data search.
/// HIFN     
/// HIFN     Note(s):
/// HIFN     
/// HIFN     (1) This function is relevant only if Search Condition is set to 
/// HIFN  IDData. (see hmo_ConfigureCANSearchCondition) 
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR condition/Sets the comparison condition for data: If the pattern contains at 
/// HIPAR condition/least one X (don't care), you can trigger on values equal or not equal 
/// HIPAR condition/to the specified value. If the pattern contains only 0 and 1, you can 
/// HIPAR condition/also trigger on a range greater than or lower than the specified value.
/// HIPAR dataLength/Defines the length of the data pattern - the number of bytes in the 
/// HIPAR dataLength/pattern.
/// HIPAR dataPattern/Defines the data pattern. The number of bytes in the data pattern is 
/// HIPAR dataPattern/defined with Data Length.
ViStatus _VI_FUNC hmo_ConfigureCANSearchData(
	ViSession	instrSession,
	ViInt32	condition,
	ViInt32	dataLength,
	ViString	dataPattern
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_CAN_DATA_CONDITION,
                                          condition), 2, "Condition");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_CAN_DATA_LENGTH,
                                          dataLength), 3, "Data Length");
    
	viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                           HMO_ATTR_SEARCH_CAN_DATA,
                                           dataPattern), 4, "Data Pattern");
    
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures source waveform of the data line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR waveformSource/Sets the input channel of the LIN signal.
ViStatus _VI_FUNC hmo_ConfigureLINSource (ViSession instrSession,
                                          ViInt32 bus, ViInt32 waveformSource)
{
	ViStatus  error = VI_SUCCESS;
    ViChar    rep_cap[30] = "";
    
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_LIN_SOURCE,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_LIN_SOURCE,
                                               waveformSource), 3, "Waveform Source");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the idle state of the bus. The idle state is 
/// HIFN  the rezessive state and corresponds to a logic 1.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR polarity/Sets the polarity of the LIN.
ViStatus _VI_FUNC hmo_ConfigureLINPolarity (ViSession instrSession,
                                            ViInt32 bus, ViInt32 polarity)
{
	ViStatus  error = VI_SUCCESS;
    ViChar    rep_cap[30] = "";
    
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_LIN_POLARITY,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_LIN_POLARITY,
                                               polarity), 3, "Polarity");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the standard and the number of transmitted 
/// HIFN  bits per second.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR standard/Sets the standard of LIN protocol.
/// HIPAR bitRate/Sets the number of transmitted bits per second.
ViStatus _VI_FUNC hmo_ConfigureLINStandard (ViSession instrSession,
                                            ViInt32 bus, ViInt32 standard,
                                            ViReal64 bitRate)
{
	ViStatus  error = VI_SUCCESS;
    ViChar    rep_cap[30] = "";
    
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_LIN_STANDARD,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_LIN_STANDARD,
                                               standard), 3, "Standard");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_LIN_BIT_RATE,
                                               bitRate), 4, "Bit Rate");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the trigger type for LIN analysis.       
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR type/Selects the trigger type for LIN analysis.
ViStatus _VI_FUNC hmo_ConfigureLINTriggerType (ViSession instrSession,
                                               ViInt32 type)
{
	ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
													  
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                               HMO_ATTR_PROTOCOL_LIN_TRIGGER_MODE,
                                               type), 2, "Type");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures conditions for ID trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR condition/Sets the operator to set a specific identifier or an identifier range.
/// HIPAR identifierPattern/Defines the identifier pattern.
ViStatus _VI_FUNC hmo_ConfigureLINTriggerID (ViSession instrSession,
                                             ViInt32 condition,
                                             ViString identifierPattern)
{
	ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
													  
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "ID",
                                               HMO_ATTR_PROTOCOL_LIN_TRIGGER_CONDITION,
                                               condition), 2, "Condition");
	
	viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                               HMO_ATTR_PROTOCOL_LIN_TRIGGER_ID_PATTERN,
                                               identifierPattern), 3, "Identifier Pattern");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures conditions for data trigger.     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR condition/Sets the comparison condition for data: If the pattern contains at 
/// HIPAR condition/least one X (don't care), you can trigger on values equal or not equal 
/// HIPAR condition/to the specified value. If the pattern contains only 0 and 1, you can 
/// HIPAR condition/also trigger on a range greater than or lower than the specified value.
/// HIPAR dataLength/Defines the length of the data pattern - the number of bytes in the 
/// HIPAR dataLength/pattern.
/// HIPAR dataPattern/Defines the data pattern. The number of bytes in the data pattern is 
/// HIPAR dataPattern/defined with Data Length.
ViStatus _VI_FUNC hmo_ConfigureLINTriggerData (ViSession instrSession,
                                               ViInt32 condition,
                                               ViInt32 dataLength,
                                               ViString dataPattern)
{
	ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
													  
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "Data",
                                               HMO_ATTR_PROTOCOL_LIN_TRIGGER_CONDITION,
                                               condition), 2, "Condition");
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                               HMO_ATTR_PROTOCOL_LIN_TRIGGER_DATA_LENGTH,
                                               dataLength), 2, "Data Length");
	
	viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                               HMO_ATTR_PROTOCOL_LIN_TRIGGER_DATA_PATTERN,
                                               dataPattern), 4, "Data Pattern");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures conditions for Error Condition trigger.     
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR checksum/Triggers on a checksum error. The checksum verifies the correct data 
/// HIPAR checksum/transmission. It is the last byte of the frame response. The checksum 
/// HIPAR checksum/includes not only the data but also the protected identifier (PID).
/// HIPAR parityError/Triggers on a parity error. Parity bits are the bits 6 and 7 of the 
/// HIPAR parityError/identifier. They verify the correct transmission of the identifier.
/// HIPAR syncError/Triggers if synchronization caused an error.
ViStatus _VI_FUNC hmo_ConfigureLINTriggerErrorConditions (ViSession instrSession,
                                                          ViBoolean checksum,
                                                          ViBoolean parityError,
                                                          ViBoolean syncError)
{
	ViStatus    error = VI_SUCCESS;
	
	checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_SetAttributeViBoolean (instrSession, "Checksum",
                                               HMO_ATTR_PROTOCOL_LIN_TRIGGER_ERROR,
                                               checksum), 2, "Checksum");
	
	viCheckParm (hmo_SetAttributeViBoolean (instrSession, "Parity",
                                               HMO_ATTR_PROTOCOL_LIN_TRIGGER_ERROR,
                                               parityError), 3, "Parity Error");
	
	viCheckParm (hmo_SetAttributeViBoolean (instrSession, "Sync",
                                               HMO_ATTR_PROTOCOL_LIN_TRIGGER_ERROR,
                                               syncError), 4, "Sync Error");
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the number of decoded frames.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR count/Returns number of decoded frames.
ViStatus _VI_FUNC hmo_QueryLINFrameCount (ViSession instrSession, ViInt32 bus,
                                            ViInt32 *count)
{
	ViStatus    error = VI_SUCCESS;
	ViChar      rep_cap [15] = "";

	checkErr (Rs_LockSession (instrSession, 0));
	
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_LIN_FRAME_COUNT,
                                                 "Bus", bus - 1, 15,
                                                 rep_cap), 2, "Bus"); 
	
	viCheckParm (hmo_GetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_PROTOCOL_LIN_FRAME_COUNT,
                                               count), 2, "Count"); 
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the overall state of the frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frame/This control selects the frame.
/// HIPAR frameStatus/Status of the frame.
/// HIPAR frameStart/Time of frame start.
/// HIPAR frameStop/Time of frame stop
/// HIPAR version/Returns the version of the LIN standard for the specified frame.
ViStatus _VI_FUNC hmo_QueryLINFrameStatus (ViSession instrSession, ViInt32 bus,
                                             ViInt32 frame, ViInt32 *frameStatus,
                                             ViReal64 *frameStart,
                                             ViReal64 *frameStop,
                                             ViInt32 *version)
{
	ViStatus    error = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE];

    checkErr (Rs_LockSession (instrSession, 0));
    
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
	
    viCheckErr (viQueryf (instrSession, "BUS%ld:LIN:FRAM%ld:STAT?", "%s", bus, frame, buffer));
    *frameStatus = hmo_StringIndex (protocolLINFrameStatus_Arr, buffer); 
    viCheckErr (viQueryf (instrSession, "BUS%ld:LIN:FRAM%ld:STAR?", "%le", bus, frame, frameStart));
    viCheckErr (viQueryf (instrSession, "BUS%ld:LIN:FRAM%ld:STOP?", "%le", bus, frame, frameStop));
    viCheckErr (viQueryf (instrSession, "BUS%ld:LIN:FRAM%ld:VERS?", "%s", bus, frame, buffer));
    *version = hmo_StringIndex (protocolLINVersion_Arr, buffer); 
	
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Queries the identifier parameters of the frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR frame/This control selects the frame.
/// HIPAR value/Returns the version of the LIN standard for the specified frame.
/// HIPAR parity/Returns the value of the identifier parity bits of the selected frame.
/// HIPAR status/Returns the identifier state of the selected frame.
ViStatus _VI_FUNC hmo_QueryLINFrameID (ViSession instrSession, ViInt32 bus,
                                         ViInt32 frame, ViInt32 *value,
                                         ViInt32 *parity, ViInt32 *status)
{
	ViStatus    error = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE];

    checkErr (Rs_LockSession (instrSession, 0));
    
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
	
	viCheckErr (viQueryf (instrSession, "BUS%ld:LIN:FRAM%ld:IDV?", "%ld", bus, frame, value));
    viCheckErr (viQueryf (instrSession, "BUS%ld:LIN:FRAM%ld:IDPV?", "%ld", bus, frame, parity));
    viCheckErr (viQueryf (instrSession, "BUS%ld:LIN:FRAM%ld:IDST?", "%s", bus, frame, buffer));
    *status = hmo_StringIndex(protocolLINIDStatus_Arr, buffer);
	
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the identifier parameters of the frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frame/This control selects the frame.
/// HIPAR field/This control selects the field which will be queried.
/// HIPAR fieldValue/Returns the value of selected field for the specified frame.
/// HIPAR fieldStatus/Returns the selected field state for the specified frame.
ViStatus _VI_FUNC hmo_QueryLINFrameField (ViSession instrSession, ViInt32 bus,
                                            ViInt32 frame, ViInt32 field,
                                            ViInt32 *fieldValue,
                                            ViInt32 *fieldStatus)
{
	ViStatus    error = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE];
	ViString    fieldArr[] = {"SY", "CS"};

    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
	viCheckParm (hmo_invalidViInt32Range (instrSession, field, HMO_VAL_LIN_FIELD_SYNC, HMO_VAL_LIN_FIELD_CHKSUM), 4, "Field");
    
    if (field == HMO_VAL_LIN_FIELD_CHKSUM)
	{
		viCheckErr (viQueryf (instrSession, "BUS%ld:LIN:FRAM%ld:%sV?\n", "%ld", bus, frame, fieldArr[field], fieldValue));
	}
	
	viCheckErr (viQueryf (instrSession, "BUS%ld:LIN:FRAM%ld:%sST?\n", "%s", bus, frame, fieldArr[field], buffer));
	*fieldStatus = hmo_StringIndex (protocolLINFieldStatus_Arr, buffer); 
	 
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the number of data bytes in the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frame/This control selects the frame.
/// HIPAR byteCount/Returns the number of data bytes in the specified frame.
ViStatus _VI_FUNC hmo_QueryLINFrameByteCount (ViSession instrSession, ViInt32 bus,
                                                ViInt32 frame,
                                                ViInt32 *byteCount)
{
	ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
	viCheckErr (viQueryf (instrSession, "BUS%ld:LIN:FRAM%ld:BCO?\n", "%ld", bus, frame, byteCount));
    
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the data value of the specified byte.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frame/This control selects the frame.
/// HIPAR byteNumber/This control selects the Byte.
/// HIPAR data/Value of the specified byte
/// HIPAR statusCode/Returns the data state for the specified frame.
ViStatus _VI_FUNC hmo_QueryLINFrameData (ViSession instrSession, ViInt32 bus,
                                           ViInt32 frame, ViInt32 byteNumber,
                                           ViInt32 *data, ViInt32 *statusCode)
{
	ViStatus    error = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE];
	
    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
	viCheckErr (viQueryf (instrSession, "BUS%ld:LIN:FRAM%ld:BYTE%ld:VAL?", "%ld", bus, frame, byteNumber, data));
    viCheckErr (viQueryf (instrSession, "BUS%ld:LIN:FRAM%ld:BYTE%ld:STAT?", "%s", bus, frame, byteNumber, buffer));
    *statusCode = hmo_StringIndex(protocolLINDataStatus_Arr, buffer); 
	 
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Queries the data bytes of the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frame/This control selects the frame.
/// HIPAR arraySize/Pass the number of values allocated for Data result array.
/// HIPAR data/Array of decimal values of the data bytes.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC hmo_QueryLINFrameAllData (ViSession instrSession, ViInt32 bus,
                                              ViInt32 frame, ViInt32 arraySize,
                                              ViInt32 data[],
                                              ViInt32 *returnedValues)
{
	ViStatus    error = VI_SUCCESS;
	ViChar      *p2buf  = NULL; 
    ViChar      *extBuf=NULL; 
    ViUInt32    ret_cnt; 
    ViInt32     i=0;
    ViInt32     value_count = 0;
	
    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
	viCheckErr( viPrintf(instrSession, "BUS%ld:LIN:FRAM%d:DATA?", bus, frame));
    viCheckErr (Rs_ReadDataUnknownLength (instrSession, &extBuf, &ret_cnt)); 
    
    p2buf = strtok (extBuf, ",");
    
    value_count = atoi (p2buf);
    
    arraySize = (arraySize < value_count) ? arraySize : value_count;
    
    p2buf = strtok(NULL, ",");
    
    while (p2buf && (i < arraySize))
    {                  
        data[i] = atol(p2buf);
        p2buf = strtok(NULL, ",");
        i++;
    }
    *returnedValues = i;
	 
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function sets the event or combination of events to be searched 
/// HIFN  for. Depending on the selected event, further settings are required.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR condition/Sets the event or combination of events to be searched for. Depending 
/// HIPAR condition/on the selected event, further settings are required.
ViStatus _VI_FUNC hmo_ConfigureLINSearchCondition(
	ViSession	instrSession,
	ViInt32	condition
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_LIN_CONDITION,
                                          condition), 2, "Condition");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function selects the frame type to be searched for. The function 
/// HIFN  is relevant if hmo_ConfigureLINSearchCondition is set to Frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frame/Selects the frame type to be searched for.
ViStatus _VI_FUNC hmo_ConfigureLINSearchFrame(
	ViSession	instrSession,
	ViInt32	frame
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_LIN_FRAME,
                                          frame), 2, "Frame");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures conditions for Error Condition search. The 
/// HIFN  function is relevant if hmo_ConfigureLINSearchCondition is set to Error 
/// HIFN  or ID Error.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR checksum/Searches for checksum errors.
/// HIPAR idParityError/Searches for parity errors.
/// HIPAR syncError/Searches for synchronization errors.
ViStatus _VI_FUNC hmo_ConfigureLINSearchErrorConditions(
	ViSession	instrSession,
	ViBoolean	checksum,
	ViBoolean	idParityError,
	ViBoolean	syncError
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_SEARCH_LIN_CHECKSUM_ERROR,
                                            checksum), 2, "Checksum");
    
	viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_SEARCH_LIN_ID_PARITY_ERROR,
                                            idParityError), 3, "ID Parity Error");
    
	viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_SEARCH_LIN_SYNC_ERROR,
                                            syncError), 4, "Sync Error");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures conditions for ID search. The function is 
/// HIFN  relevant if hmo_ConfigureLINSearchCondition is set to Identifier, ID 
/// HIFN  Data or ID Error.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR condition/Sets the comparison condition for the identifier: If the pattern 
/// HIPAR condition/contains at least one X (dont care), you can trigger on values equal or 
/// HIPAR condition/not equal to the specified value. If the pattern contains only 0 and 1, 
/// HIPAR condition/you can also trigger on a range greater than or lower than the 
/// HIPAR condition/specified value.
/// HIPAR identifierPattern/Defines the identifier pattern.
ViStatus _VI_FUNC hmo_ConfigureLINSearchID(
	ViSession	instrSession,
	ViInt32	condition,
	ViString	identifierPattern
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_LIN_ID_CONDITION,
                                          condition), 2, "Condition");
    
	viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                           HMO_ATTR_SEARCH_LIN_IDENTIFIER_PATTERN,
                                           identifierPattern), 3, "Identifier Pattern");
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures conditions for Data search. The function is 
/// HIFN  relevant if hmo_ConfigureLINSearchCondition is set to ID Data.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR condition/Sets the comparison condition for data: If the pattern contains at 
/// HIPAR condition/least one X (dont care), you can trigger on values equal or not equal 
/// HIPAR condition/to the specified value. If the pattern contains only 0 and 1, you can 
/// HIPAR condition/also trigger on a range greater than or lower than the specified value.
/// HIPAR dataLength/Defines the length of the data pattern - the number of bytes in the 
/// HIPAR dataLength/pattern.
/// HIPAR dataPattern/Defines the data pattern. The number of bytes in the data pattern is 
/// HIPAR dataPattern/defined with Data Length.
ViStatus _VI_FUNC hmo_ConfigureLINSearchData(
	ViSession	instrSession,
	ViInt32	condition,
	ViInt32	dataLength,
	ViString	dataPattern
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_LIN_DATA_CONDITION,
                                          condition), 2, "Condition");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_LIN_DATA_LENGTH,
                                          dataLength), 3, "Data Length");
    
	viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                           HMO_ATTR_SEARCH_LIN_DATA,
                                           dataPattern), 4, "Data Pattern");
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function configures the input channels for the data bit lines
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR bit/This control sets the input channel to which the corresponding bit line is connected.
/// HIPAR channel/This control selects the channel.
ViStatus _VI_FUNC hmo_ConfigureParallelSource (ViSession instrSession,
                                               ViInt32 bus, ViInt32 bit, ViInt32 channel)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[35] = "";
    ViChar      rep_cap_bus[15] = "";
    ViChar      rep_cap_line[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PARALLEL_BUS_SOURCE,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap_bus), 2, "Bus");

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PARALLEL_BUS_SOURCE,
                                                 "BitLine",
                                                 bit,
                                                 15,
                                                 rep_cap_line), 3, "Bit");
    
    strcpy (rep_cap, rep_cap_bus);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_line);
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_PARALLEL_BUS_SOURCE, channel), 4, "Channel");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function sets the number of lines to be analyzed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR line/This control sets the number of lines to be analyzed.
ViStatus _VI_FUNC hmo_ConfigureParallelAnalyzedLines (ViSession instrSession,
                                                      ViInt32 bus, ViInt32 line)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PROTOCOL_DISPLAY_FORMAT,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_PARALLEL_BUS_ANALYZED_LINES, line), 3, "Line");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Queries the number of received frames of the active parallel bus.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR count/Returns the number of received frames of the active parallel bus.
ViStatus _VI_FUNC hmo_QueryParallelBusFrameCount(
	ViSession	instrSession,
	ViInt32	bus,
	ViInt32*	count
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PARALLEL_BUS_FRAME_COUNT,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm (hmo_GetAttributeViInt32 (instrSession, rep_cap,
                                          HMO_ATTR_PARALLEL_BUS_FRAME_COUNT,
                                          count), 3, "Count");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Queries the overall state of the frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR frame/This control selects the frame.
/// HIPAR frameStatus/Returns the state of the sync field for the specified frame.
/// HIPAR frameStart/Returns the start time of the specified frame.
/// HIPAR frameStop/Returns the end time of the specified frame.
ViStatus _VI_FUNC hmo_QueryParallelBusFrameStatus(
	ViSession	instrSession,
	ViInt32	bus,
	ViInt32	frame,
	ViInt32*	frameStatus,
	ViReal64*	frameStart,
	ViReal64*	frameStop
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE];

    checkErr (Rs_LockSession (instrSession, 0));
    
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
	
    viCheckErr (viQueryf (instrSession, "BUS%ld:PAR:FRAM%ld:STAT?", "%s", bus, frame, buffer));
	
	checkErr (hmo_CheckStatus (instrSession));
    
	*frameStatus = hmo_StringIndex (protocolParallelFrameStatus_Arr, buffer); 
	
    viCheckErr (viQueryf (instrSession, "BUS%ld:PAR:FRAM%ld:STAR?", "%le", bus, frame, frameStart));
	
	checkErr (hmo_CheckStatus (instrSession));
	
    viCheckErr (viQueryf (instrSession, "BUS%ld:PAR:FRAM%ld:STOP?", "%le", bus, frame, frameStop));
    
    checkErr (hmo_CheckStatus (instrSession));
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Queries the data bytes of the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR frame/This control selects the frame.
/// HIPAR arraySize/Pass the number of values allocated for Data result array.
/// HIPAR data/Array of decimal values of the data bytes.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC hmo_QueryParallelBusFrameAllData(
	ViSession	instrSession,
	ViInt32	bus,
	ViInt32	frame,
	ViInt32	arraySize,
	ViInt32	data[],
	ViInt32*	returnedValues
)
{
    ViStatus    error = VI_SUCCESS;
	ViChar      *p2buf  = NULL; 
    ViChar      *extBuf=NULL; 
    ViUInt32    ret_cnt; 
    ViInt32     i=0;
    ViInt32     value_count = 0;
	
    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
	if (frame < 0)
    {
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Frame");
    }
    
	viCheckErr( viPrintf(instrSession, "BUS%ld:PAR:FRAM%d:DATA?", bus, frame));
    viCheckErr (Rs_ReadDataUnknownLength (instrSession, &extBuf, &ret_cnt)); 
    
    p2buf = strtok (extBuf, ",");
    
    value_count = atoi (p2buf);
    
    arraySize = (arraySize < value_count) ? arraySize : value_count;
    
    p2buf = strtok(NULL, ",");
    
    while (p2buf && (i < arraySize))
    {                  
        data[i] = atol(p2buf);
        p2buf = strtok(NULL, ",");
        i++;
    }
    *returnedValues = i;
	 
    checkErr (hmo_CheckStatus (instrSession));
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the digital channel that is assigned to the 
/// HIFN  selected bit. Use the attribute for each bit of the bus.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR bit/This control sets the input channel to which the corresponding bit 
/// HIPAR bit/line is connected.
/// HIPAR channel/This control selects the channel. 
ViStatus _VI_FUNC hmo_ConfigureParallelClockedDataLine(
	ViSession	instrSession,
	ViInt32	bus,
	ViInt32	bit,
	ViInt32	channel
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[35] = "";
    ViChar      rep_cap_bus[15] = "";
    ViChar      rep_cap_line[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bit, HMO_VAL_PARALLEL_BIT0, HMO_VAL_PARALLEL_BIT3), 3, "Bit");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PARALLEL_BUS_CLOCKED_DATA_SOURCE,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap_bus), 2, "Bus");

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PARALLEL_BUS_CLOCKED_DATA_SOURCE,
                                                 "BitLine",
                                                 bit,
                                                 15,
                                                 rep_cap_line), 3, "Bit");
    
    strcpy (rep_cap, rep_cap_bus);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_line);
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_PARALLEL_BUS_CLOCKED_DATA_SOURCE, channel), 4, "Channel");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the clock line of the parallel clocked bus.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR channel/Selects the digital channel that is used as clock line.
/// HIPAR slope/Selects if the data is sampled on the rising or falling slope of the 
/// HIPAR slope/clock, or on both edges (EITHer). The clock slope marks the begin of a 
/// HIPAR slope/new bit.
ViStatus _VI_FUNC hmo_ConfigureParallelClockedClockLine(
	ViSession	instrSession,
	ViInt32	bus,
	ViInt32	channel,
	ViInt32	slope
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar      rep_cap[15] = "";
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PARELLEL_BUS_CLOCKED_SOURCE,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                          HMO_ATTR_PARELLEL_BUS_CLOCKED_SOURCE,
                                          channel), 3, "Channel");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                          HMO_ATTR_PARALLER_BUS_CLOCKED_SLOPE,
                                          slope), 4, "Slope");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the chip select line of the parallel clocked 
/// HIFN  bus.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR channel/Selects the digital channel that is used as chip select line.
/// HIPAR polarity/Selects wether the chip select signal is high active (high = 1) or low 
/// HIPAR polarity/active (low = 1).
ViStatus _VI_FUNC hmo_ConfigureParallelClockedChipSelectLine(
	ViSession	instrSession,
	ViInt32	bus,
	ViInt32	channel,
	ViInt32	polarity
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar      rep_cap[15] = "";
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PARALLER_BUS_CLOCKED_CS_SOURCE,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                          HMO_ATTR_PARALLER_BUS_CLOCKED_CS_SOURCE,
                                          channel), 3, "Channel");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                          HMO_ATTR_PARALLER_BUS_CLOCKED_CS_POLARITY,
                                          polarity), 4, "Polarity");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function sets the number of lines to be analyzed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bus/This control selects the bus.
/// HIPAR line/Sets the number of lines to be analyzed.
ViStatus _VI_FUNC hmo_ConfigureParallelClockedAnalyzedLines(
	ViSession	instrSession,
	ViInt32	bus,
	ViInt32	line
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar      rep_cap[15] = "";
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, bus, HMO_VAL_BUS_1, HMO_VAL_BUS_2), 2, "Bus");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_PARALLER_BUS_CLOCKED_ANALYZED_LINES,
                                                 "Bus",
                                                 bus - 1,
                                                 15,
                                                 rep_cap), 2, "Bus");

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                          HMO_ATTR_PARALLER_BUS_CLOCKED_ANALYZED_LINES,
                                          line), 3, "Line");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function enables and disables the search mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function. 
/// HIPAR state/enables and disables the search mode. 
ViStatus _VI_FUNC hmo_ConfigureSearchState (ViSession instrSession,
                                              ViBoolean state)
{
	ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
        HMO_ATTR_SEARCH_STATE, state), 2, "State");
   
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
} 

/// HIFN  Selects the symptom you want to search for.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function. 
/// HIPAR action/Selects the symptom.
ViStatus _VI_FUNC hmo_ConfigureSearchCondition (ViSession instrSession,
                                                  ViInt32 action)
{
	ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
        HMO_ATTR_SEARCH_CONDITION, action), 2, "Action");
   
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Selects the waveform to be analyzed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR searchSource/Selects the waveform to be analyzed.
ViStatus _VI_FUNC hmo_ConfigureSearchSource (ViSession instrSession,
                                               ViInt32 searchSource)
{
	ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
        HMO_ATTR_SEARCH_SOURCE, searchSource), 2, "Search Source");
   
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
} 

/// HIFN  This function configures the conditions for the edge trigger search.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR triggerSlope/Sets the slope to be found.
/// HIPAR triggerLevel/Sets the voltage level for the edge search.
/// HIPAR triggerHystersis/Sets a hysteresis range above and below the search level.
ViStatus _VI_FUNC hmo_ConfigureEdgeTriggerSearch (ViSession instrSession,
                                                    ViInt32 triggerSlope,
                                                    ViReal64 triggerLevel,
                                                    ViReal64 triggerHystersis)
{
	ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_EDGE_SLOPE, triggerSlope), 2, "Trigger Slope");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_EDGE_LEVEL, triggerLevel), 3, "Trigger Level");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_EDGE_HYSTERSIS, triggerHystersis), 4, "Trigger Hystersis");
   
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}



/// HIFN  This function configures the conditions for the width trigger search.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR level/Sets the voltage level on which the pulse width is measured.
/// HIPAR levelDelta/Defines a range around the width value.
/// HIPAR width/Sets the reference pulse width, the nominal value for comparisons.
/// HIPAR widthDelta/Sets a range delta t to the reference pulse width.
/// HIPAR polarity/Sets the polarity to be found. 
/// HIPAR range/Sets how the measured pulse width is compared with the given limit(s).
ViStatus _VI_FUNC hmo_ConfigureWidthTriggerSearch (ViSession instrSession,
                                                     ViReal64 level,
                                                     ViReal64 levelDelta,
                                                     ViReal64 width,
                                                     ViReal64 widthDelta,
                                                     ViInt32 polarity,
                                                     ViInt32 range)
{
	ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_WIDTH_LEVEL, level), 2, "Level");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_WIDTH_LEVEL_DELTA, levelDelta), 4, "Level Delta");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_WIDTH_WIDTH, width), 3, "Width");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_WIDTH_DELTA, widthDelta), 4, "Width Delta");
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_WIDTH_POLARITY, polarity), 5, "Polarity");
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_WIDTH_RANGE, range), 6, "Range");
   
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the conditions for the peak trigger search.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR polarity/Sets the polarity to be found.
/// HIPAR limit/Sets the amplitude limit.
ViStatus _VI_FUNC hmo_ConfigurePeakTriggerSearch (ViSession instrSession,
                                                    ViInt32 polarity,
                                                    ViReal64 limit)
{
	ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_PEAK_POLARITY, polarity), 2, "Polarity");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_PEAK_LIMIT, limit), 3, "Limit");
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function configures the conditions for the runt trigger search.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR polarity/Sets the slope to be found.
/// HIPAR upperLevel/Sets the upper voltage threshold.
/// HIPAR lowerLevel/Sets the lower voltage threshold.
/// HIPAR range/Sets how the measured pulse width is compared with the given limit(s).
/// HIPAR width/Sets the reference runt pulse width, the nominal value for comparisons.
/// HIPAR deltaWidth/Sets a range delta t to the reference rise/fall time set with 
/// HIPAR deltaWidth/"Width" if "Range" is set to Within or Outside.
ViStatus _VI_FUNC hmo_ConfigureRuntTriggerSearch (ViSession instrSession,
                                                    ViInt32 polarity,
                                                    ViReal64 upperLevel,
                                                    ViReal64 lowerLevel,
                                                    ViInt32 range,
                                                    ViReal64 width,
                                                    ViReal64 deltaWidth)
{
	ViStatus    error = VI_SUCCESS;
	
	checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_RUNT_POLARITY, polarity), 2, "Polarity");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "Upper",
        HMO_ATTR_SEARCH_TRIGGER_RUNT_LEVEL, upperLevel), 3, "Upper Level");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "Lower",
        HMO_ATTR_SEARCH_TRIGGER_RUNT_LEVEL, lowerLevel), 4, "Lower Level");
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_RUNT_RANGE, range), 5, "Range");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_RUNT_WIDTH, width), 6, "Width");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_RUNT_DELTA_WIDTH, deltaWidth), 7, "Delta Width"); 
   
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function configures the conditions for the rise time trigger search.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR polarity/Sets the slope to be found.
/// HIPAR upperLevel/Sets the upper voltage threshold.
/// HIPAR lowerLevel/Sets the lower voltage threshold.
/// HIPAR range/Sets how the measured rise or fall time is compared with the given limit(s).
/// HIPAR time/Sets the reference rise or fall time, the nominal value for comparisons.
/// HIPAR deltaTime/Sets a range delta t to the reference rise/fall time set with
/// HIPAR deltaTime/"Time" if "Range" is set to Within or Outside.
ViStatus _VI_FUNC hmo_ConfigureRiseTimeTriggerSearch (ViSession instrSession,
                                                        ViInt32 polarity,
                                                        ViReal64 upperLevel,
                                                        ViReal64 lowerLevel,
                                                        ViInt32 range,
                                                        ViReal64 time,
                                                        ViReal64 deltaTime)
{
	ViStatus    error = VI_SUCCESS;
	
	checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_RISE_TIME_POLARITY, polarity), 2, "Polarity");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "Upper",
        HMO_ATTR_SEARCH_TRIGGER_RISE_TIME_LEVEL, upperLevel), 3, "Upper Level");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "Lower",
        HMO_ATTR_SEARCH_TRIGGER_RISE_TIME_LEVEL, lowerLevel), 4, "Lower Level");
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_RISE_TIME_RANGE, range), 5, "Range");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_RISE_TIME_REFERENCE_TIME, time), 6, "Time");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
        HMO_ATTR_SEARCH_TRIGGER_RISE_TIME_DELTA_TIME, deltaTime), 7, "Delta Time");
   
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the conditions for the Data2Clock trigger 
/// HIFN  search.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR clockSource/Selects the input channel of the clock signal.
/// HIPAR clockLevel/Sets the voltage level for the clock signal. Clock level and clock 
/// HIPAR clockLevel/edge define the reference point for setup and hold time.
/// HIPAR clockHysteresis/Set a hysteresis range to the clock level in order to avoid unwanted 
/// HIPAR clockHysteresis/search results caused by noise oscillation around the level. For a 
/// HIPAR clockHysteresis/rising edge, the hysteresis is below the search level. Otherwise, for a 
/// HIPAR clockHysteresis/falling edge the hysteresis is above the level.
/// HIPAR dataLevel/Sets the voltage level for the data signal. The data lavel defines the 
/// HIPAR dataLevel/point of data transition.
/// HIPAR dataHysteresis/Set a hysteresis range to the data level in order to avoid unwanted 
/// HIPAR dataHysteresis/search results caused by noise oscillation around the level. For a 
/// HIPAR dataHysteresis/rising edge, the hysteresis is below the search level. Otherwise, for a 
/// HIPAR dataHysteresis/falling edge the hysteresis is above the level.
/// HIPAR polarity/Sets the edge of the clock signal to define the time reference point 
/// HIPAR polarity/for the setup and hold time.                                            
/// HIPAR polarity/    
/// HIPAR setupTime/Sets the minimum time before the clock edge while the data signal must 
/// HIPAR setupTime/stay steady above or below the data level. The setup time can be 
/// HIPAR setupTime/negative. In this case, the setup interval starts after the clock edge, 
/// HIPAR setupTime/and the hold time must be positive and longer than the absolute value 
/// HIPAR setupTime/of the setup time.
/// HIPAR holdTime/Sets the minimum time after the clock edge while the data signal must 
/// HIPAR holdTime/stay steady above or below the data level. The hold time can be 
/// HIPAR holdTime/negative. In this case, the hold time ends before the clock edge, and 
/// HIPAR holdTime/the setup time must be positive and longer than the absolute value of 
/// HIPAR holdTime/the hold time.
ViStatus _VI_FUNC hmo_ConfigureData2ClockTriggerSearch(
	ViSession	instrSession,
	ViInt32	clockSource,
	ViReal64	clockLevel,
	ViReal64	clockHysteresis,
	ViReal64	dataLevel,
	ViReal64	dataHysteresis,
	ViInt32	polarity,
	ViReal64	setupTime,
	ViReal64	holdTime
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_TRIGGER_D2C_CLOCK_SOURCE,
                                          clockSource), 2, "Clock Source");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_SEARCH_TRIGGER_D2C_CLOCK_LEVEL,
                                           clockLevel), 3, "Clock Level");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_SEARCH_TRIGGER_D2C_CLOCK_HYSTERESIS,
                                           clockHysteresis), 4, "Clock Hysteresis");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_SEARCH_TRIGGER_D2C_DATA_LEVEL,
                                           dataLevel), 5, "Data Level");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_SEARCH_TRIGGER_D2C_DATA_HYSTERESIS,
                                           dataHysteresis), 6, "Data Hysteresis");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_TRIGGER_D2C_POLARITY,
                                          polarity), 7, "Polarity");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_SEARCH_TRIGGER_D2C_SETUP_TIME,
                                           setupTime), 8, "Setup Time");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_SEARCH_TRIGGER_D2C_HOLD_TIME,
                                           holdTime), 9, "Hold Time");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the conditions for the Pattern trigger 
/// HIFN  search.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR sourceChannel/Selects the source channel for Level and Hysteresis.
/// HIPAR level/Sets the threshold value for each specified source channel. You can 
/// HIPAR level/set different levels for the channels.
/// HIPAR hysteresis/Sets a hysteresis range to the level of the specified source channel 
/// HIPAR hysteresis/in order to avoid unwanted search results caused by noise oscillation 
/// HIPAR hysteresis/around the level. For a rising edge, the hysteresis is below the search 
/// HIPAR hysteresis/level. Otherwise, for a falling edge the hysteresis is above the level.
/// HIPAR pattern/Specifies the search pattern - the state for each channel.
/// HIPAR combination/Sets the logical combination of the channel states.
/// HIPAR comparison/Sets the condition how the duration of a steady pattern is compared 
/// HIPAR comparison/with the given reference time.
/// HIPAR width/Sets the reference time of a steady pattern, the nominal value for 
/// HIPAR width/comparisons.
/// HIPAR variation/Sets a range delta t to the reference pattern duration, when 
/// HIPAR variation/comparsion  is set to Equal or Not Equal (see Comparison).
ViStatus _VI_FUNC hmo_ConfigurePatternTriggerSearch(
	ViSession	instrSession,
	ViInt32	sourceChannel,
	ViReal64	level,
	ViReal64	hysteresis,
	ViString	pattern,
	ViInt32	combination,
	ViInt32	comparison,
	ViReal64	width,
	ViReal64	variation
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar      rep_cap[15] = "";
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, sourceChannel, HMO_VAL_MEASUREMENT_SOURCE_CH1, HMO_VAL_MEASUREMENT_SOURCE_CH4), 2, "Source Channel");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_SEARCH_TRIGGER_PATTERN_LEVEL,
                                                 "Channel",
                                                 sourceChannel,
                                                 15,
                                                 rep_cap), 2, "Source Channel");

    viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                           HMO_ATTR_SEARCH_TRIGGER_PATTERN_LEVEL,
                                           level), 3, "Level");

	viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                           HMO_ATTR_SEARCH_TRIGGER_PATTERN_HYSTERESIS,
                                           hysteresis), 4, "Hysteresis");

	viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                           HMO_ATTR_SEARCH_TRIGGER_PATTERN,
                                           pattern), 5, "Pattern");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_TRIGGER_PATTERN_COMBINATION,
                                          combination), 6, "Combination");

	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_TRIGGER_PATTERN_COMPARISON,
                                          comparison), 7, "Comparison");

	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_SEARCH_TRIGGER_PATTERN_WIDTH,
                                           width), 8, "Width");

	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_SEARCH_TRIGGER_PATTERN_WIDTH_DELTA,
                                           variation), 9, "Variation");

	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function shows or hides the table of search results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR showResult/Shows or hides the table of search results.
ViStatus _VI_FUNC hmo_ConfigureShowResultDiagram (ViSession instrSession,
                                                    ViBoolean showResult)
{
	ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
        HMO_ATTR_SEARCH_SHOW_RESULT, showResult), 2, "Show Result"); 
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the number of search results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR numberOfResults/Returns the number of search results.
ViStatus _VI_FUNC hmo_QueryNumberOfResults (ViSession instrSession,
                                              ViInt32 *numberOfResults)
{
	ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_GetAttributeViInt32 (instrSession, "",
        HMO_ATTR_SEARCH_NUMBER_OF_RESULTS, numberOfResults), 2, "Number Of Results"); 
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the maximum number of storable search results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR maxNumberOfStorableResults/Returns the maximum number of storable search results.
ViStatus _VI_FUNC hmo_QueryMaxNumberOfStorableResults(
	ViSession	instrSession,
	ViInt32*	maxNumberOfStorableResults
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_SEARCH_MAXIMUM_NUMBER_OF_RESULTS,
                                          maxNumberOfStorableResults), 2, "Max Number Of Storable Results");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the result values of the specified search result.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR resultNumber/Number of result to be read. 
/// HIPAR xPosition/Returns the X-position (time) of the search result
/// HIPAR yPosition/Returns the Y-position of the search result, currently not relevant. .
/// HIPAR resultType/Returns the type of the search result (Edge, Peak, Width).
/// HIPAR polarity/Returns the slope or polarity of the search result.
/// HIPAR voltageWidth/For peak searches, the value contains the peak voltage.
ViStatus _VI_FUNC hmo_QuerySearchResult (ViSession instrSession,
                                           ViInt32 resultNumber,
                                           ViReal64 *xPosition,
                                           ViReal64 *yPosition,
                                           ViInt32 *resultType,
                                           ViInt32 *polarity,
                                           ViReal64 *voltageWidth)
{
	ViStatus error = VI_SUCCESS;
    ViChar   command[HMO_IO_BUFFER_SIZE];
    ViChar   *p2buf  = NULL;
    ViChar   *p2data  = NULL;
    ViUInt32 count = 0;
	ViString resultTypeArr[] = {"EDGE","WIDTH","PEAK","RUNT","RTIM", NULL};
	ViString polarityArr[] = {"POSITIVE","NEGATIVE","EITHER",NULL}; 

    checkErr (Rs_LockSession (instrSession, 0));    
    
    sprintf (command, "SEAR:RES%ld?\n", resultNumber);
    checkErr (viWrite (instrSession, (ViBuf) command, (ViUInt32) strlen (command), NULL));
    checkErr (Rs_ReadDataUnknownLength (instrSession, &p2data, &count));
    checkErr (hmo_CheckStatus (instrSession));
    
    p2buf = strtok (p2data, ",");
	p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xPosition != NULL) *xPosition = atof (p2buf);
    
    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (yPosition != NULL) *yPosition = atof (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (resultType != NULL) *resultType = hmo_StringIndex (resultTypeArr, p2buf);;

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (polarity != NULL) *polarity = hmo_StringIndex (polarityArr, p2buf);;
	
	p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (voltageWidth != NULL) *voltageWidth = atof (p2buf);

Error:
    if (p2data) free (p2data);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns all result values of the search.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.
/// HIPAR arraySize/Pass the number of elements in the array parameters.
/// HIPAR xPosition/Returns the X-position (time) of the search result
/// HIPAR yPosition/Returns the Y-position of the search result, currently not relevant. .
/// HIPAR resultType/Returns the type of the search result (Edge, Peak, Width).
/// HIPAR polarity/Returns the slope or polarity of the search result.
/// HIPAR voltageWidth/For peak searches, the value contains the peak voltage.
/// HIPAR numberOfResults/Number of returned results.
ViStatus _VI_FUNC hmo_QueryAllSearchResults (ViSession instrSession,
                                               ViInt32 arraySize,
                                               ViReal64 xPosition[],
                                               ViReal64 yPosition[],
                                               ViInt32 resultType[],
                                               ViInt32 polarity[],
                                               ViReal64 voltageWidth[],
                                               ViInt32 *numberOfResults)
{
	ViStatus error = VI_SUCCESS;
    ViChar   command[HMO_IO_BUFFER_SIZE];
    ViChar   *p2buf  = NULL;
    ViChar   *p2data  = NULL;
    ViUInt32 count = 0;
	ViInt32	 i = 0;
	ViString resultTypeArr[] = {"EDGE","WIDTH","PEAK","RUNT","RTIM", NULL};
	ViString polarityArr[] = {"POSITIVE","NEGATIVE","EITHER",NULL}; 

    checkErr (Rs_LockSession (instrSession, 0));    
    
    sprintf (command, "SEAR:RES:ALL?\n");
    checkErr (viWrite (instrSession, (ViBuf) command, (ViUInt32) strlen (command), NULL));
    checkErr (Rs_ReadDataUnknownLength (instrSession, &p2data, &count));
    checkErr (hmo_CheckStatus (instrSession));
    
	p2buf = strtok (p2data, ",");
	
    for (i=0; i<arraySize; i++)
	{
		p2buf = strtok (NULL, ",");
	    if (p2buf == NULL)
	        checkErr (VI_ERROR_INV_RESPONSE);
	    xPosition[i] = atof (p2buf);
    
	    p2buf = strtok (NULL, ",");
	    if (p2buf == NULL)
	        checkErr (VI_ERROR_INV_RESPONSE);
	    yPosition[i] = atof (p2buf);

	    p2buf = strtok (NULL, ",");
	    if (p2buf == NULL)
	        checkErr (VI_ERROR_INV_RESPONSE);
	    resultType[i] = hmo_StringIndex (resultTypeArr, p2buf);;

	    p2buf = strtok (NULL, ",");
	    if (p2buf == NULL)
	        checkErr (VI_ERROR_INV_RESPONSE);
	    polarity[i] = hmo_StringIndex (polarityArr, p2buf);;
	
		p2buf = strtok (NULL, ",");
	    if (p2buf == NULL)
	        checkErr (VI_ERROR_INV_RESPONSE);
	    voltageWidth[i] = atof (p2buf);
		*numberOfResults = i;
		p2buf = strtok (NULL, ",");
		if (p2buf == NULL) break;
	}

Error:
    if (p2data) free (p2data);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the component test.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR state/Switches the compoenent tester mode on or off.
/// HIPAR sourceFrequency/Sets the frequenc of the component tester source.
ViStatus _VI_FUNC hmo_ConfigureComponentTest (ViSession instrSession,
                                              ViBoolean state,
                                              ViInt32 sourceFrequency)
{
    ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm(hmo_SetAttributeViBoolean(instrSession, "",
        HMO_ATTR_COMPONENT_TEST_STATE, state), 2, "State");
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, "",
        HMO_ATTR_COMPONENT_TEST_FREQUENCY, sourceFrequency), 3, "Source Frequency");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the logic channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR state/Switches the channel signal on or off.
/// HIPAR size/Set the size of the display of teh logic channel.
/// HIPAR position/Set the position of a logic channel.
ViStatus _VI_FUNC hmo_ConfigureLogicChannel (ViSession instrSession,
                                             ViInt32 digitalInput, ViBoolean state,
                                             ViInt32 size, ViReal64 position)
{
    ViStatus    error = VI_SUCCESS;
    ViChar    rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, digitalInput, HMO_VAL_DIGITAL_INPUT_0, HMO_VAL_DIGITAL_INPUT_7), 2, "Digital Input");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_LOGIC_CHANNEL_STATE,
                                                 "Input",
                                                 digitalInput - 1,
                                                 15,
                                                 rep_cap), 2, "Digital Input");       

    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_LOGIC_CHANNEL_SIZE, size), 4, "Size");
    
    viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_LOGIC_CHANNEL_POSITION, position), 5, "Position");
    
    viCheckParm(hmo_SetAttributeViBoolean(instrSession, rep_cap,
        HMO_ATTR_LOGIC_CHANNEL_STATE, state), 3, "State");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Configuration of the logic channel label.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR labelState/Switches the label of the logic channel on or off.
/// HIPAR label/Sets the label for the logic channel, maximum 8 characters.
ViStatus _VI_FUNC hmo_ConfigureLogicChannelLabel (ViSession instrSession,
                                                  ViInt32 digitalInput,
                                                  ViBoolean labelState,
                                                  ViString label)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, digitalInput, HMO_VAL_DIGITAL_INPUT_0, HMO_VAL_DIGITAL_INPUT_7), 2, "Digital Input");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_LOGIC_CHANNEL_LABEL_STATE,
                                                 "Input",
                                                 digitalInput,
                                                 15,
                                                 rep_cap), 2, "Digital Input");

    viCheckParm(hmo_SetAttributeViBoolean(instrSession, rep_cap,
        HMO_ATTR_LOGIC_CHANNEL_LABEL_STATE, labelState), 3, "Label State");    
    
    viCheckParm(hmo_SetAttributeViString(instrSession, rep_cap,
        HMO_ATTR_LOGIC_CHANNEL_LABEL, label), 4, "Label");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the Pod.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or hmo_InitWithOptions function.  The handle identifies a particular instrument session.
/// HIPAR pod/This control selects the Pod.
/// HIPAR state/Switches the Pod on or off.
/// HIPAR threshold/Threshold Mode for Logic Pod. If the signal value is higher than
/// HIPAR threshold/the threshold, the signal state is high (1 or true for the
/// HIPAR threshold/boolean logic). Otherwise, the signal state is considered low (0
/// HIPAR threshold/or false) if the signal value is below the threshold.
/// HIPAR userDefinedThreshold/Set the User high level threshold for the pod.
ViStatus _VI_FUNC hmo_ConfigurePod (ViSession instrSession, ViInt32 pod,
                                    ViBoolean state, ViInt32 threshold,
                                    ViReal64 userDefinedThreshold)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap_pod[15] = "";
    ViChar  rep_cap[30] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, pod, HMO_VAL_POD_1, HMO_VAL_POD_2), 2, "Pod");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_POD_STATE,
                                                 "Pod",
                                                 pod - 1,
                                                 15,
                                                 rep_cap_pod), 2, "Pod");

    viCheckParm(hmo_SetAttributeViBoolean(instrSession, rep_cap_pod,
        HMO_ATTR_POD_STATE, state), 3, "State");    
    
    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap_pod,
        HMO_ATTR_POD_THRESHOLD, threshold), 4, "Threshold");
    
    if ((threshold == HMO_VAL_POD_THRESHOLD_USER_1) || (threshold == HMO_VAL_POD_THRESHOLD_USER_2))
    {
        strcpy (rep_cap, rep_cap_pod);
        if (threshold == HMO_VAL_POD_THRESHOLD_USER_1)
            strcat (rep_cap, ",User1");
        else
            strcat (rep_cap, ",User2");
        
        viCheckParm(hmo_SetAttributeViReal64(instrSession, rep_cap,
            HMO_ATTR_POD_THRESHOLD_USER_LEVEL, userDefinedThreshold), 5, "User Defined Threshold");    
    }
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the Pod range of samples.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR pod/This control selects the Pod.
/// HIPAR range/Selects a range of samples.
ViStatus _VI_FUNC hmo_ConfigurePodRange (ViSession instrSession, ViInt32 pod,
                                         ViInt32 range)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap_pod[15] = "";
	
	checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, pod, HMO_VAL_POD_1, HMO_VAL_POD_2), 2, "Pod");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_POD_RANGE,
                                                 "Pod",
                                                 pod - 1,
                                                 15,
                                                 rep_cap_pod), 2, "Pod");
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap_pod,
        HMO_ATTR_POD_RANGE, range), 3, "Range");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the Pod type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR pod/This control selects the Pod.
/// HIPAR type/Sets the POD type.
ViStatus _VI_FUNC hmo_ConfigurePodType(
	ViSession	instrSession,
	ViInt32	pod,
	ViInt32	type
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap_pod[15] = "";
	
	checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, pod, HMO_VAL_POD_1, HMO_VAL_POD_2), 2, "Pod");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_POD_TYPE,
                                                 "Pod",
                                                 pod - 1,
                                                 15,
                                                 rep_cap_pod), 2, "Pod");
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap_pod,
                                          HMO_ATTR_POD_TYPE, type), 3, "Type");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function queries the minimum and maximum values state of the pod.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR pod/This control selects the Pod.
/// HIPAR minimum/Queries the minimum value state of the pod.
/// HIPAR maximum/Queries the maximum value state of the pod.
ViStatus _VI_FUNC hmo_QueryPodValueState(
	ViSession	instrSession,
	ViInt32	pod,
	ViInt32*	minimum,
	ViInt32*	maximum
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap_pod[15] = "";
	
	checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, pod, HMO_VAL_POD_1, HMO_VAL_POD_2), 2, "Pod");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_POD_STATUS_MIN,
                                                 "Pod",
                                                 pod - 1,
                                                 15,
                                                 rep_cap_pod), 2, "Pod");
	
	viCheckParm (hmo_GetAttributeViInt32 (instrSession, rep_cap_pod,
                                          HMO_ATTR_POD_STATUS_MIN, minimum), 3, "Minimum");
    
	viCheckParm (hmo_GetAttributeViInt32 (instrSession, rep_cap_pod,
                                          HMO_ATTR_POD_STATUS_MAX, maximum), 4, "Maximum");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the digital voltmeter.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR measurementPlace/This control selects the measurement place.
/// HIPAR state/Activates or deactivates the digital voltmeter function.
/// HIPAR source/Selects the source for the digital voltmeter function.
/// HIPAR type/Sets the measurement type for the indicated DVM measurement.
/// HIPAR position/Selects the display position of the digital voltmeter values.
ViStatus _VI_FUNC hmo_ConfigureDigitalVoltmeter(
	ViSession	instrSession,
	ViInt32	measurementPlace,
	ViBoolean	state,
	ViInt32	source,
	ViInt32	type,
	ViInt32	position
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";
	
	checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, measurementPlace, HMO_VAL_DVM_1, HMO_VAL_DVM_4), 2, "Measurement Place");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_DVM_ENABLE,
                                                 "DigitalVoltmeter",
                                                 measurementPlace - 1,
                                                 15,
                                                 rep_cap), 2, "Measurement Place");
	
	viCheckParm (hmo_SetAttributeViBoolean (instrSession, rep_cap,
                                            HMO_ATTR_DVM_ENABLE,
                                            state), 3, "State");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                          HMO_ATTR_DVM_SOURCE,
                                          source), 4, "Source");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                          HMO_ATTR_DVM_TYPE,
                                          type), 5, "Type");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                          HMO_ATTR_DVM_POSITION,
                                          position), 6, "Position");
    
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the result value and the status of the result.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR measurementPlace/This control selects the measurement place.
/// HIPAR result/Returns the result value.
/// HIPAR status/Returns the status is the decimal representation of a 4-bit register 
/// HIPAR status/value:
ViStatus _VI_FUNC hmo_QueryDigitalVoltmeterResult(
	ViSession	instrSession,
	ViInt32	measurementPlace,
	ViReal64*	result,
	ViInt32*	status
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";
	ViChar  buffer[HMO_IO_BUFFER_SIZE] = "";
	ViChar  *p2buf = NULL;
	
	checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, measurementPlace, HMO_VAL_DVM_1, HMO_VAL_DVM_4), 2, "Measurement Place");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_DVM_RESULT_STATUS,
                                                 "DigitalVoltmeter",
                                                 measurementPlace - 1,
                                                 15,
                                                 rep_cap), 2, "Measurement Place");
	
	viCheckErr (hmo_GetAttributeViString (instrSession, rep_cap,
                                          HMO_ATTR_DVM_RESULT_STATUS, HMO_IO_BUFFER_SIZE,
                                          buffer));
	
	p2buf = strtok (buffer, ",");
	
	if (p2buf != NULL)
		*result = hmo_atof (p2buf);
	
	p2buf = strtok (NULL, ",");
	
	if (p2buf != NULL)
		*status = hmo_atoi (p2buf);

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the function generator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR generatorOutputState/Activates or deactivates the function generator output.
/// HIPAR function/Selects the generator function.
/// HIPAR amplitude/Defines the amplitude value (peak-peak value) of the selected 
/// HIPAR amplitude/generator function.
/// HIPAR dcOffset/Sets the DC offset of the selected generator function.
/// HIPAR frequency/Defines the frequency value of the selected generator function.
/// HIPAR rampPolarity/Sets the polarity of the generator function ramp.
/// HIPAR pulseDutyCycles/Defines the duty cycle value of the generator function pulse.
ViStatus _VI_FUNC hmo_ConfigureFunctionGenerator(
	ViSession	instrSession,
	ViBoolean	generatorOutputState,
	ViInt32	function,
	ViReal64	amplitude,
	ViReal64	dcOffset,
	ViReal64	frequency,
	ViInt32	rampPolarity,
	ViReal64	pulseDutyCycles
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_GENERATOR_OUTPUT_ENABLE,
                                            generatorOutputState), 2, "Generator Output State");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_GENERATOR_FUNCTION,
                                          function), 3, "Function");
	
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_GENERATOR_AMPLITUDE,
                                           amplitude), 4, "Amplitude");
	
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_GENERATOR_OFFSET,
                                           dcOffset), 5, "DC Offset");
	
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_GENERATOR_FREQUENCY,
                                           frequency), 6, "Frequency");
	
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_GENERATOR_RAMP_POLARITY,
                                          rampPolarity), 7, "Ramp Polarity");
	
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_GENERATOR_DUTY_CYCLES,
                                           pulseDutyCycles), 8, "Pulse Duty Cycles");
	
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the pattern generator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR patternGeneratorState/Activates or deactivates the pattern
/// HIPAR function/Selects the pattern generator function.
ViStatus _VI_FUNC hmo_ConfigurePatternGenerator(
	ViSession	instrSession,
	ViBoolean	patternGeneratorState,
	ViInt32	function
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_PATTERN_GENERATOR_STATE,
                                            patternGeneratorState), 2, "Pattern Generator State");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_PATTERN_GENERATOR_FUNCTION,
                                          function), 3, "Function");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the pattern generator settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR sampleTime/Defines the sample time of the pattern generator function.
/// HIPAR period/Defines the period of the pattern generator function.
/// HIPAR frequency/Defines the frequency (period) value of the pattern generator 
/// HIPAR frequency/function.
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorSettings(
	ViSession	instrSession,
	ViReal64	sampleTime,
	ViReal64	period,
	ViReal64	frequency
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_PATTERN_GENERATOR_SAMPLE_TIME,
                                           sampleTime), 2, "Sample Time");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_PATTERN_GENERATOR_PERIOD,
                                           period), 3, "Period");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_PATTERN_GENERATOR_FREQUENCY,
                                           frequency), 4, "Frequency");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the pattern generator burts settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR burstState/Turns the BURST function on or off.
/// HIPAR burstCycles/Defines the BURST pattern cycles. The cycles can be only defined with 
/// HIPAR burstCycles/activated BURST function.
/// HIPAR idleTime/Defines the idle time of the pattern generator function. The idle time 
/// HIPAR idleTime/can be only defined with activated BURST function.
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorBurst(
	ViSession	instrSession,
	ViBoolean	burstState,
	ViInt32	burstCycles,
	ViReal64	idleTime
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_PATTERN_GENERATOR_BURST_STATE,
                                            burstState), 2, "Burst State");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_PATTERN_GENERATOR_BURST_CYCLES,
                                          burstCycles), 3, "Burst Cycles");
    
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_PATTERN_GENERATOR_IDLE_TIME,
                                           idleTime), 4, "Idle Time");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the pattern generator trigger settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Defines the arbitrary trigger mode of the pattern generator function.
/// HIPAR externalSlope/Defines the slope of the external arbitrary pattern trigger.
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorTrigger(
	ViSession	instrSession,
	ViInt32	mode,
	ViInt32	externalSlope
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_PATTERN_GENERATOR_TRIGGER_MODE,
                                          mode), 2, "Mode");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_PATTERN_GENERATOR_EXTERNAL_SLOPE,
                                          externalSlope), 3, "External Slope");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function sends manual output of a pattern (single trigger).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC hmo_SendPatternGeneratorTrigger(
	ViSession	instrSession
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckErr (hmo_SetAttributeViString (instrSession, "",
                                          HMO_ATTR_PATTERN_GENERATOR_TRIGGER_SINGLE, NULL));
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the pattern generator ARB data.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR dataLength/Defines the arbitrary pattern length.
/// HIPAR patternData/Defines the arbitrary pattern. The array should consist of at least as 
/// HIPAR patternData/many elements as defined with 'Data Length' control.
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorArbitraryData(
	ViSession	instrSession,
	ViInt32	dataLength,
	ViInt32	patternData[]  
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar    *data = NULL;
	ViChar    *p2data = NULL;
	ViInt32   i= 0;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_PATTERN_GENERATOR_ARBITRATY_DATA_LENGTH,
                                          dataLength), 2, "Data Length");
   
	viCheckAlloc (data = (ViChar*) malloc((size_t)(dataLength * 15 + 300)));
	
	p2data = data;

	for (i = 0; i < dataLength; i++)
	{
		data += sprintf (data, "%ld,", patternData[i]);
	}
	
	*--data = '\0';
    
	viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                           HMO_ATTR_PATTERN_GENERATOR_ARBITRARY_DATA,
                                           p2data), 3, "Pattern Data");

Error:
	if (p2data) free (p2data);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the pattern generator data appending.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR index/Defines the index of the arbitrary pattern.
/// HIPAR appendType/Selects the append type.
/// HIPAR dataLength/Defines the arbitrary pattern length.
/// HIPAR patternData/Defines the arbitrary pattern. The array should consist of at least as 
/// HIPAR patternData/many elements as defined with 'Data Length' control.
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorAppendArbitraryData(
	ViSession	instrSession,
	ViInt32	index,
	ViInt32	appendType,
	ViInt32	dataLength,
	ViInt32	patternData[]
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar    *data = NULL;
	ViChar    *p2data = NULL;
	ViInt32   i= 0;
	ViAttr    attr[3] = {HMO_ATTR_PATTERN_GENERATOR_APPEND_DATA,
						HMO_ATTR_PATTERN_GENERATOR_APPEND_DATA_BINARY_AND,
						HMO_ATTR_PATTERN_GENERATOR_APPEND_DATA_BINARY_OR};
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_PATTERN_GENERATOR_APPEND_INDEX,
                                          index), 2, "Index");
   
	viCheckParm (hmo_invalidViInt32Range (instrSession, appendType, HMO_VAL_NORMAL, HMO_VAL_OR), 3, "Append Type");
    
	viCheckParm (hmo_invalidViInt32Range (instrSession, dataLength, 1, 2048), 4, "Data Length");
    
	viCheckAlloc (data = (ViChar*) malloc((size_t)(dataLength * 15 + 300)));

	p2data = data;

	for (i = 0; i < dataLength; i++)
	{
		data += sprintf (data, "%ld,", patternData[i]);
	}
	
	*--data = '\0';
    
	viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                           attr[appendType],
                                           p2data), 5, "Pattern Data");

Error:
	if (p2data) free (p2data);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the pattern generator counter settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR frequency/Defines the frequency value of the pattern generator counter function. 
/// HIPAR frequency/The user frequency always refers to the switching of the pattern 
/// HIPAR frequency/condition. This results in square waveforms for individual pins.
/// HIPAR direction/Sets the pattern generator counter direction.
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorCounter(
	ViSession	instrSession,
	ViReal64	frequency,
	ViInt32	direction
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                           HMO_ATTR_PATTERN_GENERATOR_COUNTER_FREQUENCY,
                                           frequency), 2, "Frequency");
    
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_PATTERN_GENERATOR_COUNT_DIRECTION,
                                          direction), 3, "Direction");
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the pattern generator square wave settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR polarity/Defines the polarity of the pattern generator square wave function.
/// HIPAR dutyCycle/Sets the duty cycle of the square wave function
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorSquareWave(
	ViSession	instrSession,
	ViInt32	polarity,
	ViReal64 dutyCycle
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_PATTERN_GENERATOR_SQUARE_WAVE_POLARITY,
                                          polarity), 2, "Polarity");
    
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
                                          HMO_ATTR_PATTERN_GENERATOR_SQUARE_WAVE_DUTY_CYCLE,
                                          dutyCycle), 3, "Duty Cycle");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the pattern generator pin states.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR pin1/Sets pin S0 state to high(H) or low(L).
/// HIPAR pin2/Sets pin S1 state to high(H) or low(L).
/// HIPAR pin3/Sets pin S2 state to high(H) or low(L).
/// HIPAR pin4/Sets pin S3 state to high(H) or low(L).
ViStatus _VI_FUNC hmo_ConfigurePatternGeneratorPinState(
	ViSession	instrSession,
	ViBoolean	pinS0,
	ViBoolean	pinS1,
	ViBoolean	pinS2,
	ViBoolean	pinS3
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "Pin0",
                                            HMO_ATTR_PATTERN_GENERATOR_PIN_STATE,
                                            pinS0), 2, "Pin S0");
    
    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "Pin1",
                                            HMO_ATTR_PATTERN_GENERATOR_PIN_STATE,
                                            pinS1), 3, "Pin S1");
    
    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "Pin2",
                                            HMO_ATTR_PATTERN_GENERATOR_PIN_STATE,
                                            pinS2), 4, "Pin S2");
    
    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "Pin3",
                                            HMO_ATTR_PATTERN_GENERATOR_PIN_STATE,
                                            pinS3), 5, "Pin S3");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function defines a destination file for the hadcopy output.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR scheme/Defines the color mode for printing.
/// HIPAR pageOrientation/Defines the page orientation.
/// HIPAR printerName/Name of the printer.
/// HIPAR size/Paper size.
ViStatus _VI_FUNC hmo_ConfigureHardcopyPrinter(
    ViSession    instrSession,
    ViString     printerName,
    ViInt32      pageOrientation,
    ViInt32      scheme,
    ViInt32      size

)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, NULL,
                                            HMO_ATTR_HARDCOPY_DEVICE_DESTINATION,
                                            HMO_VAL_HARDCOPY_DEVICE_PRINT), 1, "Device Destination");

    viCheckParm (hmo_SetAttributeViString (instrSession, NULL,
                                                HMO_ATTR_HARDCOPY_SELECT_PRINTER,
                                                printerName
                                                ), 2, "Printer Name");

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, NULL,
                                       HMO_ATTR_HARDCOPY_DEVICE_ORIENTATION,
                                       pageOrientation
                                       ), 3, "Page Orientation");
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, NULL,
                                                 HMO_ATTR_HARDCOPY_COLOR_SCHEME,
                                                 scheme
                                                 ), 4, "Scheme");
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, NULL,
        HMO_ATTR_HARDCOPY_PAGE_SIZE, size), 5, "Size");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function defines a destination file for the hadcopy output.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR name/File name.
/// HIPAR scheme/Defines the color mode for printing.
/// HIPAR format/Defines the output associated with device configuration.
ViStatus _VI_FUNC hmo_ConfigureHardcopyFile(
    ViSession instrSession,
    ViString  name,
    ViInt32   format,
    ViInt32   scheme

)
{
    ViStatus    error = VI_SUCCESS;
    

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, NULL,
                                       HMO_ATTR_HARDCOPY_DEVICE_DESTINATION,
                                       HMO_VAL_HARDCOPY_DEVICE_MEM
                                       ), 1, "Device Destination");
    viCheckParm (hmo_SetAttributeViString (instrSession, "",
                                                HMO_ATTR_HARDCOPY_FILE_NAME,
                                                name
                                                ), 2, "Name");

            
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, NULL,
                                       HMO_ATTR_HARDCOPY_DEVICE_LANGUAGE_OUTPUT_FORMAT,
                                       format
                                       ), 3, "Format");
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, NULL,
                                                 HMO_ATTR_HARDCOPY_COLOR_SCHEME,
                                                 scheme
                                                 ), 4, "Scheme");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function prints an image of the display to the printer or saves 
/// HIFN  an image to a file or the clipboard.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC hmo_HardcopyPrint(
    ViSession    instrSession
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViString (instrSession, NULL,
                                                HMO_ATTR_HARDCOPY_PRINT,
                                                NULL
                                                ), 1, "Session");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function queries the list of printers under Windows.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/This control indicates the allocated memory in Printer List.
/// HIPAR printerList/This control returns list of printers available under  Windows NT 
/// HIPAR printerList/system. Names are separated using commas (,).
ViStatus _VI_FUNC hmo_HardcopyGetPrinterList(
    ViSession    instrSession,
    ViInt32        bufferSize,
    ViChar        printerList[]
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE] = "";
    ViChar      *p2buf;
    ViInt32     count;
    
    checkErr (Rs_LockSession (instrSession, 0));

    p2buf=printerList;
    count=0;     
    
    viCheckErr (hmo_GetAttributeViString (instrSession, "", HMO_ATTR_HARDCOPY_GET_FIRST_PRINTER,
                HMO_IO_BUFFER_SIZE, buffer));
    
    while (sscanf (buffer, "'%[^']'", buffer) == 1)
    {
        count+=(ViUInt32) strlen(buffer);  
        count++; //add one position for comma
        if (count<=bufferSize)
            p2buf += sprintf (p2buf, "%s,", buffer);
        viCheckErr (hmo_GetAttributeViString (instrSession, "", HMO_ATTR_HARDCOPY_GET_NEXT_PRINTER,
                HMO_IO_BUFFER_SIZE, buffer));      
    }
    if (count > 0)
        *--p2buf='\0';
    
    if (count>bufferSize)
        error = count;     

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function sets the printer language.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR commandSet/Sets the printer language.
ViStatus _VI_FUNC hmo_ConfigureHardcopyCommandSet(
	ViSession	instrSession,
	ViInt32	commandSet
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
                                          HMO_ATTR_HARDCOPY_COMMAND_SET,
                                          commandSet), 2, "Command Set");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function defines an instrument name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR name/Defines the name.
ViStatus _VI_FUNC hmo_ConfigureInstrumentName (ViSession instrSession,
                                          ViString name)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViString (instrSession, "",
        HMO_ATTR_INSTRUMENT_NAME, name), 2, "Name");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function sets the value of a ViInt32 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name 
/// HIPAR channelName/of the channel on which to set the value of the attribute. If the 
/// HIPAR channelName/attribute is not channel-based, then pass VI_NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC hmo_SetAttributeViInt32 (ViSession instrSession, ViString channelName,
                                                ViUInt32 attributeId, ViInt32 value)
{
    return Rs_SetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/// HIFN  This function sets the value of a ViReal64 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name 
/// HIPAR channelName/of the channel on which to set the value of the attribute. If the 
/// HIPAR channelName/attribute is not channel-based, then pass VI_NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC hmo_SetAttributeViReal64 (ViSession instrSession, ViString channelName,
                                                 ViUInt32 attributeId, ViReal64 value)
{
     return Rs_SetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/// HIFN  This function sets the value of a ViString attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name 
/// HIPAR channelName/of the channel on which to set the value of the attribute. If the 
/// HIPAR channelName/attribute is not channel-based, then pass VI_NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC hmo_SetAttributeViString (ViSession instrSession, ViString channelName,
                                                 ViUInt32 attributeId, ViString value)
{
    return Rs_SetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);
}

/// HIFN  This function sets the value of a ViBoolean attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name 
/// HIPAR channelName/of the channel on which to set the value of the attribute. If the 
/// HIPAR channelName/attribute is not channel-based, then pass VI_NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC hmo_SetAttributeViBoolean (ViSession instrSession, ViString channelName,
                                                  ViUInt32 attributeId, ViBoolean value)
{
    return Rs_SetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/// HIFN  This function sets the value of a ViSession attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name 
/// HIPAR channelName/of the channel on which to set the value of the attribute. If the 
/// HIPAR channelName/attribute is not channel-based, then pass VI_NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC hmo_SetAttributeViSession (ViSession instrSession, ViString channelName,
                                                  ViUInt32 attributeId, ViSession value)
{
    return Rs_SetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/// HIFN  This function queries the value of a ViInt32 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name 
/// HIPAR channelName/of the channel on which to obtain the value of the attribute. If the 
/// HIPAR channelName/attribute is not channel-based, then pass VI_NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a 
/// HIPAR value/ViInt32 variable.
ViStatus _VI_FUNC hmo_GetAttributeViInt32 (ViSession instrSession, ViString channelName,
                                                ViUInt32 attributeId, ViInt32 *value)
{
    return Rs_GetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL,
                            (ViInt32) sizeof (ViInt32), (ViInt32 *)value);
}

/// HIFN  This function queries the value of a ViReal64 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name 
/// HIPAR channelName/of the channel on which to obtain the value of the attribute. If the 
/// HIPAR channelName/attribute is not channel-based, then pass VI_NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a 
/// HIPAR value/ViReal64 variable.
ViStatus _VI_FUNC hmo_GetAttributeViReal64 (ViSession instrSession, ViString channelName,
                                                 ViUInt32 attributeId, ViReal64 *value)
{
    return Rs_GetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL,
                            (ViInt32) sizeof (ViReal64), (ViReal64 *)value);
}

/// HIFN  This function queries the value of a ViString attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name 
/// HIPAR channelName/of the channel on which to obtain the value of the attribute. If the 
/// HIPAR channelName/attribute is not channel-based, then pass VI_NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR bufSize/Pass the number of bytes in the ViChar array you specify for the 
/// HIPAR bufSize/Attribute Value parameter.  
/// HIPAR value/The buffer in which the function returns the current value of the 
/// HIPAR value/attribute.  The buffer must be of type ViChar and have at least as many 
/// HIPAR value/bytes as indicated in the Buffer Size parameter.
ViStatus _VI_FUNC hmo_GetAttributeViString (ViSession instrSession, ViString channelName,
                                                 ViUInt32 attributeId, ViInt32 bufSize,
                                                 ViChar value[])
{
    return Rs_GetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL,
                            bufSize, value);
}

/// HIFN  This function queries the value of a ViBoolean attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name 
/// HIPAR channelName/of the channel on which to obtain the value of the attribute. If the 
/// HIPAR channelName/attribute is not channel-based, then pass VI_NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a 
/// HIPAR value/ViBoolean variable.
ViStatus _VI_FUNC hmo_GetAttributeViBoolean (ViSession instrSession, ViString channelName,
                                                  ViUInt32 attributeId, ViBoolean *value)
{
    return Rs_GetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL,
                            (ViInt32) sizeof (ViBoolean), (ViBoolean *)value);
}

/// HIFN  This function queries the value of a ViSession attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name 
/// HIPAR channelName/of the channel on which to obtain the value of the attribute. If the 
/// HIPAR channelName/attribute is not channel-based, then pass VI_NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a 
/// HIPAR value/ViSession variable.
ViStatus _VI_FUNC hmo_GetAttributeViSession (ViSession instrSession, ViString channelName,
                                                  ViUInt32 attributeId, ViSession *value)
{
    return Rs_GetAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL,
                            (ViInt32) sizeof (ViSession), (ViSession *)value);
}

/// HIFN  This function checks the validity of a value you specify for a ViInt32 
/// HIFN  attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name 
/// HIPAR channelName/of the channel on which to check the attribute value. If the attribute 
/// HIPAR channelName/is not channel-based, then pass VI_NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value which you want to verify as a valid value for the 
/// HIPAR value/attribute.
ViStatus _VI_FUNC hmo_CheckAttributeViInt32 (ViSession instrSession, ViString channelName,
                                                  ViUInt32 attributeId, ViInt32 value)
{
    return Rs_CheckAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/// HIFN  This function checks the validity of a value you specify for a 
/// HIFN  ViReal64 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name 
/// HIPAR channelName/of the channel on which to check the attribute value. If the attribute 
/// HIPAR channelName/is not channel-based, then pass VI_NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value which you want to verify as a valid value for the 
/// HIPAR value/attribute.
ViStatus _VI_FUNC hmo_CheckAttributeViReal64 (ViSession instrSession, ViString channelName,
                                                   ViUInt32 attributeId, ViReal64 value)
{
    return Rs_CheckAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/// HIFN  This function checks the validity of a value you specify for a 
/// HIFN  ViString attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name 
/// HIPAR channelName/of the channel on which to check the attribute value. If the attribute 
/// HIPAR channelName/is not channel-based, then pass VI_NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value which you want to verify as a valid value for the 
/// HIPAR value/attribute.
ViStatus _VI_FUNC hmo_CheckAttributeViString (ViSession instrSession, ViString channelName,
                                                   ViUInt32 attributeId, ViString value)
{
    return Rs_CheckAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, value);
}

/// HIFN  This function checks the validity of a value you specify for a 
/// HIFN  ViBoolean attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name 
/// HIPAR channelName/of the channel on which to check the attribute value. If the attribute 
/// HIPAR channelName/is not channel-based, then pass VI_NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value which you want to verify as a valid value for the 
/// HIPAR value/attribute.
ViStatus _VI_FUNC hmo_CheckAttributeViBoolean (ViSession instrSession, ViString channelName,
                                                    ViUInt32 attributeId, ViBoolean value)
{
    return Rs_CheckAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/// HIFN  This function checks the validity of a value you specify for a 
/// HIFN  ViSession attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name 
/// HIPAR channelName/of the channel on which to check the attribute value. If the attribute 
/// HIPAR channelName/is not channel-based, then pass VI_NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value which you want to verify as a valid value for the 
/// HIPAR value/attribute.
ViStatus _VI_FUNC hmo_CheckAttributeViSession (ViSession instrSession, ViString channelName,
                                                    ViUInt32 attributeId, ViSession value)
{
    return Rs_CheckAttribute (instrSession, channelName, attributeId, RS_VAL_DIRECT_USER_CALL, &value);
}

/// HIFN This function returns the repeated capability id(s) that belongs
/// HIFN to the attribute you specify. More then one id is listed in
/// HIFN comma separated string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR attributeID/Pass the ID of an attribute.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the Repeated Capability Id(s) parameter.
/// HIPAR repeatedCapabilityIds/The buffer in which the function returns the repeated capability id(s) belonging to the attribute.
ViStatus _VI_FUNC hmo_GetAttributeRepeatedCapabilityIds (ViSession instrSession,
                                                            ViUInt32 attributeID,
                                                            ViInt32 bufferSize,
                                                            ViChar _VI_FAR repeatedCapabilityIds[])
{
    ViStatus    error = VI_SUCCESS;
    ViChar      repCapNameId[RS_MAX_MESSAGE_BUF_SIZE] = "";

    if (bufferSize <= 0)
        viCheckParm(RS_ERROR_INVALID_PARAMETER, 3, "Buffer Size");

    viCheckErr (Rs_GetAttributeRepCapNameId (instrSession, attributeID, repCapNameId));

    strncpy (repeatedCapabilityIds, repCapNameId, RS_MAX_MESSAGE_BUF_SIZE);
    repeatedCapabilityIds[(bufferSize > RS_MAX_MESSAGE_BUF_SIZE) ?
        RS_MAX_MESSAGE_BUF_SIZE : bufferSize] = '\0';

Error:
    return error;
}

/// HIFN This function returns the repeated capability name(s) that
/// HIFN belongs to the attribute and single repeated capability id you
/// HIFN may specify. More then one name is listed in comma separated
/// HIFN string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR attributeID/Pass the ID of an attribute.
/// HIPAR repeatedCapabilityId/If the attribute applies to a repeated capability such as a trace, this parameter defines the Id of the repeated capability on which to query repeated capability id name(s).
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the Repeated Capability Id Name(s) parameter.
/// HIPAR repeatedCapabilityIdNames/The buffer in which the function returns the repeated capability id name(s) belonging to the attribute.
ViStatus _VI_FUNC hmo_GetAttributeRepeatedCapabilityIdNames (ViSession instrSession,
                                                                ViUInt32 attributeID,
                                                                ViString repeatedCapabilityId,
                                                                ViInt32 bufferSize,
                                                                ViChar _VI_FAR repeatedCapabilityIdNames[])
{
    ViStatus    error = VI_SUCCESS;
    ViChar      repCapName[RS_MAX_MESSAGE_BUF_SIZE] = "";

    if (bufferSize <= 0)
        viCheckParm(RS_ERROR_INVALID_PARAMETER, 4, "Buffer Size");

    viCheckErr (Rs_GetAttributeRepCapName (instrSession,
                                           attributeID,
                                           repeatedCapabilityId,
                                           repCapName));

    strncpy (repeatedCapabilityIdNames, repCapName, RS_MAX_MESSAGE_BUF_SIZE);
    repeatedCapabilityIdNames[(bufferSize >= RS_MAX_MESSAGE_BUF_SIZE) ?
        RS_MAX_MESSAGE_BUF_SIZE - 1 : bufferSize - 1] = '\0';

Error:
    return error;
}

/// HIFN  Enables the math waveform display.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR mathEnabled/Enables the math waveform display.
ViStatus _VI_FUNC hmo_ConfigureMathEnabled(
    ViSession   instrSession,
    ViInt32 mathNumber,
    ViBoolean   mathEnabled
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap [5];

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    sprintf (rep_cap, "M%ld", mathNumber);  

    viCheckParm (hmo_SetAttributeViBoolean (instrSession, rep_cap,
                                                 HMO_ATTR_MATH_WAVEFORM_ENABLED,
                                                 mathEnabled), 3, "Math Enabled");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function sets the vertical position of the specified math waveform in the window.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR waveformPosition/Sets the vertical position of the specified math waveform in the window.
ViStatus _VI_FUNC hmo_ConfigureMathWaveformPosition (ViSession instrSession,
                                                       ViInt32 mathNumber,
                                                       ViReal64 waveformPosition)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap [5];

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    sprintf (rep_cap, "M%ld", mathNumber);  

    viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                                 HMO_ATTR_MATH_WAVEFORM_POSITION,
                                                 waveformPosition), 3, "Waveform Position");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function sets the vertical scale for the specified math waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR verticalScale/Sets the vertical scale for the specified math waveform.
ViStatus _VI_FUNC hmo_ConfigureMathScaling (ViSession instrSession,
                                              ViInt32 mathNumber,
                                              ViReal64 verticalScale)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap [5];

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    sprintf (rep_cap, "M%ld", mathNumber);  

    viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                                 HMO_ATTR_MATH_VERTICAL_SCALE,
                                                 verticalScale), 3, "Vertical Scale");
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Configures general mathematics parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR calculationMethod/Selects the method to build the resulting math waveform from 
/// HIPAR calculationMethod/consecutive acquisitions. The processing is similar to the waveform 
/// HIPAR calculationMethod/arithmetics - instead of the acquired waveforms the math waveforms are 
/// HIPAR calculationMethod/used to create envelope and average.
/// HIPAR expression/Defines the math expression to be calculated for the specified math 
/// HIPAR expression/channel.
ViStatus _VI_FUNC hmo_ConfigureMathSetup(
    ViSession   instrSession,
    ViInt32 mathNumber,
    ViInt32 calculationMethod,
    ViString    expression
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    sprintf (rep_cap, "M%ld", mathNumber);  

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_MATH_ACQUISITION_TYPE,
                                               calculationMethod), 3, "Calculation Method");
    
    viCheckParm (hmo_SetAttributeViString (instrSession, rep_cap,
                                                HMO_ATTR_MATH_EXPRESSION,
                                                expression), 4, "Expression");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Configuration of the math waveform label.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR labelState/Switches the label of the math channel on or off.
/// HIPAR label/Sets the label for the Math waveform, maximum 8 characters.
ViStatus _VI_FUNC hmo_ConfigureMathLabel (ViSession instrSession,
                                          ViInt32 mathNumber,
                                          ViBoolean labelState, ViString label)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_MATH_LABEL_STATE,
                                                 "Math",
                                                 mathNumber - 1,
                                                 15,
                                                 rep_cap), 2, "Math Number");

    viCheckParm(hmo_SetAttributeViBoolean(instrSession, rep_cap,
        HMO_ATTR_MATH_LABEL_STATE, labelState), 3, "Label State");    
    
    viCheckParm(hmo_SetAttributeViString(instrSession, rep_cap,
        HMO_ATTR_MATH_LABEL, label), 4, "Label");    
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Defines whether the Quickmath waveform is active or not. Only if a 
/// HIFN  channel is active it is visible on the screen and can be
/// HIFN  selected as a source for analysis and display functions. Quickmath is 
/// HIFN  only available in YT and Zoom mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR quickmathEnabled/Enables the quickmath waveform.
ViStatus _VI_FUNC hmo_ConfigureQuickmathEnabled (ViSession instrSession,
                                                 ViBoolean quickmathEnabled)
{
	ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm(hmo_SetAttributeViBoolean (instrSession, "",
        HMO_ATTR_QUICKMATH_WAVEFORM_ENABLED, quickmathEnabled), 2, "Quickmath Enabled");
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Defines the Source 1 and Source 2 of the Quickmath waveform and the 
/// HIFN  operation between them.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR source1/Defines the source 1 of the Quickmath waveform.
/// HIPAR source2/Defines the source 2 of the Quickmath waveform.
/// HIPAR operation/Defines the operation between sources.
ViStatus _VI_FUNC hmo_ConfigureQuickmathSource (ViSession instrSession,
                                                ViInt32 source1, ViInt32 source2,
                                                ViInt32 operation)
{
	ViStatus    error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_SetAttributeViInt32 (instrSession, "S1",
        		HMO_ATTR_QUICKMATH_SOURCE, source1), 2, "Source1");
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "S2",
        		HMO_ATTR_QUICKMATH_SOURCE, source2), 3, "Source2");
	
	viCheckParm (hmo_SetAttributeViInt32 (instrSession, "",
        		HMO_ATTR_QUICKMATH_OPERATION, operation), 2, "Operation");
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function sets the vertical position of the Quickmath waveform in the window.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR waveformPosition/Sets the vertical position of the Quickmath waveform in the window.
ViStatus _VI_FUNC hmo_ConfigureQuickmathWaveformPosition (ViSession instrSession,
                                                          ViReal64 waveformPosition)
{
    ViStatus    error = VI_SUCCESS; 
	
	checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
        		HMO_ATTR_QUICKMATH_POSITION, waveformPosition), 2, "Waveform Position");
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function sets the vertical scale for the Quickmath waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR verticalScale/Sets the vertical scale for the Quickmath waveform.
ViStatus _VI_FUNC hmo_ConfigureQuickmathScaling (ViSession instrSession,
                                                 ViReal64 verticalScale)
{
    ViStatus    error = VI_SUCCESS; 
	
	checkErr (Rs_LockSession (instrSession, 0));
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, "",
        		HMO_ATTR_QUICKMATH_VERTICAL_SCALE, verticalScale), 2, "Vertical Scale");
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Defines the frequency range by means of center frequency and frequency 
/// HIFN  span.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR centerFrequency/Defines the position of the displayed frequency range, which is 
/// HIPAR centerFrequency/(Center - Span/2) to (Center + Span/2).
/// HIPAR frequencySpan/Defines the stop frequency of the displayed frequency span.
ViStatus _VI_FUNC hmo_ConfigureFFTFrequencyCenterSpan(
    ViSession   instrSession,
    ViInt32 mathNumber,
    ViReal64    centerFrequency,
    ViReal64    frequencySpan
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    sprintf (rep_cap, "M%ld", mathNumber);  

    viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                                HMO_ATTR_FFT_CENTER_FREQUENCY,
                                                centerFrequency), 3, "Center Frequency");
    
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                                HMO_ATTR_FFT_FREQUENCY_SPAN,
                                                frequencySpan), 4, "Frequency Span");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Performs FFT calculation for the full frequency span.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
ViStatus _VI_FUNC hmo_ConfigureFFTFrequencySpanFull(
    ViSession   instrSession,
    ViInt32 mathNumber
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    sprintf (rep_cap, "M%ld", mathNumber);  

    viCheckErr (hmo_SetAttributeViString (instrSession, rep_cap,
                                               HMO_ATTR_FFT_FULL_SPAN, NULL));
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Defines the frequency range by means of start and stop frequency.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR startFrequency/Defines the start frequency of the displayed frequency span.
/// HIPAR stopFrequency/Defines the stop frequency of the displayed frequency span.
ViStatus _VI_FUNC hmo_ConfigureFFTFrequencyStartStop(
    ViSession   instrSession,
    ViInt32 mathNumber,
    ViReal64    startFrequency,
    ViReal64    stopFrequency
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    sprintf (rep_cap, "M%ld", mathNumber);  

    viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                                HMO_ATTR_FFT_START_FREQUENCY,
                                                startFrequency), 3, "Start Frequency");
    
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                                HMO_ATTR_FFT_STOP_FREQUENCY,
                                                stopFrequency), 4, "Stop Frequency");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Defines the FFT frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR rbwandSpanCouplingEnabled/Couples the frequency span to the RBW.
/// HIPAR rbwRatio/Defines the ratio resolution bandwidth (Hz) / span (Hz).
/// HIPAR resolutionBandwidth/Defines the resolution bandwidth.
ViStatus _VI_FUNC hmo_ConfigureFFTResolutionBandwidth(
    ViSession   instrSession,
    ViInt32 mathNumber,
    ViBoolean   rbwandSpanCouplingEnabled,
    ViReal64 rbwRatio,
    ViReal64    resolutionBandwidth
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    sprintf (rep_cap, "M%ld", mathNumber);  

    viCheckParm (hmo_SetAttributeViBoolean (instrSession, rep_cap,
                                                 HMO_ATTR_FFT_RESOLUTION_BANDWIDTH_COUPLING_ENABLED,
                                                 rbwandSpanCouplingEnabled), 3, "RBW and Span Coupling Enabled");

    if (rbwandSpanCouplingEnabled == VI_TRUE)
    {
        viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                                   HMO_ATTR_FFT_RESOLUTION_BANDWIDTH_RATIO,
                                                   rbwRatio), 4, "RBW Ratio");
    }
    else
    {
        viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                                    HMO_ATTR_FFT_RESOLUTION_BANDWIDTH,
                                                    resolutionBandwidth), 5, "Resolution Bandwidth");
    }
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Queries the effective resolution bandwidth.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR adjustedRBW/Queries the effective resolution bandwidth.
ViStatus _VI_FUNC hmo_QueryFFTAdjustedResolutionBandwidth(
    ViSession   instrSession,
    ViInt32 mathNumber,
    ViReal64*   adjustedRBW
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    sprintf (rep_cap, "M%ld", mathNumber);  

    viCheckParm (hmo_GetAttributeViReal64 (instrSession, rep_cap,
                                                HMO_ATTR_FFT_EFFECTIVE_RESOLUTION_BANDWIDTH,
                                                adjustedRBW), 3, "Adjusted RBW");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Defines the FFT window.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR windowType/Windowing helps minimize the discontinuities at the end of the 
/// HIPAR windowType/measured signal interval and thus reduces the effect of spectral 
/// HIPAR windowType/leakage, increasing the frequency resolution.
ViStatus _VI_FUNC hmo_ConfigureFFTWindowType(
    ViSession   instrSession,
    ViInt32 mathNumber,
    ViInt32 windowType
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    sprintf (rep_cap, "M%ld", mathNumber);  

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_FFT_WINDOW_TYPE,
                                               windowType), 3, "Window Type");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Defines the number of spectrums used for averaging.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR numberOfSpectrums/Defines the number of spectrums used for averaging.
ViStatus _VI_FUNC hmo_ConfigureFFTAveraging (ViSession instrSession,
                                                 ViInt32 mathNumber,
                                                 ViInt32 numberOfSpectrums)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
	sprintf (rep_cap, "M%ld", mathNumber);  

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_FFT_AVERAGING,
                                               numberOfSpectrums), 3, "Number Of Spectrums");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN This function defines the scaling unit and sets the vertical scale for the specified math waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR scalingUnit/Defines the scaling unit of the y-axis.
/// HIPAR verticalScale/Sets the vertical scale for the specified math waveform.
ViStatus _VI_FUNC hmo_ConfigureFFTScaling (ViSession instrSession,
                                             ViInt32 mathNumber,
                                             ViInt32 scalingUnit,
                                             ViReal64 verticalScale)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap [5];

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    sprintf (rep_cap, "M%ld", mathNumber);  

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                                 HMO_ATTR_FFT_SCALING_UNIT,
                                                 scalingUnit), 3, "Scaling Unit");
    
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                                 HMO_ATTR_MATH_VERTICAL_SCALE,
                                                 verticalScale), 4, "Vertical Scale");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the sample rate of data used in an FFT analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR sampleRate/Returns the sample rate of data used in an FFT analysis.
ViStatus _VI_FUNC hmo_QueryFFTSampleRate(
	ViSession	instrSession,
	ViInt32	mathNumber,
	ViReal64*	sampleRate
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";
	
	checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_FFT_SAMPLE_RATE,
                                                 "Math",
                                                 mathNumber - 1,
                                                 15,
                                                 rep_cap), 2, "MathNumber");
	
	viCheckParm (hmo_GetAttributeViReal64 (instrSession, rep_cap,
                                           HMO_ATTR_FFT_SAMPLE_RATE,
                                           sampleRate), 3, "Sample Rate");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function defines the width and the position of the time base 
/// HIFN  extract in the Y(t)-window for which the FFT is calculated.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR width/Defines the width of the time base extract from the Y(t)-window for 
/// HIPAR width/which the FFT is calculated.
/// HIPAR position/Defines the position of the time base extract in the Y(t)-window for 
/// HIPAR position/which the FFT is calculated.
ViStatus _VI_FUNC hmo_ConfigureFFTTimeBase(
	ViSession	instrSession,
	ViInt32	mathNumber,
	ViReal64	width,
	ViReal64	position
)
{
    ViStatus  error = VI_SUCCESS;
    ViChar  rep_cap[15] = "";
	
	checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_FFT_YT_WINDOW_WIDTH,
                                                 "Math",
                                                 mathNumber - 1,
                                                 15,
                                                 rep_cap), 2, "MathNumber");
	
	viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                           HMO_ATTR_FFT_YT_WINDOW_WIDTH,
                                           width), 3, "Width");

	viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                           HMO_ATTR_FFT_YT_WINDOW_POSITION,
                                           position), 4, "Position");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Selects the source waveform to be used as a reference.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR referenceNumber/Selects the reference waveform.
/// HIPAR source/Selects the source waveform to be used as a reference.
ViStatus _VI_FUNC hmo_ConfigureReferenceWaveformSource(
    ViSession    instrSession,
    ViInt32    referenceNumber,
    ViInt32    source
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar    rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, referenceNumber, 1, 4), 2, "Reference Number");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_REFERENCE_WAVEFORM_SOURCE,
                                                 "ReferenceWfm",
                                                 referenceNumber - 1,
                                                 5,
                                                 rep_cap), 2, "Reference Number");       

    viCheckParm (hmo_SetAttributeViInt32 (instrSession, rep_cap,
                                               HMO_ATTR_REFERENCE_WAVEFORM_SOURCE, source
                                               ), 3, "Source");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Copies the selected source waveform with all its settings to the 
/// HIFN  memory of the reference waveform
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR referenceNumber/Selects the reference waveform.
ViStatus _VI_FUNC hmo_UpdateReferenceWaveformWithSelectedSource(
    ViSession    instrSession,
    ViInt32    referenceNumber
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar    rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_REFERENCE_WAVEFORM_UPDATE,
                                                 "ReferenceWfm",
                                                 referenceNumber - 1,
                                                 5,
                                                 rep_cap), 2, "Reference Number");       

    viCheckErr (hmo_SetAttributeViString (instrSession, rep_cap,
                                               HMO_ATTR_REFERENCE_WAVEFORM_UPDATE, NULL));

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Enables the reference waveform display in the diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR displayEnabled/If enabled, the reference waveform is displayed in the diagram.
/// HIPAR referenceNumber/Selects the reference waveform.
ViStatus _VI_FUNC hmo_ConfigureReferenceWaveformDisplayState(
    ViSession    instrSession,
    ViInt32        referenceNumber,
    ViBoolean    displayEnabled
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar    rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_REFERENCE_WAVEFORM_DISPLAY_ENABLED,
                                                 "ReferenceWfm",
                                                 referenceNumber - 1,
                                                 5,
                                                 rep_cap), 2, "Reference Number");       

    viCheckParm (hmo_SetAttributeViBoolean (instrSession, rep_cap,
                                                 HMO_ATTR_REFERENCE_WAVEFORM_DISPLAY_ENABLED, displayEnabled
                                                 ), 3, "Display Enabled");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Loads or saves the reference waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWfm/Selects the reference waveform.
/// HIPAR fileName/DDefines the file name.
/// HIPAR operation/This control selects the type of waveform operation to be performed.
ViStatus _VI_FUNC hmo_ReferenceWaveformFileOperations (ViSession instrSession,
                                                         ViInt32 referenceWfm,
                                                         ViInt32 operation,
                                                         ViString fileName)
{
    ViStatus    error = VI_SUCCESS;
    ViChar    rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_REFERENCE_WAVEFORM_LOAD_FROM_FILE,
                                                 "ReferenceWfm",
                                                 referenceWfm - 1,
                                                 5,
                                                 rep_cap), 2, "Reference Number");       


    switch (operation)
    {
        case HMO_VAL_WAV_LOAD_CFG:
            viCheckParm (hmo_SetAttributeViString (instrSession, rep_cap,
                                                HMO_ATTR_REFERENCE_WAVEFORM_LOAD_CONFIGURATION, NULL
                                                ), 1, "Reference Waveform");
        break;
        
        case HMO_VAL_WAV_LOAD:
            viCheckParm (hmo_SetAttributeViString (instrSession, rep_cap,
                HMO_ATTR_REFERENCE_WAVEFORM_LOAD_FROM_FILE, fileName), 3, "File Name");
        break;
        
        case HMO_VAL_WAV_SAVE:
            viCheckParm (hmo_SetAttributeViString (instrSession, rep_cap,
                HMO_ATTR_REFERENCE_WAVEFORM_SAVE_TO_FILE, fileName), 3, "File Name");
        break;
        default: 
            viCheckParm (RS_ERROR_INVALID_PARAMETER, 4, "Operation");
    }
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the vertical scaling of the reference 
/// HIFN  waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR referenceNumber/Selects the reference waveform.
/// HIPAR verticalScale/Sets the scale factor for the reference waveform.
/// HIPAR verticalPosition/Moves the reference waveform and its horizontal axis up or down in the 
/// HIPAR verticalPosition/diagram, if vertical scaling is set to "Independent".
ViStatus _VI_FUNC hmo_ConfigureReferenceWaveformVerticalScale(
    ViSession    instrSession,
    ViInt32        referenceNumber,
    ViReal64    verticalScale,
    ViReal64    verticalPosition
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar    rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_REFERENCE_WAVEFORM_VERTICAL_SCALE,
                                                 "ReferenceWfm",
                                                 referenceNumber - 1,
                                                 5,
                                                 rep_cap), 2, "Reference Number");       

    viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                                HMO_ATTR_REFERENCE_WAVEFORM_VERTICAL_SCALE, verticalScale
                                                ), 3, "Vertical Scale");
    
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
                                                HMO_ATTR_REFERENCE_WAVEFORM_VERTICAL_POSITION, verticalPosition
                                                ), 4, "Vertical Position");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function changes the horizontal scale (timebase) of the reference waveform independent of the channel waveform settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWfm/This control selects the reference waveform.
/// HIPAR scale/This control sets horizontal scale.
ViStatus _VI_FUNC hmo_ConfigureReferenceWaveformHorizontalScale (ViSession instrSession,
                                                            ViInt32 referenceWfm,
                                                            ViReal64 scale,
                                                            ViReal64 horizontalPosition)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_REFERENCE_WAVEFORM_HORIZONTAL_SCALE,
                                                 "ReferenceWfm",
                                                 referenceWfm - 1,
                                                 5,
                                                 rep_cap), 2, "Reference Wfm");       

    viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
        HMO_ATTR_REFERENCE_WAVEFORM_HORIZONTAL_SCALE, scale), 3, "Scale");
    viCheckParm (hmo_SetAttributeViReal64 (instrSession, rep_cap,
        HMO_ATTR_REFERENCE_WAVEFORM_HORIZONTAL_POSITION, horizontalPosition), 4, "Horizontal Position");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function returns the source waveform - channel, math or reference waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWfm/This control selects the reference waveform.
/// HIPAR arraySize/Sets the size of catalog control.
/// HIPAR catalog/Document parameter here.
/// HIPAR returnedValues/Document parameter here.
ViStatus _VI_FUNC hmo_ReferenceReadWaveformCatalog (ViSession instrSession,
                                                ViInt32 referenceWfm,
                                                ViInt32 arraySize,
                                                ViChar catalog[],
                                                ViInt32 *returnedValues)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      *pbuffer = NULL;
    ViUInt32    count = 0;
	ViInt32     cnt = 0;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, referenceWfm, HMO_VAL_REF_WAVEFORM_1, HMO_VAL_REF_WAVEFORM_4), 2, "Reference Wfm");
    
    viCheckErr (viPrintf (instrSession, "REFC%ld:SOUR:CAT?\n", referenceWfm));
	 viCheckErr (Rs_ReadDataUnknownLength(instrSession, &pbuffer, &count));
	 if (returnedValues)
		 *returnedValues = count;
    viCheckErr (hmo_ParseCatalog(pbuffer, arraySize, catalog, &cnt));

Error:
	if (pbuffer) free (pbuffer);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function initiates an acquisition on the channels that you enable 
/// HIFN  with the hmo_ConfigureChannel function.  It then waits for the 
/// HIFN  acquisition to complete, and returns the waveform for the channel you 
/// HIFN  specify.  You call the hmo_FetchWaveform function to obtain the 
/// HIFN  waveforms for each of the remaining enabled channels without initiating 
/// HIFN  another acquisition.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR channel/This control selects the channel.
/// HIPAR waveformSize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR maximumTime/Pass the maximum length of time in which to allow the read waveform 
/// HIPAR maximumTime/operation to complete.    
/// HIPAR waveformArray/Returns the waveform that the oscilloscope acquires.  
/// HIPAR actualPoints/Indicates the number of points the function places in the Waveform 
/// HIPAR actualPoints/Array parameter.
/// HIPAR initialX/Indicates the time of the first point in the Waveform Array.  The time 
/// HIPAR initialX/is relative to the trigger event.  
/// HIPAR xIncrement/Indicates the length of time between points in the Waveform Array.  
ViStatus _VI_FUNC hmo_ReadWaveform(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32 waveformSize,
    ViInt32 maximumTime,
    ViReal64  waveformArray[],
    ViInt32*    actualPoints,
    ViReal64*   initialX,
    ViReal64*   xIncrement
)
{
    ViStatus    error = VI_SUCCESS;
    ViInt32     timeout = 0;

    checkErr (Rs_LockSession (instrSession, 0));

    checkErr (hmo_GetAttributeViInt32 (instrSession, "",
                                           RS_ATTR_OPC_TIMEOUT, &timeout));
    checkErr (hmo_SetAttributeViInt32 (instrSession, "",
                                           RS_ATTR_OPC_TIMEOUT, maximumTime));
    checkErr (hmo_FetchWaveform (instrSession, channel, waveformSize,
                                     waveformArray, actualPoints, initialX,
                                     xIncrement));
    
Error:
    checkErr (hmo_SetAttributeViInt32 (instrSession, "",
                                           RS_ATTR_OPC_TIMEOUT, timeout));
	
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function initiates an acquisition on the channels that you enable 
/// HIFN  with the hmo_ConfigureChannel function.  It then waits for the 
/// HIFN  acquisition to complete, obtains a main waveform measurement on the channel 
/// HIFN  you specify, and returns the measurement value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR measurement/Selects waveform measurement.
/// HIPAR measurementFunction/Defines or queries the main measurement.
/// HIPAR maximumTime/Pass the maximum length of time in which to allow the read waveform 
/// HIPAR maximumTime/operation to complete.    
/// HIPAR measurementResult/Returns the measured value.  
ViStatus _VI_FUNC hmo_ReadMainWaveformMeasurement (ViSession instrSession,
                                                          ViInt32 measurement,
                                                          ViInt32 measurementFunction,
                                                          ViInt32 maximumTime,
                                                          ViReal64 *measurementResult)
{
    ViStatus    error = VI_SUCCESS;
	ViInt32     timeout = 0;   	
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, measurement, 1, 6), 2, "Measurement");
    
    checkErr (hmo_GetAttributeViInt32 (instrSession, "",
                                           RS_ATTR_OPC_TIMEOUT, &timeout));
    checkErr (hmo_SetAttributeViInt32 (instrSession, "",
                                           RS_ATTR_OPC_TIMEOUT, maximumTime));


    checkErr (hmo_FetchMainWaveformMeasurement (instrSession, 
                                                    measurement,
                                                    measurementFunction,
                                                    measurementResult));
Error:
    checkErr (hmo_SetAttributeViInt32 (instrSession, "",
                                           RS_ATTR_OPC_TIMEOUT, timeout));
	
    Rs_UnlockSession(instrSession, 0);    
    return error;
}


/// HIFN  This function initiates a waveform acquisition.  After you call this 
/// HIFN  function, the oscilloscope leaves the Idle state and waits for a 
/// HIFN  trigger.  The oscilloscope acquires a waveform for each channel you 
/// HIFN  have enabled with the  hmo_ConfigureChannel function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR action/Select action to be performed.
ViStatus _VI_FUNC hmo_InitiateAcquisition(
    ViSession   instrSession,
    ViInt32 action
)
{
    ViStatus    error = VI_SUCCESS;
    ViUInt32    attr = HMO_ATTR_RUN_SINGLE;

    checkErr (Rs_LockSession (instrSession, 0));
    
    switch (action)
    {
        case HMO_VAL_INIT_SINGLE:
            attr = HMO_ATTR_RUN_SINGLE;
            break;
        case HMO_VAL_INIT_CONTINUOUS:
            attr = HMO_ATTR_RUN_CONTINUOUS;
            break;
        case HMO_VAL_INIT_SINGLE_AND_WAIT:
            attr = HMO_ATTR_RUN_SINGLE_WAIT_FOR_OPC;
            break;
			
        default:
            viCheckParm (RS_ERROR_INVALID_PARAMETER, 2, "Action");
    }

    viCheckErr (hmo_SetAttributeViString (instrSession, "", attr, NULL));

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Sends software trigger and waits for operation complete.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR maximumTime/Pass the maximum length of time (in milliseconds) in which to allow 
/// HIPAR maximumTime/the read waveform operation to complete.    
ViStatus _VI_FUNC hmo_SendSoftwareTrigger(
    ViSession   instrSession,
    ViInt32 maximumTime
)
{
    ViStatus    error = VI_SUCCESS;
    ViInt32     timeout = 0;

    checkErr (Rs_LockSession (instrSession, 0));

    checkErr (hmo_GetAttributeViInt32 (instrSession, "",
                                           RS_ATTR_OPC_TIMEOUT, &timeout));
    checkErr (hmo_SetAttributeViInt32 (instrSession, "",
                                           RS_ATTR_OPC_TIMEOUT, maximumTime));
    
    viCheckErr (hmo_SetAttributeViString (instrSession, "",
                                              HMO_ATTR_SEND_SW_TRIGGER_AND_WAIT,
                                              NULL));

Error:
    checkErr (hmo_SetAttributeViInt32 (instrSession, "",
                                           RS_ATTR_OPC_TIMEOUT, timeout));
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the waveform the oscilloscope acquires for the 
/// HIFN  channel you specify.  The waveform is from an acquisition that you 
/// HIFN  previously initiated.  
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR waveformSize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformArray/Returns the waveform that the oscilloscope acquires.  
/// HIPAR actualPoints/Indicates the number of points the function places in the Waveform 
/// HIPAR actualPoints/Array parameter.
/// HIPAR initialX/Indicates the time of the first point in the Waveform Array.  The time 
/// HIPAR initialX/is relative to the trigger event.  
/// HIPAR xIncrement/Indicates the length of time between points in the Waveform Array.  
ViStatus _VI_FUNC hmo_FetchWaveform(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32 waveformSize,
    ViReal64    waveformArray[],
    ViInt32*    actualPoints,
    ViReal64*   initialX,
    ViReal64*   xIncrement
)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[HMO_IO_BUFFER_SIZE] = "";
    ViChar   *p2data  = NULL;

    checkErr (Rs_LockSession (instrSession, 0));

    sprintf (buffer, "CH%ld", channel);
    viCheckParm(hmo_GetAttributeViReal64(instrSession, buffer,
        HMO_ATTR_WAVEFORM_CONVERSION_X_START, initialX), 6, "Initial X");
    viCheckParm(hmo_GetAttributeViReal64(instrSession, buffer,
        HMO_ATTR_WAVEFORM_CONVERSION_X_INCREMENT, xIncrement), 7, "X Increment");

    //sprintf (buffer, "FORM REAL,32;CHAN%ld:DATA?", channel);
	sprintf (buffer, "CHAN%ld:DATA?", channel);
    checkErr (hmo_dataReadTrace (instrSession, buffer, waveformSize, waveformArray, actualPoints));
Error:
    if (p2data) free (p2data);
	//viPrintf (instrSession, "FORM ASCII");
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the waveform the oscilloscope acquires for the 
/// HIFN  channel you specify.  The waveform is from an acquisition that you 
/// HIFN  previously initiated.  
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR waveformSize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformArray/Returns the waveform that the oscilloscope acquires.  
/// HIPAR actualPoints/Indicates the number of points the function places in the Waveform 
/// HIPAR actualPoints/Array parameter.
/// HIPAR initialX/Indicates the time of the first point in the Waveform Array.  The time 
/// HIPAR initialX/is relative to the trigger event.  
/// HIPAR xIncrement/Indicates the length of time between points in the Waveform Array.
ViStatus _VI_FUNC hmo_FetchWaveformInteger (ViSession instrSession,
                                            ViInt32 channel,
                                            ViInt32 waveformSize,
                                            ViUInt16 waveformArray[],
                                            ViInt32 *actualPoints,
                                            ViReal64 *initialX,
                                            ViReal64 *xIncrement)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[HMO_IO_BUFFER_SIZE] = "";
	ViChar   *ext_buf = NULL;
	ViUInt32 ret_cnt = 0;
	ViUInt32 count = 0;

    checkErr (Rs_LockSession (instrSession, 0));

    sprintf (buffer, "CH%ld", channel);
    viCheckParm(hmo_GetAttributeViReal64(instrSession, buffer,
        HMO_ATTR_WAVEFORM_CONVERSION_X_START, initialX), 6, "Initial X");
    viCheckParm(hmo_GetAttributeViReal64(instrSession, buffer,
        HMO_ATTR_WAVEFORM_CONVERSION_X_INCREMENT, xIncrement), 7, "X Increment");

	viPrintf (instrSession, "FORM UINT,16;CHAN%ld:DATA?\n", channel);
	checkErr (hmo_readBinaryDataBlock (instrSession, &ext_buf, &ret_cnt));		 
	count = ret_cnt/2;
	hmo_SWAP_16 ((ViPBuf)ext_buf, count);
	
	*actualPoints = (count > (ViUInt32) waveformSize) ? (ViUInt32) waveformSize : count;
	memcpy (waveformArray, ext_buf, *actualPoints * sizeof (ViUInt16));  
	
Error:
    if (ext_buf) free (ext_buf);
    viPrintf (instrSession, "FORM ASCII\n");
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the waveform the oscilloscope acquires for the 
/// HIFN  channel you specify.  The waveform is from an acquisition that you 
/// HIFN  previously initiated.  
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR waveformSize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformArray/Returns the waveform that the oscilloscope acquires.  
/// HIPAR actualPoints/Indicates the number of points the function places in the Waveform 
/// HIPAR actualPoints/Array parameter.
/// HIPAR initialX/Indicates the time of the first point in the Waveform Array.  The time 
/// HIPAR initialX/is relative to the trigger event.  
/// HIPAR xIncrement/Indicates the length of time between points in the Waveform Array.
ViStatus _VI_FUNC hmo_FetchWaveformByte (ViSession instrSession,
                                         ViInt32 channel, ViInt32 waveformSize,
                                         ViByte waveformArray[],
                                         ViInt32 *actualPoints,
                                         ViReal64 *initialX,
                                         ViReal64 *xIncrement)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[HMO_IO_BUFFER_SIZE] = "";
    ViChar   *p2data  = NULL;
	ViChar   *ext_buf = NULL;
	ViUInt32 ret_cnt = 0;

    checkErr (Rs_LockSession (instrSession, 0));

    sprintf (buffer, "CH%ld", channel);
    viCheckParm(hmo_GetAttributeViReal64(instrSession, buffer,
        HMO_ATTR_WAVEFORM_CONVERSION_X_START, initialX), 6, "Initial X");
    viCheckParm(hmo_GetAttributeViReal64(instrSession, buffer,
        HMO_ATTR_WAVEFORM_CONVERSION_X_INCREMENT, xIncrement), 7, "X Increment");

    viPrintf (instrSession, "FORM UINT,8;CHAN%ld:DATA?\n", channel);
	checkErr (hmo_readBinaryDataBlock (instrSession, &ext_buf, &ret_cnt));
	
	*actualPoints = (ret_cnt > (ViUInt32)waveformSize) ? (ViUInt32)waveformSize : ret_cnt;
	memcpy (waveformArray, ext_buf, *actualPoints);		
	
Error:
    if (p2data) free (p2data);
	viPrintf (instrSession, "FORM ASCII\n");
    Rs_UnlockSession(instrSession, 0);    
    return error; 
}

/// HIFN Returns information on the waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR xStart/X Start in seconds.
/// HIPAR xStop/X Stop in seconds.
/// HIPAR recordLength/Record length of the waveform in Samples.
/// HIPAR valuesPerSample/Number of values per sample interval, usually 1.
ViStatus _VI_FUNC hmo_FetchWaveformHeader (ViSession instrSession,
                                             ViInt32 channel, ViReal64 *xStart,
                                             ViReal64 *xStop,
                                             ViInt32 *recordLength,
                                             ViInt32 *valuesPerSample)
{
    ViStatus error = VI_SUCCESS;
    ViChar   header[HMO_IO_BUFFER_SIZE];
    ViChar   *p2buf  = NULL;
    ViChar   *p2data  = NULL;
    ViUInt32 count = 0;

    checkErr (Rs_LockSession (instrSession, 0));    
    
    sprintf (header, "CHAN%ld:DATA:HEAD?\n", channel);
    checkErr (viWrite (instrSession, (ViBuf) header, (ViUInt32) strlen (header), NULL));
    checkErr (Rs_ReadDataUnknownLength (instrSession, &p2data, &count));
    checkErr (hmo_CheckStatus (instrSession));
    
    
    p2buf = strtok (p2data, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStart != NULL) *xStart = atof (p2buf);
    
    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStop != NULL) *xStop = atof (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (recordLength != NULL) *recordLength = atol (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (valuesPerSample != NULL) *valuesPerSample = atol (p2buf);

Error:
    if (p2data) free (p2data);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the waveform conversion data.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR xStart/Return the time of the first sample of the indicated waveform.
/// HIPAR xIncrement/Return the time difference between two adjacent samples of the indicated waveform.
/// HIPAR yStart/Return the voltage value for binary value 0 of the indicated waveform.
/// HIPAR yIncrement/Return the voltage value per bit of the indicated waveform.
/// HIPAR yResolution/Return the vertical bit resolution of the indicated waveform.
ViStatus _VI_FUNC hmo_FetchWaveformConversionData (ViSession instrSession,
                                                   ViInt32 channel,
                                                   ViReal64 *xStart,
                                                   ViReal64 *xIncrement,
                                                   ViReal64 *yStart,
                                                   ViReal64 *yIncrement,
                                                   ViInt32 *yResolution)
{
	ViStatus error = VI_SUCCESS;
    ViChar   rep_cap_channel[50] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_TRIGGER_LEVEL,
                                                 "Channel",
                                                 channel,
                                                 15,
                                                 rep_cap_channel), 2, "Channel");
   
    
    viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap_channel,
        HMO_ATTR_WAVEFORM_CONVERSION_X_START, xStart), 3, "X Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap_channel,
        HMO_ATTR_WAVEFORM_CONVERSION_X_INCREMENT, xIncrement), 4, "X Increment");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap_channel,
        HMO_ATTR_WAVEFORM_CONVERSION_Y_START, yStart), 5, "Y Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap_channel,
        HMO_ATTR_WAVEFORM_CONVERSION_Y_INCREMENT, yIncrement), 6, "Y Increment");

	viCheckParm(hmo_GetAttributeViInt32(instrSession, rep_cap_channel,
        HMO_ATTR_WAVEFORM_CONVERSION_Y_RESOLUTION, yResolution), 7, "Y Resolution");

	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the data of the envelope.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR waveformSize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformArray/Returns the waveform that the oscilloscope acquires.  
/// HIPAR actualPoints/Indicates the number of points the function places in the Waveform 
/// HIPAR actualPoints/Array parameter.
/// HIPAR initialX/Indicates the time of the first point in the Waveform Array.  The time 
/// HIPAR initialX/is relative to the trigger event.  
/// HIPAR xIncrement/Indicates the length of time between points in the Waveform Array.  
ViStatus _VI_FUNC hmo_FetchEnvelopeWaveform (ViSession instrSession,
                                                 ViInt32 channel,
                                                 ViInt32 waveformSize,
                                                 ViReal64 waveformArray[],
                                                 ViInt32 *actualPoints,
                                                 ViReal64 *initialX,
                                                 ViReal64 *xIncrement)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[HMO_IO_BUFFER_SIZE] = "";
    xIncrement;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, channel, 1, 4), 2, "Channel");
    
    checkErr (hmo_FetchEnvelopeWaveformHeader (instrSession, channel,
                                                 initialX, NULL,
                                                 actualPoints, NULL));
    
    sprintf (buffer, "CHAN%ld:DATA:ENV?", channel);
    checkErr (hmo_dataReadTrace (instrSession, buffer, waveformSize, waveformArray, actualPoints));
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN Returns information on the envelope waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR xStart/X Start in seconds.
/// HIPAR xStop/X Stop in seconds.
/// HIPAR recordLength/Record length of the waveform in Samples.
/// HIPAR valuesPerSample/Number of values per sample interval, usually 2.
ViStatus _VI_FUNC hmo_FetchEnvelopeWaveformHeader (ViSession instrSession,
                                                     ViInt32 channel,
                                                     ViReal64 *xStart,
                                                     ViReal64 *xStop,
                                                     ViInt32 *recordLength,
                                                     ViInt32 *valuesPerSample)
{
    ViStatus error = VI_SUCCESS;
    ViChar   header[HMO_IO_BUFFER_SIZE];
    ViChar   *p2buf  = NULL;
    ViChar   *p2data  = NULL;
    ViUInt32 count = 0;

    checkErr (Rs_LockSession (instrSession, 0));    
    
    sprintf (header, "CHAN%ld:DATA:ENV:HEAD?\n", channel);
    checkErr (viWrite (instrSession, (ViBuf) header, (ViUInt32) strlen (header), NULL));
    checkErr (Rs_ReadDataUnknownLength (instrSession, &p2data, &count));
    checkErr (hmo_CheckStatus (instrSession));
    
    
    p2buf = strtok (p2data, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStart != NULL) *xStart = atof (p2buf);
    
    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStop != NULL) *xStop = atof (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (recordLength != NULL) *recordLength = atol (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (valuesPerSample != NULL) *valuesPerSample = atol (p2buf);

Error:
    if (p2data) free (p2data);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the envelope waveform conversion data.
/// HIFN  attributes of the waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR channel/This control selects the channel.
/// HIPAR xStart/Return the time of the first sample of the indicated waveform.
/// HIPAR xIncrement/Return the time difference between two adjacent samples of the indicated waveform.
/// HIPAR yStart/Return the voltage value for binary value 0 of the indicated waveform.
/// HIPAR yIncrement/Return the voltage value per bit of the indicated waveform.
/// HIPAR yResolution/Return the vertical bit resolution of the indicated waveform.
ViStatus _VI_FUNC hmo_FetchEnvelopeWaveformConversionData (ViSession instrSession,
                                                           ViInt32 channel,
                                                           ViReal64 *xStart,
                                                           ViReal64 *xIncrement,
                                                           ViReal64 *yStart,
                                                           ViReal64 *yIncrement,
                                                           ViInt32 *yResolution)
{
    ViStatus error = VI_SUCCESS;
    ViChar   rep_cap_channel[150] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_TRIGGER_LEVEL,
                                                 "Channel",
                                                 channel,
                                                 150,
                                                 rep_cap_channel), 2, "Channel");
   
    
    viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap_channel,
        HMO_ATTR_ENVELOPE_WAVEFORM_CONVERSION_X_START, xStart), 3, "X Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap_channel,
        HMO_ATTR_ENVELOPE_WAVEFORM_CONVERSION_X_INCREMENT, xIncrement), 4, "X Increment");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap_channel,
        HMO_ATTR_ENVELOPE_WAVEFORM_CONVERSION_Y_START, yStart), 5, "Y Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap_channel,
        HMO_ATTR_ENVELOPE_WAVEFORM_CONVERSION_Y_INCREMENT, yIncrement), 6, "Y Increment");

	viCheckParm(hmo_GetAttributeViInt32(instrSession, rep_cap_channel,
        HMO_ATTR_ENVELOPE_WAVEFORM_CONVERSION_Y_RESOLUTION, yResolution), 7, "Y Resolution");

	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the data of the math waveform points.  
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR waveformSize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformArray/Returns the vertical values - voltages of recorded waveform samples, 
/// HIPAR waveformArray/or magnitudes of a spectrum.  
/// HIPAR actualPoints/Indicates the number of points the function places in the Waveform 
/// HIPAR actualPoints/Array parameter.
ViStatus _VI_FUNC hmo_FetchMathWaveform(
    ViSession    instrSession,
    ViInt32        mathNumber,
    ViInt32        waveformSize,
    ViReal64    waveformArray[],
    ViInt32*    actualPoints
)
{
    ViStatus error = VI_SUCCESS;
    ViChar   header[HMO_IO_BUFFER_SIZE] = "";
    ViChar   *p2data  = NULL;

    checkErr (Rs_LockSession (instrSession, 0));

    // Use header to fetch horizontal parameters

    sprintf (header, "CALC:MATH%d:DATA?", mathNumber);
    checkErr (hmo_dataReadTrace (instrSession, header, waveformSize, waveformArray, actualPoints));
    
    
Error:
    if (p2data) free (p2data);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the header of math waveform data. The header contains  
/// HIFN  attributes of the waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR xStart/X Start in seconds.
/// HIPAR xStop/X Stop in seconds.
/// HIPAR recordLength/Record length of the waveform in Samples.
/// HIPAR valuesPerSample/Number of values per sample interval, usually 1.
ViStatus _VI_FUNC hmo_FetchMathWaveformHeader (ViSession instrSession,
                                                 ViInt32 mathNumber,
                                                 ViReal64 *xStart,
                                                 ViReal64 *xStop,
                                                 ViInt32 *recordLength,
                                                 ViInt32 *valuesPerSample)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[5] = "";
    ViChar      buffer[HMO_IO_BUFFER_SIZE] = "";
    ViChar      *p2buf = NULL;
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_MATH_WAVEFORM_HEADER,
                                                 "Math",
                                                 mathNumber - 1,
                                                 5,
                                                 rep_cap), 2, "Math Number");       

    viCheckParm (hmo_GetAttributeViString (instrSession, rep_cap,
                                                HMO_ATTR_MATH_WAVEFORM_HEADER,
                                                HMO_IO_BUFFER_SIZE,
                                                buffer), 3, "Math Waveform Header");
    
    p2buf = strtok (buffer, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStart != NULL) *xStart = atof (p2buf);
    
    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStop != NULL) *xStop = atof (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (recordLength != NULL) *recordLength = atol (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (valuesPerSample != NULL) *valuesPerSample = atol (p2buf);

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the header of math waveform data. The header contains  
/// HIFN  attributes of the waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR xStart/Return the time of the first sample of the indicated waveform.
/// HIPAR xIncrement/Return the time difference between two adjacent samples of the indicated waveform.
/// HIPAR yStart/Return the voltage value for binary value 0 of the indicated waveform.
/// HIPAR yIncrement/Return the voltage value per bit of the indicated waveform.
/// HIPAR yResolution/Return the vertical bit resolution of the indicated waveform.
ViStatus _VI_FUNC hmo_FetchMathWaveformConversionData (ViSession instrSession,
                                                       ViInt32 mathNumber,
                                                       ViReal64 *xStart,
                                                       ViReal64 *xIncrement,
                                                       ViReal64 *yStart,
                                                       ViReal64 *yIncrement,
                                                       ViInt32 *yResolution)
{
	
    ViStatus error = VI_SUCCESS;
    ViChar   rep_cap[50] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    sprintf (rep_cap, "M%ld", mathNumber);     
    
    viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_MATH_WAVEFORM_CONVERSION_X_START, xStart), 3, "X Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_MATH_WAVEFORM_CONVERSION_X_INCREMENT, xIncrement), 4, "X Increment");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_MATH_WAVEFORM_CONVERSION_Y_START, yStart), 5, "Y Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_MATH_WAVEFORM_CONVERSION_Y_INCREMENT, yIncrement), 6, "Y Increment");

	viCheckParm(hmo_GetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_MATH_WAVEFORM_CONVERSION_Y_RESOLUTION, yResolution), 7, "Y Resolution");

	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the data of the math envelope waveform points.  
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR waveformSize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformArray/Returns the vertical values - voltages of recorded waveform samples, 
/// HIPAR waveformArray/or magnitudes of a spectrum.  
/// HIPAR actualPoints/Indicates the number of points the function places in the Waveform 
/// HIPAR actualPoints/Array parameter.
ViStatus _VI_FUNC hmo_FetchMathEnvelopeWaveform(
	ViSession	instrSession,
	ViInt32	mathNumber,
	ViInt32	waveformSize,
	ViReal64	waveformArray[],
	ViInt32*	actualPoints
)
{
    ViStatus error = VI_SUCCESS;
    ViChar   header[HMO_IO_BUFFER_SIZE] = "";
    
    checkErr (Rs_LockSession (instrSession, 0));

    // Use header to fetch horizontal parameters

    sprintf (header, "CALC:MATH%d:DATA:ENV?", mathNumber);
    checkErr (hmo_dataReadTrace (instrSession, header, waveformSize, waveformArray, actualPoints));
    
	checkErr (hmo_CheckStatus (instrSession));    
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the header of math envelope waveform data. The header contains 
/// HIFN   attributes of the waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR xStart/X Start in seconds.
/// HIPAR xStop/X Stop in seconds.
/// HIPAR recordLength/Record length of the waveform in Samples.
/// HIPAR valuesPerSample/Number of values per sample interval, usually 1.
ViStatus _VI_FUNC hmo_FetchMathEnvelopeWaveformHeader(
	ViSession	instrSession,
	ViInt32	mathNumber,
	ViReal64*	xStart,
	ViReal64*	xStop,
	ViInt32*	recordLength,
	ViInt32*	valuesPerSample
)
{
    ViStatus error = VI_SUCCESS;
    ViChar   header[HMO_IO_BUFFER_SIZE];
    ViChar   *p2buf  = NULL;
    ViChar   *p2data  = NULL;
    ViUInt32 count = 0;

    checkErr (Rs_LockSession (instrSession, 0));    
    
    sprintf (header, "CALC:MATH%ld:DATA:ENV:HEAD?\n", mathNumber);
    checkErr (viWrite (instrSession, (ViBuf) header, (ViUInt32) strlen (header), NULL));
    checkErr (Rs_ReadDataUnknownLength (instrSession, &p2data, &count));
    checkErr (hmo_CheckStatus (instrSession));
    
    p2buf = strtok (p2data, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStart != NULL) *xStart = hmo_atof (p2buf);
    
    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStop != NULL) *xStop = hmo_atof (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (recordLength != NULL) *recordLength = hmo_atoi (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (valuesPerSample != NULL) *valuesPerSample = hmo_atoi (p2buf);

Error:
    if (p2data) free (p2data);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the math envelope waveform conversion data.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR mathNumber/Selects the math waveform.
/// HIPAR xStart/Returns the time of the first sample of the indicated waveform of the 
/// HIPAR xStart/envelope.
/// HIPAR xIncrement/Returns the time difference between two adjacent samples of the 
/// HIPAR xIncrement/indicated waveform of the envelope.
/// HIPAR yStart/Returns the voltage value for binary value 0 of the indicated waveform 
/// HIPAR yStart/of the envelope.
/// HIPAR yIncrement/Returns the voltage value per bit of the indicated waveform of the 
/// HIPAR yIncrement/envelope.
/// HIPAR yResolution/Returns the vertical bit resolution of the indicated waveform of the 
/// HIPAR yResolution/envelope.
ViStatus _VI_FUNC hmo_FetchMathEnvelopeWaveformConversionData(
	ViSession	instrSession,
	ViInt32	mathNumber,
	ViReal64*	xStart,
	ViReal64*	xIncrement,
	ViReal64*	yStart,
	ViReal64*	yIncrement,
	ViInt32*	yResolution
)
{
    ViStatus error = VI_SUCCESS;
    ViChar   rep_cap[50] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_invalidViInt32Range (instrSession, mathNumber, 1, 5), 2, "Math Number");
    
    sprintf (rep_cap, "M%ld", mathNumber);     
    
    viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_MATH_ENVELOPE_WAVEFORM_X_START, xStart), 3, "X Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_MATH_ENVELOPE_WAVEFORM_X_INCREMENT, xIncrement), 4, "X Increment");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_MATH_ENVELOPE_WAVEFORM_Y_START, yStart), 5, "Y Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_MATH_ENVELOPE_WAVEFORM_Y_INCREMENT, yIncrement), 6, "Y Increment");

	viCheckParm(hmo_GetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_MATH_ENVELOPE_WAVEFORM_Y_RESOLUTION, yResolution), 7, "Y Resolution");

	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the header of math waveform data. The header contains  
/// HIFN  attributes of the waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR waveformSize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformArray/Returns the vertical values - voltages of recorded waveform samples, or magnitudes of a spectrum.
/// HIPAR actualPoints/Indicates the number of points the function places in the waveform Array parameter.
ViStatus _VI_FUNC hmo_FetchQuickmathWaveform (ViSession instrSession,
                                              ViInt32 waveformSize,
                                              ViReal64 waveformArray[],
                                              ViInt32 *actualPoints)
{
   ViStatus error = VI_SUCCESS;
    ViChar   *p2buf  = NULL;
    ViChar   *p2data  = NULL;
    ViUInt32 count = 0;
    ViInt32  i = 0;

    checkErr (Rs_LockSession (instrSession, 0));    
    
    viCheckErr (viPrintf(instrSession, "CALC:QMAT:DATA?\n"));

    checkErr (Rs_ReadDataUnknownLength (instrSession, &p2data, &count));
    checkErr (hmo_CheckStatus (instrSession));
    
    p2buf = strtok (p2data, ",");
    while (p2buf && (i < waveformSize))
    {
        if (i<waveformSize)
            waveformArray[i++] = atof (p2buf);
        else
            i++;
        p2buf = strtok (NULL, ",");
    }
    *actualPoints = i;
    
Error:
    if (p2data) free (p2data);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the header of Quickmath waveform data. The header contains attributes of the waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR xStart/X Start in seconds.
/// HIPAR xStop/X Stop in seconds.
/// HIPAR recordLength/Record length of the waveform in Samples.
/// HIPAR values_perSample/Number of values per sample interval, usually 1.
ViStatus _VI_FUNC hmo_FetchQuickmathWaveformHeader (ViSession instrSession,
                                                    ViReal64 *xStart,
                                                    ViReal64 *xStop,
                                                    ViInt32 *recordLength,
                                                    ViInt32 *values_perSample)
{
    ViStatus error = VI_SUCCESS;
	ViChar   header[HMO_IO_BUFFER_SIZE];
    ViChar   *p2buf  = NULL;
    ViChar   *p2data  = NULL;
    ViUInt32 count = 0;

    checkErr (Rs_LockSession (instrSession, 0));    
    
    sprintf (header, "CALC:QMAT:DATA:HEAD?\n");
    checkErr (viWrite (instrSession, (ViBuf) header, (ViUInt32) strlen (header), NULL));
    checkErr (Rs_ReadDataUnknownLength (instrSession, &p2data, &count));
    checkErr (hmo_CheckStatus (instrSession));
	
    p2buf = strtok (p2data, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStart != NULL) *xStart = atof (p2buf);
    
    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStop != NULL) *xStop = atof (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (recordLength != NULL) *recordLength = atol (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (values_perSample != NULL) *values_perSample = atol (p2buf);

Error:
	if (p2data) free (p2data);
    Rs_UnlockSession(instrSession, 0);
    return error;
}

/// HIFN  Returns the quick math waveform conversion data.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR xStart/Return the time of the first sample of the indicated waveform.
/// HIPAR xIncrement/Return the time difference between two adjacent samples of the indicated waveform.
/// HIPAR yStart/Return the voltage value for binary value 0 of the indicated waveform.
/// HIPAR yIncrement/Return the voltage value per bit of the indicated waveform.
/// HIPAR yResolution/Return the vertical bit resolution of the indicated waveform.
ViStatus _VI_FUNC hmo_FetchQuickmathWaveformConversionData (ViSession instrSession,
                                                            ViReal64 *xStart,
                                                            ViReal64 *xIncrement,
                                                            ViReal64 *yStart,
                                                            ViReal64 *yIncrement,
                                                            ViInt32 *yResolution)
{
    ViStatus error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm(hmo_GetAttributeViReal64(instrSession, "",
        HMO_ATTR_QUICKMATH_WAVEFORM_CONVERSION_X_START, xStart), 2, "X Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, "",
        HMO_ATTR_QUICKMATH_WAVEFORM_CONVERSION_X_INCREMENT, xIncrement), 3, "X Increment");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, "",
        HMO_ATTR_QUICKMATH_WAVEFORM_CONVERSION_Y_START, yStart), 4, "Y Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, "",
        HMO_ATTR_QUICKMATH_WAVEFORM_CONVERSION_Y_INCREMENT, yIncrement), 5, "Y Increment");

	viCheckParm(hmo_GetAttributeViInt32(instrSession, "",
        HMO_ATTR_QUICKMATH_WAVEFORM_CONVERSION_Y_RESOLUTION, yResolution), 6, "Y Resolution");

	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the data of the reference waveform points.  
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWfm/Selects the reference waveform, the internal reference storage.
/// HIPAR waveformSize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformArray/Returns the vertical values - voltages of recorded waveform samples, 
/// HIPAR waveformArray/or magnitudes of a spectrum.  
/// HIPAR actualPoints/Indicates the number of points the function places in the Waveform 
/// HIPAR actualPoints/Array parameter.
ViStatus _VI_FUNC hmo_FetchReferenceWaveform (ViSession instrSession,
                                                     ViInt32 referenceWfm,
                                                     ViInt32 waveformSize,
                                                     ViReal64 waveformArray[],
                                                     ViInt32 *actualPoints)
{
    ViStatus error = VI_SUCCESS;
    ViChar   *p2buf  = NULL;
    ViChar   *p2data  = NULL;
    ViUInt32 count = 0;
    ViInt32  i = 0;

    checkErr (Rs_LockSession (instrSession, 0));    
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, referenceWfm, HMO_VAL_REF_WAVEFORM_1, HMO_VAL_REF_WAVEFORM_4), 2, "Reference Wfm");
    
    viCheckErr (viPrintf(instrSession, "REFC%ld:DATA?\n", referenceWfm));

    checkErr (Rs_ReadDataUnknownLength (instrSession, &p2data, &count));
    checkErr (hmo_CheckStatus (instrSession));
    
    p2buf = strtok (p2data, ",");
    while (p2buf && (i < waveformSize))
    {
        if (i<waveformSize)
            waveformArray[i++] = atof (p2buf);
        else
            i++;
        p2buf = strtok (NULL, ",");
    }
    *actualPoints = i;
    
Error:
    if (p2data) free (p2data);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the header of math waveform data. The header contains  
/// HIFN  attributes of the waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR xStart/X Start in seconds.
/// HIPAR xStop/X Stop in seconds.
/// HIPAR recordLength/Record length of the waveform in Samples.
/// HIPAR valuesPerSample/Number of values per sample interval, usually 1.
ViStatus _VI_FUNC hmo_FetchReferenceWaveformHeader (ViSession instrSession,
                                                      ViInt32 channel,
                                                      ViReal64 *xStart,
                                                      ViReal64 *xStop,
                                                      ViInt32 *recordLength,
                                                      ViInt32 *valuesPerSample)
{
    ViStatus    error = VI_SUCCESS;
    ViChar      rep_cap[5] = "";
    ViChar      buffer[HMO_IO_BUFFER_SIZE] = "";
    ViChar      *p2buf = NULL;
    
    checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_REFERENCE_WAVEFORM_HEADER,
                                                 "ReferenceWfm",
                                                 channel - 1,
                                                 5,
                                                 rep_cap), 2, "Reference Wfm");       

    viCheckParm (hmo_GetAttributeViString (instrSession, rep_cap,
                                                HMO_ATTR_REFERENCE_WAVEFORM_HEADER,
                                                HMO_IO_BUFFER_SIZE,
                                                buffer), 3, "Reference Waveform Header");
    
    p2buf = strtok (buffer, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStart != NULL) *xStart = atof (p2buf);
    
    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStop != NULL) *xStop = atof (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (recordLength != NULL) *recordLength = atol (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (valuesPerSample != NULL) *valuesPerSample = atol (p2buf);

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function obtains a main waveform measurement on the channel you 
/// HIFN  specify, and returns the measurement value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR referenceWfm/selects the reference waveform.	
/// HIPAR xStart/Return the time of the first sample of the indicated waveform.
/// HIPAR xIncrement/Return the time difference between two adjacent samples of the indicated waveform.
/// HIPAR yStart/Return the voltage value for binary value 0 of the indicated waveform.
/// HIPAR yIncrement/Return the voltage value per bit of the indicated waveform.
/// HIPAR yResolution/Return the vertical bit resolution of the indicated waveform.
ViStatus _VI_FUNC hmo_FetchReferenceWaveformConversionData (ViSession instrSession,
                                                            ViInt32 referenceWfm,
                                                            ViReal64 *xStart,
                                                            ViReal64 *xIncrement,
                                                            ViReal64 *yStart,
                                                            ViReal64 *yIncrement,
                                                            ViInt32 *yResolution)
{
    ViStatus error = VI_SUCCESS;
	ViChar      rep_cap[5] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_REFERENCE_WAVEFORM_CONVERSION_X_START,
                                                 "ReferenceWfm",
                                                 referenceWfm - 1,
                                                 5,
                                                 rep_cap), 2, "Reference Wfm");
	
	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_REFERENCE_WAVEFORM_CONVERSION_X_START, xStart), 3, "X Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_REFERENCE_WAVEFORM_CONVERSION_X_INCREMENT, xIncrement), 4, "X Increment");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_REFERENCE_WAVEFORM_CONVERSION_Y_START, yStart), 5, "Y Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_REFERENCE_WAVEFORM_CONVERSION_Y_INCREMENT, yIncrement), 6, "Y Increment");

	viCheckParm(hmo_GetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_REFERENCE_WAVEFORM_CONVERSION_Y_RESOLUTION, yResolution), 7, "Y Resolution");

	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function obtains a main waveform measurement on the channel you 
/// HIFN  specify, and returns the measurement value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR measurement/Selects waveform measurement.
/// HIPAR measurementFunction/Defines or queries the main measurement.
/// HIPAR measurementResult/Returns the measured value.  
ViStatus _VI_FUNC hmo_FetchMainWaveformMeasurement (ViSession instrSession,
                                                           ViInt32 measurement,
                                                           ViInt32 measurementFunction,
                                                           ViReal64 *measurementResult)
{
    ViStatus error = VI_SUCCESS;
    ViChar   rep_cap_measurement[25] = "";
    ViChar   rep_cap_meas_function[25] = "";
    ViChar   rep_cap[75] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_MAIN_MEASUREMENT_RESULT,
                                                 "Measurement",
                                                 measurement - 1,
                                                 25,
                                                 rep_cap_measurement), 2, "Measurement");
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_MAIN_MEASUREMENT_RESULT,
                                                 "MeasType",
                                                 measurementFunction - 1,
                                                 25,
                                                 rep_cap_meas_function), 3, "Result Type");
    strcpy (rep_cap, rep_cap_measurement);
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_meas_function);

    viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap,
        HMO_ATTR_MAIN_MEASUREMENT_RESULT, measurementResult), 4, "Result");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the data of the POD.
/// HIFN  hmo_InitiateAcquisition function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR pod/Selects the Pod.
/// HIPAR waveformSize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformArray/Returns the vertical values - voltages of recorded waveform samples or magnitudes of a spectrum.
/// HIPAR actualPoints/Indicates the number of points the function places in the Waveform Array parameter.
ViStatus _VI_FUNC hmo_FetchPodData (ViSession instrSession, ViInt32 pod,
                                    ViInt32 waveformSize,
                                    ViReal64 waveformArray[],
                                    ViInt32 *actualPoints)
{
    ViStatus error = VI_SUCCESS;
    ViChar   *p2buf  = NULL;
    ViChar   *p2data  = NULL;
    ViUInt32 count = 0;
    ViInt32  i = 0;

    checkErr (Rs_LockSession (instrSession, 0));    
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, pod, HMO_VAL_POD_1, HMO_VAL_POD_2), 2, "Pod");
    
    viCheckErr (viPrintf(instrSession, "POD%ld:DATA?\n", pod));

    checkErr (Rs_ReadDataUnknownLength (instrSession, &p2data, &count));
    checkErr (hmo_CheckStatus (instrSession));
    
    p2buf = strtok (p2data, ",");
    while (p2buf && (i < waveformSize))
    {
        if (i<waveformSize)
            waveformArray[i++] = atof (p2buf);
        else
            i++;
        p2buf = strtok (NULL, ",");
    }
    *actualPoints = i;
    
Error:
    if (p2data) free (p2data);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the header of data of the POD.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR pod/Selects the Pod.
/// HIPAR xStart/X Start in seconds.
/// HIPAR xStop/X Stop in seconds.
/// HIPAR number_ofSamples/Number of samples.
/// HIPAR values_perSample/Number of values per sample interval, usually 2.
ViStatus _VI_FUNC hmo_FetchPodDataHeader (ViSession instrSession,
                                          ViInt32 pod, ViReal64 *xStart,
                                          ViReal64 *xStop,
                                          ViInt32 *number_ofSamples,
                                          ViInt32 *values_perSample)
{
 
	ViStatus error = VI_SUCCESS;
    ViChar   header[HMO_IO_BUFFER_SIZE];
    ViChar   *p2buf  = NULL;
    ViChar   *p2data  = NULL;
    ViUInt32 count = 0;
	
    checkErr (Rs_LockSession (instrSession, 0));
    
	viCheckParm (hmo_invalidViInt32Range (instrSession, pod, HMO_VAL_POD_1, HMO_VAL_POD_2), 2, "Pod");
    
    //viCheckErr (viPrintf(instrSession, "POD%ld:DATA:HEAD?\n", pod));
	sprintf (header, "POD%ld:DATA:HEAD?\n", pod);
	checkErr (viWrite (instrSession, (ViBuf) header, (ViUInt32) strlen (header), NULL));
    checkErr (Rs_ReadDataUnknownLength (instrSession, &p2data, &count));
    checkErr (hmo_CheckStatus (instrSession));
	
    p2buf = strtok (p2data, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStart != NULL) *xStart = atof (p2buf);
    
    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStop != NULL) *xStop = atof (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (number_ofSamples != NULL) *number_ofSamples = atol (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (values_perSample != NULL) *values_perSample = atol (p2buf);

Error:
	if (p2data) free (p2data);  
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the number of available data.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR pod/Selects the Pod.
/// HIPAR number_ofSamples/Returns the number of samples for the selected range.
ViStatus _VI_FUNC hmo_FetchPodNumberOfSamples (ViSession instrSession,
                                               ViInt32 pod,
                                               ViInt32 *number_ofSamples)
{
	ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap_pod[15] = "";
	
	checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, pod, HMO_VAL_POD_1, HMO_VAL_POD_2), 2, "Pod");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_POD_NUMBER_OF_SAMPLES,
                                                 "Pod",
                                                 pod - 1,
                                                 15,
                                                 rep_cap_pod), 2, "Pod");
	
	viCheckParm (hmo_GetAttributeViInt32 (instrSession, rep_cap_pod,
        HMO_ATTR_POD_NUMBER_OF_SAMPLES, number_ofSamples), 3, "Number of Samples");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the Pod waveform conversion data.
/// HIFN  hmo_InitiateAcquisition function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR pod/Selects the Pod.
/// HIPAR xStart/Returns the time of the first sample of the indicated waveform.
/// HIPAR xIncrement/Returns the time difference between two adjacent samples of the indicated waveform.
/// HIPAR yStart/Returns the voltage value for binary value 0 of the indicated waveform.
/// HIPAR yIncrement/Returns the voltage value per bit of the indicated waveform.
/// HIPAR yResolution/Returns the vertical bit resolution of the indicated waveform.
ViStatus _VI_FUNC hmo_FetchPodDataConversionData (ViSession instrSession,
                                                  ViInt32 pod, ViReal64 *xStart,
                                                  ViReal64 *xIncrement,
                                                  ViReal64 *yStart,
                                                  ViReal64 *yIncrement,
                                                  ViInt32 *yResolution)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  rep_cap_pod[15] = "";
	
	checkErr (Rs_LockSession (instrSession, 0));
    
    viCheckParm (hmo_invalidViInt32Range (instrSession, pod, HMO_VAL_POD_1, HMO_VAL_POD_2), 2, "Pod");
    
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_POD_WAVEFORM_CONVERSION_X_START,
                                                 "Pod",
                                                 pod - 1,
                                                 15,
                                                 rep_cap_pod), 2, "Pod");
	
	
    viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap_pod,
        HMO_ATTR_POD_WAVEFORM_CONVERSION_X_START, xStart), 3, "X Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap_pod,
        HMO_ATTR_POD_WAVEFORM_CONVERSION_X_INCREMENT, xIncrement), 4, "X Increment");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap_pod,
        HMO_ATTR_POD_WAVEFORM_CONVERSION_Y_START, yStart), 5, "Y Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, rep_cap_pod,
        HMO_ATTR_POD_WAVEFORM_CONVERSION_Y_INCREMENT, yIncrement), 6, "Y Increment");

	viCheckParm(hmo_GetAttributeViInt32(instrSession, rep_cap_pod,
        HMO_ATTR_POD_WAVEFORM_CONVERSION_Y_RESOLUTION, yResolution), 7, "Y Resolution");

	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the data of the mask waveform.  
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR waveformSize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformArray/Returns the vertical values - voltages of recorded waveform samples, 
/// HIPAR waveformArray/or magnitudes of a spectrum.  
/// HIPAR actualPoints/Indicates the number of points the function places in the Waveform 
/// HIPAR actualPoints/Array parameter.
ViStatus _VI_FUNC hmo_FetchMaskDataWaveform(
	ViSession	instrSession,
	ViInt32	waveformSize,
	ViReal64	waveformArray[],
	ViInt32*	actualPoints
)
{
    ViStatus error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    // Use header to fetch horizontal parameters

    checkErr (hmo_dataReadTrace (instrSession, "MASK:DATA?", waveformSize, waveformArray, actualPoints));
    
	checkErr (hmo_CheckStatus (instrSession));    
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the header of mask waveform data. The header contains  
/// HIFN  attributes of the waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR xStart/X Start in seconds.
/// HIPAR xStop/X Stop in seconds.
/// HIPAR recordLength/Record length of the waveform in Samples.
/// HIPAR valuesPerSample/Number of values per sample interval, usually 1.
ViStatus _VI_FUNC hmo_FetchMaskDataWaveformHeader(
	ViSession	instrSession,
	ViReal64*	xStart,
	ViReal64*	xStop,
	ViInt32*	recordLength,
	ViInt32*	valuesPerSample
)
{
    ViStatus error = VI_SUCCESS;
    ViChar   *p2buf  = NULL;
    ViChar   *p2data  = NULL;
    ViUInt32 count = 0;

    checkErr (Rs_LockSession (instrSession, 0));    
    
    checkErr (viWrite (instrSession, (ViBuf) "MASK:DATA:HEAD?\n", 16, NULL));
    checkErr (Rs_ReadDataUnknownLength (instrSession, &p2data, &count));
    checkErr (hmo_CheckStatus (instrSession));
    
    p2buf = strtok (p2data, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStart != NULL) *xStart = hmo_atof (p2buf);
    
    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (xStop != NULL) *xStop = hmo_atof (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (recordLength != NULL) *recordLength = hmo_atoi (p2buf);

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        checkErr (VI_ERROR_INV_RESPONSE);
    if (valuesPerSample != NULL) *valuesPerSample = hmo_atoi (p2buf);

Error:
    if (p2data) free (p2data);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the mask waveform conversion data.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR xStart/Return the time of the first sample of the indicated mask waveform.
/// HIPAR xIncrement/Return the time difference between two adjacent samples of the mask 
/// HIPAR xIncrement/waveform
/// HIPAR yStart/Return the voltage value for binary value 0 of the indicated mask 
/// HIPAR yStart/waveform.
/// HIPAR yIncrement/Return the voltage value per bit of the indicated mask waveform.
/// HIPAR yResolution/Return the vertical bit resolution of the indicated waveform.
ViStatus _VI_FUNC hmo_FetchMaskDataWaveformConversionData(
	ViSession	instrSession,
	ViReal64*	xStart,
	ViReal64*	xIncrement,
	ViReal64*	yStart,
	ViReal64*	yIncrement,
	ViInt32*	yResolution
)
{
    ViStatus error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_GetAttributeViReal64(instrSession, "",
        HMO_ATTR_MASK_DATA_CONVERSION_X_START, xStart), 3, "X Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, "",
        HMO_ATTR_MASK_DATA_CONVERSION_X_INCREMENT, xIncrement), 4, "X Increment");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, "",
        HMO_ATTR_MASK_DATA_CONVERSION_Y_START, yStart), 5, "Y Start");

	viCheckParm(hmo_GetAttributeViReal64(instrSession, "",
        HMO_ATTR_MASK_DATA_CONVERSION_Y_INCREMENT, yIncrement), 6, "Y Increment");

	viCheckParm(hmo_GetAttributeViInt32(instrSession, "",
        HMO_ATTR_MASK_DATA_CONVERSION_Y_RESOLUTION, yResolution), 7, "Y Resolution");
	
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function aborts an acquisition and returns the oscilloscope to 
/// HIFN  the Idle state.  You initiate an acquisition with the 
/// HIFN  hmo_InitiateAcquisition function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
ViStatus _VI_FUNC hmo_Abort(
    ViSession   instrSession
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckErr (hmo_SetAttributeViString (instrSession, "",
                                              HMO_ATTR_STOP, NULL));
Error:
    (void) Rs_UnlockSession (instrSession, 0);
    return error;
}

/// HIFN This function resets the instrument to a known state and sends initialization commands to the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
ViStatus _VI_FUNC hmo_reset (ViSession instrSession)
{
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, 0));

    if (Rs_Simulating(instrSession) == 0)                /* call only when locked */
        {
        viCheckErr( viPrintf (instrSession, "*RST\n"));
        }

    checkErr( hmo_DefaultInstrSetup (instrSession));
    checkErr( hmo_CheckStatus (instrSession));

Error:

    (void) Rs_UnlockSession (instrSession, 0);

    return error;
}

/// HIFN This function runs the instrument's self test routine and returns the test result(s).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR testResult/Contains the value returned from the instrument self test.
/// HIPAR testMessage/Returns the self-test response string from the instrument.
ViStatus _VI_FUNC hmo_self_test (ViSession instrSession, ViInt16 *testResult, 
                                      ViChar testMessage[])
{
    ViStatus    error   = VI_SUCCESS;
    ViInt32     result = 0;
    
    checkErr( Rs_LockSession (instrSession, 0));

    if (testResult == NULL)
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 2, "Null address for Test Result");
    if (testMessage == NULL)
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Null address for Test Message");

    viCheckErr (hmo_GetAttributeViInt32 (instrSession, NULL, HMO_ATTR_SELF_TEST_QUERY, &result));
    if (*testResult == 0)
        strcpy (testMessage, "Self-Test Passed.");
    else
        strcpy (testMessage, "Self-Test Failed.");

Error:
    (void) Rs_UnlockSession(instrSession, 0);
    return error;
}

/// HIFN This function returns the driver and instrument revisions.
/// HIRET /// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR driverRev/Returns the instrument driver software revision numbers in the form of a string.
/// HIPAR instrRev/Returns the instrument firmware revision numbers in the form of a string.
ViStatus _VI_FUNC hmo_revision_query (ViSession instrSession, ViChar driverRev[], 
                                           ViChar instrRev[])
{
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, 0));

    if (driverRev == NULL)
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 2, "Null address for Driver Revision");
    if (instrRev == NULL)
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Null address for Instrument Revision");

    checkErr( Rs_GetAttribute (instrSession, NULL, HMO_ATTR_SPECIFIC_DRIVER_REVISION,
                                        0, 256, driverRev));
    checkErr( Rs_GetAttribute (instrSession, "", HMO_ATTR_INSTRUMENT_FIRMWARE_REVISION,
                                        0, 256, instrRev));
    checkErr( hmo_CheckStatus (instrSession));

Error:
    (void) Rs_UnlockSession(instrSession, 0);
    return error;
}

/// HIFN This function reads an error code and a message from the
/// HIFN instrument's error queue.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR errorCode/Returns the error code read from the instrument's error queue.
/// HIPAR errorMessage/Returns the error message string read from the instrument's error message queue.
ViStatus _VI_FUNC hmo_error_query (ViSession instrSession, ViInt32 *errorCode, 
                                        ViChar errorMessage[])
{
    ViStatus    error   = VI_SUCCESS;
    ViChar      buffer[HMO_IO_BUFFER_SIZE] = "";
    ViInt32     oldCode = 0;
    ViChar      oldMessage[256] = "";
    ViChar      *p2buf = NULL;
    ViInt32     i = 0;
    ViUInt32    retCnt = 0;

    checkErr( Rs_LockSession (instrSession, 0));

    if (errorCode == NULL)
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 2, "Null address for Error Code");
    if (errorMessage == NULL)
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Null address for Error Message");

    if (Rs_Simulating(instrSession) == 0)                /* call only when locked */
    {
        p2buf = (char *)malloc (1);

        *p2buf='\0';
            
        do 
        {
            checkErr (viWrite (instrSession, (ViBuf) ":SYST:ERR?\n", 11, NULL));
            checkErr (viRead (instrSession, (ViBuf)buffer, HMO_IO_BUFFER_SIZE, &retCnt));
            if  (sscanf (buffer, "%ld,%*[^0-9a-zA-Z]%256[^\"]", &oldCode, oldMessage) != 2)
            {
                viCheckErr(RS_ERROR_UNEXPECTED_RESPONSE);
            }
            else
            {
                if (oldCode != 0)
                {
                    *errorCode = oldCode;
                    
                    p2buf = (char *)realloc (p2buf, strlen(p2buf) + strlen (oldMessage) + 2);
        
                    strcat (p2buf, oldMessage);
        
                    strcat (p2buf, "\n");
                    
                    i++;
                }
                else if (i == 0)
                {
                    *errorCode = oldCode;
    
                    strncpy (errorMessage, oldMessage, 1024);
                }
            }

        } while (oldCode != 0);
        
        if (i > 0)
        {
            p2buf[strlen (p2buf) - 1] = '\0'; 
            
            strncpy (errorMessage, p2buf, 1024);
        }
    }
    
    else
    {
        /* Simulate Error Query */
        *errorCode = 0;
        strcpy (errorMessage, "No error.");
    }

Error:
    if (p2buf) free (p2buf);
    (void) Rs_UnlockSession(instrSession, 0);
    return error;
}


/// HIFN Queries the error/event queue for all unread items and removes them from the queue.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR bufferSize/Sets the size of Errors string.
/// HIPAR errors/Returns the error message string read from the instrument's error message queue.
ViStatus _VI_FUNC hmo_ErrorList (ViSession instrSession,
                                   ViInt32 bufferSize, ViChar errors[])
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeViString (instrSession, NULL,
                                                 HMO_ATTR_SYST_ERR_LIST, bufferSize,
                                                 errors), 3, "Errors"); 
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function converts a status code returned by an instrument driver function into a user-readable string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR errorCode/Pass the Status parameter that is returned from any of the instrument driver functions.
/// HIPAR errorMessage/Returns the user-readable message string that corresponds to the status code you specify.
ViStatus _VI_FUNC hmo_error_message (ViSession instrSession, ViStatus errorCode,
                                          ViChar errorMessage[256])
{
    ViStatus    error   = VI_SUCCESS;

    static      RsStringValueTable errorTable =
        {
            HMO_ERROR_CODES_AND_MSGS,
            {0, NULL}
        };

    (void) Rs_LockSession(instrSession, 0);

        /* all VISA and RS error codes are handled as well as codes in the table */
    if (errorMessage == NULL)
        viCheckParm( RS_ERROR_INVALID_PARAMETER, 3, "Null address for Error Message");

    checkErr( Rs_GetSpecificDriverStatusDesc(instrSession, errorCode, errorMessage, errorTable));

Error:
    (void) Rs_UnlockSession(instrSession, 0);
    return error;
}

/// HIFN  This function resets all STATUS:QUESTIONALBLE registers.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
ViStatus _VI_FUNC hmo_ResetStatusRegisters (ViSession instrSession)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckErr (hmo_SetAttributeViString (instrSession, NULL, HMO_ATTR_RESET_STATUS_REGISTER, NULL)); 
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function sets the status reporting system.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR registerType/This control selects type of the registers that will be configured.
/// HIPAR statusRegister/This control selects the registers that will be configured.
/// HIPAR registerPart/This control selects the registers that will be configured.
/// HIPAR registerValue/Value of selected register.
ViStatus _VI_FUNC hmo_SetStatusRegister (ViSession instrSession,
                                             ViInt32 registerType,
                                             ViInt32 statusRegister,
                                             ViInt32 registerPart,
                                             ViInt32 registerValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   rep_cap_part[25] = "";
    ViChar   rep_cap[75] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_REGISTER,
                                                 "RegisterType",
                                                 registerType,
                                                 25,
                                                 rep_cap), 2, "Register Type");
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_REGISTER,
                                                 "Register",
                                                 statusRegister,
                                                 25,
                                                 rep_cap_part), 3, "Status Register");
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_part);

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_REGISTER,
                                                 "RegisterPart",
                                                 registerPart,
                                                 25,
                                                 rep_cap_part), 4, "Register Part");

    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_part);

    viCheckParm(hmo_SetAttributeViInt32(instrSession, rep_cap,
        HMO_ATTR_REGISTER, registerValue), 5, "Register Value");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function queries the status reporting system.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR registerType/This control selects type of the registers that will be queried.
/// HIPAR statusRegister/This control selects the registers that will be queried.
/// HIPAR registerPart/This control selects the registers that will be queried.
/// HIPAR registerValue/Returns value of selected register.
ViStatus _VI_FUNC hmo_GetStatusRegister (ViSession instrSession,
                                                ViInt32 registerType,
                                                ViInt32 statusRegister,
                                                ViInt32 registerPart,
                                                ViInt32 *registerValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   rep_cap_part[25] = "";
    ViChar   rep_cap[75] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_REGISTER,
                                                 "RegisterType",
                                                 registerType,
                                                 25,
                                                 rep_cap), 2, "Register Type");
    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_REGISTER,
                                                 "Register",
                                                 statusRegister,
                                                 25,
                                                 rep_cap_part), 3, "Status Register");
    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_part);

    viCheckParm (hmo_GetAttributeRepCapName (instrSession,
                                                 HMO_ATTR_REGISTER,
                                                 "RegisterPart",
                                                 registerPart,
                                                 25,
                                                 rep_cap_part), 4, "Register Part");

    strcat (rep_cap, ",");
    strcat (rep_cap, rep_cap_part);

    viCheckParm(hmo_GetAttributeViInt32 (instrSession, rep_cap,
        HMO_ATTR_REGISTER, registerValue), 5, "Register Value");

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function specifies the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsrtm20xx_init or 
/// HIPAR instrSession/rsrtm20xx_InitWithOptions function.  
/// HIPAR VISATimeout/This control sets the timeout value.
ViStatus _VI_FUNC hmo_SetVISATimeout(ViSession instrSession,
                                  ViUInt32 VISATimeout)
{
	ViStatus	error = VI_SUCCESS;
	
	checkErr( Rs_LockSession (instrSession, NULL));

    viCheckErr( viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, VISATimeout ));
    
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN This function returns the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  
/// HIPAR VISATimeout/This control gets the timeout value.
ViStatus _VI_FUNC hmo_GetVISATimeout(ViSession instrSession,
                                  ViUInt32 *VISATimeout)
{
	ViStatus	error = VI_SUCCESS;
	
	checkErr( Rs_LockSession (instrSession, NULL));

    viCheckErr( viGetAttribute (instrSession, VI_ATTR_TMO_VALUE, VISATimeout ));
    
Error:
    (void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN This function switches ON/OFF various error checkings performed inside of the driver.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR optionChecking/This control switches option checking On or Off.
/// HIPAR rangeChecking/This control enables or disables range checking.
/// HIPAR statusChecking/This control enables or disables instrument state checking
ViStatus _VI_FUNC hmo_ConfigureErrorChecking (ViSession instrSession,
                                                  ViBoolean optionChecking,
                                                  ViBoolean rangeChecking,
                                                  ViBoolean statusChecking)
{
    ViStatus    error = VI_SUCCESS;
    ViInt32     p2value         = 0;
    RsSessionPropertiesPtr  sessionProperties = Rs_ViSession (instrSession);

    sessionProperties -> optionChecking = optionChecking;
    p2value = (ViInt32) statusChecking;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_QUERY_INSTRUMENT_STATUS, 0, &p2value));
    p2value = (ViInt32) rangeChecking;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_RANGE_CHECK, 0, &p2value));
	
Error:
    return error;
}

/// HIFN  This function clears status.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC hmo_ClearStatus(
	ViSession	instrSession
)
{
    ViStatus  error = VI_SUCCESS;

	checkErr (Rs_LockSession (instrSession, 0));

	checkErr (viWrite (instrSession, (ViBuf) "*CLS\n", 5, NULL));
    checkErr (hmo_CheckStatus (instrSession));

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function returns the ID Query response string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of IDQueryResponse buffer
/// HIPAR idQueryResponse/Returns the ID Query response string. The array should consist of at 
/// HIPAR idQueryResponse/least 256 elements.
ViStatus _VI_FUNC hmo_IDQueryResponse (ViSession instrSession,
                                         ViUInt32 bufferSize,
                                         ViChar IDQueryResponse[])
{
	ViStatus	error = VI_SUCCESS;

	checkErr (Rs_LockSession (instrSession, 0));
	
	checkErr (viWrite (instrSession, (ViBuf) "*IDN?\n", 6, NULL));
	checkErr (viRead (instrSession, (ViBuf) IDQueryResponse, bufferSize, NULL));
    checkErr (hmo_CheckStatus (instrSession));

Error:
    Rs_UnlockSession(instrSession, 0);    
	return error;
}

/// HIFN  Stops further command processing until all commands sent before *WAI 
/// HIFN  have been executed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC hmo_ProcessAllPreviousCommands(
	ViSession	instrSession
)
{
    ViStatus	error = VI_SUCCESS;

	checkErr (Rs_LockSession (instrSession, 0));
	
	checkErr (hmo_WriteInstrData (instrSession, "*WAI\n"));
	
Error:
	(void) Rs_UnlockSession (instrSession, 0);
    return error;
}

/// HIFN  This function queries the OPC.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR opc/Queries the OPC.
ViStatus _VI_FUNC hmo_QueryOPC(
	ViSession	instrSession,
	ViInt32*	opc
)
{
    ViStatus  error = VI_SUCCESS;
	ViChar      cmd[100] = "*OPC?\n";

	checkErr (Rs_LockSession (instrSession, 0));

	viCheckErr (viWrite (instrSession, (ViBuf) cmd, (ViUInt32) strlen (cmd), NULL));
	viCheckErr (viRead (instrSession, (ViBuf) cmd, 100UL, NULL));
	sscanf (cmd, "%ld", opc);
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function retrieves and then clears the error information
/// HIFN for the session or the current execution thread.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR errorCode/Returns the error code for the session or execution thread.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the Description parameter.
/// HIPAR description/Returns the error description for the session or execution thread. If there is no description, the function returns an empty string.
ViStatus _VI_FUNC hmo_GetError (ViSession instrSession, 
                                     ViStatus *errorCode, 
                                     ViInt32 bufferSize,
                                     ViChar description[])  
{
    ViStatus    error       = VI_SUCCESS;
    ViStatus    primary     = VI_SUCCESS,
                secondary   = VI_SUCCESS;
    ViChar      elaboration[RS_MAX_MESSAGE_BUF_SIZE]    = "";
    ViChar      errorMessage[RS_MAX_MESSAGE_BUF_SIZE]  = "";
    ViChar     *appendPoint = errorMessage;
    ViInt32     actualSize  = 0;
    ViBoolean   locked      = VI_FALSE;
    RsSessionPropertiesPtr  sessionProperties = Rs_ViSession (instrSession);

    /* Lock Session */
    checkErr( Rs_LockSession(instrSession, &locked));

    /* Test for nulls and acquire error data */
    if (bufferSize != 0)
    {
        if (errorCode == NULL)
        {
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 2, "Null address for Error");
        }
        if (sessionProperties == NULL)
        {
            primary = VI_ERROR_RSRC_NFOUND;
            secondary = 0;
        }
        else
        {
            checkErr( Rs_GetErrorInfo (instrSession, &primary, &secondary, elaboration));
        }
    }

    else
        {
            if (sessionProperties == NULL)
            {
                (void) Rs_UnlockSession (instrSession, &locked);
                return 1024;
            }
            else
            {
                checkErr( Rs_GetAttribute (instrSession, NULL, RS_ATTR_ERROR_ELABORATION, 0, 256, elaboration));
                checkErr( Rs_GetAttribute (instrSession, NULL, RS_ATTR_SECONDARY_ERROR, 0, (ViInt32) sizeof (secondary), &secondary));
                checkErr( Rs_GetAttribute (instrSession, NULL, RS_ATTR_PRIMARY_ERROR, 0, (ViInt32) sizeof (primary), &primary));
            }
        }

    /* Format data */
    if (primary != VI_SUCCESS)
        {
        ViChar msg[256] = "";
        checkErr( hmo_error_message (instrSession, primary, msg));
        appendPoint += sprintf(appendPoint, "Primary Error: (Hex 0x%08X) %s\n", (unsigned int) primary, msg);
        }

    if (secondary != VI_SUCCESS)
        {
        ViChar msg[256] = "";
        checkErr( hmo_error_message (instrSession, secondary, msg));
        appendPoint += sprintf(appendPoint, "Secondary Error: (Hex 0x%08X) %s\n", (unsigned int) secondary, msg);
        }

    if (strlen (elaboration) > 0)
        {
        sprintf(appendPoint, "Elaboration: %s", elaboration);
        }

    actualSize = (ViInt32) (strlen(errorMessage) + 1);

    /* Prepare return values */
    if (bufferSize == 0)
        {
        error = (ViStatus) actualSize;
        }
    else
        {
        if (bufferSize > 0)
            {
            if (actualSize > bufferSize)
                {
                error = actualSize;
                actualSize = bufferSize;
                }
            }
        if (description == NULL)
            {
            viCheckParm( RS_ERROR_INVALID_PARAMETER, 4, "Null address for Description");
            }
        memcpy(description, errorMessage, (size_t)(actualSize-1));
        description[actualSize-1] = '\0';
        }

    if (errorCode)
        {
        *errorCode = primary;
        }

Error:
    /* Unlock Session */
    (void) Rs_UnlockSession (instrSession, &locked);
    return error;
}

/// HIFN This function clears the error code and error description for
/// HIFN the session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
ViStatus _VI_FUNC hmo_ClearError (ViSession instrSession)                                                        
{                                                                                                           
    return Rs_ClearErrorInfo (instrSession);                                                                             
}

/// HIFN This function writes a user-specified string to the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR writeBuffer/Pass the string to be written to the instrument.
ViStatus _VI_FUNC hmo_WriteInstrData (ViSession instrSession, ViString writeBuffer)
{
    return Rs_WriteInstrData (instrSession, writeBuffer);
}

/// HIFN Document your function here.
/// HIFN You may use multiple lines for documentation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR numBytes/Pass the maximum number of bytes to read from the instruments.
/// HIPAR rdBuf/After this function executes, this parameter contains the data that was read from the instrument.
/// HIPAR bytesRead/Returns the number of bytes actually read from the instrument and stored in the Read Buffer.
ViStatus _VI_FUNC hmo_ReadInstrData (ViSession instrSession, ViInt32 numBytes,
                                          ViChar rdBuf[], ViUInt32 *bytesRead)
{
    return Rs_ReadInstrData (instrSession, numBytes, rdBuf, bytesRead);
}

/// HIFN This function queries the ViBoolean value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR command/The query to be sent to the instrument.
/// HIPAR value/Returns the ViBoolean value.
ViStatus _VI_FUNC hmo_QueryViBoolean (ViSession instrSession,
                                           ViString command, 
                                           ViBoolean *value)
{
    ViStatus    error = VI_SUCCESS;
    
    checkErr( Rs_LockSession (instrSession, 0)); 
    if (strlen(command)==0)
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 2, "Command");
    if (value==NULL)
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Value");
    viCheckErr (viQueryf (instrSession, "%s\n", "%d", command, value));
    checkErr( hmo_CheckStatus (instrSession)); 
Error:
    (void) Rs_UnlockSession(instrSession, 0);
    return error;
}

/// HIFN This function queries the ViInt32 value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR command/The query to be sent to the instrument.
/// HIPAR value/Returns the ViInt32 value.
ViStatus _VI_FUNC hmo_QueryViInt32 (ViSession instrSession,
                                         ViString command, 
                                         ViInt32 *value)
{
    ViStatus    error = VI_SUCCESS;
    
    checkErr( Rs_LockSession (instrSession, 0)); 
    if (strlen(command)==0)
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 2, "Command");
    if (value==NULL)
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Value");
    viCheckErr (viQueryf (instrSession, "%s\n", "%ld", command, value));
    checkErr( hmo_CheckStatus (instrSession)); 
Error:
    (void) Rs_UnlockSession(instrSession, 0);
    return error;
}

/// HIFN This function queries the ViReal64 value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR command/The query to be sent to the instrument.
/// HIPAR value/Returns the ViReal64 value.
ViStatus _VI_FUNC hmo_QueryViReal64 (ViSession instrSession,
                                          ViString command, 
                                          ViReal64 *value)
{
    ViStatus    error = VI_SUCCESS;
    
    checkErr( Rs_LockSession (instrSession, 0)); 
    if (strlen(command)==0)
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 2, "Command");
    if (value==NULL)
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Value");
    viCheckErr (viQueryf (instrSession, "%s\n", "%le", command, value));
    checkErr( hmo_CheckStatus (instrSession)); 
Error:
    (void) Rs_UnlockSession(instrSession, 0);
    return error;
}

/// HIFN This function queries the ViString value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
/// HIPAR command/The query to be sent to the instrument.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the Value parameter.
/// HIPAR value/Returns the string value.
ViStatus _VI_FUNC hmo_QueryViString (ViSession instrSession,
                                          ViString command, 
                                          ViInt32 bufferSize,
                                          ViChar _VI_FAR value[])
{
    ViStatus    error = VI_SUCCESS;
    ViChar      *pbuffer = NULL;
    ViUInt32        bytesRead;
    
    checkErr( Rs_LockSession (instrSession, 0)); 
    if (strlen(command)==0)
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 2, "Command");
    if (value==NULL)
        viCheckParm (RS_ERROR_INVALID_PARAMETER, 3, "Value");
    viCheckErr (viPrintf (instrSession, "%s\n", command));
    viCheckErr(Rs_ReadDataUnknownLength (instrSession, &pbuffer, &bytesRead));  
    if (bytesRead>=(ViUInt32)bufferSize)
    {
        strncpy(value, pbuffer, (size_t) (bufferSize-1));
        value[bufferSize-1]='\0';
        error = (ViStatus) (bytesRead+1);
    } 
    else
    {
        strncpy(value, pbuffer, (size_t) bytesRead); 
        value[bytesRead]='\0';   
    }
    checkErr( hmo_CheckStatus (instrSession)); 
Error:
    if (pbuffer) free (pbuffer);
    (void) Rs_UnlockSession(instrSession, 0);
    return error;
}

/// HIFN Sends a command to the instrument synchronised with OPC-polling.
/// HIFN Use this function to wait for an instrument operation that can
/// HIFN take a long time to complete, e.g. self-alignment. 
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR writeBuffer/Pass the string to be written to the instrument.
/// HIPAR timeout/This control sets the timeout value.
ViStatus _VI_FUNC hmo_WriteCommandWithOPCSync (ViSession instrSession,
                                                    ViString writeBuffer,
                                                    ViUInt32 timeout)
{
	ViStatus	error = VI_SUCCESS;
	ViChar      buffer[RS_MAX_MESSAGE_BUF_SIZE] = "";
		
	checkErr( Rs_LockSession (instrSession, NULL)); 

	viCheckParm (strlen(writeBuffer) == 0, 2, "Write Buffer");
    
    viCheckErr (Rs_ClearBeforeRead (instrSession));
	
	sprintf (buffer, "%s;*OPC\n", writeBuffer);
	
	viCheckErr (Rs_WriteInstrData (instrSession, buffer));
	
	viCheckErr (hmo_WaitForOPC (instrSession, timeout));
	
	checkErr (hmo_CheckStatus (instrSession));
	
Error:
	(void) Rs_UnlockSession(instrSession, NULL);
    return error;
}

/// HIFN Sends a query to the instrument synchronised with OPC-polling.
/// HIFN Use this function to wait for a response that can take a long
/// HIFN time to complete e.g. self-alignment, calibration or self-test. 
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR writeBuffer/Pass the string to be written to the instrument.
/// HIPAR timeout/This control sets the timeout value.
/// HIPAR bufferSize/Pass the maximum number of bytes to read from the instruments.
/// HIPAR readBuffer/After this function executes, this parameter contains the data
/// HIPAR readBuffer/that was read from the instrument.
/// HIPAR numBytesRead/Returns the number of bytes actually read from the instrument
/// HIPAR numBytesRead/and stored in the Read Buffer.
ViStatus _VI_FUNC hmo_QueryWithOPCSync (ViSession instrSession,
                                             ViString writeBuffer,
                                             ViUInt32 timeout,
                                             ViInt32 bufferSize,
                                             ViChar readBuffer[],
                                             ViUInt32 *numBytesRead)
{
	ViStatus	error = VI_SUCCESS;
	ViChar      *pbuffer = NULL;
    ViUInt32    bytesRead;
    ViChar      buffer[RS_MAX_MESSAGE_BUF_SIZE] = "";
		
	checkErr( Rs_LockSession (instrSession, NULL)); 

	viCheckParm (strlen(writeBuffer) == 0, 2, "Write Buffer");
    viCheckParm (readBuffer == NULL, 5, "Read Buffer");

    viCheckErr (Rs_ClearBeforeRead (instrSession));
	
	sprintf (buffer, "%s;*OPC\n", writeBuffer);
	
	viCheckErr (Rs_WriteInstrData (instrSession, buffer));
	
	viCheckErr (hmo_WaitForOPC (instrSession, timeout));
	
	viCheckErr(Rs_ReadDataUnknownLength (instrSession, &pbuffer, &bytesRead));  
    if (bytesRead>=(ViUInt32)bufferSize)
    {
        strncpy(readBuffer, pbuffer, (size_t) (bufferSize-1));
        readBuffer[bufferSize-1]='\0';
    } 
    else
    {
        strncpy(readBuffer, pbuffer, (size_t) bytesRead); 
        readBuffer[bytesRead] = '\0';   
    }
	
	*numBytesRead = bytesRead;
    
	checkErr (hmo_CheckStatus (instrSession));
	
Error:
	(void) Rs_UnlockSession(instrSession, NULL);
    return error;
}


/// HIFN  This function provides mass storage capabilities for the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR operation/This control selects the type of memory operation to be performed.
/// HIPAR source/This control specifies the source of the operation to be performed. If 
/// HIPAR source/the operation requires a single parameter, this control specifies that 
/// HIPAR source/parameter.
/// HIPAR destination/This control specifies the destination of the operation to be 
/// HIPAR destination/performed.
ViStatus _VI_FUNC hmo_FileManagerOperations(
    ViSession   instrSession,
    ViInt32 operation,
    ViString    source,
    ViString    destination
)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[HMO_IO_BUFFER_SIZE] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    switch (operation)
    {
        case HMO_VAL_FILE_COPY:
            sprintf (buffer, "MMEM:COPY '%s','%s'\n", source, destination);
            checkErr (viWrite (instrSession, (ViBuf) buffer, (ViUInt32) strlen (buffer), NULL));
            checkErr (hmo_CheckStatus (instrSession));
            break;
        case HMO_VAL_FILE_MOVE:
            sprintf (buffer, "MMEM:MOVE '%s','%s'\n", source, destination);
            checkErr (viWrite (instrSession, (ViBuf) buffer, (ViUInt32) strlen (buffer), NULL));
            checkErr (hmo_CheckStatus (instrSession));
            break;
        case HMO_VAL_FILE_DELETE:
            viCheckParm (hmo_SetAttributeViString(instrSession, "",
                HMO_ATTR_DELETE_FILE, source), 3, "Source");
            break;
        case HMO_VAL_FILE_NEW_DIR:
            viCheckParm (hmo_SetAttributeViString(instrSession, "",
                HMO_ATTR_CREATE_DIRECTORY, source), 3, "Source");
            break;
        case HMO_VAL_FILE_CDIR:
            viCheckParm (hmo_SetAttributeViString(instrSession, "",
                HMO_ATTR_CURRENT_DIRECTORY, source), 3, "Source");
            break;
        case HMO_VAL_FILE_RDIR:
            viCheckParm (hmo_SetAttributeViString(instrSession, "",
                HMO_ATTR_REMOVE_DIRECTORY, source), 3, "Source");
            break;
        case HMO_VAL_FILE_CDRIVE:
            viCheckParm (hmo_SetAttributeViString(instrSession, "",
                HMO_ATTR_CHANGE_DRIVE, source), 3, "Source");
            break;
        default:
            viCheckParm (RS_ERROR_INVALID_PARAMETER, 2, "Operation");
    }
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the number of files and subdirectories of the current or of a 
/// HIFN  specified directory. The number includes the parent directory strings 
/// HIFN  "." and ".." so that it corresponds to the number of strings returned 
/// HIFN  by the hmo_FileDirectoryContent function after the initial numeric 
/// HIFN  parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR numberofFilesAndFolders/Returns the number of files and subdirectories of the current or of a 
/// HIPAR numberofFilesAndFolders/specified directory.
ViStatus _VI_FUNC hmo_FileCount(
    ViSession   instrSession,
    ViString    directory,
    ViInt32*    numberofFilesAndFolders
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  buffer[HMO_IO_BUFFER_SIZE] = "";
    ViChar *p2buf = NULL;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckAlloc (numberofFilesAndFolders);
    
    p2buf = buffer + sprintf (buffer, "MMEM:CAT:LENG?");
    
    if ((directory != NULL) && (strlen (directory) > 0))
        p2buf += sprintf (p2buf, " '%s'", directory);
    
    strcat (buffer, "\n");
    checkErr (viWrite (instrSession, (ViBuf) buffer, (ViUInt32) strlen (buffer), NULL));
    checkErr (viScanf (instrSession, "%ld", numberofFilesAndFolders));
    checkErr (hmo_CheckStatus (instrSession));

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function reads the indicated directory. According to DOS 
/// HIFN  convention, wild card characters can be entered in order to query eg. a 
/// HIFN  list of all file of a certain type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the 
/// HIPAR bufferSize/Output parameter.  
/// HIPAR output/This indicator returns the files in the indicated directory as comma 
/// HIPAR output/separated strings, for example: 'SPOOL1.WMF','SPOOL2.WMF','SPOOL3.WMF'
ViStatus _VI_FUNC hmo_FileDirectoryContent(
    ViSession   instrSession,
    ViString    directory,
    ViInt32 bufferSize,
    ViChar    output[]
)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[HMO_IO_BUFFER_SIZE] = "";
    ViChar   *p2buf = NULL;
    ViUInt32  count = 0;
    ViUInt32  length = 0;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckAlloc (output);
    
    p2buf = buffer + sprintf (buffer, "MMEM:CAT?");
    
    if ((directory != NULL) && (strlen (directory) > 0))
        p2buf += sprintf (p2buf, " '%s'", directory);
    
    strcat (buffer, "\n");
    checkErr (viWrite (instrSession, (ViBuf) buffer, (ViUInt32) strlen (buffer), NULL));
    p2buf = NULL;
    checkErr (Rs_ReadDataUnknownLength (instrSession, &p2buf, &count));
    
    length = ((ViInt32)count > bufferSize) ? bufferSize : count;
    memcpy (output, p2buf, length);
    
    checkErr (hmo_CheckStatus (instrSession));

Error:
    if (p2buf != NULL) free (p2buf);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the number of subdirectories of the current or of a specified 
/// HIFN  directory. The number includes the parent directory strings "." and 
/// HIFN  ".." so that it corresponds to the number of strings returned by the 
/// HIFN  hmo_FileSubdirectories.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR numberofSubdirectories/Returns the number of files and subdirectories of the current or of a 
/// HIPAR numberofSubdirectories/specified directory.
ViStatus _VI_FUNC hmo_FileSubdirectoriesCount(
    ViSession   instrSession,
    ViString    directory,
    ViInt32*    numberofSubdirectories
)
{
    ViStatus    error = VI_SUCCESS;
    ViChar  buffer[HMO_IO_BUFFER_SIZE] = "";
    ViChar *p2buf = NULL;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckAlloc (numberofSubdirectories);
    
    p2buf = buffer + sprintf (buffer, "MMEM:DCAT:LENG?");
    
    if ((directory != NULL) && (strlen (directory) > 0))
        p2buf += sprintf (p2buf, " '%s'", directory);
    
    strcat (buffer, "\n");
    checkErr (viWrite (instrSession, (ViBuf) buffer, (ViUInt32) strlen (buffer), NULL));
    checkErr (viScanf (instrSession, "%ld", numberofSubdirectories));
    checkErr (hmo_CheckStatus (instrSession));

Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns the subdirectories of the current or of a specified directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR directory/This control specifies the directory in which the command will be 
/// HIPAR directory/performed.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the 
/// HIPAR bufferSize/Output parameter.  
/// HIPAR output/This indicator returns the files in the indicated directory as comma 
/// HIPAR output/separated strings, for example: 'SPOOL1.WMF','SPOOL2.WMF','SPOOL3.WMF'
ViStatus _VI_FUNC hmo_FileSubdirectories(
    ViSession   instrSession,
    ViString    directory,
    ViInt32 bufferSize,
    ViChar    output[]
)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[HMO_IO_BUFFER_SIZE] = "";
    ViChar   *p2buf = NULL;
    ViUInt32  count = 0;
    ViUInt32  length = 0;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckAlloc (output);
    
    p2buf = buffer + sprintf (buffer, "MMEM:DCAT?");
    
    if ((directory != NULL) && (strlen (directory) > 0))
        p2buf += sprintf (p2buf, " '%s'", directory);
    
    strcat (buffer, "\n");
    checkErr (viWrite (instrSession, (ViBuf) buffer, (ViUInt32) strlen (buffer), NULL));
    p2buf = NULL;
    checkErr (Rs_ReadDataUnknownLength (instrSession, &p2buf, &count));
    
    length = ((ViInt32)count > bufferSize) ? bufferSize : count;
    memcpy (output, p2buf, length);
    
    checkErr (hmo_CheckStatus (instrSession));

Error:
    if (p2buf != NULL) free (p2buf);
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  Returns a list of the drives of the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR output/Returns a list of the drives of the instrument.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the 
/// HIPAR bufferSize/Output parameter.  
ViStatus _VI_FUNC hmo_FileDrives(
    ViSession   instrSession,
    ViInt32   bufferSize,
    ViChar    output[]
)
{
    ViStatus    error = VI_SUCCESS;

    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm(hmo_GetAttributeViString(instrSession, "",
        HMO_ATTR_DRIVES, bufferSize, output), 2, "Drives");
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function is used to read data from the instrument and write it to 
/// HIFN  a user specified file on the host computer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from instrument to 
/// HIPAR source/control computer.
/// HIPAR destination/This control defines destination file to which the data transfer from 
/// HIPAR destination/instrument to control computer applies.
ViStatus _VI_FUNC hmo_ReadToFileFromInstrument(
    ViSession   instrSession,
    ViString    source,
    ViString    destination
)
{
    ViStatus    error = VI_SUCCESS;
    ViUInt32    ret_count = 0;
    ViUInt64    length = 0;
    ViChar      buffer[HMO_IO_BUFFER_SIZE] = "";
    ViUInt16 intfc = VI_INTF_GPIB;     
	ViChar      *pbuffer = NULL;
	int i;
    
    checkErr( Rs_LockSession (instrSession, NULL));
    
	viCheckParm (!source, 2, "Source");
	viCheckParm (!destination, 3, "Destination");    
    
	checkErr (viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &intfc));
    switch (intfc)
    {
        case VI_INTF_ASRL: /* Serial intfc. */
            viCheckErr( viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_NONE));
        break;
    }
    viCheckErr( viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_FALSE));
    
    viCheckErr (viPrintf(instrSession, ":MMEM:DATA? '%s'\n", source));
    checkErr (viRead (instrSession, (ViBuf) buffer, 1, NULL)); 

	
	if (buffer[0] == '#')
	{   /* Binary data */
		/* Disable termination character */
		checkErr(viSetAttribute(instrSession, VI_ATTR_TERMCHAR_EN, VI_FALSE));

		/* Parse header */
		checkErr(viRead(instrSession, (ViBuf)buffer, 1, NULL));

		buffer[1] = '\0';
		if (buffer[0] == '(')
		{
			for (i = 0; i < 20; i++)
			{
				checkErr(viRead(instrSession, (ViBuf)buffer + i, 1, NULL));

				if (buffer[i] == ')')
				{
					buffer[i] = '\0';
					sscanf(buffer, "%lld", &length);
					break;
				}
			}
			if (i == 20)
			{
				//couldn't find the ')' character
				checkErr(RS_ERROR_UNEXPECTED_RESPONSE);
			}
		}
		else if (buffer[0] == '0')
		{
			length = 0;
		}
		else
		{
			sscanf(buffer, "%llu", &length);
			if (length > 9 || length < 1)
			{
				//expected number 1 to 9
				checkErr(RS_ERROR_UNEXPECTED_RESPONSE);
			}

			checkErr(viRead(instrSession, (ViBuf)buffer, (ViUInt32) length, NULL));
			buffer[length] = '\0';
			sscanf(buffer, "%llu", &length);
		}

		if (length > 0)
		{
			viCheckErr(Rs_ReadToFile2(instrSession, destination, length, RS_VAL_TRUNCATE));
			/* Flush garbage */
			viScanf(instrSession, "%*[^\r\n]");
			if (error > 0) error = VI_SUCCESS;
		}
		else
		{
			/* Unlimited size of data */
			checkErr(Rs_ReadDataUnknownLength(instrSession, &pbuffer, &ret_count));
		}
    }
    else
    {
        checkErr(RS_ERROR_UNEXPECTED_RESPONSE);         
    }
	
    viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);        
    checkErr( hmo_CheckStatus (instrSession));
  
Error:
    viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
    if (pbuffer) free(pbuffer);
    switch (intfc)
    {
        case VI_INTF_ASRL:
            viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
        break;    
    }  
    (void) Rs_UnlockSession(instrSession, NULL);
    
    return error;
}

/// HIFN  This function is used to read data from the host computer and write it 
/// HIFN  to a user specified file in the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from control computer 
/// HIPAR source/to instrument.
/// HIPAR destination/This control defines destination file to which the data transfer from 
/// HIPAR destination/control computer to instrument applies.
ViStatus _VI_FUNC hmo_WriteFromFileToInstrument(
    ViSession   instrSession,
    ViString    source,
    ViString    destination
)
{
    ViStatus    error = VI_SUCCESS;
    ViUInt32    digits = 0;
    FILE        *sourceFile = NULL;
    ViUInt64    fileSize = 0;
#if defined (_CVI_)
	ViUInt32      fileSize32 = 0;
#endif
    
    checkErr( Rs_LockSession (instrSession, NULL));
    viCheckParm (!source, 2, "Source");
    viCheckParm (!destination, 3, "Destination");  
        
    /* Open source file from host controller */
    if ((sourceFile = fopen (source, "rb")) == NULL)
        viCheckErr(RS_ERROR_CANNOT_OPEN_FILE);

    /* Get size of file */
    (void) fseek (sourceFile, 0, SEEK_END);
#if defined (_CVI_)
    GetFileSize (source, &fileSize32);
	fileSize = (ViUInt64) fileSize32;
#elif defined(_MSC_VER)
    fileSize = (ViUInt64) _ftelli64 (sourceFile);
#else
    fileSize = (ViUInt64) ftell (sourceFile);
#endif
    (void) fseek (sourceFile, 0, SEEK_SET);

    (void) viSetAttribute (instrSession, VI_ATTR_SEND_END_EN, VI_FALSE);
		
    /* Create command header */
    digits = (ViUInt32) ((int)floor(log10((double)fileSize))) + 1;
    if (digits < 10)
	{
		viCheckErr (viPrintf (instrSession, ":MMEM:DATA '%s',#%ld%lld", destination, digits, fileSize));
	}
	else
	{
		viCheckErr (viPrintf (instrSession, ":MMEM:DATA '%s',#(%lld)", destination, fileSize));
	}
    
    viCheckErr (Rs_WriteFromFile2(instrSession, source, fileSize, 0));
        
    checkErr( hmo_CheckStatusTimed (instrSession));
 
 Error:
    if (sourceFile) (void) fclose (sourceFile);
	
    (void) Rs_UnlockSession(instrSession, 0);
    
    return error;
}

/// HIFN  This function allows to provide data set operation for Save/Recall 
/// HIFN  items of memory subsystem.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize 
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR operation/This control selects the type of memory operation to be performed.
/// HIPAR stateNumber/Defines save and recall state position.
/// HIPAR path/This control specifies the source of the operation to be performed. 
ViStatus _VI_FUNC hmo_DataSetFileOperations(
    ViSession   instrSession,
    ViInt32 operation,
    ViInt32 stateNumber,
    ViString    path
)
{
    ViStatus error = VI_SUCCESS;
    ViChar   buffer[HMO_IO_BUFFER_SIZE] = "";

    checkErr (Rs_LockSession (instrSession, 0));

    switch (operation)
    {
        case HMO_VAL_MEM_SAVE:
            sprintf (buffer, "MMEM:STOR:STAT %ld,'%s'\n", stateNumber, path);
            checkErr (viWrite (instrSession, (ViBuf) buffer, (ViUInt32) strlen (buffer), NULL));
            checkErr (hmo_CheckStatus (instrSession));
            break;                
        case HMO_VAL_MEM_RECALL:
            sprintf (buffer, "MMEM:LOAD:STAT %ld,'%s'\n", stateNumber, path);
            checkErr (viWrite (instrSession, (ViBuf) buffer, (ViUInt32) strlen (buffer), NULL));
            checkErr (hmo_CheckStatus (instrSession));
            break;
        default:
            viCheckParm (RS_ERROR_INVALID_PARAMETER, 2, "Operation");
    }
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function configures the sound states.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR controlSound/Enables a beep sound, if a control has been limited (e.g. the end of 
/// HIPAR controlSound/the range of a rotary sensor).
/// HIPAR triggerSound/Enables a beep sound, if the device is triggering.
/// HIPAR errorSound/Enables a beep sound, if an error is occured.
ViStatus _VI_FUNC hmo_ConfigureSound(
	ViSession	instrSession,
	ViBoolean	controlSound,
	ViBoolean	triggerSound,
	ViBoolean	errorSound
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_SOUND_ENABLED,
                                            controlSound), 2, "Control Sound");
    
    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_SOUND_TRIGGER_ENABLED,
                                            triggerSound), 3, "Trigger Sound");
    
    viCheckParm (hmo_SetAttributeViBoolean (instrSession, "",
                                            HMO_ATTR_SOUND_ERROR_ENABLED,
                                            errorSound), 4, "Error Sound");
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN  This function generates a beep sound on the device.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.  The handle identifies a particular 
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC hmo_GenerateSound(
	ViSession	instrSession
)
{
    ViStatus  error = VI_SUCCESS;
    
    checkErr (Rs_LockSession (instrSession, 0));

    viCheckErr (hmo_SetAttributeViString (instrSession, "",
                                          HMO_ATTR_SOUND_GENERATE, NULL));
    
Error:
    Rs_UnlockSession(instrSession, 0);    
    return error;
}

/// HIFN This function closes the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
ViStatus _VI_FUNC hmo_close (ViSession instrSession)
{
    ViStatus    error   = VI_SUCCESS;

    checkErr( Rs_LockSession (instrSession, 0));
    
    checkErr (viWrite (instrSession, (ViBuf) "&GTL\n", 5, NULL));
    
    checkErr( hmo_RsClose (instrSession));

Error:

    (void) Rs_UnlockSession (instrSession, 0);
    (void) Rs_Dispose (instrSession);

    return error;
}

/// HIFN This function performs all of the drivers clean-up operations
/// HIFN except for closing the RS session.  This function is called by
/// HIFN hmo_close or by an RS class driver.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the hmo_init or 
/// HIPAR instrSession/hmo_InitWithOptions function.
ViStatus _VI_FUNC hmo_RsClose (ViSession instrSession)
{
    ViStatus    error   = VI_SUCCESS;
    ViSession   io      = 0;

    /* Do not lock here. The caller manages the lock. */

Error:

    if(io != 0)
        {
        ViSession   rmSession = 0;

        checkErr( Rs_GetAttribute (instrSession, NULL, RS_ATTR_VISA_RM_SESSION, 0, (ViUInt32) sizeof (rmSession), &rmSession));
        
        (void) viClose (io);
        (void) viClose (rmSession);
        }
    
    return error;
}
/*****************************************************************************
 *------------------- End Instrument Driver Source Code ---------------------*
 *****************************************************************************/
